/*
  This instrumentation is taking code from here as a starting point:
    https://github.com/open-telemetry/opentelemetry-js-contrib/blob/main/plugins/web/opentelemetry-instrumentation-user-interaction/src/instrumentation.ts

  But not using that instrumentation directly because:

    1) We want to record clicks as span events on the Session span
    2) There is a bug with the instrumentation that causes a large number of spans to be created for a single click
      when zone context isn't available. To avoid the bug we take a simpler approach here and add a listener directly
      to `document` rather than trying to patch the `addEventListener` method on the prototype, this does mean we miss
      recording click events for which `stopPropagation` is called. See https://github.com/open-telemetry/opentelemetry-js-contrib/issues/1368
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { EmbraceInstrumentationBase } from '../../EmbraceInstrumentationBase/index.js';
import { getHTMLElementFriendlyName } from './utils.js';
var ClicksInstrumentation = /** @class */ (function (_super) {
    __extends(ClicksInstrumentation, _super);
    function ClicksInstrumentation(_a) {
        var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf;
        var _this = _super.call(this, {
            instrumentationName: 'SpanSessionBrowserActivityInstrumentation',
            instrumentationVersion: '1.0.0',
            diag: diag,
            perf: perf,
            config: {},
        }) || this;
        _this._onClickHandler = function (event) {
            var element = event.target;
            if (!(element instanceof HTMLElement)) {
                return;
            }
            if (element.hasAttribute('disabled')) {
                return;
            }
            try {
                var currentSessionSpan = _this.sessionManager.getSessionSpan();
                if (currentSessionSpan) {
                    currentSessionSpan.addEvent('click', {
                        'emb.type': 'ux.tap',
                        'view.name': getHTMLElementFriendlyName(element),
                        'tap.coords': "".concat(event.x.toString(), ",").concat(event.y.toString()),
                    }, _this.perf.epochMillisFromOriginOffset(event.timeStamp));
                }
            }
            catch (e) {
                _this._diag.error('failed to create new user interaction span event', e);
            }
        };
        if (_this._config.enabled) {
            _this.enable();
        }
        return _this;
    }
    ClicksInstrumentation.prototype.disable = function () {
        document.removeEventListener('click', this._onClickHandler);
    };
    ClicksInstrumentation.prototype.enable = function () {
        document.addEventListener('click', this._onClickHandler);
    };
    return ClicksInstrumentation;
}(EmbraceInstrumentationBase));
export { ClicksInstrumentation };
//# sourceMappingURL=ClicksInstrumentation.js.map