var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { bulkAddEventListener, bulkRemoveEventListener, throttle, } from '../../../utils/index.js';
import { EmbraceInstrumentationBase } from '../../EmbraceInstrumentationBase/index.js';
import { EVENT_THROTTLING_TIME_WINDOW, TIMEOUT_TIME, WINDOW_USER_EVENTS, } from './constants.js';
/**
 *  SpanSessionBrowserActivityInstrumentation will track the user activity and end the session span if there is no
 *  activity for a certain amount of time.
 *  SpanSessionBrowserActivityInstrumentation will initialize new sessions if new activity is detected and there is no
 *  active session.
 * */
var SpanSessionBrowserActivityInstrumentation = /** @class */ (function (_super) {
    __extends(SpanSessionBrowserActivityInstrumentation, _super);
    function SpanSessionBrowserActivityInstrumentation(_a) {
        var _b = _a === void 0 ? {} : _a, diag = _b.diag;
        var _this = _super.call(this, {
            instrumentationName: 'SpanSessionBrowserActivityInstrumentation',
            instrumentationVersion: '1.0.0',
            diag: diag,
            config: {},
        }) || this;
        _this.disable = function () {
            bulkRemoveEventListener({
                target: window,
                events: WINDOW_USER_EVENTS,
                callback: _this._onActivityThrottled,
            });
            if (_this._activityTimeout) {
                clearTimeout(_this._activityTimeout);
            }
            _this._activityTimeout = null;
        };
        _this.enable = function () {
            bulkAddEventListener({
                target: window,
                events: WINDOW_USER_EVENTS,
                callback: _this._onActivityThrottled,
            });
        };
        _this._onInactivity = function () {
            _this._diag.debug('Inactivity detected');
            if (_this._activityTimeout) {
                clearTimeout(_this._activityTimeout);
            }
            _this._activityTimeout = null;
            _this.sessionManager.endSessionSpanInternal('inactivity');
        };
        _this._onActivity = function () {
            _this._diag.debug('Activity detected');
            if (_this._activityTimeout) {
                clearTimeout(_this._activityTimeout);
            }
            // if there was no active session, start one
            if (!_this.sessionManager.getSessionId()) {
                _this.sessionManager.startSessionSpan();
            }
            _this._activityTimeout = setTimeout(_this._onInactivity, TIMEOUT_TIME);
        };
        _this._activityTimeout = null;
        _this._onActivityThrottled = throttle(_this._onActivity, EVENT_THROTTLING_TIME_WINDOW);
        if (_this._config.enabled) {
            _this.enable();
        }
        return _this;
    }
    return SpanSessionBrowserActivityInstrumentation;
}(EmbraceInstrumentationBase));
export { SpanSessionBrowserActivityInstrumentation };
//# sourceMappingURL=SpanSessionBrowserActivityInstrumentation.js.map