var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { hrTimeToMilliseconds } from '@opentelemetry/core';
import { EmbraceInstrumentationBase } from '../../EmbraceInstrumentationBase/index.js';
import { TIMEOUT_TIME } from './constants.js';
/**
 *  SpanSessionTimeoutInstrumentation will track how long has a session been active and end it after a certain amount of time.
 *  It will immediately start a new session after the previous one ends.
 **/
var SpanSessionTimeoutInstrumentation = /** @class */ (function (_super) {
    __extends(SpanSessionTimeoutInstrumentation, _super);
    function SpanSessionTimeoutInstrumentation(_a) {
        var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf;
        var _this = _super.call(this, {
            instrumentationName: 'SpanSessionTimeoutInstrumentation',
            instrumentationVersion: '1.0.0',
            diag: diag,
            perf: perf,
            config: {},
        }) || this;
        _this.disable = function () {
            if (_this._sessionTimeout) {
                clearTimeout(_this._sessionTimeout);
            }
            _this._sessionTimeout = null;
        };
        _this.enable = function () {
            _this._checkTimeout();
        };
        _this._onTimeout = function () {
            _this._diag.debug('Timeout detected');
            // clear existing timeout
            if (_this._sessionTimeout) {
                clearTimeout(_this._sessionTimeout);
            }
            _this.sessionManager.endSessionSpanInternal('timer');
            _this.sessionManager.startSessionSpan();
            // set a new check in TIMEOUT_TIME for the session we just started
            _this._sessionTimeout = setTimeout(_this._checkTimeout, TIMEOUT_TIME);
        };
        _this._checkTimeout = function () {
            var currentSessionStartTime = _this.sessionManager.getSessionStartTime();
            // validate that there is an active session, as it may already been finished for other reasons.
            if (currentSessionStartTime) {
                // check how much time has passed since the session started
                var currentTime = _this.perf.getNowHRTime();
                var currentTimeMillis = hrTimeToMilliseconds(currentTime);
                var currentSessionStartTimeMillis = hrTimeToMilliseconds(currentSessionStartTime);
                var timePassed = currentTimeMillis - currentSessionStartTimeMillis;
                var remainingTime = TIMEOUT_TIME - timePassed;
                // if the remaining time is 0 or less, the session has already timed out.
                if (remainingTime <= 0) {
                    // the session has already timed out.
                    _this._onTimeout();
                    return;
                }
                // if there is time remaining, set a new timeout for check again after it
                if (_this._sessionTimeout) {
                    clearTimeout(_this._sessionTimeout);
                }
                _this._sessionTimeout = setTimeout(_this._checkTimeout, remainingTime);
                return;
            }
            // if there is no currentSessionStartTime then there is no active session,
            //  check again in TIMEOUT_TIME in case a new one is started.
            if (_this._sessionTimeout) {
                clearTimeout(_this._sessionTimeout);
            }
            _this._sessionTimeout = setTimeout(_this._checkTimeout, TIMEOUT_TIME);
        };
        _this._sessionTimeout = null;
        if (_this._config.enabled) {
            _this.enable();
        }
        return _this;
    }
    return SpanSessionTimeoutInstrumentation;
}(EmbraceInstrumentationBase));
export { SpanSessionTimeoutInstrumentation };
//# sourceMappingURL=SpanSessionTimeoutInstrumentation.js.map