var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { logs, SeverityNumber } from '@opentelemetry/api-logs';
import { ATTR_EXCEPTION_MESSAGE, ATTR_EXCEPTION_STACKTRACE, ATTR_EXCEPTION_TYPE, } from '@opentelemetry/semantic-conventions';
import { EMB_TYPES, KEY_EMB_EXCEPTION_HANDLING, KEY_EMB_JS_EXCEPTION_STACKTRACE, KEY_EMB_TYPE, } from '../../constants/index.js';
import { OTelPerformanceManager, } from '../../utils/index.js';
var EmbraceLogManager = /** @class */ (function () {
    function EmbraceLogManager(_a) {
        var _b = _a === void 0 ? {} : _a, perf = _b.perf;
        this._perf = perf !== null && perf !== void 0 ? perf : new OTelPerformanceManager();
        this._logger = logs.getLogger('embrace-web-sdk-logs');
    }
    EmbraceLogManager._logSeverityToSeverityNumber = function (severity) {
        switch (severity) {
            case 'info':
                return SeverityNumber.INFO;
            case 'warning':
                return SeverityNumber.WARN;
            default:
                return SeverityNumber.ERROR;
        }
    };
    EmbraceLogManager.prototype.logException = function (error, handled, attributes, timestamp) {
        var _a;
        if (attributes === void 0) { attributes = {}; }
        if (timestamp === void 0) { timestamp = this._perf.getNowMillis(); }
        this._logger.emit({
            timestamp: timestamp,
            severityNumber: SeverityNumber.ERROR,
            severityText: 'ERROR',
            body: error.message || '',
            attributes: __assign(__assign({}, attributes), (_a = {}, _a[KEY_EMB_TYPE] = EMB_TYPES.SystemException, _a[KEY_EMB_EXCEPTION_HANDLING] = handled ? 'HANDLED' : 'UNHANDLED', _a[ATTR_EXCEPTION_TYPE] = error.constructor.name, _a['exception.name'] = error.name, _a[ATTR_EXCEPTION_MESSAGE] = error.message, _a[ATTR_EXCEPTION_STACKTRACE] = error.stack, _a)),
        });
    };
    EmbraceLogManager.prototype.message = function (message, severity, attributes, includeStacktrace) {
        if (includeStacktrace === void 0) { includeStacktrace = true; }
        this._logMessage({
            message: message,
            severity: severity,
            timestamp: this._perf.getNowMillis(),
            attributes: attributes,
            stackTrace: includeStacktrace && severity != 'info' ? new Error().stack : undefined,
        });
    };
    EmbraceLogManager.prototype._logMessage = function (_a) {
        var _b, _c;
        var message = _a.message, severity = _a.severity, timestamp = _a.timestamp, _d = _a.attributes, attributes = _d === void 0 ? {} : _d, stackTrace = _a.stackTrace;
        this._logger.emit({
            timestamp: timestamp,
            severityNumber: EmbraceLogManager._logSeverityToSeverityNumber(severity),
            severityText: severity.toUpperCase(),
            body: message,
            attributes: __assign(__assign(__assign({}, attributes), (_b = {}, _b[KEY_EMB_TYPE] = EMB_TYPES.SystemLog, _b)), (stackTrace
                ? (_c = {},
                    _c[KEY_EMB_JS_EXCEPTION_STACKTRACE] = stackTrace,
                    _c) : {})),
        });
    };
    return EmbraceLogManager;
}());
export { EmbraceLogManager };
//# sourceMappingURL=EmbraceLogManager.js.map