import { diag } from '@opentelemetry/api';
import { KEY_ENDUSER_PSEUDO_ID } from '../../api-users/index.js';
import { generateUUID } from '../../utils/index.js';
import { EMBRACE_USER_STORAGE_KEY } from './constants.js';
import { isUser } from './types.js';
var EmbraceUserManager = /** @class */ (function () {
    function EmbraceUserManager(_a) {
        var _b = _a === void 0 ? {} : _a, diagParam = _b.diag, _c = _b.storage, storage = _c === void 0 ? localStorage : _c;
        this._activeUser = null;
        this._diag =
            diagParam !== null && diagParam !== void 0 ? diagParam : diag.createComponentLogger({
                namespace: 'EmbraceUserManager',
            });
        this._storage = storage;
        this._initialSetup();
    }
    EmbraceUserManager.prototype.clearUser = function () {
        try {
            this._storage.removeItem(EMBRACE_USER_STORAGE_KEY);
        }
        catch (e) {
            this._diag.warn('Failed to retrieve user object from storage', e);
        }
        this._activeUser = null;
    };
    EmbraceUserManager.prototype.getUser = function () {
        return this._activeUser;
    };
    EmbraceUserManager.prototype.setUser = function (user) {
        this._activeUser = user;
    };
    EmbraceUserManager.prototype._initialSetup = function () {
        try {
            var encodedUserString = this._storage.getItem(EMBRACE_USER_STORAGE_KEY);
            if (!encodedUserString) {
                this._diag.debug('No existing user found in storage, creating a new one');
                this._generateNewUser();
                return;
            }
            var existingUser = JSON.parse(encodedUserString);
            if (isUser(existingUser)) {
                this.setUser(existingUser);
            }
            else {
                this._diag.warn('Invalid user object in localStorage, defaulting to a new one');
            }
        }
        catch (e) {
            this._diag.warn('Failed to parse user from localStorage, defaulting to a new one', e);
        }
        if (!this._activeUser) {
            this._generateNewUser();
        }
    };
    EmbraceUserManager.prototype._generateNewUser = function () {
        var _a;
        var user = (_a = {},
            _a[KEY_ENDUSER_PSEUDO_ID] = generateUUID(),
            _a);
        try {
            var encodedUserString = JSON.stringify(user);
            this._storage.setItem(EMBRACE_USER_STORAGE_KEY, encodedUserString);
        }
        catch (e) {
            this._diag.warn('Failed to persist user object for storage, keeping it in-memory only', e);
        }
        this.setUser(user);
    };
    return EmbraceUserManager;
}());
export { EmbraceUserManager };
//# sourceMappingURL=EmbraceUserManager.js.map