import { browserDetector } from '@opentelemetry/opentelemetry-browser-detector';
import { detectResourcesSync, Resource } from '@opentelemetry/resources';
import { ATTR_SERVICE_NAME, ATTR_TELEMETRY_SDK_LANGUAGE, ATTR_TELEMETRY_SDK_NAME, ATTR_TELEMETRY_SDK_VERSION, } from '@opentelemetry/semantic-conventions';
import { EMBRACE_SERVICE_NAME, NATIVE_FRAMEWORK, SDK_VERSION, TEMPLATE_APP_VERSION, TEMPLATE_BUNDLE_ID, } from './constants/index.js';
export var getWebSDKResource = function (appVersion) {
    var _a;
    /* We need to trim the app  version to remove any leading/trailing spaces
    added by our cli tool. This is required to guarantee that the version is always
    20 characters long in the final bundle, so sourcemaps don't get confused by
    changing the length of the inlined app version. E.g. versions "0.0.1" and "0.0.115"
    are both valid, but injecting them without leading whitespaces will result in
    different lengths, pushing the sourcemaps mapping out of range. Instead,
    "               0.0.1" and "             0.0.115" are both 20 characters long,
    and we trim them before loading at runtime
  
    if the app version has been passed as an argument, we use it instead of the
    one processed by our cli tool. This will allow for no cli installations,
    like importing the web sdk from a CDN
    */
    var processedAppVersion = appVersion !== null && appVersion !== void 0 ? appVersion : TEMPLATE_APP_VERSION.trim();
    var resource = new Resource((_a = {},
        _a[ATTR_SERVICE_NAME] = EMBRACE_SERVICE_NAME,
        _a[ATTR_TELEMETRY_SDK_NAME] = EMBRACE_SERVICE_NAME,
        _a.app_version = processedAppVersion,
        _a.app_framework = NATIVE_FRAMEWORK,
        _a.bundle_id = TEMPLATE_BUNDLE_ID,
        _a.sdk_version = SDK_VERSION,
        _a[ATTR_TELEMETRY_SDK_VERSION] = SDK_VERSION,
        _a.sdk_simple_version = 1,
        _a.sdk_platform = 'web',
        _a[ATTR_TELEMETRY_SDK_LANGUAGE] = 'webjs',
        _a));
    var detectedResources = detectResourcesSync({
        detectors: [browserDetector],
    });
    resource = resource.merge(detectedResources);
    return resource;
};
//# sourceMappingURL=webSdkResource.js.map