import { GlobalExceptionInstrumentation, SpanSessionBrowserActivityInstrumentation, SpanSessionOnLoadInstrumentation, SpanSessionTimeoutInstrumentation, SpanSessionVisibilityInstrumentation, WebVitalsInstrumentation, ClicksInstrumentation, } from '../instrumentations/index.js';
import { DocumentLoadInstrumentation } from '@opentelemetry/instrumentation-document-load';
import { FetchInstrumentation } from '@opentelemetry/instrumentation-fetch';
import { XMLHttpRequestInstrumentation } from '@opentelemetry/instrumentation-xml-http-request';
export var setupDefaultInstrumentations = function (config) {
    var _a, _b, _c, _d, _e, _f;
    if (config === void 0) { config = {}; }
    /*
      These instrumentations are core to managing the session lifecycle and so are not optional
     */
    var instrumentations = [
        new SpanSessionOnLoadInstrumentation(config['session-on-load']),
        new SpanSessionVisibilityInstrumentation(config['session-visibility']),
        new SpanSessionBrowserActivityInstrumentation(config['session-activity']),
        new SpanSessionTimeoutInstrumentation(config['session-timeout']),
    ];
    if (!((_a = config.omit) === null || _a === void 0 ? void 0 : _a.has('exception'))) {
        instrumentations.push(new GlobalExceptionInstrumentation(config['exception']));
    }
    if (!((_b = config.omit) === null || _b === void 0 ? void 0 : _b.has('click'))) {
        instrumentations.push(new ClicksInstrumentation(config['click']));
    }
    if (!((_c = config.omit) === null || _c === void 0 ? void 0 : _c.has('web-vital'))) {
        instrumentations.push(new WebVitalsInstrumentation(config['web-vital']));
    }
    if (!((_d = config.omit) === null || _d === void 0 ? void 0 : _d.has('@opentelemetry/instrumentation-document-load'))) {
        instrumentations.push(new DocumentLoadInstrumentation(config['@opentelemetry/instrumentation-document-load']));
    }
    if (!((_e = config.omit) === null || _e === void 0 ? void 0 : _e.has('@opentelemetry/instrumentation-fetch'))) {
        instrumentations.push(new FetchInstrumentation(config['@opentelemetry/instrumentation-fetch']));
    }
    if (!((_f = config.omit) === null || _f === void 0 ? void 0 : _f.has('@opentelemetry/instrumentation-xml-http-request'))) {
        instrumentations.push(new XMLHttpRequestInstrumentation(config['@opentelemetry/instrumentation-xml-http-request']));
    }
    return instrumentations;
};
//# sourceMappingURL=setupDefaultInstrumentations.js.map