import { logs } from '@opentelemetry/api-logs';
import { InMemoryLogRecordExporter, LoggerProvider, SimpleLogRecordProcessor, } from '@opentelemetry/sdk-logs';
/**
 * setupTestLogExporter is a utility function that sets up a test log exporter for use in testing.
 * It returns an instance of InMemoryLogRecordExporter, hooked into a SimpleLogRecordProcessor, and a LoggerProvider.
 * */
export var setupTestLogExporter = function (logProcessors) {
    if (logProcessors === void 0) { logProcessors = []; }
    var memoryExporter = new InMemoryLogRecordExporter();
    var logProvider = new LoggerProvider();
    logProcessors.forEach(function (processor) {
        logProvider.addLogRecordProcessor(processor);
    });
    logProvider.addLogRecordProcessor(new SimpleLogRecordProcessor(memoryExporter));
    logs.setGlobalLoggerProvider(logProvider);
    return memoryExporter;
};
//# sourceMappingURL=setupTestLogExporter.js.map