import { EmbraceInstrumentationBase } from '../../EmbraceInstrumentationBase/index.js';
export class GlobalExceptionInstrumentation extends EmbraceInstrumentationBase {
    constructor({ diag, perf } = {}) {
        super({
            instrumentationName: 'GlobalExceptionInstrumentation',
            instrumentationVersion: '1.0.0',
            diag,
            perf,
            config: {},
        });
        this._onErrorHandler = (event) => {
            this.logManager.logException(event.error, false, {}, this.perf.epochMillisFromOriginOffset(event.timeStamp));
        };
        this._onUnhandledRejectionHandler = (event) => {
            let error;
            if (event.reason && event.reason instanceof Error) {
                error = event.reason;
            }
            else {
                error = new Error(typeof event.reason === 'string'
                    ? event.reason
                    : 'Unhandled Rejected Promise');
                error.stack = '';
            }
            this.logManager.logException(error, false, {}, this.perf.epochMillisFromOriginOffset(event.timeStamp));
        };
        if (this._config.enabled) {
            this.enable();
        }
    }
    disable() {
        window.removeEventListener('error', this._onErrorHandler);
        window.removeEventListener('unhandledrejection', this._onUnhandledRejectionHandler);
    }
    enable() {
        window.addEventListener('error', this._onErrorHandler);
        window.addEventListener('unhandledrejection', this._onUnhandledRejectionHandler);
    }
}
//# sourceMappingURL=GlobalExceptionInstrumentation.js.map