import { logs, SeverityNumber } from '@opentelemetry/api-logs';
import { ATTR_EXCEPTION_MESSAGE, ATTR_EXCEPTION_STACKTRACE, ATTR_EXCEPTION_TYPE, } from '@opentelemetry/semantic-conventions';
import { EMB_TYPES, KEY_EMB_EXCEPTION_HANDLING, KEY_EMB_JS_EXCEPTION_STACKTRACE, KEY_EMB_TYPE, } from '../../constants/index.js';
import { OTelPerformanceManager, } from '../../utils/index.js';
export class EmbraceLogManager {
    constructor({ perf } = {}) {
        this._perf = perf !== null && perf !== void 0 ? perf : new OTelPerformanceManager();
        this._logger = logs.getLogger('embrace-web-sdk-logs');
    }
    static _logSeverityToSeverityNumber(severity) {
        switch (severity) {
            case 'info':
                return SeverityNumber.INFO;
            case 'warning':
                return SeverityNumber.WARN;
            default:
                return SeverityNumber.ERROR;
        }
    }
    logException(error, handled, attributes = {}, timestamp = this._perf.getNowMillis()) {
        this._logger.emit({
            timestamp,
            severityNumber: SeverityNumber.ERROR,
            severityText: 'ERROR',
            body: error.message || '',
            attributes: Object.assign(Object.assign({}, attributes), { [KEY_EMB_TYPE]: EMB_TYPES.SystemException, [KEY_EMB_EXCEPTION_HANDLING]: handled ? 'HANDLED' : 'UNHANDLED', [ATTR_EXCEPTION_TYPE]: error.constructor.name, ['exception.name']: error.name, [ATTR_EXCEPTION_MESSAGE]: error.message, [ATTR_EXCEPTION_STACKTRACE]: error.stack }),
        });
    }
    message(message, severity, attributes, includeStacktrace = true) {
        this._logMessage({
            message,
            severity,
            timestamp: this._perf.getNowMillis(),
            attributes,
            stackTrace: includeStacktrace && severity != 'info' ? new Error().stack : undefined,
        });
    }
    _logMessage({ message, severity, timestamp, attributes = {}, stackTrace, }) {
        this._logger.emit({
            timestamp,
            severityNumber: EmbraceLogManager._logSeverityToSeverityNumber(severity),
            severityText: severity.toUpperCase(),
            body: message,
            attributes: Object.assign(Object.assign(Object.assign({}, attributes), { [KEY_EMB_TYPE]: EMB_TYPES.SystemLog }), (stackTrace
                ? {
                    [KEY_EMB_JS_EXCEPTION_STACKTRACE]: stackTrace,
                }
                : {})),
        });
    }
}
//# sourceMappingURL=EmbraceLogManager.js.map