import { diag } from '@opentelemetry/api';
import { KEY_ENDUSER_PSEUDO_ID } from '../../api-users/index.js';
import { generateUUID } from '../../utils/index.js';
import { EMBRACE_USER_STORAGE_KEY } from './constants.js';
import { isUser } from './types.js';
export class EmbraceUserManager {
    constructor({ diag: diagParam, storage = localStorage, } = {}) {
        this._activeUser = null;
        this._diag =
            diagParam !== null && diagParam !== void 0 ? diagParam : diag.createComponentLogger({
                namespace: 'EmbraceUserManager',
            });
        this._storage = storage;
        this._initialSetup();
    }
    clearUser() {
        try {
            this._storage.removeItem(EMBRACE_USER_STORAGE_KEY);
        }
        catch (e) {
            this._diag.warn('Failed to retrieve user object from storage', e);
        }
        this._activeUser = null;
    }
    getUser() {
        return this._activeUser;
    }
    setUser(user) {
        this._activeUser = user;
    }
    _initialSetup() {
        try {
            const encodedUserString = this._storage.getItem(EMBRACE_USER_STORAGE_KEY);
            if (!encodedUserString) {
                this._diag.debug('No existing user found in storage, creating a new one');
                this._generateNewUser();
                return;
            }
            const existingUser = JSON.parse(encodedUserString);
            if (isUser(existingUser)) {
                this.setUser(existingUser);
            }
            else {
                this._diag.warn('Invalid user object in localStorage, defaulting to a new one');
            }
        }
        catch (e) {
            this._diag.warn('Failed to parse user from localStorage, defaulting to a new one', e);
        }
        if (!this._activeUser) {
            this._generateNewUser();
        }
    }
    _generateNewUser() {
        const user = {
            [KEY_ENDUSER_PSEUDO_ID]: generateUUID(),
        };
        try {
            const encodedUserString = JSON.stringify(user);
            this._storage.setItem(EMBRACE_USER_STORAGE_KEY, encodedUserString);
        }
        catch (e) {
            this._diag.warn('Failed to persist user object for storage, keeping it in-memory only', e);
        }
        this.setUser(user);
    }
}
//# sourceMappingURL=EmbraceUserManager.js.map