import { ATTR_HTTP_REQUEST_METHOD, ATTR_HTTP_RESPONSE_STATUS_CODE, ATTR_URL_FULL, SEMATTRS_HTTP_METHOD, SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH, SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH, SEMATTRS_HTTP_STATUS_CODE, SEMATTRS_HTTP_URL, } from '@opentelemetry/semantic-conventions';
import { ATTR_HTTP_REQUEST_BODY_SIZE, ATTR_HTTP_RESPONSE_BODY_SIZE, } from '@opentelemetry/semantic-conventions/incubating';
import { EMB_TYPES, KEY_EMB_TYPE } from '../../constants/index.js';
import { isNetworkSpan } from './types.js';
/**
 * Embrace's API expects network spans to have some specific attributes.
 * This processor checks if a span is a network span and adds them.
 */
export class EmbraceNetworkSpanProcessor {
    forceFlush() {
        return Promise.resolve(undefined);
    }
    // TODO `onEnd` is not supposed to modify the span. There is a new experimental onEnding api that allows modifying
    //  the span before it is sent to the exporter. This processor should be updated to use that api once that is available
    onEnd(span) {
        var _a, _b, _c, _d, _e;
        var _f, _g, _h, _j, _k;
        if (isNetworkSpan(span)) {
            span.attributes[KEY_EMB_TYPE] = EMB_TYPES.Network;
            /*
              Fallback on deprecated attribute names in case the span is using those instead of the latest ones
      
              The current versions of @opentelemetry/instrumentation-xml-http-request and @opentelemetry/instrumentation-fetch
              that we're getting from @opentelemetry/auto-instrumentations-web are using these, once we update we'll remove
              this fallback and only support a single version of the semantic convention
             */
            // eslint-disable-next-line @typescript-eslint/no-deprecated
            (_a = (_f = span.attributes)[ATTR_URL_FULL]) !== null && _a !== void 0 ? _a : (_f[ATTR_URL_FULL] = span.attributes[SEMATTRS_HTTP_URL]);
            (_b = (_g = span.attributes)[ATTR_HTTP_RESPONSE_STATUS_CODE]) !== null && _b !== void 0 ? _b : (_g[ATTR_HTTP_RESPONSE_STATUS_CODE] = span.attributes[SEMATTRS_HTTP_STATUS_CODE]);
            (_c = (_h = span.attributes)[ATTR_HTTP_REQUEST_METHOD]) !== null && _c !== void 0 ? _c : (_h[ATTR_HTTP_REQUEST_METHOD] = span.attributes[SEMATTRS_HTTP_METHOD]);
            (_d = (_j = span.attributes)[ATTR_HTTP_RESPONSE_BODY_SIZE]) !== null && _d !== void 0 ? _d : (_j[ATTR_HTTP_RESPONSE_BODY_SIZE] = span.attributes[SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH]);
            (_e = (_k = span.attributes)[ATTR_HTTP_REQUEST_BODY_SIZE]) !== null && _e !== void 0 ? _e : (_k[ATTR_HTTP_REQUEST_BODY_SIZE] = span.attributes[SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH]);
        }
    }
    onStart() {
        // do nothing.
    }
    shutdown() {
        return Promise.resolve(undefined);
    }
}
//# sourceMappingURL=EmbraceNetworkSpanProcessor.js.map