"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpanSessionBrowserActivityInstrumentation = void 0;
const index_js_1 = require("../../../utils/index.js");
const index_js_2 = require("../../EmbraceInstrumentationBase/index.js");
const constants_js_1 = require("./constants.js");
/**
 *  SpanSessionBrowserActivityInstrumentation will track the user activity and end the session span if there is no
 *  activity for a certain amount of time.
 *  SpanSessionBrowserActivityInstrumentation will initialize new sessions if new activity is detected and there is no
 *  active session.
 * */
class SpanSessionBrowserActivityInstrumentation extends index_js_2.EmbraceInstrumentationBase {
    constructor({ diag, } = {}) {
        super({
            instrumentationName: 'SpanSessionBrowserActivityInstrumentation',
            instrumentationVersion: '1.0.0',
            diag,
            config: {},
        });
        this.disable = () => {
            (0, index_js_1.bulkRemoveEventListener)({
                target: window,
                events: constants_js_1.WINDOW_USER_EVENTS,
                callback: this._onActivityThrottled,
            });
            if (this._activityTimeout) {
                clearTimeout(this._activityTimeout);
            }
            this._activityTimeout = null;
        };
        this.enable = () => {
            (0, index_js_1.bulkAddEventListener)({
                target: window,
                events: constants_js_1.WINDOW_USER_EVENTS,
                callback: this._onActivityThrottled,
            });
        };
        this._onInactivity = () => {
            this._diag.debug('Inactivity detected');
            if (this._activityTimeout) {
                clearTimeout(this._activityTimeout);
            }
            this._activityTimeout = null;
            this.sessionManager.endSessionSpanInternal('inactivity');
        };
        this._onActivity = () => {
            this._diag.debug('Activity detected');
            if (this._activityTimeout) {
                clearTimeout(this._activityTimeout);
            }
            // if there was no active session, start one
            if (!this.sessionManager.getSessionId()) {
                this.sessionManager.startSessionSpan();
            }
            this._activityTimeout = setTimeout(this._onInactivity, constants_js_1.TIMEOUT_TIME);
        };
        this._activityTimeout = null;
        this._onActivityThrottled = (0, index_js_1.throttle)(this._onActivity, constants_js_1.EVENT_THROTTLING_TIME_WINDOW);
        if (this._config.enabled) {
            this.enable();
        }
    }
}
exports.SpanSessionBrowserActivityInstrumentation = SpanSessionBrowserActivityInstrumentation;
//# sourceMappingURL=SpanSessionBrowserActivityInstrumentation.js.map