"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbraceLogManager = void 0;
const api_logs_1 = require("@opentelemetry/api-logs");
const semantic_conventions_1 = require("@opentelemetry/semantic-conventions");
const index_js_1 = require("../../constants/index.js");
const index_js_2 = require("../../utils/index.js");
class EmbraceLogManager {
    constructor({ perf } = {}) {
        this._perf = perf !== null && perf !== void 0 ? perf : new index_js_2.OTelPerformanceManager();
        this._logger = api_logs_1.logs.getLogger('embrace-web-sdk-logs');
    }
    static _logSeverityToSeverityNumber(severity) {
        switch (severity) {
            case 'info':
                return api_logs_1.SeverityNumber.INFO;
            case 'warning':
                return api_logs_1.SeverityNumber.WARN;
            default:
                return api_logs_1.SeverityNumber.ERROR;
        }
    }
    logException(error, handled, attributes = {}, timestamp = this._perf.getNowMillis()) {
        this._logger.emit({
            timestamp,
            severityNumber: api_logs_1.SeverityNumber.ERROR,
            severityText: 'ERROR',
            body: error.message || '',
            attributes: Object.assign(Object.assign({}, attributes), { [index_js_1.KEY_EMB_TYPE]: index_js_1.EMB_TYPES.SystemException, [index_js_1.KEY_EMB_EXCEPTION_HANDLING]: handled ? 'HANDLED' : 'UNHANDLED', [semantic_conventions_1.ATTR_EXCEPTION_TYPE]: error.constructor.name, ['exception.name']: error.name, [semantic_conventions_1.ATTR_EXCEPTION_MESSAGE]: error.message, [semantic_conventions_1.ATTR_EXCEPTION_STACKTRACE]: error.stack }),
        });
    }
    message(message, severity, attributes, includeStacktrace = true) {
        this._logMessage({
            message,
            severity,
            timestamp: this._perf.getNowMillis(),
            attributes,
            stackTrace: includeStacktrace && severity != 'info' ? new Error().stack : undefined,
        });
    }
    _logMessage({ message, severity, timestamp, attributes = {}, stackTrace, }) {
        this._logger.emit({
            timestamp,
            severityNumber: EmbraceLogManager._logSeverityToSeverityNumber(severity),
            severityText: severity.toUpperCase(),
            body: message,
            attributes: Object.assign(Object.assign(Object.assign({}, attributes), { [index_js_1.KEY_EMB_TYPE]: index_js_1.EMB_TYPES.SystemLog }), (stackTrace
                ? {
                    [index_js_1.KEY_EMB_JS_EXCEPTION_STACKTRACE]: stackTrace,
                }
                : {})),
        });
    }
}
exports.EmbraceLogManager = EmbraceLogManager;
//# sourceMappingURL=EmbraceLogManager.js.map