"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbraceUserManager = void 0;
const api_1 = require("@opentelemetry/api");
const index_js_1 = require("../../api-users/index.js");
const index_js_2 = require("../../utils/index.js");
const constants_js_1 = require("./constants.js");
const types_js_1 = require("./types.js");
class EmbraceUserManager {
    constructor({ diag: diagParam, storage = localStorage, } = {}) {
        this._activeUser = null;
        this._diag =
            diagParam !== null && diagParam !== void 0 ? diagParam : api_1.diag.createComponentLogger({
                namespace: 'EmbraceUserManager',
            });
        this._storage = storage;
        this._initialSetup();
    }
    clearUser() {
        try {
            this._storage.removeItem(constants_js_1.EMBRACE_USER_STORAGE_KEY);
        }
        catch (e) {
            this._diag.warn('Failed to retrieve user object from storage', e);
        }
        this._activeUser = null;
    }
    getUser() {
        return this._activeUser;
    }
    setUser(user) {
        this._activeUser = user;
    }
    _initialSetup() {
        try {
            const encodedUserString = this._storage.getItem(constants_js_1.EMBRACE_USER_STORAGE_KEY);
            if (!encodedUserString) {
                this._diag.debug('No existing user found in storage, creating a new one');
                this._generateNewUser();
                return;
            }
            const existingUser = JSON.parse(encodedUserString);
            if ((0, types_js_1.isUser)(existingUser)) {
                this.setUser(existingUser);
            }
            else {
                this._diag.warn('Invalid user object in localStorage, defaulting to a new one');
            }
        }
        catch (e) {
            this._diag.warn('Failed to parse user from localStorage, defaulting to a new one', e);
        }
        if (!this._activeUser) {
            this._generateNewUser();
        }
    }
    _generateNewUser() {
        const user = {
            [index_js_1.KEY_ENDUSER_PSEUDO_ID]: (0, index_js_2.generateUUID)(),
        };
        try {
            const encodedUserString = JSON.stringify(user);
            this._storage.setItem(constants_js_1.EMBRACE_USER_STORAGE_KEY, encodedUserString);
        }
        catch (e) {
            this._diag.warn('Failed to persist user object for storage, keeping it in-memory only', e);
        }
        this.setUser(user);
    }
}
exports.EmbraceUserManager = EmbraceUserManager;
//# sourceMappingURL=EmbraceUserManager.js.map