"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbraceNetworkSpanProcessor = void 0;
const semantic_conventions_1 = require("@opentelemetry/semantic-conventions");
const incubating_1 = require("@opentelemetry/semantic-conventions/incubating");
const index_js_1 = require("../../constants/index.js");
const types_js_1 = require("./types.js");
/**
 * Embrace's API expects network spans to have some specific attributes.
 * This processor checks if a span is a network span and adds them.
 */
class EmbraceNetworkSpanProcessor {
    forceFlush() {
        return Promise.resolve(undefined);
    }
    // TODO `onEnd` is not supposed to modify the span. There is a new experimental onEnding api that allows modifying
    //  the span before it is sent to the exporter. This processor should be updated to use that api once that is available
    onEnd(span) {
        var _a, _b, _c, _d, _e;
        var _f, _g, _h, _j, _k;
        if ((0, types_js_1.isNetworkSpan)(span)) {
            span.attributes[index_js_1.KEY_EMB_TYPE] = index_js_1.EMB_TYPES.Network;
            /*
              Fallback on deprecated attribute names in case the span is using those instead of the latest ones
      
              The current versions of @opentelemetry/instrumentation-xml-http-request and @opentelemetry/instrumentation-fetch
              that we're getting from @opentelemetry/auto-instrumentations-web are using these, once we update we'll remove
              this fallback and only support a single version of the semantic convention
             */
            // eslint-disable-next-line @typescript-eslint/no-deprecated
            (_a = (_f = span.attributes)[semantic_conventions_1.ATTR_URL_FULL]) !== null && _a !== void 0 ? _a : (_f[semantic_conventions_1.ATTR_URL_FULL] = span.attributes[semantic_conventions_1.SEMATTRS_HTTP_URL]);
            (_b = (_g = span.attributes)[semantic_conventions_1.ATTR_HTTP_RESPONSE_STATUS_CODE]) !== null && _b !== void 0 ? _b : (_g[semantic_conventions_1.ATTR_HTTP_RESPONSE_STATUS_CODE] = span.attributes[semantic_conventions_1.SEMATTRS_HTTP_STATUS_CODE]);
            (_c = (_h = span.attributes)[semantic_conventions_1.ATTR_HTTP_REQUEST_METHOD]) !== null && _c !== void 0 ? _c : (_h[semantic_conventions_1.ATTR_HTTP_REQUEST_METHOD] = span.attributes[semantic_conventions_1.SEMATTRS_HTTP_METHOD]);
            (_d = (_j = span.attributes)[incubating_1.ATTR_HTTP_RESPONSE_BODY_SIZE]) !== null && _d !== void 0 ? _d : (_j[incubating_1.ATTR_HTTP_RESPONSE_BODY_SIZE] = span.attributes[semantic_conventions_1.SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH]);
            (_e = (_k = span.attributes)[incubating_1.ATTR_HTTP_REQUEST_BODY_SIZE]) !== null && _e !== void 0 ? _e : (_k[incubating_1.ATTR_HTTP_REQUEST_BODY_SIZE] = span.attributes[semantic_conventions_1.SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH]);
        }
    }
    onStart() {
        // do nothing.
    }
    shutdown() {
        return Promise.resolve(undefined);
    }
}
exports.EmbraceNetworkSpanProcessor = EmbraceNetworkSpanProcessor;
//# sourceMappingURL=EmbraceNetworkSpanProcessor.js.map