"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmbraceSessionBatchedSpanProcessor = void 0;
const core_1 = require("@opentelemetry/core");
const index_js_1 = require("../../constants/index.js");
const index_js_2 = require("../EmbraceProcessor/index.js");
const isSessionSpan = (span) => span.attributes[index_js_1.KEY_EMB_TYPE] === index_js_1.EMB_TYPES.Session;
class EmbraceSessionBatchedSpanProcessor extends index_js_2.EmbraceProcessor {
    constructor(_a) {
        var { exporter } = _a, parentArgs = __rest(_a, ["exporter"]);
        super(Object.assign(Object.assign({}, parentArgs), { processorName: 'EmbraceSessionBatchedSpanProcessor' }));
        this._pendingSpans = [];
        this._shutdown = () => {
            return this._exporter.shutdown();
        };
        this._exporter = exporter;
        this._shutdownOnce = new core_1.BindOnceFuture(this._shutdown, this);
    }
    forceFlush() {
        this.diag.debug('forceFlush called for EmbraceSessionBatchedSpanProcessor. This is a no op');
        return Promise.resolve(undefined);
    }
    onEnd(span) {
        if (this._shutdownOnce.isCalled) {
            this.diag.debug('span ended after processor shutdown. Ignoring span.');
            return;
        }
        if (!isSessionSpan(span)) {
            this.diag.debug('non-session span ended. Adding to pending spans queue.');
            this._pendingSpans.push(span);
        }
        else {
            this.diag.debug('session span ended. Exporting all pending spans.');
            core_1.internal
                ._export(this._exporter, [span, ...this._pendingSpans])
                .then((result) => {
                var _a;
                if (result.code === core_1.ExportResultCode.FAILED) {
                    this.diag.error(`spans failed to export: ${((_a = result.error) === null || _a === void 0 ? void 0 : _a.message) || 'unknown error'}`);
                }
            })
                // Seems like everything related to the export logic does a good job of catching and only ever resolving with
                // an ExportResult even on failure: https://github.com/open-telemetry/opentelemetry-js/blob/cf6dffeebcf72c42b2cb4d2bf2db720369b53081/packages/opentelemetry-core/src/internal/exporter.ts#L37
                // Keep this block just in case that assumption changes in a future version
                .catch((reason) => {
                let msg = 'unknown error';
                if (reason && reason instanceof Error) {
                    msg = reason.message;
                }
                else if (typeof reason === 'string') {
                    msg = reason;
                }
                this.diag.error(`spans failed to export: ${msg}`);
            });
            this._pendingSpans = [];
        }
    }
    onStart() {
        // do nothing.
    }
    shutdown() {
        return this._shutdownOnce.call();
    }
}
exports.EmbraceSessionBatchedSpanProcessor = EmbraceSessionBatchedSpanProcessor;
//# sourceMappingURL=EmbraceSessionBatchedSpanProcessor.js.map