"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebSDKResource = void 0;
const opentelemetry_browser_detector_1 = require("@opentelemetry/opentelemetry-browser-detector");
const resources_1 = require("@opentelemetry/resources");
const semantic_conventions_1 = require("@opentelemetry/semantic-conventions");
const index_js_1 = require("./constants/index.js");
const getWebSDKResource = (appVersion) => {
    /* We need to trim the app  version to remove any leading/trailing spaces
    added by our cli tool. This is required to guarantee that the version is always
    20 characters long in the final bundle, so sourcemaps don't get confused by
    changing the length of the inlined app version. E.g. versions "0.0.1" and "0.0.115"
    are both valid, but injecting them without leading whitespaces will result in
    different lengths, pushing the sourcemaps mapping out of range. Instead,
    "               0.0.1" and "             0.0.115" are both 20 characters long,
    and we trim them before loading at runtime
  
    if the app version has been passed as an argument, we use it instead of the
    one processed by our cli tool. This will allow for no cli installations,
    like importing the web sdk from a CDN
    */
    const processedAppVersion = appVersion !== null && appVersion !== void 0 ? appVersion : index_js_1.TEMPLATE_APP_VERSION.trim();
    let resource = new resources_1.Resource({
        [semantic_conventions_1.ATTR_SERVICE_NAME]: index_js_1.EMBRACE_SERVICE_NAME,
        [semantic_conventions_1.ATTR_TELEMETRY_SDK_NAME]: index_js_1.EMBRACE_SERVICE_NAME,
        app_version: processedAppVersion,
        app_framework: index_js_1.NATIVE_FRAMEWORK,
        bundle_id: index_js_1.TEMPLATE_BUNDLE_ID,
        sdk_version: index_js_1.SDK_VERSION,
        [semantic_conventions_1.ATTR_TELEMETRY_SDK_VERSION]: index_js_1.SDK_VERSION,
        sdk_simple_version: 1,
        sdk_platform: 'web',
        [semantic_conventions_1.ATTR_TELEMETRY_SDK_LANGUAGE]: 'webjs',
    });
    const detectedResources = (0, resources_1.detectResourcesSync)({
        detectors: [opentelemetry_browser_detector_1.browserDetector],
    });
    resource = resource.merge(detectedResources);
    return resource;
};
exports.getWebSDKResource = getWebSDKResource;
//# sourceMappingURL=webSdkResource.js.map