"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupDefaultInstrumentations = void 0;
const index_js_1 = require("../instrumentations/index.js");
const instrumentation_document_load_1 = require("@opentelemetry/instrumentation-document-load");
const instrumentation_fetch_1 = require("@opentelemetry/instrumentation-fetch");
const instrumentation_xml_http_request_1 = require("@opentelemetry/instrumentation-xml-http-request");
const setupDefaultInstrumentations = (config = {}) => {
    var _a, _b, _c, _d, _e, _f;
    /*
      These instrumentations are core to managing the session lifecycle and so are not optional
     */
    const instrumentations = [
        new index_js_1.SpanSessionOnLoadInstrumentation(config['session-on-load']),
        new index_js_1.SpanSessionVisibilityInstrumentation(config['session-visibility']),
        new index_js_1.SpanSessionBrowserActivityInstrumentation(config['session-activity']),
        new index_js_1.SpanSessionTimeoutInstrumentation(config['session-timeout']),
    ];
    if (!((_a = config.omit) === null || _a === void 0 ? void 0 : _a.has('exception'))) {
        instrumentations.push(new index_js_1.GlobalExceptionInstrumentation(config['exception']));
    }
    if (!((_b = config.omit) === null || _b === void 0 ? void 0 : _b.has('click'))) {
        instrumentations.push(new index_js_1.ClicksInstrumentation(config['click']));
    }
    if (!((_c = config.omit) === null || _c === void 0 ? void 0 : _c.has('web-vital'))) {
        instrumentations.push(new index_js_1.WebVitalsInstrumentation(config['web-vital']));
    }
    if (!((_d = config.omit) === null || _d === void 0 ? void 0 : _d.has('@opentelemetry/instrumentation-document-load'))) {
        instrumentations.push(new instrumentation_document_load_1.DocumentLoadInstrumentation(config['@opentelemetry/instrumentation-document-load']));
    }
    if (!((_e = config.omit) === null || _e === void 0 ? void 0 : _e.has('@opentelemetry/instrumentation-fetch'))) {
        instrumentations.push(new instrumentation_fetch_1.FetchInstrumentation(config['@opentelemetry/instrumentation-fetch']));
    }
    if (!((_f = config.omit) === null || _f === void 0 ? void 0 : _f.has('@opentelemetry/instrumentation-xml-http-request'))) {
        instrumentations.push(new instrumentation_xml_http_request_1.XMLHttpRequestInstrumentation(config['@opentelemetry/instrumentation-xml-http-request']));
    }
    return instrumentations;
};
exports.setupDefaultInstrumentations = setupDefaultInstrumentations;
//# sourceMappingURL=setupDefaultInstrumentations.js.map