"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTestLogExporter = void 0;
const api_logs_1 = require("@opentelemetry/api-logs");
const sdk_logs_1 = require("@opentelemetry/sdk-logs");
/**
 * setupTestLogExporter is a utility function that sets up a test log exporter for use in testing.
 * It returns an instance of InMemoryLogRecordExporter, hooked into a SimpleLogRecordProcessor, and a LoggerProvider.
 * */
const setupTestLogExporter = (logProcessors = []) => {
    const memoryExporter = new sdk_logs_1.InMemoryLogRecordExporter();
    const logProvider = new sdk_logs_1.LoggerProvider();
    logProcessors.forEach(processor => {
        logProvider.addLogRecordProcessor(processor);
    });
    logProvider.addLogRecordProcessor(new sdk_logs_1.SimpleLogRecordProcessor(memoryExporter));
    api_logs_1.logs.setGlobalLoggerProvider(logProvider);
    return memoryExporter;
};
exports.setupTestLogExporter = setupTestLogExporter;
//# sourceMappingURL=setupTestLogExporter.js.map