"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTestTraceExporter = void 0;
const api_1 = require("@opentelemetry/api");
const sdk_trace_web_1 = require("@opentelemetry/sdk-trace-web");
/**
 * setupTestTraceExporter is a utility function that sets up a test trace exporter for use in testing.
 * It returns an instance of InMemorySpanExporter, hooked into a SimpleSpanProcessor, and a WebTracerProvider.
 * */
const setupTestTraceExporter = (spanProcessors = []) => {
    const memoryExporter = new sdk_trace_web_1.InMemorySpanExporter();
    const tracerProvider = new sdk_trace_web_1.WebTracerProvider({
        spanProcessors: [
            ...spanProcessors,
            new sdk_trace_web_1.SimpleSpanProcessor(memoryExporter),
        ],
    });
    api_1.trace.setGlobalTracerProvider(tracerProvider);
    return memoryExporter;
};
exports.setupTestTraceExporter = setupTestTraceExporter;
//# sourceMappingURL=setupTestTraceExporter.js.map