"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RetryingTransport = void 0;
const index_js_1 = require("../../utils/index.js");
const constants_js_1 = require("./constants.js");
/**
 * Get a pseudo-random jitter that falls in the range of [-JITTER, +JITTER]
 */
const getJitter = () => Math.random() * (2 * constants_js_1.JITTER) - constants_js_1.JITTER;
// Taken directly from open-telemetry/opentelemetry-js/experimental/packages/otlp-exporter-base/src/retrying-transport.ts
// File is not exposed externally
/*
 * Copyright The OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
class RetryingTransport {
    constructor(_transport, _perf = new index_js_1.OTelPerformanceManager()) {
        this._transport = _transport;
        this._perf = _perf;
    }
    async send(data, timeoutMillis) {
        var _a;
        const deadline = this._perf.getNowMillis() + timeoutMillis;
        let result = await this._transport.send(data, timeoutMillis);
        let attempts = constants_js_1.MAX_ATTEMPTS;
        let nextBackoff = constants_js_1.INITIAL_BACKOFF;
        while (result.status === 'retryable' && attempts > 0) {
            attempts--;
            // use maximum of computed backoff and 0 to avoid negative timeouts
            const backoff = Math.max(Math.min(nextBackoff, constants_js_1.MAX_BACKOFF) + getJitter(), 0);
            nextBackoff = nextBackoff * constants_js_1.BACKOFF_MULTIPLIER;
            const retryInMillis = (_a = result.retryInMillis) !== null && _a !== void 0 ? _a : backoff;
            // return when expected retry time is after the export deadline.
            const remainingTimeoutMillis = deadline - this._perf.getNowMillis();
            if (retryInMillis > remainingTimeoutMillis) {
                return result;
            }
            result = await this._retry(data, remainingTimeoutMillis, retryInMillis);
        }
        return result;
    }
    shutdown() {
        this._transport.shutdown();
    }
    _retry(data, timeoutMillis, inMillis) {
        return new Promise((resolve, reject) => {
            setTimeout(() => {
                this._transport.send(data, timeoutMillis).then(resolve, reject);
            }, inMillis);
        });
    }
}
exports.RetryingTransport = RetryingTransport;
//# sourceMappingURL=RetryingTransport.js.map