"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withErrorFallback = void 0;
/**
 * Wraps a callback in a try-catch and returns a default value upon failure
 */
const withErrorFallback = (fn, defaultValue, silent = true, diag) => (...args) => {
    try {
        return fn(...args);
    }
    catch (e) {
        if (!silent) {
            if (diag) {
                const message = e instanceof Error ? e.message : 'Unknown error.';
                diag.error(message);
            }
            else {
                console.error(e);
            }
        }
        return defaultValue;
    }
};
exports.withErrorFallback = withErrorFallback;
//# sourceMappingURL=withErrorFallback.js.map