var EmbraceWebSdk = (function (exports) {
    'use strict';

    var NoOpLogManager = /** @class */ (function () {
        function NoOpLogManager() {
        }
        NoOpLogManager.prototype.logException = function (_error, _handled, _attributes, _timestamp) {
            // no op
        };
        NoOpLogManager.prototype.message = function (_message, _level, _attributes, _includeStacktrace) {
            // no op
        };
        return NoOpLogManager;
    }());

    var NOOP_LOG_MANAGER = new NoOpLogManager();
    var ProxyLogManager = /** @class */ (function () {
        function ProxyLogManager() {
        }
        ProxyLogManager.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_LOG_MANAGER;
        };
        ProxyLogManager.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyLogManager.prototype.logException = function (error, handled, attributes, timestamp) {
            this.getDelegate().logException(error, handled, attributes, timestamp);
        };
        ProxyLogManager.prototype.message = function (message, level, attributes, includeStacktrace) {
            this.getDelegate().message(message, level, attributes, includeStacktrace);
        };
        return ProxyLogManager;
    }());

    var LogAPI = /** @class */ (function () {
        function LogAPI(_a) {
            var proxyLogManager = _a.proxyLogManager;
            var _this = this;
            this.getLogManager = function () {
                return _this._proxyLogManager;
            };
            this._proxyLogManager = proxyLogManager;
        }
        LogAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new LogAPI({
                    proxyLogManager: new ProxyLogManager(),
                });
            }
            return this._instance;
        };
        LogAPI.prototype.setGlobalLogManager = function (logManager) {
            this._proxyLogManager.setDelegate(logManager);
        };
        LogAPI.prototype.logException = function (error, handled, attributes, timestamp) {
            this.getLogManager().logException(error, handled, attributes, timestamp);
        };
        LogAPI.prototype.message = function (message, level, attributes, includeStacktrace) {
            this.getLogManager().message(message, level, attributes, includeStacktrace);
        };
        return LogAPI;
    }());

    var log = LogAPI.getInstance();

    var NoOpSpanSessionManager = /** @class */ (function () {
        function NoOpSpanSessionManager() {
            this.getSessionId = function () { return null; };
        }
        NoOpSpanSessionManager.prototype.addBreadcrumb = function (_name) {
            // do nothing.
        };
        NoOpSpanSessionManager.prototype.addProperty = function (_key, _value) {
            // do nothing.
        };
        NoOpSpanSessionManager.prototype.endSessionSpan = function () {
            // do nothing.
        };
        NoOpSpanSessionManager.prototype.endSessionSpanInternal = function () {
            // do nothing.
        };
        NoOpSpanSessionManager.prototype.getSessionSpan = function () {
            return null;
        };
        NoOpSpanSessionManager.prototype.getSessionStartTime = function () {
            return null;
        };
        NoOpSpanSessionManager.prototype.startSessionSpan = function () {
            // do nothing.
        };
        return NoOpSpanSessionManager;
    }());

    var NOOP_SPAN_SESSION_MANAGER = new NoOpSpanSessionManager();
    var ProxySpanSessionManager = /** @class */ (function () {
        function ProxySpanSessionManager() {
        }
        ProxySpanSessionManager.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_SPAN_SESSION_MANAGER;
        };
        ProxySpanSessionManager.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxySpanSessionManager.prototype.addBreadcrumb = function (name) {
            this.getDelegate().addBreadcrumb(name);
        };
        ProxySpanSessionManager.prototype.addProperty = function (key, value) {
            this.getDelegate().addProperty(key, value);
        };
        ProxySpanSessionManager.prototype.endSessionSpan = function () {
            this.getDelegate().endSessionSpan();
        };
        ProxySpanSessionManager.prototype.endSessionSpanInternal = function (reason) {
            this.getDelegate().endSessionSpanInternal(reason);
        };
        ProxySpanSessionManager.prototype.getSessionId = function () {
            return this.getDelegate().getSessionId();
        };
        ProxySpanSessionManager.prototype.getSessionSpan = function () {
            return this.getDelegate().getSessionSpan();
        };
        ProxySpanSessionManager.prototype.getSessionStartTime = function () {
            return this.getDelegate().getSessionStartTime();
        };
        ProxySpanSessionManager.prototype.startSessionSpan = function () {
            this.getDelegate().startSessionSpan();
        };
        return ProxySpanSessionManager;
    }());

    var SessionAPI = /** @class */ (function () {
        function SessionAPI(_a) {
            var proxySpanSessionManager = _a.proxySpanSessionManager;
            var _this = this;
            this.getSpanSessionManager = function () {
                return _this._proxySpanSessionManager;
            };
            this._proxySpanSessionManager = proxySpanSessionManager;
        }
        SessionAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new SessionAPI({
                    proxySpanSessionManager: new ProxySpanSessionManager(),
                });
            }
            return this._instance;
        };
        SessionAPI.prototype.setGlobalSessionManager = function (sessionManager) {
            this._proxySpanSessionManager.setDelegate(sessionManager);
        };
        SessionAPI.prototype.addBreadcrumb = function (name) {
            this.getSpanSessionManager().addBreadcrumb(name);
        };
        SessionAPI.prototype.addProperty = function (key, value) {
            this.getSpanSessionManager().addProperty(key, value);
        };
        SessionAPI.prototype.endSessionSpan = function () {
            this.getSpanSessionManager().endSessionSpan();
        };
        SessionAPI.prototype.endSessionSpanInternal = function (reason) {
            this.getSpanSessionManager().endSessionSpanInternal(reason);
        };
        SessionAPI.prototype.getSessionId = function () {
            return this.getSpanSessionManager().getSessionId();
        };
        SessionAPI.prototype.getSessionSpan = function () {
            return this.getSpanSessionManager().getSessionSpan();
        };
        SessionAPI.prototype.getSessionStartTime = function () {
            return this.getSpanSessionManager().getSessionStartTime();
        };
        SessionAPI.prototype.startSessionSpan = function () {
            this.getSpanSessionManager().startSessionSpan();
        };
        return SessionAPI;
    }());

    var session = SessionAPI.getInstance();

    var NoOpTraceManager = /** @class */ (function () {
        function NoOpTraceManager() {
        }
        NoOpTraceManager.prototype.startPerformanceSpan = function (_name, _options) {
            return null;
        };
        return NoOpTraceManager;
    }());

    var NOOP_TRACE_MANAGER = new NoOpTraceManager();
    var ProxyTraceManager = /** @class */ (function () {
        function ProxyTraceManager() {
        }
        ProxyTraceManager.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_TRACE_MANAGER;
        };
        ProxyTraceManager.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyTraceManager.prototype.startPerformanceSpan = function (name, options) {
            return this.getDelegate().startPerformanceSpan(name, options);
        };
        return ProxyTraceManager;
    }());

    var TraceAPI$1 = /** @class */ (function () {
        function TraceAPI(_a) {
            var proxyTraceManager = _a.proxyTraceManager;
            var _this = this;
            this.getTraceManager = function () {
                return _this._proxyTraceManager;
            };
            this._proxyTraceManager = proxyTraceManager;
        }
        TraceAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new TraceAPI({
                    proxyTraceManager: new ProxyTraceManager(),
                });
            }
            return this._instance;
        };
        TraceAPI.prototype.setGlobalTraceManager = function (traceManager) {
            this._proxyTraceManager.setDelegate(traceManager);
        };
        TraceAPI.prototype.startPerformanceSpan = function (name, options) {
            return this.getTraceManager().startPerformanceSpan(name, options);
        };
        return TraceAPI;
    }());

    var trace$1 = TraceAPI$1.getInstance();

    var KEY_ENDUSER_PSEUDO_ID = 'enduser.pseudo.id';

    var NoOpUserManager = /** @class */ (function () {
        function NoOpUserManager() {
        }
        NoOpUserManager.prototype.clearUser = function () {
            // do nothing.
        };
        NoOpUserManager.prototype.getUser = function () {
            return null;
        };
        NoOpUserManager.prototype.setUser = function () {
            // do nothing.
        };
        return NoOpUserManager;
    }());

    var NOOP_USER_MANAGER = new NoOpUserManager();
    var ProxyUserManager = /** @class */ (function () {
        function ProxyUserManager() {
        }
        ProxyUserManager.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_USER_MANAGER;
        };
        ProxyUserManager.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyUserManager.prototype.clearUser = function () {
            this.getDelegate().clearUser();
        };
        ProxyUserManager.prototype.getUser = function () {
            return this.getDelegate().getUser();
        };
        ProxyUserManager.prototype.setUser = function (user) {
            this.getDelegate().setUser(user);
        };
        return ProxyUserManager;
    }());

    var UserAPI = /** @class */ (function () {
        function UserAPI(_a) {
            var proxyUserManager = _a.proxyUserManager;
            this._proxyUserManager = proxyUserManager;
        }
        UserAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new UserAPI({
                    proxyUserManager: new ProxyUserManager(),
                });
            }
            return this._instance;
        };
        UserAPI.prototype.getUserManager = function () {
            return this._proxyUserManager;
        };
        UserAPI.prototype.setGlobalUserManager = function (userManager) {
            this._proxyUserManager.setDelegate(userManager);
        };
        UserAPI.prototype.clearUser = function () {
            this.getUserManager().clearUser();
        };
        UserAPI.prototype.getUser = function () {
            return this.getUserManager().getUser();
        };
        UserAPI.prototype.setUser = function (user) {
            this.getUserManager().setUser(user);
        };
        return UserAPI;
    }());

    var user = UserAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Updates to this file should also be replicated to @opentelemetry/core too.
    /**
     * - globalThis (New standard)
     * - self (Will return the current window instance for supported browsers)
     * - window (fallback for older browser implementations)
     * - global (NodeJS implementation)
     * - <object> (When all else fails)
     */
    /** only globals that common to node and browsers are allowed */
    // eslint-disable-next-line node/no-unsupported-features/es-builtins, no-undef
    var _globalThis$3 = typeof globalThis === 'object'
        ? globalThis
        : typeof self === 'object'
            ? self
            : typeof window === 'object'
                ? window
                : typeof global === 'object'
                    ? global
                    : {};

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // this is autogenerated file, see scripts/version-update.js
    var VERSION$4 = '1.9.0';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var re = /^(\d+)\.(\d+)\.(\d+)(-(.+))?$/;
    /**
     * Create a function to test an API version to see if it is compatible with the provided ownVersion.
     *
     * The returned function has the following semantics:
     * - Exact match is always compatible
     * - Major versions must match exactly
     *    - 1.x package cannot use global 2.x package
     *    - 2.x package cannot use global 1.x package
     * - The minor version of the API module requesting access to the global API must be less than or equal to the minor version of this API
     *    - 1.3 package may use 1.4 global because the later global contains all functions 1.3 expects
     *    - 1.4 package may NOT use 1.3 global because it may try to call functions which don't exist on 1.3
     * - If the major version is 0, the minor version is treated as the major and the patch is treated as the minor
     * - Patch and build tag differences are not considered at this time
     *
     * @param ownVersion version which should be checked against
     */
    function _makeCompatibilityCheck(ownVersion) {
        var acceptedVersions = new Set([ownVersion]);
        var rejectedVersions = new Set();
        var myVersionMatch = ownVersion.match(re);
        if (!myVersionMatch) {
            // we cannot guarantee compatibility so we always return noop
            return function () { return false; };
        }
        var ownVersionParsed = {
            major: +myVersionMatch[1],
            minor: +myVersionMatch[2],
            patch: +myVersionMatch[3],
            prerelease: myVersionMatch[4],
        };
        // if ownVersion has a prerelease tag, versions must match exactly
        if (ownVersionParsed.prerelease != null) {
            return function isExactmatch(globalVersion) {
                return globalVersion === ownVersion;
            };
        }
        function _reject(v) {
            rejectedVersions.add(v);
            return false;
        }
        function _accept(v) {
            acceptedVersions.add(v);
            return true;
        }
        return function isCompatible(globalVersion) {
            if (acceptedVersions.has(globalVersion)) {
                return true;
            }
            if (rejectedVersions.has(globalVersion)) {
                return false;
            }
            var globalVersionMatch = globalVersion.match(re);
            if (!globalVersionMatch) {
                // cannot parse other version
                // we cannot guarantee compatibility so we always noop
                return _reject(globalVersion);
            }
            var globalVersionParsed = {
                major: +globalVersionMatch[1],
                minor: +globalVersionMatch[2],
                patch: +globalVersionMatch[3],
                prerelease: globalVersionMatch[4],
            };
            // if globalVersion has a prerelease tag, versions must match exactly
            if (globalVersionParsed.prerelease != null) {
                return _reject(globalVersion);
            }
            // major versions must match
            if (ownVersionParsed.major !== globalVersionParsed.major) {
                return _reject(globalVersion);
            }
            if (ownVersionParsed.major === 0) {
                if (ownVersionParsed.minor === globalVersionParsed.minor &&
                    ownVersionParsed.patch <= globalVersionParsed.patch) {
                    return _accept(globalVersion);
                }
                return _reject(globalVersion);
            }
            if (ownVersionParsed.minor <= globalVersionParsed.minor) {
                return _accept(globalVersion);
            }
            return _reject(globalVersion);
        };
    }
    /**
     * Test an API version to see if it is compatible with this API.
     *
     * - Exact match is always compatible
     * - Major versions must match exactly
     *    - 1.x package cannot use global 2.x package
     *    - 2.x package cannot use global 1.x package
     * - The minor version of the API module requesting access to the global API must be less than or equal to the minor version of this API
     *    - 1.3 package may use 1.4 global because the later global contains all functions 1.3 expects
     *    - 1.4 package may NOT use 1.3 global because it may try to call functions which don't exist on 1.3
     * - If the major version is 0, the minor version is treated as the major and the patch is treated as the minor
     * - Patch and build tag differences are not considered at this time
     *
     * @param version version of the API requesting an instance of the global API
     */
    var isCompatible = _makeCompatibilityCheck(VERSION$4);

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var major = VERSION$4.split('.')[0];
    var GLOBAL_OPENTELEMETRY_API_KEY = Symbol.for("opentelemetry.js.api." + major);
    var _global$2 = _globalThis$3;
    function registerGlobal(type, instance, diag, allowOverride) {
        var _a;
        if (allowOverride === void 0) { allowOverride = false; }
        var api = (_global$2[GLOBAL_OPENTELEMETRY_API_KEY] = (_a = _global$2[GLOBAL_OPENTELEMETRY_API_KEY]) !== null && _a !== void 0 ? _a : {
            version: VERSION$4,
        });
        if (!allowOverride && api[type]) {
            // already registered an API of this type
            var err = new Error("@opentelemetry/api: Attempted duplicate registration of API: " + type);
            diag.error(err.stack || err.message);
            return false;
        }
        if (api.version !== VERSION$4) {
            // All registered APIs must be of the same version exactly
            var err = new Error("@opentelemetry/api: Registration of version v" + api.version + " for " + type + " does not match previously registered API v" + VERSION$4);
            diag.error(err.stack || err.message);
            return false;
        }
        api[type] = instance;
        diag.debug("@opentelemetry/api: Registered a global for " + type + " v" + VERSION$4 + ".");
        return true;
    }
    function getGlobal(type) {
        var _a, _b;
        var globalVersion = (_a = _global$2[GLOBAL_OPENTELEMETRY_API_KEY]) === null || _a === void 0 ? void 0 : _a.version;
        if (!globalVersion || !isCompatible(globalVersion)) {
            return;
        }
        return (_b = _global$2[GLOBAL_OPENTELEMETRY_API_KEY]) === null || _b === void 0 ? void 0 : _b[type];
    }
    function unregisterGlobal(type, diag) {
        diag.debug("@opentelemetry/api: Unregistering a global for " + type + " v" + VERSION$4 + ".");
        var api = _global$2[GLOBAL_OPENTELEMETRY_API_KEY];
        if (api) {
            delete api[type];
        }
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$n = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$d = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /**
     * Component Logger which is meant to be used as part of any component which
     * will add automatically additional namespace in front of the log message.
     * It will then forward all message to global diag logger
     * @example
     * const cLogger = diag.createComponentLogger({ namespace: '@opentelemetry/instrumentation-http' });
     * cLogger.debug('test');
     * // @opentelemetry/instrumentation-http test
     */
    var DiagComponentLogger = /** @class */ (function () {
        function DiagComponentLogger(props) {
            this._namespace = props.namespace || 'DiagComponentLogger';
        }
        DiagComponentLogger.prototype.debug = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return logProxy('debug', this._namespace, args);
        };
        DiagComponentLogger.prototype.error = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return logProxy('error', this._namespace, args);
        };
        DiagComponentLogger.prototype.info = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return logProxy('info', this._namespace, args);
        };
        DiagComponentLogger.prototype.warn = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return logProxy('warn', this._namespace, args);
        };
        DiagComponentLogger.prototype.verbose = function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            return logProxy('verbose', this._namespace, args);
        };
        return DiagComponentLogger;
    }());
    function logProxy(funcName, namespace, args) {
        var logger = getGlobal('diag');
        // shortcut if logger not set
        if (!logger) {
            return;
        }
        args.unshift(namespace);
        return logger[funcName].apply(logger, __spreadArray$d([], __read$n(args), false));
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Defines the available internal logging levels for the diagnostic logger, the numeric values
     * of the levels are defined to match the original values from the initial LogLevel to avoid
     * compatibility/migration issues for any implementation that assume the numeric ordering.
     */
    var DiagLogLevel;
    (function (DiagLogLevel) {
        /** Diagnostic Logging level setting to disable all logging (except and forced logs) */
        DiagLogLevel[DiagLogLevel["NONE"] = 0] = "NONE";
        /** Identifies an error scenario */
        DiagLogLevel[DiagLogLevel["ERROR"] = 30] = "ERROR";
        /** Identifies a warning scenario */
        DiagLogLevel[DiagLogLevel["WARN"] = 50] = "WARN";
        /** General informational log message */
        DiagLogLevel[DiagLogLevel["INFO"] = 60] = "INFO";
        /** General debug log message */
        DiagLogLevel[DiagLogLevel["DEBUG"] = 70] = "DEBUG";
        /**
         * Detailed trace level logging should only be used for development, should only be set
         * in a development environment.
         */
        DiagLogLevel[DiagLogLevel["VERBOSE"] = 80] = "VERBOSE";
        /** Used to set the logging level to include all logging */
        DiagLogLevel[DiagLogLevel["ALL"] = 9999] = "ALL";
    })(DiagLogLevel || (DiagLogLevel = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function createLogLevelDiagLogger(maxLevel, logger) {
        if (maxLevel < DiagLogLevel.NONE) {
            maxLevel = DiagLogLevel.NONE;
        }
        else if (maxLevel > DiagLogLevel.ALL) {
            maxLevel = DiagLogLevel.ALL;
        }
        // In case the logger is null or undefined
        logger = logger || {};
        function _filterFunc(funcName, theLevel) {
            var theFunc = logger[funcName];
            if (typeof theFunc === 'function' && maxLevel >= theLevel) {
                return theFunc.bind(logger);
            }
            return function () { };
        }
        return {
            error: _filterFunc('error', DiagLogLevel.ERROR),
            warn: _filterFunc('warn', DiagLogLevel.WARN),
            info: _filterFunc('info', DiagLogLevel.INFO),
            debug: _filterFunc('debug', DiagLogLevel.DEBUG),
            verbose: _filterFunc('verbose', DiagLogLevel.VERBOSE),
        };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$m = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$c = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var API_NAME$4 = 'diag';
    /**
     * Singleton object which represents the entry point to the OpenTelemetry internal
     * diagnostic API
     */
    var DiagAPI = /** @class */ (function () {
        /**
         * Private internal constructor
         * @private
         */
        function DiagAPI() {
            function _logProxy(funcName) {
                return function () {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    var logger = getGlobal('diag');
                    // shortcut if logger not set
                    if (!logger)
                        return;
                    return logger[funcName].apply(logger, __spreadArray$c([], __read$m(args), false));
                };
            }
            // Using self local variable for minification purposes as 'this' cannot be minified
            var self = this;
            // DiagAPI specific functions
            var setLogger = function (logger, optionsOrLogLevel) {
                var _a, _b, _c;
                if (optionsOrLogLevel === void 0) { optionsOrLogLevel = { logLevel: DiagLogLevel.INFO }; }
                if (logger === self) {
                    // There isn't much we can do here.
                    // Logging to the console might break the user application.
                    // Try to log to self. If a logger was previously registered it will receive the log.
                    var err = new Error('Cannot use diag as the logger for itself. Please use a DiagLogger implementation like ConsoleDiagLogger or a custom implementation');
                    self.error((_a = err.stack) !== null && _a !== void 0 ? _a : err.message);
                    return false;
                }
                if (typeof optionsOrLogLevel === 'number') {
                    optionsOrLogLevel = {
                        logLevel: optionsOrLogLevel,
                    };
                }
                var oldLogger = getGlobal('diag');
                var newLogger = createLogLevelDiagLogger((_b = optionsOrLogLevel.logLevel) !== null && _b !== void 0 ? _b : DiagLogLevel.INFO, logger);
                // There already is an logger registered. We'll let it know before overwriting it.
                if (oldLogger && !optionsOrLogLevel.suppressOverrideMessage) {
                    var stack = (_c = new Error().stack) !== null && _c !== void 0 ? _c : '<failed to generate stacktrace>';
                    oldLogger.warn("Current logger will be overwritten from " + stack);
                    newLogger.warn("Current logger will overwrite one already registered from " + stack);
                }
                return registerGlobal('diag', newLogger, self, true);
            };
            self.setLogger = setLogger;
            self.disable = function () {
                unregisterGlobal(API_NAME$4, self);
            };
            self.createComponentLogger = function (options) {
                return new DiagComponentLogger(options);
            };
            self.verbose = _logProxy('verbose');
            self.debug = _logProxy('debug');
            self.info = _logProxy('info');
            self.warn = _logProxy('warn');
            self.error = _logProxy('error');
        }
        /** Get the singleton instance of the DiagAPI API */
        DiagAPI.instance = function () {
            if (!this._instance) {
                this._instance = new DiagAPI();
            }
            return this._instance;
        };
        return DiagAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$l = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __values$c = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var BaggageImpl = /** @class */ (function () {
        function BaggageImpl(entries) {
            this._entries = entries ? new Map(entries) : new Map();
        }
        BaggageImpl.prototype.getEntry = function (key) {
            var entry = this._entries.get(key);
            if (!entry) {
                return undefined;
            }
            return Object.assign({}, entry);
        };
        BaggageImpl.prototype.getAllEntries = function () {
            return Array.from(this._entries.entries()).map(function (_a) {
                var _b = __read$l(_a, 2), k = _b[0], v = _b[1];
                return [k, v];
            });
        };
        BaggageImpl.prototype.setEntry = function (key, entry) {
            var newBaggage = new BaggageImpl(this._entries);
            newBaggage._entries.set(key, entry);
            return newBaggage;
        };
        BaggageImpl.prototype.removeEntry = function (key) {
            var newBaggage = new BaggageImpl(this._entries);
            newBaggage._entries.delete(key);
            return newBaggage;
        };
        BaggageImpl.prototype.removeEntries = function () {
            var e_1, _a;
            var keys = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                keys[_i] = arguments[_i];
            }
            var newBaggage = new BaggageImpl(this._entries);
            try {
                for (var keys_1 = __values$c(keys), keys_1_1 = keys_1.next(); !keys_1_1.done; keys_1_1 = keys_1.next()) {
                    var key = keys_1_1.value;
                    newBaggage._entries.delete(key);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (keys_1_1 && !keys_1_1.done && (_a = keys_1.return)) _a.call(keys_1);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return newBaggage;
        };
        BaggageImpl.prototype.clear = function () {
            return new BaggageImpl();
        };
        return BaggageImpl;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Symbol used to make BaggageEntryMetadata an opaque type
     */
    var baggageEntryMetadataSymbol = Symbol('BaggageEntryMetadata');

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var diag$1 = DiagAPI.instance();
    /**
     * Create a new Baggage with optional entries
     *
     * @param entries An array of baggage entries the new baggage should contain
     */
    function createBaggage(entries) {
        if (entries === void 0) { entries = {}; }
        return new BaggageImpl(new Map(Object.entries(entries)));
    }
    /**
     * Create a serializable BaggageEntryMetadata object from a string.
     *
     * @param str string metadata. Format is currently not defined by the spec and has no special meaning.
     *
     */
    function baggageEntryMetadataFromString(str) {
        if (typeof str !== 'string') {
            diag$1.error("Cannot create baggage metadata from unknown type: " + typeof str);
            str = '';
        }
        return {
            __TYPE__: baggageEntryMetadataSymbol,
            toString: function () {
                return str;
            },
        };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** Get a key to uniquely identify a context value */
    function createContextKey(description) {
        // The specification states that for the same input, multiple calls should
        // return different keys. Due to the nature of the JS dependency management
        // system, this creates problems where multiple versions of some package
        // could hold different keys for the same property.
        //
        // Therefore, we use Symbol.for which returns the same key for the same input.
        return Symbol.for(description);
    }
    var BaseContext = /** @class */ (function () {
        /**
         * Construct a new context which inherits values from an optional parent context.
         *
         * @param parentContext a context from which to inherit values
         */
        function BaseContext(parentContext) {
            // for minification
            var self = this;
            self._currentContext = parentContext ? new Map(parentContext) : new Map();
            self.getValue = function (key) { return self._currentContext.get(key); };
            self.setValue = function (key, value) {
                var context = new BaseContext(self._currentContext);
                context._currentContext.set(key, value);
                return context;
            };
            self.deleteValue = function (key) {
                var context = new BaseContext(self._currentContext);
                context._currentContext.delete(key);
                return context;
            };
        }
        return BaseContext;
    }());
    /** The root context is used as the default parent context when there is no active context */
    var ROOT_CONTEXT = new BaseContext();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var consoleMap = [
        { n: 'error', c: 'error' },
        { n: 'warn', c: 'warn' },
        { n: 'info', c: 'info' },
        { n: 'debug', c: 'debug' },
        { n: 'verbose', c: 'trace' },
    ];
    /**
     * A simple Immutable Console based diagnostic logger which will output any messages to the Console.
     * If you want to limit the amount of logging to a specific level or lower use the
     * {@link createLogLevelDiagLogger}
     */
    var DiagConsoleLogger = /** @class */ (function () {
        function DiagConsoleLogger() {
            function _consoleFunc(funcName) {
                return function () {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    if (console) {
                        // Some environments only expose the console when the F12 developer console is open
                        // eslint-disable-next-line no-console
                        var theFunc = console[funcName];
                        if (typeof theFunc !== 'function') {
                            // Not all environments support all functions
                            // eslint-disable-next-line no-console
                            theFunc = console.log;
                        }
                        // One last final check
                        if (typeof theFunc === 'function') {
                            return theFunc.apply(console, args);
                        }
                    }
                };
            }
            for (var i = 0; i < consoleMap.length; i++) {
                this[consoleMap[i].n] = _consoleFunc(consoleMap[i].c);
            }
        }
        return DiagConsoleLogger;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$n = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * NoopMeter is a noop implementation of the {@link Meter} interface. It reuses
     * constant NoopMetrics for all of its methods.
     */
    var NoopMeter = /** @class */ (function () {
        function NoopMeter() {
        }
        /**
         * @see {@link Meter.createGauge}
         */
        NoopMeter.prototype.createGauge = function (_name, _options) {
            return NOOP_GAUGE_METRIC;
        };
        /**
         * @see {@link Meter.createHistogram}
         */
        NoopMeter.prototype.createHistogram = function (_name, _options) {
            return NOOP_HISTOGRAM_METRIC;
        };
        /**
         * @see {@link Meter.createCounter}
         */
        NoopMeter.prototype.createCounter = function (_name, _options) {
            return NOOP_COUNTER_METRIC;
        };
        /**
         * @see {@link Meter.createUpDownCounter}
         */
        NoopMeter.prototype.createUpDownCounter = function (_name, _options) {
            return NOOP_UP_DOWN_COUNTER_METRIC;
        };
        /**
         * @see {@link Meter.createObservableGauge}
         */
        NoopMeter.prototype.createObservableGauge = function (_name, _options) {
            return NOOP_OBSERVABLE_GAUGE_METRIC;
        };
        /**
         * @see {@link Meter.createObservableCounter}
         */
        NoopMeter.prototype.createObservableCounter = function (_name, _options) {
            return NOOP_OBSERVABLE_COUNTER_METRIC;
        };
        /**
         * @see {@link Meter.createObservableUpDownCounter}
         */
        NoopMeter.prototype.createObservableUpDownCounter = function (_name, _options) {
            return NOOP_OBSERVABLE_UP_DOWN_COUNTER_METRIC;
        };
        /**
         * @see {@link Meter.addBatchObservableCallback}
         */
        NoopMeter.prototype.addBatchObservableCallback = function (_callback, _observables) { };
        /**
         * @see {@link Meter.removeBatchObservableCallback}
         */
        NoopMeter.prototype.removeBatchObservableCallback = function (_callback) { };
        return NoopMeter;
    }());
    var NoopMetric = /** @class */ (function () {
        function NoopMetric() {
        }
        return NoopMetric;
    }());
    var NoopCounterMetric = /** @class */ (function (_super) {
        __extends$n(NoopCounterMetric, _super);
        function NoopCounterMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        NoopCounterMetric.prototype.add = function (_value, _attributes) { };
        return NoopCounterMetric;
    }(NoopMetric));
    var NoopUpDownCounterMetric = /** @class */ (function (_super) {
        __extends$n(NoopUpDownCounterMetric, _super);
        function NoopUpDownCounterMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        NoopUpDownCounterMetric.prototype.add = function (_value, _attributes) { };
        return NoopUpDownCounterMetric;
    }(NoopMetric));
    var NoopGaugeMetric = /** @class */ (function (_super) {
        __extends$n(NoopGaugeMetric, _super);
        function NoopGaugeMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        NoopGaugeMetric.prototype.record = function (_value, _attributes) { };
        return NoopGaugeMetric;
    }(NoopMetric));
    var NoopHistogramMetric = /** @class */ (function (_super) {
        __extends$n(NoopHistogramMetric, _super);
        function NoopHistogramMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        NoopHistogramMetric.prototype.record = function (_value, _attributes) { };
        return NoopHistogramMetric;
    }(NoopMetric));
    var NoopObservableMetric = /** @class */ (function () {
        function NoopObservableMetric() {
        }
        NoopObservableMetric.prototype.addCallback = function (_callback) { };
        NoopObservableMetric.prototype.removeCallback = function (_callback) { };
        return NoopObservableMetric;
    }());
    var NoopObservableCounterMetric = /** @class */ (function (_super) {
        __extends$n(NoopObservableCounterMetric, _super);
        function NoopObservableCounterMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        return NoopObservableCounterMetric;
    }(NoopObservableMetric));
    var NoopObservableGaugeMetric = /** @class */ (function (_super) {
        __extends$n(NoopObservableGaugeMetric, _super);
        function NoopObservableGaugeMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        return NoopObservableGaugeMetric;
    }(NoopObservableMetric));
    var NoopObservableUpDownCounterMetric = /** @class */ (function (_super) {
        __extends$n(NoopObservableUpDownCounterMetric, _super);
        function NoopObservableUpDownCounterMetric() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        return NoopObservableUpDownCounterMetric;
    }(NoopObservableMetric));
    var NOOP_METER = new NoopMeter();
    // Synchronous instruments
    var NOOP_COUNTER_METRIC = new NoopCounterMetric();
    var NOOP_GAUGE_METRIC = new NoopGaugeMetric();
    var NOOP_HISTOGRAM_METRIC = new NoopHistogramMetric();
    var NOOP_UP_DOWN_COUNTER_METRIC = new NoopUpDownCounterMetric();
    // Asynchronous instruments
    var NOOP_OBSERVABLE_COUNTER_METRIC = new NoopObservableCounterMetric();
    var NOOP_OBSERVABLE_GAUGE_METRIC = new NoopObservableGaugeMetric();
    var NOOP_OBSERVABLE_UP_DOWN_COUNTER_METRIC = new NoopObservableUpDownCounterMetric();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var defaultTextMapGetter = {
        get: function (carrier, key) {
            if (carrier == null) {
                return undefined;
            }
            return carrier[key];
        },
        keys: function (carrier) {
            if (carrier == null) {
                return [];
            }
            return Object.keys(carrier);
        },
    };
    var defaultTextMapSetter = {
        set: function (carrier, key, value) {
            if (carrier == null) {
                return;
            }
            carrier[key] = value;
        },
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$k = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$b = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var NoopContextManager = /** @class */ (function () {
        function NoopContextManager() {
        }
        NoopContextManager.prototype.active = function () {
            return ROOT_CONTEXT;
        };
        NoopContextManager.prototype.with = function (_context, fn, thisArg) {
            var args = [];
            for (var _i = 3; _i < arguments.length; _i++) {
                args[_i - 3] = arguments[_i];
            }
            return fn.call.apply(fn, __spreadArray$b([thisArg], __read$k(args), false));
        };
        NoopContextManager.prototype.bind = function (_context, target) {
            return target;
        };
        NoopContextManager.prototype.enable = function () {
            return this;
        };
        NoopContextManager.prototype.disable = function () {
            return this;
        };
        return NoopContextManager;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$j = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$a = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var API_NAME$3 = 'context';
    var NOOP_CONTEXT_MANAGER = new NoopContextManager();
    /**
     * Singleton object which represents the entry point to the OpenTelemetry Context API
     */
    var ContextAPI = /** @class */ (function () {
        /** Empty private constructor prevents end users from constructing a new instance of the API */
        function ContextAPI() {
        }
        /** Get the singleton instance of the Context API */
        ContextAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new ContextAPI();
            }
            return this._instance;
        };
        /**
         * Set the current context manager.
         *
         * @returns true if the context manager was successfully registered, else false
         */
        ContextAPI.prototype.setGlobalContextManager = function (contextManager) {
            return registerGlobal(API_NAME$3, contextManager, DiagAPI.instance());
        };
        /**
         * Get the currently active context
         */
        ContextAPI.prototype.active = function () {
            return this._getContextManager().active();
        };
        /**
         * Execute a function with an active context
         *
         * @param context context to be active during function execution
         * @param fn function to execute in a context
         * @param thisArg optional receiver to be used for calling fn
         * @param args optional arguments forwarded to fn
         */
        ContextAPI.prototype.with = function (context, fn, thisArg) {
            var _a;
            var args = [];
            for (var _i = 3; _i < arguments.length; _i++) {
                args[_i - 3] = arguments[_i];
            }
            return (_a = this._getContextManager()).with.apply(_a, __spreadArray$a([context, fn, thisArg], __read$j(args), false));
        };
        /**
         * Bind a context to a target function or event emitter
         *
         * @param context context to bind to the event emitter or function. Defaults to the currently active context
         * @param target function or event emitter to bind
         */
        ContextAPI.prototype.bind = function (context, target) {
            return this._getContextManager().bind(context, target);
        };
        ContextAPI.prototype._getContextManager = function () {
            return getGlobal(API_NAME$3) || NOOP_CONTEXT_MANAGER;
        };
        /** Disable and remove the global context manager */
        ContextAPI.prototype.disable = function () {
            this._getContextManager().disable();
            unregisterGlobal(API_NAME$3, DiagAPI.instance());
        };
        return ContextAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var TraceFlags;
    (function (TraceFlags) {
        /** Represents no flag set. */
        TraceFlags[TraceFlags["NONE"] = 0] = "NONE";
        /** Bit to represent whether trace is sampled in trace flags. */
        TraceFlags[TraceFlags["SAMPLED"] = 1] = "SAMPLED";
    })(TraceFlags || (TraceFlags = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var INVALID_SPANID = '0000000000000000';
    var INVALID_TRACEID = '00000000000000000000000000000000';
    var INVALID_SPAN_CONTEXT = {
        traceId: INVALID_TRACEID,
        spanId: INVALID_SPANID,
        traceFlags: TraceFlags.NONE,
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * The NonRecordingSpan is the default {@link Span} that is used when no Span
     * implementation is available. All operations are no-op including context
     * propagation.
     */
    var NonRecordingSpan = /** @class */ (function () {
        function NonRecordingSpan(_spanContext) {
            if (_spanContext === void 0) { _spanContext = INVALID_SPAN_CONTEXT; }
            this._spanContext = _spanContext;
        }
        // Returns a SpanContext.
        NonRecordingSpan.prototype.spanContext = function () {
            return this._spanContext;
        };
        // By default does nothing
        NonRecordingSpan.prototype.setAttribute = function (_key, _value) {
            return this;
        };
        // By default does nothing
        NonRecordingSpan.prototype.setAttributes = function (_attributes) {
            return this;
        };
        // By default does nothing
        NonRecordingSpan.prototype.addEvent = function (_name, _attributes) {
            return this;
        };
        NonRecordingSpan.prototype.addLink = function (_link) {
            return this;
        };
        NonRecordingSpan.prototype.addLinks = function (_links) {
            return this;
        };
        // By default does nothing
        NonRecordingSpan.prototype.setStatus = function (_status) {
            return this;
        };
        // By default does nothing
        NonRecordingSpan.prototype.updateName = function (_name) {
            return this;
        };
        // By default does nothing
        NonRecordingSpan.prototype.end = function (_endTime) { };
        // isRecording always returns false for NonRecordingSpan.
        NonRecordingSpan.prototype.isRecording = function () {
            return false;
        };
        // By default does nothing
        NonRecordingSpan.prototype.recordException = function (_exception, _time) { };
        return NonRecordingSpan;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * span key
     */
    var SPAN_KEY = createContextKey('OpenTelemetry Context Key SPAN');
    /**
     * Return the span if one exists
     *
     * @param context context to get span from
     */
    function getSpan(context) {
        return context.getValue(SPAN_KEY) || undefined;
    }
    /**
     * Gets the span from the current context, if one exists.
     */
    function getActiveSpan() {
        return getSpan(ContextAPI.getInstance().active());
    }
    /**
     * Set the span on a context
     *
     * @param context context to use as parent
     * @param span span to set active
     */
    function setSpan(context, span) {
        return context.setValue(SPAN_KEY, span);
    }
    /**
     * Remove current span stored in the context
     *
     * @param context context to delete span from
     */
    function deleteSpan(context) {
        return context.deleteValue(SPAN_KEY);
    }
    /**
     * Wrap span context in a NoopSpan and set as span in a new
     * context
     *
     * @param context context to set active span on
     * @param spanContext span context to be wrapped
     */
    function setSpanContext(context, spanContext) {
        return setSpan(context, new NonRecordingSpan(spanContext));
    }
    /**
     * Get the span context of the span if it exists.
     *
     * @param context context to get values from
     */
    function getSpanContext(context) {
        var _a;
        return (_a = getSpan(context)) === null || _a === void 0 ? void 0 : _a.spanContext();
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var VALID_TRACEID_REGEX = /^([0-9a-f]{32})$/i;
    var VALID_SPANID_REGEX = /^[0-9a-f]{16}$/i;
    function isValidTraceId(traceId) {
        return VALID_TRACEID_REGEX.test(traceId) && traceId !== INVALID_TRACEID;
    }
    function isValidSpanId(spanId) {
        return VALID_SPANID_REGEX.test(spanId) && spanId !== INVALID_SPANID;
    }
    /**
     * Returns true if this {@link SpanContext} is valid.
     * @return true if this {@link SpanContext} is valid.
     */
    function isSpanContextValid(spanContext) {
        return (isValidTraceId(spanContext.traceId) && isValidSpanId(spanContext.spanId));
    }
    /**
     * Wrap the given {@link SpanContext} in a new non-recording {@link Span}
     *
     * @param spanContext span context to be wrapped
     * @returns a new non-recording {@link Span} with the provided context
     */
    function wrapSpanContext(spanContext) {
        return new NonRecordingSpan(spanContext);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var contextApi = ContextAPI.getInstance();
    /**
     * No-op implementations of {@link Tracer}.
     */
    var NoopTracer = /** @class */ (function () {
        function NoopTracer() {
        }
        // startSpan starts a noop span.
        NoopTracer.prototype.startSpan = function (name, options, context) {
            if (context === void 0) { context = contextApi.active(); }
            var root = Boolean(options === null || options === void 0 ? void 0 : options.root);
            if (root) {
                return new NonRecordingSpan();
            }
            var parentFromContext = context && getSpanContext(context);
            if (isSpanContext(parentFromContext) &&
                isSpanContextValid(parentFromContext)) {
                return new NonRecordingSpan(parentFromContext);
            }
            else {
                return new NonRecordingSpan();
            }
        };
        NoopTracer.prototype.startActiveSpan = function (name, arg2, arg3, arg4) {
            var opts;
            var ctx;
            var fn;
            if (arguments.length < 2) {
                return;
            }
            else if (arguments.length === 2) {
                fn = arg2;
            }
            else if (arguments.length === 3) {
                opts = arg2;
                fn = arg3;
            }
            else {
                opts = arg2;
                ctx = arg3;
                fn = arg4;
            }
            var parentContext = ctx !== null && ctx !== void 0 ? ctx : contextApi.active();
            var span = this.startSpan(name, opts, parentContext);
            var contextWithSpanSet = setSpan(parentContext, span);
            return contextApi.with(contextWithSpanSet, fn, undefined, span);
        };
        return NoopTracer;
    }());
    function isSpanContext(spanContext) {
        return (typeof spanContext === 'object' &&
            typeof spanContext['spanId'] === 'string' &&
            typeof spanContext['traceId'] === 'string' &&
            typeof spanContext['traceFlags'] === 'number');
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NOOP_TRACER = new NoopTracer();
    /**
     * Proxy tracer provided by the proxy tracer provider
     */
    var ProxyTracer = /** @class */ (function () {
        function ProxyTracer(_provider, name, version, options) {
            this._provider = _provider;
            this.name = name;
            this.version = version;
            this.options = options;
        }
        ProxyTracer.prototype.startSpan = function (name, options, context) {
            return this._getTracer().startSpan(name, options, context);
        };
        ProxyTracer.prototype.startActiveSpan = function (_name, _options, _context, _fn) {
            var tracer = this._getTracer();
            return Reflect.apply(tracer.startActiveSpan, tracer, arguments);
        };
        /**
         * Try to get a tracer from the proxy tracer provider.
         * If the proxy tracer provider has no delegate, return a noop tracer.
         */
        ProxyTracer.prototype._getTracer = function () {
            if (this._delegate) {
                return this._delegate;
            }
            var tracer = this._provider.getDelegateTracer(this.name, this.version, this.options);
            if (!tracer) {
                return NOOP_TRACER;
            }
            this._delegate = tracer;
            return this._delegate;
        };
        return ProxyTracer;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * An implementation of the {@link TracerProvider} which returns an impotent
     * Tracer for all calls to `getTracer`.
     *
     * All operations are no-op.
     */
    var NoopTracerProvider = /** @class */ (function () {
        function NoopTracerProvider() {
        }
        NoopTracerProvider.prototype.getTracer = function (_name, _version, _options) {
            return new NoopTracer();
        };
        return NoopTracerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NOOP_TRACER_PROVIDER = new NoopTracerProvider();
    /**
     * Tracer provider which provides {@link ProxyTracer}s.
     *
     * Before a delegate is set, tracers provided are NoOp.
     *   When a delegate is set, traces are provided from the delegate.
     *   When a delegate is set after tracers have already been provided,
     *   all tracers already provided will use the provided delegate implementation.
     */
    var ProxyTracerProvider = /** @class */ (function () {
        function ProxyTracerProvider() {
        }
        /**
         * Get a {@link ProxyTracer}
         */
        ProxyTracerProvider.prototype.getTracer = function (name, version, options) {
            var _a;
            return ((_a = this.getDelegateTracer(name, version, options)) !== null && _a !== void 0 ? _a : new ProxyTracer(this, name, version, options));
        };
        ProxyTracerProvider.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_TRACER_PROVIDER;
        };
        /**
         * Set the delegate tracer provider
         */
        ProxyTracerProvider.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyTracerProvider.prototype.getDelegateTracer = function (name, version, options) {
            var _a;
            return (_a = this._delegate) === null || _a === void 0 ? void 0 : _a.getTracer(name, version, options);
        };
        return ProxyTracerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * @deprecated use the one declared in @opentelemetry/sdk-trace-base instead.
     * A sampling decision that determines how a {@link Span} will be recorded
     * and collected.
     */
    var SamplingDecision$1;
    (function (SamplingDecision) {
        /**
         * `Span.isRecording() === false`, span will not be recorded and all events
         * and attributes will be dropped.
         */
        SamplingDecision[SamplingDecision["NOT_RECORD"] = 0] = "NOT_RECORD";
        /**
         * `Span.isRecording() === true`, but `Sampled` flag in {@link TraceFlags}
         * MUST NOT be set.
         */
        SamplingDecision[SamplingDecision["RECORD"] = 1] = "RECORD";
        /**
         * `Span.isRecording() === true` AND `Sampled` flag in {@link TraceFlags}
         * MUST be set.
         */
        SamplingDecision[SamplingDecision["RECORD_AND_SAMPLED"] = 2] = "RECORD_AND_SAMPLED";
    })(SamplingDecision$1 || (SamplingDecision$1 = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var SpanKind;
    (function (SpanKind) {
        /** Default value. Indicates that the span is used internally. */
        SpanKind[SpanKind["INTERNAL"] = 0] = "INTERNAL";
        /**
         * Indicates that the span covers server-side handling of an RPC or other
         * remote request.
         */
        SpanKind[SpanKind["SERVER"] = 1] = "SERVER";
        /**
         * Indicates that the span covers the client-side wrapper around an RPC or
         * other remote request.
         */
        SpanKind[SpanKind["CLIENT"] = 2] = "CLIENT";
        /**
         * Indicates that the span describes producer sending a message to a
         * broker. Unlike client and server, there is no direct critical path latency
         * relationship between producer and consumer spans.
         */
        SpanKind[SpanKind["PRODUCER"] = 3] = "PRODUCER";
        /**
         * Indicates that the span describes consumer receiving a message from a
         * broker. Unlike client and server, there is no direct critical path latency
         * relationship between producer and consumer spans.
         */
        SpanKind[SpanKind["CONSUMER"] = 4] = "CONSUMER";
    })(SpanKind || (SpanKind = {}));

    /**
     * An enumeration of status codes.
     */
    var SpanStatusCode;
    (function (SpanStatusCode) {
        /**
         * The default status.
         */
        SpanStatusCode[SpanStatusCode["UNSET"] = 0] = "UNSET";
        /**
         * The operation has been validated by an Application developer or
         * Operator to have completed successfully.
         */
        SpanStatusCode[SpanStatusCode["OK"] = 1] = "OK";
        /**
         * The operation contains an error.
         */
        SpanStatusCode[SpanStatusCode["ERROR"] = 2] = "ERROR";
    })(SpanStatusCode || (SpanStatusCode = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Split module-level variable definition into separate files to allow
    // tree-shaking on each api instance.
    /** Entrypoint for context API */
    var context = ContextAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Split module-level variable definition into separate files to allow
    // tree-shaking on each api instance.
    /**
     * Entrypoint for Diag API.
     * Defines Diagnostic handler used for internal diagnostic logging operations.
     * The default provides a Noop DiagLogger implementation which may be changed via the
     * diag.setLogger(logger: DiagLogger) function.
     */
    var diag = DiagAPI.instance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * An implementation of the {@link MeterProvider} which returns an impotent Meter
     * for all calls to `getMeter`
     */
    var NoopMeterProvider = /** @class */ (function () {
        function NoopMeterProvider() {
        }
        NoopMeterProvider.prototype.getMeter = function (_name, _version, _options) {
            return NOOP_METER;
        };
        return NoopMeterProvider;
    }());
    var NOOP_METER_PROVIDER = new NoopMeterProvider();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var API_NAME$2 = 'metrics';
    /**
     * Singleton object which represents the entry point to the OpenTelemetry Metrics API
     */
    var MetricsAPI = /** @class */ (function () {
        /** Empty private constructor prevents end users from constructing a new instance of the API */
        function MetricsAPI() {
        }
        /** Get the singleton instance of the Metrics API */
        MetricsAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new MetricsAPI();
            }
            return this._instance;
        };
        /**
         * Set the current global meter provider.
         * Returns true if the meter provider was successfully registered, else false.
         */
        MetricsAPI.prototype.setGlobalMeterProvider = function (provider) {
            return registerGlobal(API_NAME$2, provider, DiagAPI.instance());
        };
        /**
         * Returns the global meter provider.
         */
        MetricsAPI.prototype.getMeterProvider = function () {
            return getGlobal(API_NAME$2) || NOOP_METER_PROVIDER;
        };
        /**
         * Returns a meter from the global meter provider.
         */
        MetricsAPI.prototype.getMeter = function (name, version, options) {
            return this.getMeterProvider().getMeter(name, version, options);
        };
        /** Remove the global meter provider */
        MetricsAPI.prototype.disable = function () {
            unregisterGlobal(API_NAME$2, DiagAPI.instance());
        };
        return MetricsAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Split module-level variable definition into separate files to allow
    // tree-shaking on each api instance.
    /** Entrypoint for metrics API */
    var metrics = MetricsAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * No-op implementations of {@link TextMapPropagator}.
     */
    var NoopTextMapPropagator = /** @class */ (function () {
        function NoopTextMapPropagator() {
        }
        /** Noop inject function does nothing */
        NoopTextMapPropagator.prototype.inject = function (_context, _carrier) { };
        /** Noop extract function does nothing and returns the input context */
        NoopTextMapPropagator.prototype.extract = function (context, _carrier) {
            return context;
        };
        NoopTextMapPropagator.prototype.fields = function () {
            return [];
        };
        return NoopTextMapPropagator;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Baggage key
     */
    var BAGGAGE_KEY = createContextKey('OpenTelemetry Baggage Key');
    /**
     * Retrieve the current baggage from the given context
     *
     * @param {Context} Context that manage all context values
     * @returns {Baggage} Extracted baggage from the context
     */
    function getBaggage(context) {
        return context.getValue(BAGGAGE_KEY) || undefined;
    }
    /**
     * Retrieve the current baggage from the active/current context
     *
     * @returns {Baggage} Extracted baggage from the context
     */
    function getActiveBaggage() {
        return getBaggage(ContextAPI.getInstance().active());
    }
    /**
     * Store a baggage in the given context
     *
     * @param {Context} Context that manage all context values
     * @param {Baggage} baggage that will be set in the actual context
     */
    function setBaggage(context, baggage) {
        return context.setValue(BAGGAGE_KEY, baggage);
    }
    /**
     * Delete the baggage stored in the given context
     *
     * @param {Context} Context that manage all context values
     */
    function deleteBaggage(context) {
        return context.deleteValue(BAGGAGE_KEY);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var API_NAME$1 = 'propagation';
    var NOOP_TEXT_MAP_PROPAGATOR = new NoopTextMapPropagator();
    /**
     * Singleton object which represents the entry point to the OpenTelemetry Propagation API
     */
    var PropagationAPI = /** @class */ (function () {
        /** Empty private constructor prevents end users from constructing a new instance of the API */
        function PropagationAPI() {
            this.createBaggage = createBaggage;
            this.getBaggage = getBaggage;
            this.getActiveBaggage = getActiveBaggage;
            this.setBaggage = setBaggage;
            this.deleteBaggage = deleteBaggage;
        }
        /** Get the singleton instance of the Propagator API */
        PropagationAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new PropagationAPI();
            }
            return this._instance;
        };
        /**
         * Set the current propagator.
         *
         * @returns true if the propagator was successfully registered, else false
         */
        PropagationAPI.prototype.setGlobalPropagator = function (propagator) {
            return registerGlobal(API_NAME$1, propagator, DiagAPI.instance());
        };
        /**
         * Inject context into a carrier to be propagated inter-process
         *
         * @param context Context carrying tracing data to inject
         * @param carrier carrier to inject context into
         * @param setter Function used to set values on the carrier
         */
        PropagationAPI.prototype.inject = function (context, carrier, setter) {
            if (setter === void 0) { setter = defaultTextMapSetter; }
            return this._getGlobalPropagator().inject(context, carrier, setter);
        };
        /**
         * Extract context from a carrier
         *
         * @param context Context which the newly created context will inherit from
         * @param carrier Carrier to extract context from
         * @param getter Function used to extract keys from a carrier
         */
        PropagationAPI.prototype.extract = function (context, carrier, getter) {
            if (getter === void 0) { getter = defaultTextMapGetter; }
            return this._getGlobalPropagator().extract(context, carrier, getter);
        };
        /**
         * Return a list of all fields which may be used by the propagator.
         */
        PropagationAPI.prototype.fields = function () {
            return this._getGlobalPropagator().fields();
        };
        /** Remove the global propagator */
        PropagationAPI.prototype.disable = function () {
            unregisterGlobal(API_NAME$1, DiagAPI.instance());
        };
        PropagationAPI.prototype._getGlobalPropagator = function () {
            return getGlobal(API_NAME$1) || NOOP_TEXT_MAP_PROPAGATOR;
        };
        return PropagationAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Split module-level variable definition into separate files to allow
    // tree-shaking on each api instance.
    /** Entrypoint for propagation API */
    var propagation = PropagationAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var API_NAME = 'trace';
    /**
     * Singleton object which represents the entry point to the OpenTelemetry Tracing API
     */
    var TraceAPI = /** @class */ (function () {
        /** Empty private constructor prevents end users from constructing a new instance of the API */
        function TraceAPI() {
            this._proxyTracerProvider = new ProxyTracerProvider();
            this.wrapSpanContext = wrapSpanContext;
            this.isSpanContextValid = isSpanContextValid;
            this.deleteSpan = deleteSpan;
            this.getSpan = getSpan;
            this.getActiveSpan = getActiveSpan;
            this.getSpanContext = getSpanContext;
            this.setSpan = setSpan;
            this.setSpanContext = setSpanContext;
        }
        /** Get the singleton instance of the Trace API */
        TraceAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new TraceAPI();
            }
            return this._instance;
        };
        /**
         * Set the current global tracer.
         *
         * @returns true if the tracer provider was successfully registered, else false
         */
        TraceAPI.prototype.setGlobalTracerProvider = function (provider) {
            var success = registerGlobal(API_NAME, this._proxyTracerProvider, DiagAPI.instance());
            if (success) {
                this._proxyTracerProvider.setDelegate(provider);
            }
            return success;
        };
        /**
         * Returns the global tracer provider.
         */
        TraceAPI.prototype.getTracerProvider = function () {
            return getGlobal(API_NAME) || this._proxyTracerProvider;
        };
        /**
         * Returns a tracer from the global tracer provider.
         */
        TraceAPI.prototype.getTracer = function (name, version) {
            return this.getTracerProvider().getTracer(name, version);
        };
        /** Remove the global tracer provider */
        TraceAPI.prototype.disable = function () {
            unregisterGlobal(API_NAME, DiagAPI.instance());
            this._proxyTracerProvider = new ProxyTracerProvider();
        };
        return TraceAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Split module-level variable definition into separate files to allow
    // tree-shaking on each api instance.
    /** Entrypoint for trace API */
    var trace = TraceAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var SeverityNumber;
    (function (SeverityNumber) {
        SeverityNumber[SeverityNumber["UNSPECIFIED"] = 0] = "UNSPECIFIED";
        SeverityNumber[SeverityNumber["TRACE"] = 1] = "TRACE";
        SeverityNumber[SeverityNumber["TRACE2"] = 2] = "TRACE2";
        SeverityNumber[SeverityNumber["TRACE3"] = 3] = "TRACE3";
        SeverityNumber[SeverityNumber["TRACE4"] = 4] = "TRACE4";
        SeverityNumber[SeverityNumber["DEBUG"] = 5] = "DEBUG";
        SeverityNumber[SeverityNumber["DEBUG2"] = 6] = "DEBUG2";
        SeverityNumber[SeverityNumber["DEBUG3"] = 7] = "DEBUG3";
        SeverityNumber[SeverityNumber["DEBUG4"] = 8] = "DEBUG4";
        SeverityNumber[SeverityNumber["INFO"] = 9] = "INFO";
        SeverityNumber[SeverityNumber["INFO2"] = 10] = "INFO2";
        SeverityNumber[SeverityNumber["INFO3"] = 11] = "INFO3";
        SeverityNumber[SeverityNumber["INFO4"] = 12] = "INFO4";
        SeverityNumber[SeverityNumber["WARN"] = 13] = "WARN";
        SeverityNumber[SeverityNumber["WARN2"] = 14] = "WARN2";
        SeverityNumber[SeverityNumber["WARN3"] = 15] = "WARN3";
        SeverityNumber[SeverityNumber["WARN4"] = 16] = "WARN4";
        SeverityNumber[SeverityNumber["ERROR"] = 17] = "ERROR";
        SeverityNumber[SeverityNumber["ERROR2"] = 18] = "ERROR2";
        SeverityNumber[SeverityNumber["ERROR3"] = 19] = "ERROR3";
        SeverityNumber[SeverityNumber["ERROR4"] = 20] = "ERROR4";
        SeverityNumber[SeverityNumber["FATAL"] = 21] = "FATAL";
        SeverityNumber[SeverityNumber["FATAL2"] = 22] = "FATAL2";
        SeverityNumber[SeverityNumber["FATAL3"] = 23] = "FATAL3";
        SeverityNumber[SeverityNumber["FATAL4"] = 24] = "FATAL4";
    })(SeverityNumber || (SeverityNumber = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NoopLogger$1 = /** @class */ (function () {
        function NoopLogger() {
        }
        NoopLogger.prototype.emit = function (_logRecord) { };
        return NoopLogger;
    }());
    var NOOP_LOGGER$1 = new NoopLogger$1();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NoopLoggerProvider$1 = /** @class */ (function () {
        function NoopLoggerProvider() {
        }
        NoopLoggerProvider.prototype.getLogger = function (_name, _version, _options) {
            return new NoopLogger$1();
        };
        return NoopLoggerProvider;
    }());
    var NOOP_LOGGER_PROVIDER$1 = new NoopLoggerProvider$1();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var ProxyLogger$1 = /** @class */ (function () {
        function ProxyLogger(_provider, name, version, options) {
            this._provider = _provider;
            this.name = name;
            this.version = version;
            this.options = options;
        }
        /**
         * Emit a log record. This method should only be used by log appenders.
         *
         * @param logRecord
         */
        ProxyLogger.prototype.emit = function (logRecord) {
            this._getLogger().emit(logRecord);
        };
        /**
         * Try to get a logger from the proxy logger provider.
         * If the proxy logger provider has no delegate, return a noop logger.
         */
        ProxyLogger.prototype._getLogger = function () {
            if (this._delegate) {
                return this._delegate;
            }
            var logger = this._provider.getDelegateLogger(this.name, this.version, this.options);
            if (!logger) {
                return NOOP_LOGGER$1;
            }
            this._delegate = logger;
            return this._delegate;
        };
        return ProxyLogger;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var ProxyLoggerProvider$1 = /** @class */ (function () {
        function ProxyLoggerProvider() {
        }
        ProxyLoggerProvider.prototype.getLogger = function (name, version, options) {
            var _a;
            return ((_a = this.getDelegateLogger(name, version, options)) !== null && _a !== void 0 ? _a : new ProxyLogger$1(this, name, version, options));
        };
        ProxyLoggerProvider.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_LOGGER_PROVIDER$1;
        };
        /**
         * Set the delegate logger provider
         */
        ProxyLoggerProvider.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyLoggerProvider.prototype.getDelegateLogger = function (name, version, options) {
            var _a;
            return (_a = this._delegate) === null || _a === void 0 ? void 0 : _a.getLogger(name, version, options);
        };
        return ProxyLoggerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Updates to this file should also be replicated to @opentelemetry/api and
    // @opentelemetry/core too.
    /**
     * - globalThis (New standard)
     * - self (Will return the current window instance for supported browsers)
     * - window (fallback for older browser implementations)
     * - global (NodeJS implementation)
     * - <object> (When all else fails)
     */
    /** only globals that common to node and browsers are allowed */
    // eslint-disable-next-line node/no-unsupported-features/es-builtins, no-undef
    var _globalThis$2 = typeof globalThis === 'object'
        ? globalThis
        : typeof self === 'object'
            ? self
            : typeof window === 'object'
                ? window
                : typeof global === 'object'
                    ? global
                    : {};

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var GLOBAL_LOGS_API_KEY$1 = Symbol.for('io.opentelemetry.js.api.logs');
    var _global$1 = _globalThis$2;
    /**
     * Make a function which accepts a version integer and returns the instance of an API if the version
     * is compatible, or a fallback version (usually NOOP) if it is not.
     *
     * @param requiredVersion Backwards compatibility version which is required to return the instance
     * @param instance Instance which should be returned if the required version is compatible
     * @param fallback Fallback instance, usually NOOP, which will be returned if the required version is not compatible
     */
    function makeGetter$1(requiredVersion, instance, fallback) {
        return function (version) {
            return version === requiredVersion ? instance : fallback;
        };
    }
    /**
     * A number which should be incremented each time a backwards incompatible
     * change is made to the API. This number is used when an API package
     * attempts to access the global API to ensure it is getting a compatible
     * version. If the global API is not compatible with the API package
     * attempting to get it, a NOOP API implementation will be returned.
     */
    var API_BACKWARDS_COMPATIBILITY_VERSION$1 = 1;

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var LogsAPI$1 = /** @class */ (function () {
        function LogsAPI() {
            this._proxyLoggerProvider = new ProxyLoggerProvider$1();
        }
        LogsAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new LogsAPI();
            }
            return this._instance;
        };
        LogsAPI.prototype.setGlobalLoggerProvider = function (provider) {
            if (_global$1[GLOBAL_LOGS_API_KEY$1]) {
                return this.getLoggerProvider();
            }
            _global$1[GLOBAL_LOGS_API_KEY$1] = makeGetter$1(API_BACKWARDS_COMPATIBILITY_VERSION$1, provider, NOOP_LOGGER_PROVIDER$1);
            this._proxyLoggerProvider.setDelegate(provider);
            return provider;
        };
        /**
         * Returns the global logger provider.
         *
         * @returns LoggerProvider
         */
        LogsAPI.prototype.getLoggerProvider = function () {
            var _a, _b;
            return ((_b = (_a = _global$1[GLOBAL_LOGS_API_KEY$1]) === null || _a === void 0 ? void 0 : _a.call(_global$1, API_BACKWARDS_COMPATIBILITY_VERSION$1)) !== null && _b !== void 0 ? _b : this._proxyLoggerProvider);
        };
        /**
         * Returns a logger from the global logger provider.
         *
         * @returns Logger
         */
        LogsAPI.prototype.getLogger = function (name, version, options) {
            return this.getLoggerProvider().getLogger(name, version, options);
        };
        /** Remove the global logger provider */
        LogsAPI.prototype.disable = function () {
            delete _global$1[GLOBAL_LOGS_API_KEY$1];
            this._proxyLoggerProvider = new ProxyLoggerProvider$1();
        };
        return LogsAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var logs$1 = LogsAPI$1.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Enable instrumentations
     * @param instrumentations
     * @param tracerProvider
     * @param meterProvider
     */
    function enableInstrumentations(instrumentations, tracerProvider, meterProvider, loggerProvider) {
        for (var i = 0, j = instrumentations.length; i < j; i++) {
            var instrumentation = instrumentations[i];
            if (tracerProvider) {
                instrumentation.setTracerProvider(tracerProvider);
            }
            if (meterProvider) {
                instrumentation.setMeterProvider(meterProvider);
            }
            if (loggerProvider && instrumentation.setLoggerProvider) {
                instrumentation.setLoggerProvider(loggerProvider);
            }
            // instrumentations have been already enabled during creation
            // so enable only if user prevented that by setting enabled to false
            // this is to prevent double enabling but when calling register all
            // instrumentations should be now enabled
            if (!instrumentation.getConfig().enabled) {
                instrumentation.enable();
            }
        }
    }
    /**
     * Disable instrumentations
     * @param instrumentations
     */
    function disableInstrumentations(instrumentations) {
        instrumentations.forEach(function (instrumentation) { return instrumentation.disable(); });
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * It will register instrumentations and plugins
     * @param options
     * @return returns function to unload instrumentation and plugins that were
     *   registered
     */
    function registerInstrumentations(options) {
        var _a, _b;
        var tracerProvider = options.tracerProvider || trace.getTracerProvider();
        var meterProvider = options.meterProvider || metrics.getMeterProvider();
        var loggerProvider = options.loggerProvider || logs$1.getLoggerProvider();
        var instrumentations = (_b = (_a = options.instrumentations) === null || _a === void 0 ? void 0 : _a.flat()) !== null && _b !== void 0 ? _b : [];
        enableInstrumentations(instrumentations, tracerProvider, meterProvider, loggerProvider);
        return function () {
            disableInstrumentations(instrumentations);
        };
    }

    var shimmer_1;
    var hasRequiredShimmer;

    function requireShimmer () {
    	if (hasRequiredShimmer) return shimmer_1;
    	hasRequiredShimmer = 1;

    	function isFunction (funktion) {
    	  return typeof funktion === 'function'
    	}

    	// Default to complaining loudly when things don't go according to plan.
    	var logger = console.error.bind(console);

    	// Sets a property on an object, preserving its enumerability.
    	// This function assumes that the property is already writable.
    	function defineProperty (obj, name, value) {
    	  var enumerable = !!obj[name] && obj.propertyIsEnumerable(name);
    	  Object.defineProperty(obj, name, {
    	    configurable: true,
    	    enumerable: enumerable,
    	    writable: true,
    	    value: value
    	  });
    	}

    	// Keep initialization idempotent.
    	function shimmer (options) {
    	  if (options && options.logger) {
    	    if (!isFunction(options.logger)) logger("new logger isn't a function, not replacing");
    	    else logger = options.logger;
    	  }
    	}

    	function wrap (nodule, name, wrapper) {
    	  if (!nodule || !nodule[name]) {
    	    logger('no original function ' + name + ' to wrap');
    	    return
    	  }

    	  if (!wrapper) {
    	    logger('no wrapper function');
    	    logger((new Error()).stack);
    	    return
    	  }

    	  if (!isFunction(nodule[name]) || !isFunction(wrapper)) {
    	    logger('original object and wrapper must be functions');
    	    return
    	  }

    	  var original = nodule[name];
    	  var wrapped = wrapper(original, name);

    	  defineProperty(wrapped, '__original', original);
    	  defineProperty(wrapped, '__unwrap', function () {
    	    if (nodule[name] === wrapped) defineProperty(nodule, name, original);
    	  });
    	  defineProperty(wrapped, '__wrapped', true);

    	  defineProperty(nodule, name, wrapped);
    	  return wrapped
    	}

    	function massWrap (nodules, names, wrapper) {
    	  if (!nodules) {
    	    logger('must provide one or more modules to patch');
    	    logger((new Error()).stack);
    	    return
    	  } else if (!Array.isArray(nodules)) {
    	    nodules = [nodules];
    	  }

    	  if (!(names && Array.isArray(names))) {
    	    logger('must provide one or more functions to wrap on modules');
    	    return
    	  }

    	  nodules.forEach(function (nodule) {
    	    names.forEach(function (name) {
    	      wrap(nodule, name, wrapper);
    	    });
    	  });
    	}

    	function unwrap (nodule, name) {
    	  if (!nodule || !nodule[name]) {
    	    logger('no function to unwrap.');
    	    logger((new Error()).stack);
    	    return
    	  }

    	  if (!nodule[name].__unwrap) {
    	    logger('no original to unwrap to -- has ' + name + ' already been unwrapped?');
    	  } else {
    	    return nodule[name].__unwrap()
    	  }
    	}

    	function massUnwrap (nodules, names) {
    	  if (!nodules) {
    	    logger('must provide one or more modules to patch');
    	    logger((new Error()).stack);
    	    return
    	  } else if (!Array.isArray(nodules)) {
    	    nodules = [nodules];
    	  }

    	  if (!(names && Array.isArray(names))) {
    	    logger('must provide one or more functions to unwrap on modules');
    	    return
    	  }

    	  nodules.forEach(function (nodule) {
    	    names.forEach(function (name) {
    	      unwrap(nodule, name);
    	    });
    	  });
    	}

    	shimmer.wrap = wrap;
    	shimmer.massWrap = massWrap;
    	shimmer.unwrap = unwrap;
    	shimmer.massUnwrap = massUnwrap;

    	shimmer_1 = shimmer;
    	return shimmer_1;
    }

    var shimmerExports = requireShimmer();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __assign$b = (undefined && undefined.__assign) || function () {
        __assign$b = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$b.apply(this, arguments);
    };
    /**
     * Base abstract internal class for instrumenting node and web plugins
     */
    var InstrumentationAbstract$2 = /** @class */ (function () {
        function InstrumentationAbstract(instrumentationName, instrumentationVersion, config) {
            this.instrumentationName = instrumentationName;
            this.instrumentationVersion = instrumentationVersion;
            this._config = {};
            /* Api to wrap instrumented method */
            this._wrap = shimmerExports.wrap;
            /* Api to unwrap instrumented methods */
            this._unwrap = shimmerExports.unwrap;
            /* Api to mass wrap instrumented method */
            this._massWrap = shimmerExports.massWrap;
            /* Api to mass unwrap instrumented methods */
            this._massUnwrap = shimmerExports.massUnwrap;
            this.setConfig(config);
            this._diag = diag.createComponentLogger({
                namespace: instrumentationName,
            });
            this._tracer = trace.getTracer(instrumentationName, instrumentationVersion);
            this._meter = metrics.getMeter(instrumentationName, instrumentationVersion);
            this._logger = logs$1.getLogger(instrumentationName, instrumentationVersion);
            this._updateMetricInstruments();
        }
        Object.defineProperty(InstrumentationAbstract.prototype, "meter", {
            /* Returns meter */
            get: function () {
                return this._meter;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Sets MeterProvider to this plugin
         * @param meterProvider
         */
        InstrumentationAbstract.prototype.setMeterProvider = function (meterProvider) {
            this._meter = meterProvider.getMeter(this.instrumentationName, this.instrumentationVersion);
            this._updateMetricInstruments();
        };
        Object.defineProperty(InstrumentationAbstract.prototype, "logger", {
            /* Returns logger */
            get: function () {
                return this._logger;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Sets LoggerProvider to this plugin
         * @param loggerProvider
         */
        InstrumentationAbstract.prototype.setLoggerProvider = function (loggerProvider) {
            this._logger = loggerProvider.getLogger(this.instrumentationName, this.instrumentationVersion);
        };
        /**
         * @experimental
         *
         * Get module definitions defined by {@link init}.
         * This can be used for experimental compile-time instrumentation.
         *
         * @returns an array of {@link InstrumentationModuleDefinition}
         */
        InstrumentationAbstract.prototype.getModuleDefinitions = function () {
            var _a;
            var initResult = (_a = this.init()) !== null && _a !== void 0 ? _a : [];
            if (!Array.isArray(initResult)) {
                return [initResult];
            }
            return initResult;
        };
        /**
         * Sets the new metric instruments with the current Meter.
         */
        InstrumentationAbstract.prototype._updateMetricInstruments = function () {
            return;
        };
        /* Returns InstrumentationConfig */
        InstrumentationAbstract.prototype.getConfig = function () {
            return this._config;
        };
        /**
         * Sets InstrumentationConfig to this plugin
         * @param config
         */
        InstrumentationAbstract.prototype.setConfig = function (config) {
            // copy config first level properties to ensure they are immutable.
            // nested properties are not copied, thus are mutable from the outside.
            this._config = __assign$b({ enabled: true }, config);
        };
        /**
         * Sets TraceProvider to this plugin
         * @param tracerProvider
         */
        InstrumentationAbstract.prototype.setTracerProvider = function (tracerProvider) {
            this._tracer = tracerProvider.getTracer(this.instrumentationName, this.instrumentationVersion);
        };
        Object.defineProperty(InstrumentationAbstract.prototype, "tracer", {
            /* Returns tracer */
            get: function () {
                return this._tracer;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Execute span customization hook, if configured, and log any errors.
         * Any semantics of the trigger and info are defined by the specific instrumentation.
         * @param hookHandler The optional hook handler which the user has configured via instrumentation config
         * @param triggerName The name of the trigger for executing the hook for logging purposes
         * @param span The span to which the hook should be applied
         * @param info The info object to be passed to the hook, with useful data the hook may use
         */
        InstrumentationAbstract.prototype._runSpanCustomizationHook = function (hookHandler, triggerName, span, info) {
            if (!hookHandler) {
                return;
            }
            try {
                hookHandler(span, info);
            }
            catch (e) {
                this._diag.error("Error running span customization hook due to exception in handler", { triggerName: triggerName }, e);
            }
        };
        return InstrumentationAbstract;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$m = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * Base abstract class for instrumenting web plugins
     */
    var InstrumentationBase$1 = /** @class */ (function (_super) {
        __extends$m(InstrumentationBase, _super);
        function InstrumentationBase(instrumentationName, instrumentationVersion, config) {
            var _this = _super.call(this, instrumentationName, instrumentationVersion, config) || this;
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        return InstrumentationBase;
    }(InstrumentationAbstract$2));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * function to execute patched function and being able to catch errors
     * @param execute - function to be executed
     * @param onFinish - callback to run when execute finishes
     */
    function safeExecuteInTheMiddle$1(execute, onFinish, preventThrowingError) {
        var error;
        var result;
        try {
            result = execute();
        }
        catch (e) {
            error = e;
        }
        finally {
            onFinish(error, result);
            // eslint-disable-next-line no-unsafe-finally
            return result;
        }
    }
    /**
     * Checks if certain function has been already wrapped
     * @param func
     */
    function isWrapped(func) {
        return (typeof func === 'function' &&
            typeof func.__original === 'function' &&
            typeof func.__unwrap === 'function' &&
            func.__wrapped === true);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var TMP_EXCEPTION_TYPE = 'exception.type';
    var TMP_EXCEPTION_MESSAGE = 'exception.message';
    var TMP_EXCEPTION_STACKTRACE = 'exception.stacktrace';
    var TMP_HTTP_METHOD = 'http.method';
    var TMP_HTTP_URL = 'http.url';
    var TMP_HTTP_HOST = 'http.host';
    var TMP_HTTP_SCHEME = 'http.scheme';
    var TMP_HTTP_STATUS_CODE = 'http.status_code';
    var TMP_HTTP_USER_AGENT = 'http.user_agent';
    var TMP_HTTP_REQUEST_CONTENT_LENGTH = 'http.request_content_length';
    var TMP_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED = 'http.request_content_length_uncompressed';
    var TMP_HTTP_RESPONSE_CONTENT_LENGTH = 'http.response_content_length';
    var TMP_HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED = 'http.response_content_length_uncompressed';
    /**
     * The type of the exception (its fully-qualified class name, if applicable). The dynamic type of the exception should be preferred over the static type in languages that support it.
     *
     * @deprecated Use ATTR_EXCEPTION_TYPE.
     */
    var SEMATTRS_EXCEPTION_TYPE = TMP_EXCEPTION_TYPE;
    /**
     * The exception message.
     *
     * @deprecated Use ATTR_EXCEPTION_MESSAGE.
     */
    var SEMATTRS_EXCEPTION_MESSAGE = TMP_EXCEPTION_MESSAGE;
    /**
     * A stacktrace as a string in the natural representation for the language runtime. The representation is to be determined and documented by each language SIG.
     *
     * @deprecated Use ATTR_EXCEPTION_STACKTRACE.
     */
    var SEMATTRS_EXCEPTION_STACKTRACE = TMP_EXCEPTION_STACKTRACE;
    /**
     * HTTP request method.
     *
     * @deprecated Use ATTR_HTTP_METHOD in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_METHOD = TMP_HTTP_METHOD;
    /**
     * Full HTTP request URL in the form `scheme://host[:port]/path?query[#fragment]`. Usually the fragment is not transmitted over HTTP, but if it is known, it should be included nevertheless.
     *
     * Note: `http.url` MUST NOT contain credentials passed via URL in form of `https://username:password@www.example.com/`. In such case the attribute&#39;s value should be `https://www.example.com/`.
     *
     * @deprecated Use ATTR_HTTP_URL in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_URL = TMP_HTTP_URL;
    /**
     * The value of the [HTTP host header](https://tools.ietf.org/html/rfc7230#section-5.4). An empty Host header should also be reported, see note.
     *
     * Note: When the header is present but empty the attribute SHOULD be set to the empty string. Note that this is a valid situation that is expected in certain cases, according the aforementioned [section of RFC 7230](https://tools.ietf.org/html/rfc7230#section-5.4). When the header is not set the attribute MUST NOT be set.
     *
     * @deprecated Use ATTR_HTTP_HOST in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_HOST = TMP_HTTP_HOST;
    /**
     * The URI scheme identifying the used protocol.
     *
     * @deprecated Use ATTR_HTTP_SCHEME in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_SCHEME = TMP_HTTP_SCHEME;
    /**
     * [HTTP response status code](https://tools.ietf.org/html/rfc7231#section-6).
     *
     * @deprecated Use ATTR_HTTP_STATUS_CODE in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_STATUS_CODE = TMP_HTTP_STATUS_CODE;
    /**
     * Value of the [HTTP User-Agent](https://tools.ietf.org/html/rfc7231#section-5.5.3) header sent by the client.
     *
     * @deprecated Use ATTR_HTTP_USER_AGENT in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_USER_AGENT = TMP_HTTP_USER_AGENT;
    /**
     * The size of the request payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the [Content-Length](https://tools.ietf.org/html/rfc7230#section-3.3.2) header. For requests using transport encoding, this should be the compressed size.
     *
     * @deprecated Use ATTR_HTTP_REQUEST_CONTENT_LENGTH in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH = TMP_HTTP_REQUEST_CONTENT_LENGTH;
    /**
     * The size of the uncompressed request payload body after transport decoding. Not set if transport encoding not used.
     *
     * @deprecated Use ATTR_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED = TMP_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED;
    /**
     * The size of the response payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the [Content-Length](https://tools.ietf.org/html/rfc7230#section-3.3.2) header. For requests using transport encoding, this should be the compressed size.
     *
     * @deprecated Use ATTR_HTTP_RESPONSE_CONTENT_LENGTH in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH = TMP_HTTP_RESPONSE_CONTENT_LENGTH;
    /**
     * The size of the uncompressed response payload body after transport decoding. Not set if transport encoding not used.
     *
     * @deprecated Use ATTR_HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED = TMP_HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED;

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var TMP_PROCESS_RUNTIME_NAME = 'process.runtime.name';
    var TMP_SERVICE_NAME = 'service.name';
    var TMP_TELEMETRY_SDK_NAME = 'telemetry.sdk.name';
    var TMP_TELEMETRY_SDK_LANGUAGE = 'telemetry.sdk.language';
    var TMP_TELEMETRY_SDK_VERSION = 'telemetry.sdk.version';
    /**
     * The name of the runtime of this process. For compiled native binaries, this SHOULD be the name of the compiler.
     *
     * @deprecated Use ATTR_PROCESS_RUNTIME_NAME in [incubating entry-point]({@link https://github.com/open-telemetry/opentelemetry-js/blob/main/semantic-conventions/README.md#unstable-semconv}).
     */
    var SEMRESATTRS_PROCESS_RUNTIME_NAME = TMP_PROCESS_RUNTIME_NAME;
    /**
     * Logical name of the service.
     *
     * Note: MUST be the same for all instances of horizontally scaled services. If the value was not specified, SDKs MUST fallback to `unknown_service:` concatenated with [`process.executable.name`](process.md#process), e.g. `unknown_service:bash`. If `process.executable.name` is not available, the value MUST be set to `unknown_service`.
     *
     * @deprecated Use ATTR_SERVICE_NAME.
     */
    var SEMRESATTRS_SERVICE_NAME = TMP_SERVICE_NAME;
    /**
     * The name of the telemetry SDK as defined above.
     *
     * @deprecated Use ATTR_TELEMETRY_SDK_NAME.
     */
    var SEMRESATTRS_TELEMETRY_SDK_NAME = TMP_TELEMETRY_SDK_NAME;
    /**
     * The language of the telemetry SDK.
     *
     * @deprecated Use ATTR_TELEMETRY_SDK_LANGUAGE.
     */
    var SEMRESATTRS_TELEMETRY_SDK_LANGUAGE = TMP_TELEMETRY_SDK_LANGUAGE;
    /**
     * The version string of the telemetry SDK.
     *
     * @deprecated Use ATTR_TELEMETRY_SDK_VERSION.
     */
    var SEMRESATTRS_TELEMETRY_SDK_VERSION = TMP_TELEMETRY_SDK_VERSION;
    var TMP_TELEMETRYSDKLANGUAGEVALUES_WEBJS = 'webjs';
    /**
     * The language of the telemetry SDK.
     *
     * @deprecated Use TELEMETRY_SDK_LANGUAGE_VALUE_WEBJS.
     */
    var TELEMETRYSDKLANGUAGEVALUES_WEBJS = TMP_TELEMETRYSDKLANGUAGEVALUES_WEBJS;

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    //----------------------------------------------------------------------------------------------------------
    // DO NOT EDIT, this is an Auto-generated file from scripts/semconv/templates/registry/stable/attributes.ts.j2
    //----------------------------------------------------------------------------------------------------------
    /**
     * Rate-limiting result, shows whether the lease was acquired or contains a rejection reason
     *
     * @example acquired
     * @example request_canceled
     */
    /**
     * The language of the telemetry SDK.
     */
    var ATTR_TELEMETRY_SDK_LANGUAGE = 'telemetry.sdk.language';
    /**
     * The name of the telemetry SDK as defined above.
     *
     * @example opentelemetry
     *
     * @note The OpenTelemetry SDK **MUST** set the `telemetry.sdk.name` attribute to `opentelemetry`.
     * If another SDK, like a fork or a vendor-provided implementation, is used, this SDK **MUST** set the
     * `telemetry.sdk.name` attribute to the fully-qualified class or module name of this SDK's main entry point
     * or another suitable identifier depending on the language.
     * The identifier `opentelemetry` is reserved and **MUST NOT** be used in this case.
     * All custom identifiers **SHOULD** be stable across different versions of an implementation.
     */
    var ATTR_TELEMETRY_SDK_NAME = 'telemetry.sdk.name';
    /**
     * The version string of the telemetry SDK.
     *
     * @example 1.2.3
     */
    var ATTR_TELEMETRY_SDK_VERSION = 'telemetry.sdk.version';
    /**
     * The exception message.
     *
     * @example Division by zero
     * @example Can't convert 'int' object to str implicitly
     */
    var ATTR_EXCEPTION_MESSAGE = 'exception.message';
    /**
     * A stacktrace as a string in the natural representation for the language runtime. The representation is to be determined and documented by each language SIG.
     *
     * @example "Exception in thread "main" java.lang.RuntimeException: Test exception\\n at com.example.GenerateTrace.methodB(GenerateTrace.java:13)\\n at com.example.GenerateTrace.methodA(GenerateTrace.java:9)\\n at com.example.GenerateTrace.main(GenerateTrace.java:5)\\n"
     */
    var ATTR_EXCEPTION_STACKTRACE = 'exception.stacktrace';
    /**
     * The type of the exception (its fully-qualified class name, if applicable). The dynamic type of the exception should be preferred over the static type in languages that support it.
     *
     * @example java.net.ConnectException
     * @example OSError
     */
    var ATTR_EXCEPTION_TYPE = 'exception.type';
    /**
     * HTTP request method.
     *
     * @example GET
     * @example POST
     * @example HEAD
     *
     * @note HTTP request method value **SHOULD** be "known" to the instrumentation.
     * By default, this convention defines "known" methods as the ones listed in [RFC9110](https://www.rfc-editor.org/rfc/rfc9110.html#name-methods)
     * and the PATCH method defined in [RFC5789](https://www.rfc-editor.org/rfc/rfc5789.html).
     *
     * If the HTTP request method is not known to instrumentation, it **MUST** set the `http.request.method` attribute to `_OTHER`.
     *
     * If the HTTP instrumentation could end up converting valid HTTP request methods to `_OTHER`, then it **MUST** provide a way to override
     * the list of known HTTP methods. If this override is done via environment variable, then the environment variable **MUST** be named
     * OTEL_INSTRUMENTATION_HTTP_KNOWN_METHODS and support a comma-separated list of case-sensitive known HTTP methods
     * (this list **MUST** be a full override of the default known method, it is not a list of known methods in addition to the defaults).
     *
     * HTTP method names are case-sensitive and `http.request.method` attribute value **MUST** match a known HTTP method name exactly.
     * Instrumentations for specific web frameworks that consider HTTP methods to be case insensitive, **SHOULD** populate a canonical equivalent.
     * Tracing instrumentations that do so, **MUST** also set `http.request.method_original` to the original value.
     */
    var ATTR_HTTP_REQUEST_METHOD = 'http.request.method';
    /**
     * [HTTP response status code](https://tools.ietf.org/html/rfc7231#section-6).
     *
     * @example 200
     */
    var ATTR_HTTP_RESPONSE_STATUS_CODE = 'http.response.status_code';
    /**
     * Logical name of the service.
     *
     * @example shoppingcart
     *
     * @note **MUST** be the same for all instances of horizontally scaled services. If the value was not specified, SDKs **MUST** fallback to `unknown_service:` concatenated with [`process.executable.name`](process.md), e.g. `unknown_service:bash`. If `process.executable.name` is not available, the value **MUST** be set to `unknown_service`.
     */
    var ATTR_SERVICE_NAME = 'service.name';
    /**
     * Absolute URL describing a network resource according to [RFC3986](https://www.rfc-editor.org/rfc/rfc3986)
     *
     * @example https://www.foo.bar/search?q=OpenTelemetry#SemConv
     * @example //localhost
     *
     * @note For network calls, URL usually has `scheme://host[:port][path][?query][#fragment]` format, where the fragment is not transmitted over HTTP, but if it is known, it **SHOULD** be included nevertheless.
     * `url.full` **MUST NOT** contain credentials passed via URL in form of `https://username:password@www.example.com/`. In such case username and password **SHOULD** be redacted and attribute's value **SHOULD** be `https://REDACTED:REDACTED@www.example.com/`.
     * `url.full` **SHOULD** capture the absolute URL when it is available (or can be reconstructed). Sensitive content provided in `url.full` **SHOULD** be scrubbed when instrumentations can identify it.
     */
    var ATTR_URL_FULL = 'url.full';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var SUPPRESS_TRACING_KEY = createContextKey('OpenTelemetry SDK Context Key SUPPRESS_TRACING');
    function suppressTracing(context) {
        return context.setValue(SUPPRESS_TRACING_KEY, true);
    }
    function isTracingSuppressed(context) {
        return context.getValue(SUPPRESS_TRACING_KEY) === true;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var BAGGAGE_KEY_PAIR_SEPARATOR = '=';
    var BAGGAGE_PROPERTIES_SEPARATOR = ';';
    var BAGGAGE_ITEMS_SEPARATOR = ',';
    // Name of the http header used to propagate the baggage
    var BAGGAGE_HEADER = 'baggage';
    // Maximum number of name-value pairs allowed by w3c spec
    var BAGGAGE_MAX_NAME_VALUE_PAIRS = 180;
    // Maximum number of bytes per a single name-value pair allowed by w3c spec
    var BAGGAGE_MAX_PER_NAME_VALUE_PAIRS = 4096;
    // Maximum total length of all name-value pairs allowed by w3c spec
    var BAGGAGE_MAX_TOTAL_LENGTH = 8192;

    var __read$i = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    function serializeKeyPairs(keyPairs) {
        return keyPairs.reduce(function (hValue, current) {
            var value = "" + hValue + (hValue !== '' ? BAGGAGE_ITEMS_SEPARATOR : '') + current;
            return value.length > BAGGAGE_MAX_TOTAL_LENGTH ? hValue : value;
        }, '');
    }
    function getKeyPairs(baggage) {
        return baggage.getAllEntries().map(function (_a) {
            var _b = __read$i(_a, 2), key = _b[0], value = _b[1];
            var entry = encodeURIComponent(key) + "=" + encodeURIComponent(value.value);
            // include opaque metadata if provided
            // NOTE: we intentionally don't URI-encode the metadata - that responsibility falls on the metadata implementation
            if (value.metadata !== undefined) {
                entry += BAGGAGE_PROPERTIES_SEPARATOR + value.metadata.toString();
            }
            return entry;
        });
    }
    function parsePairKeyValue(entry) {
        var valueProps = entry.split(BAGGAGE_PROPERTIES_SEPARATOR);
        if (valueProps.length <= 0)
            return;
        var keyPairPart = valueProps.shift();
        if (!keyPairPart)
            return;
        var separatorIndex = keyPairPart.indexOf(BAGGAGE_KEY_PAIR_SEPARATOR);
        if (separatorIndex <= 0)
            return;
        var key = decodeURIComponent(keyPairPart.substring(0, separatorIndex).trim());
        var value = decodeURIComponent(keyPairPart.substring(separatorIndex + 1).trim());
        var metadata;
        if (valueProps.length > 0) {
            metadata = baggageEntryMetadataFromString(valueProps.join(BAGGAGE_PROPERTIES_SEPARATOR));
        }
        return { key: key, value: value, metadata: metadata };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Propagates {@link Baggage} through Context format propagation.
     *
     * Based on the Baggage specification:
     * https://w3c.github.io/baggage/
     */
    var W3CBaggagePropagator = /** @class */ (function () {
        function W3CBaggagePropagator() {
        }
        W3CBaggagePropagator.prototype.inject = function (context, carrier, setter) {
            var baggage = propagation.getBaggage(context);
            if (!baggage || isTracingSuppressed(context))
                return;
            var keyPairs = getKeyPairs(baggage)
                .filter(function (pair) {
                return pair.length <= BAGGAGE_MAX_PER_NAME_VALUE_PAIRS;
            })
                .slice(0, BAGGAGE_MAX_NAME_VALUE_PAIRS);
            var headerValue = serializeKeyPairs(keyPairs);
            if (headerValue.length > 0) {
                setter.set(carrier, BAGGAGE_HEADER, headerValue);
            }
        };
        W3CBaggagePropagator.prototype.extract = function (context, carrier, getter) {
            var headerValue = getter.get(carrier, BAGGAGE_HEADER);
            var baggageString = Array.isArray(headerValue)
                ? headerValue.join(BAGGAGE_ITEMS_SEPARATOR)
                : headerValue;
            if (!baggageString)
                return context;
            var baggage = {};
            if (baggageString.length === 0) {
                return context;
            }
            var pairs = baggageString.split(BAGGAGE_ITEMS_SEPARATOR);
            pairs.forEach(function (entry) {
                var keyPair = parsePairKeyValue(entry);
                if (keyPair) {
                    var baggageEntry = { value: keyPair.value };
                    if (keyPair.metadata) {
                        baggageEntry.metadata = keyPair.metadata;
                    }
                    baggage[keyPair.key] = baggageEntry;
                }
            });
            if (Object.entries(baggage).length === 0) {
                return context;
            }
            return propagation.setBaggage(context, propagation.createBaggage(baggage));
        };
        W3CBaggagePropagator.prototype.fields = function () {
            return [BAGGAGE_HEADER];
        };
        return W3CBaggagePropagator;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$b = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$h = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    function sanitizeAttributes(attributes) {
        var e_1, _a;
        var out = {};
        if (typeof attributes !== 'object' || attributes == null) {
            return out;
        }
        try {
            for (var _b = __values$b(Object.entries(attributes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var _d = __read$h(_c.value, 2), key = _d[0], val = _d[1];
                if (!isAttributeKey(key)) {
                    diag.warn("Invalid attribute key: " + key);
                    continue;
                }
                if (!isAttributeValue(val)) {
                    diag.warn("Invalid attribute value set for key: " + key);
                    continue;
                }
                if (Array.isArray(val)) {
                    out[key] = val.slice();
                }
                else {
                    out[key] = val;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return out;
    }
    function isAttributeKey(key) {
        return typeof key === 'string' && key.length > 0;
    }
    function isAttributeValue(val) {
        if (val == null) {
            return true;
        }
        if (Array.isArray(val)) {
            return isHomogeneousAttributeValueArray(val);
        }
        return isValidPrimitiveAttributeValue(val);
    }
    function isHomogeneousAttributeValueArray(arr) {
        var e_2, _a;
        var type;
        try {
            for (var arr_1 = __values$b(arr), arr_1_1 = arr_1.next(); !arr_1_1.done; arr_1_1 = arr_1.next()) {
                var element = arr_1_1.value;
                // null/undefined elements are allowed
                if (element == null)
                    continue;
                if (!type) {
                    if (isValidPrimitiveAttributeValue(element)) {
                        type = typeof element;
                        continue;
                    }
                    // encountered an invalid primitive
                    return false;
                }
                if (typeof element === type) {
                    continue;
                }
                return false;
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (arr_1_1 && !arr_1_1.done && (_a = arr_1.return)) _a.call(arr_1);
            }
            finally { if (e_2) throw e_2.error; }
        }
        return true;
    }
    function isValidPrimitiveAttributeValue(val) {
        switch (typeof val) {
            case 'number':
            case 'boolean':
            case 'string':
                return true;
        }
        return false;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Returns a function that logs an error using the provided logger, or a
     * console logger if one was not provided.
     */
    function loggingErrorHandler() {
        return function (ex) {
            diag.error(stringifyException(ex));
        };
    }
    /**
     * Converts an exception into a string representation
     * @param {Exception} ex
     */
    function stringifyException(ex) {
        if (typeof ex === 'string') {
            return ex;
        }
        else {
            return JSON.stringify(flattenException(ex));
        }
    }
    /**
     * Flattens an exception into key-value pairs by traversing the prototype chain
     * and coercing values to strings. Duplicate properties will not be overwritten;
     * the first insert wins.
     */
    function flattenException(ex) {
        var result = {};
        var current = ex;
        while (current !== null) {
            Object.getOwnPropertyNames(current).forEach(function (propertyName) {
                if (result[propertyName])
                    return;
                var value = current[propertyName];
                if (value) {
                    result[propertyName] = String(value);
                }
            });
            current = Object.getPrototypeOf(current);
        }
        return result;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** The global error handler delegate */
    var delegateHandler = loggingErrorHandler();
    /**
     * Return the global error handler
     * @param {Exception} ex
     */
    function globalErrorHandler(ex) {
        try {
            delegateHandler(ex);
        }
        catch (_a) { } // eslint-disable-line no-empty
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var TracesSamplerValues;
    (function (TracesSamplerValues) {
        TracesSamplerValues["AlwaysOff"] = "always_off";
        TracesSamplerValues["AlwaysOn"] = "always_on";
        TracesSamplerValues["ParentBasedAlwaysOff"] = "parentbased_always_off";
        TracesSamplerValues["ParentBasedAlwaysOn"] = "parentbased_always_on";
        TracesSamplerValues["ParentBasedTraceIdRatio"] = "parentbased_traceidratio";
        TracesSamplerValues["TraceIdRatio"] = "traceidratio";
    })(TracesSamplerValues || (TracesSamplerValues = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var DEFAULT_LIST_SEPARATOR = ',';
    /**
     * Environment interface to define all names
     */
    var ENVIRONMENT_BOOLEAN_KEYS = ['OTEL_SDK_DISABLED'];
    function isEnvVarABoolean(key) {
        return (ENVIRONMENT_BOOLEAN_KEYS.indexOf(key) > -1);
    }
    var ENVIRONMENT_NUMBERS_KEYS = [
        'OTEL_BSP_EXPORT_TIMEOUT',
        'OTEL_BSP_MAX_EXPORT_BATCH_SIZE',
        'OTEL_BSP_MAX_QUEUE_SIZE',
        'OTEL_BSP_SCHEDULE_DELAY',
        'OTEL_BLRP_EXPORT_TIMEOUT',
        'OTEL_BLRP_MAX_EXPORT_BATCH_SIZE',
        'OTEL_BLRP_MAX_QUEUE_SIZE',
        'OTEL_BLRP_SCHEDULE_DELAY',
        'OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT',
        'OTEL_ATTRIBUTE_COUNT_LIMIT',
        'OTEL_SPAN_ATTRIBUTE_VALUE_LENGTH_LIMIT',
        'OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT',
        'OTEL_LOGRECORD_ATTRIBUTE_VALUE_LENGTH_LIMIT',
        'OTEL_LOGRECORD_ATTRIBUTE_COUNT_LIMIT',
        'OTEL_SPAN_EVENT_COUNT_LIMIT',
        'OTEL_SPAN_LINK_COUNT_LIMIT',
        'OTEL_SPAN_ATTRIBUTE_PER_EVENT_COUNT_LIMIT',
        'OTEL_SPAN_ATTRIBUTE_PER_LINK_COUNT_LIMIT',
        'OTEL_EXPORTER_OTLP_TIMEOUT',
        'OTEL_EXPORTER_OTLP_TRACES_TIMEOUT',
        'OTEL_EXPORTER_OTLP_METRICS_TIMEOUT',
        'OTEL_EXPORTER_OTLP_LOGS_TIMEOUT',
        'OTEL_EXPORTER_JAEGER_AGENT_PORT',
    ];
    function isEnvVarANumber(key) {
        return (ENVIRONMENT_NUMBERS_KEYS.indexOf(key) > -1);
    }
    var ENVIRONMENT_LISTS_KEYS = [
        'OTEL_NO_PATCH_MODULES',
        'OTEL_PROPAGATORS',
        'OTEL_SEMCONV_STABILITY_OPT_IN',
    ];
    function isEnvVarAList(key) {
        return ENVIRONMENT_LISTS_KEYS.indexOf(key) > -1;
    }
    var DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT = Infinity;
    var DEFAULT_ATTRIBUTE_COUNT_LIMIT = 128;
    var DEFAULT_SPAN_ATTRIBUTE_PER_EVENT_COUNT_LIMIT = 128;
    var DEFAULT_SPAN_ATTRIBUTE_PER_LINK_COUNT_LIMIT = 128;
    /**
     * Default environment variables
     */
    var DEFAULT_ENVIRONMENT = {
        OTEL_SDK_DISABLED: false,
        CONTAINER_NAME: '',
        ECS_CONTAINER_METADATA_URI_V4: '',
        ECS_CONTAINER_METADATA_URI: '',
        HOSTNAME: '',
        KUBERNETES_SERVICE_HOST: '',
        NAMESPACE: '',
        OTEL_BSP_EXPORT_TIMEOUT: 30000,
        OTEL_BSP_MAX_EXPORT_BATCH_SIZE: 512,
        OTEL_BSP_MAX_QUEUE_SIZE: 2048,
        OTEL_BSP_SCHEDULE_DELAY: 5000,
        OTEL_BLRP_EXPORT_TIMEOUT: 30000,
        OTEL_BLRP_MAX_EXPORT_BATCH_SIZE: 512,
        OTEL_BLRP_MAX_QUEUE_SIZE: 2048,
        OTEL_BLRP_SCHEDULE_DELAY: 5000,
        OTEL_EXPORTER_JAEGER_AGENT_HOST: '',
        OTEL_EXPORTER_JAEGER_AGENT_PORT: 6832,
        OTEL_EXPORTER_JAEGER_ENDPOINT: '',
        OTEL_EXPORTER_JAEGER_PASSWORD: '',
        OTEL_EXPORTER_JAEGER_USER: '',
        OTEL_EXPORTER_OTLP_ENDPOINT: '',
        OTEL_EXPORTER_OTLP_TRACES_ENDPOINT: '',
        OTEL_EXPORTER_OTLP_METRICS_ENDPOINT: '',
        OTEL_EXPORTER_OTLP_LOGS_ENDPOINT: '',
        OTEL_EXPORTER_OTLP_HEADERS: '',
        OTEL_EXPORTER_OTLP_TRACES_HEADERS: '',
        OTEL_EXPORTER_OTLP_METRICS_HEADERS: '',
        OTEL_EXPORTER_OTLP_LOGS_HEADERS: '',
        OTEL_EXPORTER_OTLP_TIMEOUT: 10000,
        OTEL_EXPORTER_OTLP_TRACES_TIMEOUT: 10000,
        OTEL_EXPORTER_OTLP_METRICS_TIMEOUT: 10000,
        OTEL_EXPORTER_OTLP_LOGS_TIMEOUT: 10000,
        OTEL_EXPORTER_ZIPKIN_ENDPOINT: 'http://localhost:9411/api/v2/spans',
        OTEL_LOG_LEVEL: DiagLogLevel.INFO,
        OTEL_NO_PATCH_MODULES: [],
        OTEL_PROPAGATORS: ['tracecontext', 'baggage'],
        OTEL_RESOURCE_ATTRIBUTES: '',
        OTEL_SERVICE_NAME: '',
        OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT: DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT,
        OTEL_ATTRIBUTE_COUNT_LIMIT: DEFAULT_ATTRIBUTE_COUNT_LIMIT,
        OTEL_SPAN_ATTRIBUTE_VALUE_LENGTH_LIMIT: DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT,
        OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT: DEFAULT_ATTRIBUTE_COUNT_LIMIT,
        OTEL_LOGRECORD_ATTRIBUTE_VALUE_LENGTH_LIMIT: DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT,
        OTEL_LOGRECORD_ATTRIBUTE_COUNT_LIMIT: DEFAULT_ATTRIBUTE_COUNT_LIMIT,
        OTEL_SPAN_EVENT_COUNT_LIMIT: 128,
        OTEL_SPAN_LINK_COUNT_LIMIT: 128,
        OTEL_SPAN_ATTRIBUTE_PER_EVENT_COUNT_LIMIT: DEFAULT_SPAN_ATTRIBUTE_PER_EVENT_COUNT_LIMIT,
        OTEL_SPAN_ATTRIBUTE_PER_LINK_COUNT_LIMIT: DEFAULT_SPAN_ATTRIBUTE_PER_LINK_COUNT_LIMIT,
        OTEL_TRACES_EXPORTER: '',
        OTEL_TRACES_SAMPLER: TracesSamplerValues.ParentBasedAlwaysOn,
        OTEL_TRACES_SAMPLER_ARG: '',
        OTEL_LOGS_EXPORTER: '',
        OTEL_EXPORTER_OTLP_INSECURE: '',
        OTEL_EXPORTER_OTLP_TRACES_INSECURE: '',
        OTEL_EXPORTER_OTLP_METRICS_INSECURE: '',
        OTEL_EXPORTER_OTLP_LOGS_INSECURE: '',
        OTEL_EXPORTER_OTLP_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_TRACES_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_METRICS_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_LOGS_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_COMPRESSION: '',
        OTEL_EXPORTER_OTLP_TRACES_COMPRESSION: '',
        OTEL_EXPORTER_OTLP_METRICS_COMPRESSION: '',
        OTEL_EXPORTER_OTLP_LOGS_COMPRESSION: '',
        OTEL_EXPORTER_OTLP_CLIENT_KEY: '',
        OTEL_EXPORTER_OTLP_TRACES_CLIENT_KEY: '',
        OTEL_EXPORTER_OTLP_METRICS_CLIENT_KEY: '',
        OTEL_EXPORTER_OTLP_LOGS_CLIENT_KEY: '',
        OTEL_EXPORTER_OTLP_CLIENT_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_TRACES_CLIENT_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_METRICS_CLIENT_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_LOGS_CLIENT_CERTIFICATE: '',
        OTEL_EXPORTER_OTLP_PROTOCOL: 'http/protobuf',
        OTEL_EXPORTER_OTLP_TRACES_PROTOCOL: 'http/protobuf',
        OTEL_EXPORTER_OTLP_METRICS_PROTOCOL: 'http/protobuf',
        OTEL_EXPORTER_OTLP_LOGS_PROTOCOL: 'http/protobuf',
        OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE: 'cumulative',
        OTEL_SEMCONV_STABILITY_OPT_IN: [],
    };
    /**
     * @param key
     * @param environment
     * @param values
     */
    function parseBoolean(key, environment, values) {
        if (typeof values[key] === 'undefined') {
            return;
        }
        var value = String(values[key]);
        // support case-insensitive "true"
        environment[key] = value.toLowerCase() === 'true';
    }
    /**
     * Parses a variable as number with number validation
     * @param name
     * @param environment
     * @param values
     * @param min
     * @param max
     */
    function parseNumber(name, environment, values, min, max) {
        if (min === void 0) { min = -Infinity; }
        if (max === void 0) { max = Infinity; }
        if (typeof values[name] !== 'undefined') {
            var value = Number(values[name]);
            if (!isNaN(value)) {
                if (value < min) {
                    environment[name] = min;
                }
                else if (value > max) {
                    environment[name] = max;
                }
                else {
                    environment[name] = value;
                }
            }
        }
    }
    /**
     * Parses list-like strings from input into output.
     * @param name
     * @param environment
     * @param values
     * @param separator
     */
    function parseStringList(name, output, input, separator) {
        if (separator === void 0) { separator = DEFAULT_LIST_SEPARATOR; }
        var givenValue = input[name];
        if (typeof givenValue === 'string') {
            output[name] = givenValue.split(separator).map(function (v) { return v.trim(); });
        }
    }
    // The support string -> DiagLogLevel mappings
    var logLevelMap = {
        ALL: DiagLogLevel.ALL,
        VERBOSE: DiagLogLevel.VERBOSE,
        DEBUG: DiagLogLevel.DEBUG,
        INFO: DiagLogLevel.INFO,
        WARN: DiagLogLevel.WARN,
        ERROR: DiagLogLevel.ERROR,
        NONE: DiagLogLevel.NONE,
    };
    /**
     * Environmentally sets log level if valid log level string is provided
     * @param key
     * @param environment
     * @param values
     */
    function setLogLevelFromEnv(key, environment, values) {
        var value = values[key];
        if (typeof value === 'string') {
            var theLevel = logLevelMap[value.toUpperCase()];
            if (theLevel != null) {
                environment[key] = theLevel;
            }
        }
    }
    /**
     * Parses environment values
     * @param values
     */
    function parseEnvironment(values) {
        var environment = {};
        for (var env in DEFAULT_ENVIRONMENT) {
            var key = env;
            switch (key) {
                case 'OTEL_LOG_LEVEL':
                    setLogLevelFromEnv(key, environment, values);
                    break;
                default:
                    if (isEnvVarABoolean(key)) {
                        parseBoolean(key, environment, values);
                    }
                    else if (isEnvVarANumber(key)) {
                        parseNumber(key, environment, values);
                    }
                    else if (isEnvVarAList(key)) {
                        parseStringList(key, environment, values);
                    }
                    else {
                        var value = values[key];
                        if (typeof value !== 'undefined' && value !== null) {
                            environment[key] = String(value);
                        }
                    }
            }
        }
        return environment;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Updates to this file should also be replicated to @opentelemetry/api too.
    /**
     * - globalThis (New standard)
     * - self (Will return the current window instance for supported browsers)
     * - window (fallback for older browser implementations)
     * - global (NodeJS implementation)
     * - <object> (When all else fails)
     */
    /** only globals that common to node and browsers are allowed */
    // eslint-disable-next-line node/no-unsupported-features/es-builtins, no-undef
    var _globalThis$1 = typeof globalThis === 'object'
        ? globalThis
        : typeof self === 'object'
            ? self
            : typeof window === 'object'
                ? window
                : typeof global === 'object'
                    ? global
                    : {};

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Gets the environment variables
     */
    function getEnv() {
        var globalEnv = parseEnvironment(_globalThis$1);
        return Object.assign({}, DEFAULT_ENVIRONMENT, globalEnv);
    }
    function getEnvWithoutDefaults() {
        return parseEnvironment(_globalThis$1);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function intValue(charCode) {
        // 0-9
        if (charCode >= 48 && charCode <= 57) {
            return charCode - 48;
        }
        // a-f
        if (charCode >= 97 && charCode <= 102) {
            return charCode - 87;
        }
        // A-F
        return charCode - 55;
    }
    function hexToBinary(hexStr) {
        var buf = new Uint8Array(hexStr.length / 2);
        var offset = 0;
        for (var i = 0; i < hexStr.length; i += 2) {
            var hi = intValue(hexStr.charCodeAt(i));
            var lo = intValue(hexStr.charCodeAt(i + 1));
            buf[offset++] = (hi << 4) | lo;
        }
        return buf;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var otperformance = performance;

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // this is autogenerated file, see scripts/version-update.js
    var VERSION$3 = '1.30.0';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var _a$1;
    /** Constants describing the SDK in use */
    var SDK_INFO = (_a$1 = {},
        _a$1[SEMRESATTRS_TELEMETRY_SDK_NAME] = 'opentelemetry',
        _a$1[SEMRESATTRS_PROCESS_RUNTIME_NAME] = 'browser',
        _a$1[SEMRESATTRS_TELEMETRY_SDK_LANGUAGE] = TELEMETRYSDKLANGUAGEVALUES_WEBJS,
        _a$1[SEMRESATTRS_TELEMETRY_SDK_VERSION] = VERSION$3,
        _a$1);

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function unrefTimer(_timer) { }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NANOSECOND_DIGITS = 9;
    var NANOSECOND_DIGITS_IN_MILLIS = 6;
    var MILLISECONDS_TO_NANOSECONDS = Math.pow(10, NANOSECOND_DIGITS_IN_MILLIS);
    var SECOND_TO_NANOSECONDS = Math.pow(10, NANOSECOND_DIGITS);
    /**
     * Converts a number of milliseconds from epoch to HrTime([seconds, remainder in nanoseconds]).
     * @param epochMillis
     */
    function millisToHrTime(epochMillis) {
        var epochSeconds = epochMillis / 1000;
        // Decimals only.
        var seconds = Math.trunc(epochSeconds);
        // Round sub-nanosecond accuracy to nanosecond.
        var nanos = Math.round((epochMillis % 1000) * MILLISECONDS_TO_NANOSECONDS);
        return [seconds, nanos];
    }
    function getTimeOrigin() {
        var timeOrigin = otperformance.timeOrigin;
        if (typeof timeOrigin !== 'number') {
            var perf = otperformance;
            timeOrigin = perf.timing && perf.timing.fetchStart;
        }
        return timeOrigin;
    }
    /**
     * Returns an hrtime calculated via performance component.
     * @param performanceNow
     */
    function hrTime(performanceNow) {
        var timeOrigin = millisToHrTime(getTimeOrigin());
        var now = millisToHrTime(typeof performanceNow === 'number' ? performanceNow : otperformance.now());
        return addHrTimes(timeOrigin, now);
    }
    /**
     *
     * Converts a TimeInput to an HrTime, defaults to _hrtime().
     * @param time
     */
    function timeInputToHrTime(time) {
        // process.hrtime
        if (isTimeInputHrTime(time)) {
            return time;
        }
        else if (typeof time === 'number') {
            // Must be a performance.now() if it's smaller than process start time.
            if (time < getTimeOrigin()) {
                return hrTime(time);
            }
            else {
                // epoch milliseconds or performance.timeOrigin
                return millisToHrTime(time);
            }
        }
        else if (time instanceof Date) {
            return millisToHrTime(time.getTime());
        }
        else {
            throw TypeError('Invalid input type');
        }
    }
    /**
     * Returns a duration of two hrTime.
     * @param startTime
     * @param endTime
     */
    function hrTimeDuration(startTime, endTime) {
        var seconds = endTime[0] - startTime[0];
        var nanos = endTime[1] - startTime[1];
        // overflow
        if (nanos < 0) {
            seconds -= 1;
            // negate
            nanos += SECOND_TO_NANOSECONDS;
        }
        return [seconds, nanos];
    }
    /**
     * Convert hrTime to nanoseconds.
     * @param time
     */
    function hrTimeToNanoseconds(time) {
        return time[0] * SECOND_TO_NANOSECONDS + time[1];
    }
    /**
     * Convert hrTime to milliseconds.
     * @param time
     */
    function hrTimeToMilliseconds(time) {
        return time[0] * 1e3 + time[1] / 1e6;
    }
    /**
     * check if time is HrTime
     * @param value
     */
    function isTimeInputHrTime(value) {
        return (Array.isArray(value) &&
            value.length === 2 &&
            typeof value[0] === 'number' &&
            typeof value[1] === 'number');
    }
    /**
     * check if input value is a correct types.TimeInput
     * @param value
     */
    function isTimeInput(value) {
        return (isTimeInputHrTime(value) ||
            typeof value === 'number' ||
            value instanceof Date);
    }
    /**
     * Given 2 HrTime formatted times, return their sum as an HrTime.
     */
    function addHrTimes(time1, time2) {
        var out = [time1[0] + time2[0], time1[1] + time2[1]];
        // Nanoseconds
        if (out[1] >= SECOND_TO_NANOSECONDS) {
            out[1] -= SECOND_TO_NANOSECONDS;
            out[0] += 1;
        }
        return out;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var ExportResultCode;
    (function (ExportResultCode) {
        ExportResultCode[ExportResultCode["SUCCESS"] = 0] = "SUCCESS";
        ExportResultCode[ExportResultCode["FAILED"] = 1] = "FAILED";
    })(ExportResultCode || (ExportResultCode = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$a = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    /** Combines multiple propagators into a single propagator. */
    var CompositePropagator = /** @class */ (function () {
        /**
         * Construct a composite propagator from a list of propagators.
         *
         * @param [config] Configuration object for composite propagator
         */
        function CompositePropagator(config) {
            if (config === void 0) { config = {}; }
            var _a;
            this._propagators = (_a = config.propagators) !== null && _a !== void 0 ? _a : [];
            this._fields = Array.from(new Set(this._propagators
                // older propagators may not have fields function, null check to be sure
                .map(function (p) { return (typeof p.fields === 'function' ? p.fields() : []); })
                .reduce(function (x, y) { return x.concat(y); }, [])));
        }
        /**
         * Run each of the configured propagators with the given context and carrier.
         * Propagators are run in the order they are configured, so if multiple
         * propagators write the same carrier key, the propagator later in the list
         * will "win".
         *
         * @param context Context to inject
         * @param carrier Carrier into which context will be injected
         */
        CompositePropagator.prototype.inject = function (context, carrier, setter) {
            var e_1, _a;
            try {
                for (var _b = __values$a(this._propagators), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var propagator = _c.value;
                    try {
                        propagator.inject(context, carrier, setter);
                    }
                    catch (err) {
                        diag.warn("Failed to inject with " + propagator.constructor.name + ". Err: " + err.message);
                    }
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_1) throw e_1.error; }
            }
        };
        /**
         * Run each of the configured propagators with the given context and carrier.
         * Propagators are run in the order they are configured, so if multiple
         * propagators write the same context key, the propagator later in the list
         * will "win".
         *
         * @param context Context to add values to
         * @param carrier Carrier from which to extract context
         */
        CompositePropagator.prototype.extract = function (context, carrier, getter) {
            return this._propagators.reduce(function (ctx, propagator) {
                try {
                    return propagator.extract(ctx, carrier, getter);
                }
                catch (err) {
                    diag.warn("Failed to extract with " + propagator.constructor.name + ". Err: " + err.message);
                }
                return ctx;
            }, context);
        };
        CompositePropagator.prototype.fields = function () {
            // return a new array so our fields cannot be modified
            return this._fields.slice();
        };
        return CompositePropagator;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var VALID_KEY_CHAR_RANGE = '[_0-9a-z-*/]';
    var VALID_KEY = "[a-z]" + VALID_KEY_CHAR_RANGE + "{0,255}";
    var VALID_VENDOR_KEY = "[a-z0-9]" + VALID_KEY_CHAR_RANGE + "{0,240}@[a-z]" + VALID_KEY_CHAR_RANGE + "{0,13}";
    var VALID_KEY_REGEX = new RegExp("^(?:" + VALID_KEY + "|" + VALID_VENDOR_KEY + ")$");
    var VALID_VALUE_BASE_REGEX = /^[ -~]{0,255}[!-~]$/;
    var INVALID_VALUE_COMMA_EQUAL_REGEX = /,|=/;
    /**
     * Key is opaque string up to 256 characters printable. It MUST begin with a
     * lowercase letter, and can only contain lowercase letters a-z, digits 0-9,
     * underscores _, dashes -, asterisks *, and forward slashes /.
     * For multi-tenant vendor scenarios, an at sign (@) can be used to prefix the
     * vendor name. Vendors SHOULD set the tenant ID at the beginning of the key.
     * see https://www.w3.org/TR/trace-context/#key
     */
    function validateKey(key) {
        return VALID_KEY_REGEX.test(key);
    }
    /**
     * Value is opaque string up to 256 characters printable ASCII RFC0020
     * characters (i.e., the range 0x20 to 0x7E) except comma , and =.
     */
    function validateValue(value) {
        return (VALID_VALUE_BASE_REGEX.test(value) &&
            !INVALID_VALUE_COMMA_EQUAL_REGEX.test(value));
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var MAX_TRACE_STATE_ITEMS = 32;
    var MAX_TRACE_STATE_LEN = 512;
    var LIST_MEMBERS_SEPARATOR = ',';
    var LIST_MEMBER_KEY_VALUE_SPLITTER = '=';
    /**
     * TraceState must be a class and not a simple object type because of the spec
     * requirement (https://www.w3.org/TR/trace-context/#tracestate-field).
     *
     * Here is the list of allowed mutations:
     * - New key-value pair should be added into the beginning of the list
     * - The value of any key can be updated. Modified keys MUST be moved to the
     * beginning of the list.
     */
    var TraceState = /** @class */ (function () {
        function TraceState(rawTraceState) {
            this._internalState = new Map();
            if (rawTraceState)
                this._parse(rawTraceState);
        }
        TraceState.prototype.set = function (key, value) {
            // TODO: Benchmark the different approaches(map vs list) and
            // use the faster one.
            var traceState = this._clone();
            if (traceState._internalState.has(key)) {
                traceState._internalState.delete(key);
            }
            traceState._internalState.set(key, value);
            return traceState;
        };
        TraceState.prototype.unset = function (key) {
            var traceState = this._clone();
            traceState._internalState.delete(key);
            return traceState;
        };
        TraceState.prototype.get = function (key) {
            return this._internalState.get(key);
        };
        TraceState.prototype.serialize = function () {
            var _this = this;
            return this._keys()
                .reduce(function (agg, key) {
                agg.push(key + LIST_MEMBER_KEY_VALUE_SPLITTER + _this.get(key));
                return agg;
            }, [])
                .join(LIST_MEMBERS_SEPARATOR);
        };
        TraceState.prototype._parse = function (rawTraceState) {
            if (rawTraceState.length > MAX_TRACE_STATE_LEN)
                return;
            this._internalState = rawTraceState
                .split(LIST_MEMBERS_SEPARATOR)
                .reverse() // Store in reverse so new keys (.set(...)) will be placed at the beginning
                .reduce(function (agg, part) {
                var listMember = part.trim(); // Optional Whitespace (OWS) handling
                var i = listMember.indexOf(LIST_MEMBER_KEY_VALUE_SPLITTER);
                if (i !== -1) {
                    var key = listMember.slice(0, i);
                    var value = listMember.slice(i + 1, part.length);
                    if (validateKey(key) && validateValue(value)) {
                        agg.set(key, value);
                    }
                }
                return agg;
            }, new Map());
            // Because of the reverse() requirement, trunc must be done after map is created
            if (this._internalState.size > MAX_TRACE_STATE_ITEMS) {
                this._internalState = new Map(Array.from(this._internalState.entries())
                    .reverse() // Use reverse same as original tracestate parse chain
                    .slice(0, MAX_TRACE_STATE_ITEMS));
            }
        };
        TraceState.prototype._keys = function () {
            return Array.from(this._internalState.keys()).reverse();
        };
        TraceState.prototype._clone = function () {
            var traceState = new TraceState();
            traceState._internalState = new Map(this._internalState);
            return traceState;
        };
        return TraceState;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var TRACE_PARENT_HEADER = 'traceparent';
    var TRACE_STATE_HEADER = 'tracestate';
    var VERSION$2 = '00';
    var VERSION_PART = '(?!ff)[\\da-f]{2}';
    var TRACE_ID_PART = '(?![0]{32})[\\da-f]{32}';
    var PARENT_ID_PART = '(?![0]{16})[\\da-f]{16}';
    var FLAGS_PART = '[\\da-f]{2}';
    var TRACE_PARENT_REGEX = new RegExp("^\\s?(" + VERSION_PART + ")-(" + TRACE_ID_PART + ")-(" + PARENT_ID_PART + ")-(" + FLAGS_PART + ")(-.*)?\\s?$");
    /**
     * Parses information from the [traceparent] span tag and converts it into {@link SpanContext}
     * @param traceParent - A meta property that comes from server.
     *     It should be dynamically generated server side to have the server's request trace Id,
     *     a parent span Id that was set on the server's request span,
     *     and the trace flags to indicate the server's sampling decision
     *     (01 = sampled, 00 = not sampled).
     *     for example: '{version}-{traceId}-{spanId}-{sampleDecision}'
     *     For more information see {@link https://www.w3.org/TR/trace-context/}
     */
    function parseTraceParent(traceParent) {
        var match = TRACE_PARENT_REGEX.exec(traceParent);
        if (!match)
            return null;
        // According to the specification the implementation should be compatible
        // with future versions. If there are more parts, we only reject it if it's using version 00
        // See https://www.w3.org/TR/trace-context/#versioning-of-traceparent
        if (match[1] === '00' && match[5])
            return null;
        return {
            traceId: match[2],
            spanId: match[3],
            traceFlags: parseInt(match[4], 16),
        };
    }
    /**
     * Propagates {@link SpanContext} through Trace Context format propagation.
     *
     * Based on the Trace Context specification:
     * https://www.w3.org/TR/trace-context/
     */
    var W3CTraceContextPropagator = /** @class */ (function () {
        function W3CTraceContextPropagator() {
        }
        W3CTraceContextPropagator.prototype.inject = function (context, carrier, setter) {
            var spanContext = trace.getSpanContext(context);
            if (!spanContext ||
                isTracingSuppressed(context) ||
                !isSpanContextValid(spanContext))
                return;
            var traceParent = VERSION$2 + "-" + spanContext.traceId + "-" + spanContext.spanId + "-0" + Number(spanContext.traceFlags || TraceFlags.NONE).toString(16);
            setter.set(carrier, TRACE_PARENT_HEADER, traceParent);
            if (spanContext.traceState) {
                setter.set(carrier, TRACE_STATE_HEADER, spanContext.traceState.serialize());
            }
        };
        W3CTraceContextPropagator.prototype.extract = function (context, carrier, getter) {
            var traceParentHeader = getter.get(carrier, TRACE_PARENT_HEADER);
            if (!traceParentHeader)
                return context;
            var traceParent = Array.isArray(traceParentHeader)
                ? traceParentHeader[0]
                : traceParentHeader;
            if (typeof traceParent !== 'string')
                return context;
            var spanContext = parseTraceParent(traceParent);
            if (!spanContext)
                return context;
            spanContext.isRemote = true;
            var traceStateHeader = getter.get(carrier, TRACE_STATE_HEADER);
            if (traceStateHeader) {
                // If more than one `tracestate` header is found, we merge them into a
                // single header.
                var state = Array.isArray(traceStateHeader)
                    ? traceStateHeader.join(',')
                    : traceStateHeader;
                spanContext.traceState = new TraceState(typeof state === 'string' ? state : undefined);
            }
            return trace.setSpanContext(context, spanContext);
        };
        W3CTraceContextPropagator.prototype.fields = function () {
            return [TRACE_PARENT_HEADER, TRACE_STATE_HEADER];
        };
        return W3CTraceContextPropagator;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /* eslint-disable @typescript-eslint/no-explicit-any */
    /**
     * based on lodash in order to support esm builds without esModuleInterop.
     * lodash is using MIT License.
     **/
    var objectTag = '[object Object]';
    var nullTag = '[object Null]';
    var undefinedTag = '[object Undefined]';
    var funcProto = Function.prototype;
    var funcToString = funcProto.toString;
    var objectCtorString = funcToString.call(Object);
    var getPrototype = overArg(Object.getPrototypeOf, Object);
    var objectProto = Object.prototype;
    var hasOwnProperty = objectProto.hasOwnProperty;
    var symToStringTag = Symbol ? Symbol.toStringTag : undefined;
    var nativeObjectToString = objectProto.toString;
    /**
     * Creates a unary function that invokes `func` with its argument transformed.
     *
     * @private
     * @param {Function} func The function to wrap.
     * @param {Function} transform The argument transform.
     * @returns {Function} Returns the new function.
     */
    function overArg(func, transform) {
        return function (arg) {
            return func(transform(arg));
        };
    }
    /**
     * Checks if `value` is a plain object, that is, an object created by the
     * `Object` constructor or one with a `[[Prototype]]` of `null`.
     *
     * @static
     * @memberOf _
     * @since 0.8.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
     * @example
     *
     * function Foo() {
     *   this.a = 1;
     * }
     *
     * _.isPlainObject(new Foo);
     * // => false
     *
     * _.isPlainObject([1, 2, 3]);
     * // => false
     *
     * _.isPlainObject({ 'x': 0, 'y': 0 });
     * // => true
     *
     * _.isPlainObject(Object.create(null));
     * // => true
     */
    function isPlainObject(value) {
        if (!isObjectLike(value) || baseGetTag(value) !== objectTag) {
            return false;
        }
        var proto = getPrototype(value);
        if (proto === null) {
            return true;
        }
        var Ctor = hasOwnProperty.call(proto, 'constructor') && proto.constructor;
        return (typeof Ctor == 'function' &&
            Ctor instanceof Ctor &&
            funcToString.call(Ctor) === objectCtorString);
    }
    /**
     * Checks if `value` is object-like. A value is object-like if it's not `null`
     * and has a `typeof` result of "object".
     *
     * @static
     * @memberOf _
     * @since 4.0.0
     * @category Lang
     * @param {*} value The value to check.
     * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
     * @example
     *
     * _.isObjectLike({});
     * // => true
     *
     * _.isObjectLike([1, 2, 3]);
     * // => true
     *
     * _.isObjectLike(_.noop);
     * // => false
     *
     * _.isObjectLike(null);
     * // => false
     */
    function isObjectLike(value) {
        return value != null && typeof value == 'object';
    }
    /**
     * The base implementation of `getTag` without fallbacks for buggy environments.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the `toStringTag`.
     */
    function baseGetTag(value) {
        if (value == null) {
            return value === undefined ? undefinedTag : nullTag;
        }
        return symToStringTag && symToStringTag in Object(value)
            ? getRawTag(value)
            : objectToString(value);
    }
    /**
     * A specialized version of `baseGetTag` which ignores `Symbol.toStringTag` values.
     *
     * @private
     * @param {*} value The value to query.
     * @returns {string} Returns the raw `toStringTag`.
     */
    function getRawTag(value) {
        var isOwn = hasOwnProperty.call(value, symToStringTag), tag = value[symToStringTag];
        var unmasked = false;
        try {
            value[symToStringTag] = undefined;
            unmasked = true;
        }
        catch (e) {
            // silence
        }
        var result = nativeObjectToString.call(value);
        if (unmasked) {
            if (isOwn) {
                value[symToStringTag] = tag;
            }
            else {
                delete value[symToStringTag];
            }
        }
        return result;
    }
    /**
     * Converts `value` to a string using `Object.prototype.toString`.
     *
     * @private
     * @param {*} value The value to convert.
     * @returns {string} Returns the converted string.
     */
    function objectToString(value) {
        return nativeObjectToString.call(value);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /* eslint-disable @typescript-eslint/no-explicit-any */
    var MAX_LEVEL = 20;
    /**
     * Merges objects together
     * @param args - objects / values to be merged
     */
    function merge() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var result = args.shift();
        var objects = new WeakMap();
        while (args.length > 0) {
            result = mergeTwoObjects(result, args.shift(), 0, objects);
        }
        return result;
    }
    function takeValue(value) {
        if (isArray(value)) {
            return value.slice();
        }
        return value;
    }
    /**
     * Merges two objects
     * @param one - first object
     * @param two - second object
     * @param level - current deep level
     * @param objects - objects holder that has been already referenced - to prevent
     * cyclic dependency
     */
    function mergeTwoObjects(one, two, level, objects) {
        if (level === void 0) { level = 0; }
        var result;
        if (level > MAX_LEVEL) {
            return undefined;
        }
        level++;
        if (isPrimitive(one) || isPrimitive(two) || isFunction(two)) {
            result = takeValue(two);
        }
        else if (isArray(one)) {
            result = one.slice();
            if (isArray(two)) {
                for (var i = 0, j = two.length; i < j; i++) {
                    result.push(takeValue(two[i]));
                }
            }
            else if (isObject(two)) {
                var keys = Object.keys(two);
                for (var i = 0, j = keys.length; i < j; i++) {
                    var key = keys[i];
                    result[key] = takeValue(two[key]);
                }
            }
        }
        else if (isObject(one)) {
            if (isObject(two)) {
                if (!shouldMerge(one, two)) {
                    return two;
                }
                result = Object.assign({}, one);
                var keys = Object.keys(two);
                for (var i = 0, j = keys.length; i < j; i++) {
                    var key = keys[i];
                    var twoValue = two[key];
                    if (isPrimitive(twoValue)) {
                        if (typeof twoValue === 'undefined') {
                            delete result[key];
                        }
                        else {
                            // result[key] = takeValue(twoValue);
                            result[key] = twoValue;
                        }
                    }
                    else {
                        var obj1 = result[key];
                        var obj2 = twoValue;
                        if (wasObjectReferenced(one, key, objects) ||
                            wasObjectReferenced(two, key, objects)) {
                            delete result[key];
                        }
                        else {
                            if (isObject(obj1) && isObject(obj2)) {
                                var arr1 = objects.get(obj1) || [];
                                var arr2 = objects.get(obj2) || [];
                                arr1.push({ obj: one, key: key });
                                arr2.push({ obj: two, key: key });
                                objects.set(obj1, arr1);
                                objects.set(obj2, arr2);
                            }
                            result[key] = mergeTwoObjects(result[key], twoValue, level, objects);
                        }
                    }
                }
            }
            else {
                result = two;
            }
        }
        return result;
    }
    /**
     * Function to check if object has been already reference
     * @param obj
     * @param key
     * @param objects
     */
    function wasObjectReferenced(obj, key, objects) {
        var arr = objects.get(obj[key]) || [];
        for (var i = 0, j = arr.length; i < j; i++) {
            var info = arr[i];
            if (info.key === key && info.obj === obj) {
                return true;
            }
        }
        return false;
    }
    function isArray(value) {
        return Array.isArray(value);
    }
    function isFunction(value) {
        return typeof value === 'function';
    }
    function isObject(value) {
        return (!isPrimitive(value) &&
            !isArray(value) &&
            !isFunction(value) &&
            typeof value === 'object');
    }
    function isPrimitive(value) {
        return (typeof value === 'string' ||
            typeof value === 'number' ||
            typeof value === 'boolean' ||
            typeof value === 'undefined' ||
            value instanceof Date ||
            value instanceof RegExp ||
            value === null);
    }
    function shouldMerge(one, two) {
        if (!isPlainObject(one) || !isPlainObject(two)) {
            return false;
        }
        return true;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$l = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * Error that is thrown on timeouts.
     */
    var TimeoutError = /** @class */ (function (_super) {
        __extends$l(TimeoutError, _super);
        function TimeoutError(message) {
            var _this = _super.call(this, message) || this;
            // manually adjust prototype to retain `instanceof` functionality when targeting ES5, see:
            // https://github.com/Microsoft/TypeScript-wiki/blob/main/Breaking-Changes.md#extending-built-ins-like-error-array-and-map-may-no-longer-work
            Object.setPrototypeOf(_this, TimeoutError.prototype);
            return _this;
        }
        return TimeoutError;
    }(Error));
    /**
     * Adds a timeout to a promise and rejects if the specified timeout has elapsed. Also rejects if the specified promise
     * rejects, and resolves if the specified promise resolves.
     *
     * <p> NOTE: this operation will continue even after it throws a {@link TimeoutError}.
     *
     * @param promise promise to use with timeout.
     * @param timeout the timeout in milliseconds until the returned promise is rejected.
     */
    function callWithTimeout(promise, timeout) {
        var timeoutHandle;
        var timeoutPromise = new Promise(function timeoutFunction(_resolve, reject) {
            timeoutHandle = setTimeout(function timeoutHandler() {
                reject(new TimeoutError('Operation timed out.'));
            }, timeout);
        });
        return Promise.race([promise, timeoutPromise]).then(function (result) {
            clearTimeout(timeoutHandle);
            return result;
        }, function (reason) {
            clearTimeout(timeoutHandle);
            throw reason;
        });
    }

    var __values$9 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function urlMatches(url, urlToMatch) {
        if (typeof urlToMatch === 'string') {
            return url === urlToMatch;
        }
        else {
            return !!url.match(urlToMatch);
        }
    }
    /**
     * Check if {@param url} should be ignored when comparing against {@param ignoredUrls}
     * @param url
     * @param ignoredUrls
     */
    function isUrlIgnored(url, ignoredUrls) {
        var e_1, _a;
        if (!ignoredUrls) {
            return false;
        }
        try {
            for (var ignoredUrls_1 = __values$9(ignoredUrls), ignoredUrls_1_1 = ignoredUrls_1.next(); !ignoredUrls_1_1.done; ignoredUrls_1_1 = ignoredUrls_1.next()) {
                var ignoreUrl = ignoredUrls_1_1.value;
                if (urlMatches(url, ignoreUrl)) {
                    return true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (ignoredUrls_1_1 && !ignoredUrls_1_1.done && (_a = ignoredUrls_1.return)) _a.call(ignoredUrls_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return false;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var Deferred = /** @class */ (function () {
        function Deferred() {
            var _this = this;
            this._promise = new Promise(function (resolve, reject) {
                _this._resolve = resolve;
                _this._reject = reject;
            });
        }
        Object.defineProperty(Deferred.prototype, "promise", {
            get: function () {
                return this._promise;
            },
            enumerable: false,
            configurable: true
        });
        Deferred.prototype.resolve = function (val) {
            this._resolve(val);
        };
        Deferred.prototype.reject = function (err) {
            this._reject(err);
        };
        return Deferred;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$g = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$9 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /**
     * Bind the callback and only invoke the callback once regardless how many times `BindOnceFuture.call` is invoked.
     */
    var BindOnceFuture = /** @class */ (function () {
        function BindOnceFuture(_callback, _that) {
            this._callback = _callback;
            this._that = _that;
            this._isCalled = false;
            this._deferred = new Deferred();
        }
        Object.defineProperty(BindOnceFuture.prototype, "isCalled", {
            get: function () {
                return this._isCalled;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(BindOnceFuture.prototype, "promise", {
            get: function () {
                return this._deferred.promise;
            },
            enumerable: false,
            configurable: true
        });
        BindOnceFuture.prototype.call = function () {
            var _a;
            var _this = this;
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            if (!this._isCalled) {
                this._isCalled = true;
                try {
                    Promise.resolve((_a = this._callback).call.apply(_a, __spreadArray$9([this._that], __read$g(args), false))).then(function (val) { return _this._deferred.resolve(val); }, function (err) { return _this._deferred.reject(err); });
                }
                catch (err) {
                    this._deferred.reject(err);
                }
            }
            return this._deferred.promise;
        };
        return BindOnceFuture;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * @internal
     * Shared functionality used by Exporters while exporting data, including suppression of Traces.
     */
    function _export(exporter, arg) {
        return new Promise(function (resolve) {
            // prevent downstream exporter calls from generating spans
            context.with(suppressTracing(context.active()), function () {
                exporter.export(arg, function (result) {
                    resolve(result);
                });
            });
        });
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var internal = {
        _export: _export,
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function defaultServiceName() {
        return 'unknown_service';
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __assign$a = (undefined && undefined.__assign) || function () {
        __assign$a = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$a.apply(this, arguments);
    };
    var __awaiter$b = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$b = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var __read$f = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    /**
     * A Resource describes the entity for which a signals (metrics or trace) are
     * collected.
     */
    var Resource = /** @class */ (function () {
        function Resource(
        /**
         * A dictionary of attributes with string keys and values that provide
         * information about the entity as numbers, strings or booleans
         * TODO: Consider to add check/validation on attributes.
         */
        attributes, asyncAttributesPromise) {
            var _this = this;
            var _a;
            this._attributes = attributes;
            this.asyncAttributesPending = asyncAttributesPromise != null;
            this._syncAttributes = (_a = this._attributes) !== null && _a !== void 0 ? _a : {};
            this._asyncAttributesPromise = asyncAttributesPromise === null || asyncAttributesPromise === void 0 ? void 0 : asyncAttributesPromise.then(function (asyncAttributes) {
                _this._attributes = Object.assign({}, _this._attributes, asyncAttributes);
                _this.asyncAttributesPending = false;
                return asyncAttributes;
            }, function (err) {
                diag.debug("a resource's async attributes promise rejected: %s", err);
                _this.asyncAttributesPending = false;
                return {};
            });
        }
        /**
         * Returns an empty Resource
         */
        Resource.empty = function () {
            return Resource.EMPTY;
        };
        /**
         * Returns a Resource that identifies the SDK in use.
         */
        Resource.default = function () {
            var _a;
            return new Resource((_a = {},
                _a[SEMRESATTRS_SERVICE_NAME] = defaultServiceName(),
                _a[SEMRESATTRS_TELEMETRY_SDK_LANGUAGE] = SDK_INFO[SEMRESATTRS_TELEMETRY_SDK_LANGUAGE],
                _a[SEMRESATTRS_TELEMETRY_SDK_NAME] = SDK_INFO[SEMRESATTRS_TELEMETRY_SDK_NAME],
                _a[SEMRESATTRS_TELEMETRY_SDK_VERSION] = SDK_INFO[SEMRESATTRS_TELEMETRY_SDK_VERSION],
                _a));
        };
        Object.defineProperty(Resource.prototype, "attributes", {
            get: function () {
                var _a;
                if (this.asyncAttributesPending) {
                    diag.error('Accessing resource attributes before async attributes settled');
                }
                return (_a = this._attributes) !== null && _a !== void 0 ? _a : {};
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Returns a promise that will never be rejected. Resolves when all async attributes have finished being added to
         * this Resource's attributes. This is useful in exporters to block until resource detection
         * has finished.
         */
        Resource.prototype.waitForAsyncAttributes = function () {
            return __awaiter$b(this, void 0, void 0, function () {
                return __generator$b(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!this.asyncAttributesPending) return [3 /*break*/, 2];
                            return [4 /*yield*/, this._asyncAttributesPromise];
                        case 1:
                            _a.sent();
                            _a.label = 2;
                        case 2: return [2 /*return*/];
                    }
                });
            });
        };
        /**
         * Returns a new, merged {@link Resource} by merging the current Resource
         * with the other Resource. In case of a collision, other Resource takes
         * precedence.
         *
         * @param other the Resource that will be merged with this.
         * @returns the newly merged Resource.
         */
        Resource.prototype.merge = function (other) {
            var _this = this;
            var _a;
            if (!other)
                return this;
            // SpanAttributes from other resource overwrite attributes from this resource.
            var mergedSyncAttributes = __assign$a(__assign$a({}, this._syncAttributes), ((_a = other._syncAttributes) !== null && _a !== void 0 ? _a : other.attributes));
            if (!this._asyncAttributesPromise &&
                !other._asyncAttributesPromise) {
                return new Resource(mergedSyncAttributes);
            }
            var mergedAttributesPromise = Promise.all([
                this._asyncAttributesPromise,
                other._asyncAttributesPromise,
            ]).then(function (_a) {
                var _b;
                var _c = __read$f(_a, 2), thisAsyncAttributes = _c[0], otherAsyncAttributes = _c[1];
                return __assign$a(__assign$a(__assign$a(__assign$a({}, _this._syncAttributes), thisAsyncAttributes), ((_b = other._syncAttributes) !== null && _b !== void 0 ? _b : other.attributes)), otherAsyncAttributes);
            });
            return new Resource(mergedSyncAttributes, mergedAttributesPromise);
        };
        Resource.EMPTY = new Resource({});
        return Resource;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var isPromiseLike = function (val) {
        return (val !== null && typeof val === 'object' && typeof val.then === 'function');
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$a = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$a = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * Runs all resource detectors synchronously, merging their results. In case of attribute collision later resources will take precedence.
     *
     * @param config Configuration for resource detection
     */
    var detectResourcesSync = function (config) {
        var _a;
        if (config === void 0) { config = {}; }
        var resources = ((_a = config.detectors) !== null && _a !== void 0 ? _a : []).map(function (d) {
            try {
                var resourceOrPromise_1 = d.detect(config);
                var resource_1;
                if (isPromiseLike(resourceOrPromise_1)) {
                    var createPromise = function () { return __awaiter$a(void 0, void 0, void 0, function () {
                        var resolvedResource;
                        var _a;
                        return __generator$a(this, function (_b) {
                            switch (_b.label) {
                                case 0: return [4 /*yield*/, resourceOrPromise_1];
                                case 1:
                                    resolvedResource = _b.sent();
                                    return [4 /*yield*/, ((_a = resolvedResource.waitForAsyncAttributes) === null || _a === void 0 ? void 0 : _a.call(resolvedResource))];
                                case 2:
                                    _b.sent();
                                    return [2 /*return*/, resolvedResource.attributes];
                            }
                        });
                    }); };
                    resource_1 = new Resource({}, createPromise());
                }
                else {
                    resource_1 = resourceOrPromise_1;
                }
                if (resource_1.waitForAsyncAttributes) {
                    void resource_1
                        .waitForAsyncAttributes()
                        .then(function () {
                        return diag.debug(d.constructor.name + " found resource.", resource_1);
                    });
                }
                else {
                    diag.debug(d.constructor.name + " found resource.", resource_1);
                }
                return resource_1;
            }
            catch (e) {
                diag.error(d.constructor.name + " failed: " + e.message);
                return Resource.empty();
            }
        });
        var mergedResources = resources.reduce(function (acc, resource) { return acc.merge(resource); }, Resource.empty());
        if (mergedResources.waitForAsyncAttributes) {
            void mergedResources.waitForAsyncAttributes().then(function () {
                // Future check if verbose logging is enabled issue #1903
                logResources(resources);
            });
        }
        return mergedResources;
    };
    /**
     * Writes debug information about the detected resources to the logger defined in the resource detection config, if one is provided.
     *
     * @param resources The array of {@link Resource} that should be logged. Empty entries will be ignored.
     */
    var logResources = function (resources) {
        resources.forEach(function (resource) {
            // Print only populated resources
            if (Object.keys(resource.attributes).length > 0) {
                var resourceDebugString = JSON.stringify(resource.attributes, null, 4);
                diag.verbose(resourceDebugString);
            }
        });
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$8 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$e = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var LogRecord = /** @class */ (function () {
        function LogRecord(_sharedState, instrumentationScope, logRecord) {
            this.attributes = {};
            this.totalAttributesCount = 0;
            this._isReadonly = false;
            var timestamp = logRecord.timestamp, observedTimestamp = logRecord.observedTimestamp, severityNumber = logRecord.severityNumber, severityText = logRecord.severityText, body = logRecord.body, _a = logRecord.attributes, attributes = _a === void 0 ? {} : _a, context = logRecord.context;
            var now = Date.now();
            this.hrTime = timeInputToHrTime(timestamp !== null && timestamp !== void 0 ? timestamp : now);
            this.hrTimeObserved = timeInputToHrTime(observedTimestamp !== null && observedTimestamp !== void 0 ? observedTimestamp : now);
            if (context) {
                var spanContext = trace.getSpanContext(context);
                if (spanContext && isSpanContextValid(spanContext)) {
                    this.spanContext = spanContext;
                }
            }
            this.severityNumber = severityNumber;
            this.severityText = severityText;
            this.body = body;
            this.resource = _sharedState.resource;
            this.instrumentationScope = instrumentationScope;
            this._logRecordLimits = _sharedState.logRecordLimits;
            this.setAttributes(attributes);
        }
        Object.defineProperty(LogRecord.prototype, "severityText", {
            get: function () {
                return this._severityText;
            },
            set: function (severityText) {
                if (this._isLogRecordReadonly()) {
                    return;
                }
                this._severityText = severityText;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LogRecord.prototype, "severityNumber", {
            get: function () {
                return this._severityNumber;
            },
            set: function (severityNumber) {
                if (this._isLogRecordReadonly()) {
                    return;
                }
                this._severityNumber = severityNumber;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LogRecord.prototype, "body", {
            get: function () {
                return this._body;
            },
            set: function (body) {
                if (this._isLogRecordReadonly()) {
                    return;
                }
                this._body = body;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(LogRecord.prototype, "droppedAttributesCount", {
            get: function () {
                return this.totalAttributesCount - Object.keys(this.attributes).length;
            },
            enumerable: false,
            configurable: true
        });
        LogRecord.prototype.setAttribute = function (key, value) {
            if (this._isLogRecordReadonly()) {
                return this;
            }
            if (value === null) {
                return this;
            }
            if (key.length === 0) {
                diag.warn("Invalid attribute key: " + key);
                return this;
            }
            if (!isAttributeValue(value) &&
                !(typeof value === 'object' &&
                    !Array.isArray(value) &&
                    Object.keys(value).length > 0)) {
                diag.warn("Invalid attribute value set for key: " + key);
                return this;
            }
            this.totalAttributesCount += 1;
            if (Object.keys(this.attributes).length >=
                this._logRecordLimits.attributeCountLimit &&
                !Object.prototype.hasOwnProperty.call(this.attributes, key)) {
                // This logic is to create drop message at most once per LogRecord to prevent excessive logging.
                if (this.droppedAttributesCount === 1) {
                    diag.warn('Dropping extra attributes.');
                }
                return this;
            }
            if (isAttributeValue(value)) {
                this.attributes[key] = this._truncateToSize(value);
            }
            else {
                this.attributes[key] = value;
            }
            return this;
        };
        LogRecord.prototype.setAttributes = function (attributes) {
            var e_1, _a;
            try {
                for (var _b = __values$8(Object.entries(attributes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var _d = __read$e(_c.value, 2), k = _d[0], v = _d[1];
                    this.setAttribute(k, v);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return this;
        };
        LogRecord.prototype.setBody = function (body) {
            this.body = body;
            return this;
        };
        LogRecord.prototype.setSeverityNumber = function (severityNumber) {
            this.severityNumber = severityNumber;
            return this;
        };
        LogRecord.prototype.setSeverityText = function (severityText) {
            this.severityText = severityText;
            return this;
        };
        /**
         * @internal
         * A LogRecordProcessor may freely modify logRecord for the duration of the OnEmit call.
         * If logRecord is needed after OnEmit returns (i.e. for asynchronous processing) only reads are permitted.
         */
        LogRecord.prototype._makeReadonly = function () {
            this._isReadonly = true;
        };
        LogRecord.prototype._truncateToSize = function (value) {
            var _this = this;
            var limit = this._logRecordLimits.attributeValueLengthLimit;
            // Check limit
            if (limit <= 0) {
                // Negative values are invalid, so do not truncate
                diag.warn("Attribute value limit must be positive, got " + limit);
                return value;
            }
            // String
            if (typeof value === 'string') {
                return this._truncateToLimitUtil(value, limit);
            }
            // Array of strings
            if (Array.isArray(value)) {
                return value.map(function (val) {
                    return typeof val === 'string' ? _this._truncateToLimitUtil(val, limit) : val;
                });
            }
            // Other types, no need to apply value length limit
            return value;
        };
        LogRecord.prototype._truncateToLimitUtil = function (value, limit) {
            if (value.length <= limit) {
                return value;
            }
            return value.substring(0, limit);
        };
        LogRecord.prototype._isLogRecordReadonly = function () {
            if (this._isReadonly) {
                diag.warn('Can not execute the operation on emitted log record');
            }
            return this._isReadonly;
        };
        return LogRecord;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __assign$9 = (undefined && undefined.__assign) || function () {
        __assign$9 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$9.apply(this, arguments);
    };
    var Logger = /** @class */ (function () {
        function Logger(instrumentationScope, _sharedState) {
            this.instrumentationScope = instrumentationScope;
            this._sharedState = _sharedState;
        }
        Logger.prototype.emit = function (logRecord) {
            var currentContext = logRecord.context || context.active();
            /**
             * If a Logger was obtained with include_trace_context=true,
             * the LogRecords it emits MUST automatically include the Trace Context from the active Context,
             * if Context has not been explicitly set.
             */
            var logRecordInstance = new LogRecord(this._sharedState, this.instrumentationScope, __assign$9({ context: currentContext }, logRecord));
            /**
             * the explicitly passed Context,
             * the current Context, or an empty Context if the Logger was obtained with include_trace_context=false
             */
            this._sharedState.activeProcessor.onEmit(logRecordInstance, currentContext);
            /**
             * A LogRecordProcessor may freely modify logRecord for the duration of the OnEmit call.
             * If logRecord is needed after OnEmit returns (i.e. for asynchronous processing) only reads are permitted.
             */
            logRecordInstance._makeReadonly();
        };
        return Logger;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function loadDefaultConfig$1() {
        return {
            forceFlushTimeoutMillis: 30000,
            logRecordLimits: {
                attributeValueLengthLimit: getEnv().OTEL_LOGRECORD_ATTRIBUTE_VALUE_LENGTH_LIMIT,
                attributeCountLimit: getEnv().OTEL_LOGRECORD_ATTRIBUTE_COUNT_LIMIT,
            },
            includeTraceContext: true,
            mergeResourceWithDefaults: true,
        };
    }
    /**
     * When general limits are provided and model specific limits are not,
     * configures the model specific limits by using the values from the general ones.
     * @param logRecordLimits User provided limits configuration
     */
    function reconfigureLimits$1(logRecordLimits) {
        var _a, _b, _c, _d, _e, _f;
        var parsedEnvConfig = getEnvWithoutDefaults();
        return {
            /**
             * Reassign log record attribute count limit to use first non null value defined by user or use default value
             */
            attributeCountLimit: (_c = (_b = (_a = logRecordLimits.attributeCountLimit) !== null && _a !== void 0 ? _a : parsedEnvConfig.OTEL_LOGRECORD_ATTRIBUTE_COUNT_LIMIT) !== null && _b !== void 0 ? _b : parsedEnvConfig.OTEL_ATTRIBUTE_COUNT_LIMIT) !== null && _c !== void 0 ? _c : DEFAULT_ATTRIBUTE_COUNT_LIMIT,
            /**
             * Reassign log record attribute value length limit to use first non null value defined by user or use default value
             */
            attributeValueLengthLimit: (_f = (_e = (_d = logRecordLimits.attributeValueLengthLimit) !== null && _d !== void 0 ? _d : parsedEnvConfig.OTEL_LOGRECORD_ATTRIBUTE_VALUE_LENGTH_LIMIT) !== null && _e !== void 0 ? _e : parsedEnvConfig.OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT) !== null && _f !== void 0 ? _f : DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT,
        };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$9 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$9 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * Implementation of the {@link LogRecordProcessor} that simply forwards all
     * received events to a list of {@link LogRecordProcessor}s.
     */
    var MultiLogRecordProcessor = /** @class */ (function () {
        function MultiLogRecordProcessor(processors, forceFlushTimeoutMillis) {
            this.processors = processors;
            this.forceFlushTimeoutMillis = forceFlushTimeoutMillis;
        }
        MultiLogRecordProcessor.prototype.forceFlush = function () {
            return __awaiter$9(this, void 0, void 0, function () {
                var timeout;
                return __generator$9(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            timeout = this.forceFlushTimeoutMillis;
                            return [4 /*yield*/, Promise.all(this.processors.map(function (processor) {
                                    return callWithTimeout(processor.forceFlush(), timeout);
                                }))];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        };
        MultiLogRecordProcessor.prototype.onEmit = function (logRecord, context) {
            this.processors.forEach(function (processors) {
                return processors.onEmit(logRecord, context);
            });
        };
        MultiLogRecordProcessor.prototype.shutdown = function () {
            return __awaiter$9(this, void 0, void 0, function () {
                return __generator$9(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, Promise.all(this.processors.map(function (processor) { return processor.shutdown(); }))];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        };
        return MultiLogRecordProcessor;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NoopLogRecordProcessor = /** @class */ (function () {
        function NoopLogRecordProcessor() {
        }
        NoopLogRecordProcessor.prototype.forceFlush = function () {
            return Promise.resolve();
        };
        NoopLogRecordProcessor.prototype.onEmit = function (_logRecord, _context) { };
        NoopLogRecordProcessor.prototype.shutdown = function () {
            return Promise.resolve();
        };
        return NoopLogRecordProcessor;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var LoggerProviderSharedState = /** @class */ (function () {
        function LoggerProviderSharedState(resource, forceFlushTimeoutMillis, logRecordLimits) {
            this.resource = resource;
            this.forceFlushTimeoutMillis = forceFlushTimeoutMillis;
            this.logRecordLimits = logRecordLimits;
            this.loggers = new Map();
            this.registeredLogRecordProcessors = [];
            this.activeProcessor = new NoopLogRecordProcessor();
        }
        return LoggerProviderSharedState;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var DEFAULT_LOGGER_NAME = 'unknown';
    function prepareResource(mergeWithDefaults, providedResource) {
        var resource = providedResource !== null && providedResource !== void 0 ? providedResource : Resource.empty();
        if (mergeWithDefaults) {
            return Resource.default().merge(resource);
        }
        return resource;
    }
    var LoggerProvider = /** @class */ (function () {
        function LoggerProvider(config) {
            if (config === void 0) { config = {}; }
            var mergedConfig = merge({}, loadDefaultConfig$1(), config);
            var resource = prepareResource(mergedConfig.mergeResourceWithDefaults, config.resource);
            this._sharedState = new LoggerProviderSharedState(resource, mergedConfig.forceFlushTimeoutMillis, reconfigureLimits$1(mergedConfig.logRecordLimits));
            this._shutdownOnce = new BindOnceFuture(this._shutdown, this);
        }
        /**
         * Get a logger with the configuration of the LoggerProvider.
         */
        LoggerProvider.prototype.getLogger = function (name, version, options) {
            if (this._shutdownOnce.isCalled) {
                diag.warn('A shutdown LoggerProvider cannot provide a Logger');
                return NOOP_LOGGER$1;
            }
            if (!name) {
                diag.warn('Logger requested without instrumentation scope name.');
            }
            var loggerName = name || DEFAULT_LOGGER_NAME;
            var key = loggerName + "@" + (version || '') + ":" + ((options === null || options === void 0 ? void 0 : options.schemaUrl) || '');
            if (!this._sharedState.loggers.has(key)) {
                this._sharedState.loggers.set(key, new Logger({ name: loggerName, version: version, schemaUrl: options === null || options === void 0 ? void 0 : options.schemaUrl }, this._sharedState));
            }
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            return this._sharedState.loggers.get(key);
        };
        /**
         * Adds a new {@link LogRecordProcessor} to this logger.
         * @param processor the new LogRecordProcessor to be added.
         */
        LoggerProvider.prototype.addLogRecordProcessor = function (processor) {
            if (this._sharedState.registeredLogRecordProcessors.length === 0) {
                // since we might have enabled by default a batchProcessor, we disable it
                // before adding the new one
                this._sharedState.activeProcessor
                    .shutdown()
                    .catch(function (err) {
                    return diag.error('Error while trying to shutdown current log record processor', err);
                });
            }
            this._sharedState.registeredLogRecordProcessors.push(processor);
            this._sharedState.activeProcessor = new MultiLogRecordProcessor(this._sharedState.registeredLogRecordProcessors, this._sharedState.forceFlushTimeoutMillis);
        };
        /**
         * Notifies all registered LogRecordProcessor to flush any buffered data.
         *
         * Returns a promise which is resolved when all flushes are complete.
         */
        LoggerProvider.prototype.forceFlush = function () {
            // do not flush after shutdown
            if (this._shutdownOnce.isCalled) {
                diag.warn('invalid attempt to force flush after LoggerProvider shutdown');
                return this._shutdownOnce.promise;
            }
            return this._sharedState.activeProcessor.forceFlush();
        };
        /**
         * Flush all buffered data and shut down the LoggerProvider and all registered
         * LogRecordProcessor.
         *
         * Returns a promise which is resolved when all flushes are complete.
         */
        LoggerProvider.prototype.shutdown = function () {
            if (this._shutdownOnce.isCalled) {
                diag.warn('shutdown may only be called once per LoggerProvider');
                return this._shutdownOnce.promise;
            }
            return this._shutdownOnce.call();
        };
        LoggerProvider.prototype._shutdown = function () {
            return this._sharedState.activeProcessor.shutdown();
        };
        return LoggerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$8 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$8 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var BatchLogRecordProcessorBase = /** @class */ (function () {
        function BatchLogRecordProcessorBase(_exporter, config) {
            var _a, _b, _c, _d;
            this._exporter = _exporter;
            this._finishedLogRecords = [];
            var env = getEnv();
            this._maxExportBatchSize =
                (_a = config === null || config === void 0 ? void 0 : config.maxExportBatchSize) !== null && _a !== void 0 ? _a : env.OTEL_BLRP_MAX_EXPORT_BATCH_SIZE;
            this._maxQueueSize = (_b = config === null || config === void 0 ? void 0 : config.maxQueueSize) !== null && _b !== void 0 ? _b : env.OTEL_BLRP_MAX_QUEUE_SIZE;
            this._scheduledDelayMillis =
                (_c = config === null || config === void 0 ? void 0 : config.scheduledDelayMillis) !== null && _c !== void 0 ? _c : env.OTEL_BLRP_SCHEDULE_DELAY;
            this._exportTimeoutMillis =
                (_d = config === null || config === void 0 ? void 0 : config.exportTimeoutMillis) !== null && _d !== void 0 ? _d : env.OTEL_BLRP_EXPORT_TIMEOUT;
            this._shutdownOnce = new BindOnceFuture(this._shutdown, this);
            if (this._maxExportBatchSize > this._maxQueueSize) {
                diag.warn('BatchLogRecordProcessor: maxExportBatchSize must be smaller or equal to maxQueueSize, setting maxExportBatchSize to match maxQueueSize');
                this._maxExportBatchSize = this._maxQueueSize;
            }
        }
        BatchLogRecordProcessorBase.prototype.onEmit = function (logRecord) {
            if (this._shutdownOnce.isCalled) {
                return;
            }
            this._addToBuffer(logRecord);
        };
        BatchLogRecordProcessorBase.prototype.forceFlush = function () {
            if (this._shutdownOnce.isCalled) {
                return this._shutdownOnce.promise;
            }
            return this._flushAll();
        };
        BatchLogRecordProcessorBase.prototype.shutdown = function () {
            return this._shutdownOnce.call();
        };
        BatchLogRecordProcessorBase.prototype._shutdown = function () {
            return __awaiter$8(this, void 0, void 0, function () {
                return __generator$8(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            this.onShutdown();
                            return [4 /*yield*/, this._flushAll()];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, this._exporter.shutdown()];
                        case 2:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        };
        /** Add a LogRecord in the buffer. */
        BatchLogRecordProcessorBase.prototype._addToBuffer = function (logRecord) {
            if (this._finishedLogRecords.length >= this._maxQueueSize) {
                return;
            }
            this._finishedLogRecords.push(logRecord);
            this._maybeStartTimer();
        };
        /**
         * Send all LogRecords to the exporter respecting the batch size limit
         * This function is used only on forceFlush or shutdown,
         * for all other cases _flush should be used
         * */
        BatchLogRecordProcessorBase.prototype._flushAll = function () {
            var _this = this;
            return new Promise(function (resolve, reject) {
                var promises = [];
                var batchCount = Math.ceil(_this._finishedLogRecords.length / _this._maxExportBatchSize);
                for (var i = 0; i < batchCount; i++) {
                    promises.push(_this._flushOneBatch());
                }
                Promise.all(promises)
                    .then(function () {
                    resolve();
                })
                    .catch(reject);
            });
        };
        BatchLogRecordProcessorBase.prototype._flushOneBatch = function () {
            var _this = this;
            this._clearTimer();
            if (this._finishedLogRecords.length === 0) {
                return Promise.resolve();
            }
            return new Promise(function (resolve, reject) {
                callWithTimeout(_this._export(_this._finishedLogRecords.splice(0, _this._maxExportBatchSize)), _this._exportTimeoutMillis)
                    .then(function () { return resolve(); })
                    .catch(reject);
            });
        };
        BatchLogRecordProcessorBase.prototype._maybeStartTimer = function () {
            var _this = this;
            if (this._timer !== undefined) {
                return;
            }
            this._timer = setTimeout(function () {
                _this._flushOneBatch()
                    .then(function () {
                    if (_this._finishedLogRecords.length > 0) {
                        _this._clearTimer();
                        _this._maybeStartTimer();
                    }
                })
                    .catch(function (e) {
                    globalErrorHandler(e);
                });
            }, this._scheduledDelayMillis);
            unrefTimer(this._timer);
        };
        BatchLogRecordProcessorBase.prototype._clearTimer = function () {
            if (this._timer !== undefined) {
                clearTimeout(this._timer);
                this._timer = undefined;
            }
        };
        BatchLogRecordProcessorBase.prototype._export = function (logRecords) {
            var _this = this;
            var doExport = function () {
                return internal
                    ._export(_this._exporter, logRecords)
                    .then(function (result) {
                    var _a;
                    if (result.code !== ExportResultCode.SUCCESS) {
                        globalErrorHandler((_a = result.error) !== null && _a !== void 0 ? _a : new Error("BatchLogRecordProcessor: log record export failed (status " + result + ")"));
                    }
                })
                    .catch(globalErrorHandler);
            };
            var pendingResources = logRecords
                .map(function (logRecord) { return logRecord.resource; })
                .filter(function (resource) { return resource.asyncAttributesPending; });
            // Avoid scheduling a promise to make the behavior more predictable and easier to test
            if (pendingResources.length === 0) {
                return doExport();
            }
            else {
                return Promise.all(pendingResources.map(function (resource) { var _a; return (_a = resource.waitForAsyncAttributes) === null || _a === void 0 ? void 0 : _a.call(resource); })).then(doExport, globalErrorHandler);
            }
        };
        return BatchLogRecordProcessorBase;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$k = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var BatchLogRecordProcessor = /** @class */ (function (_super) {
        __extends$k(BatchLogRecordProcessor, _super);
        function BatchLogRecordProcessor(exporter, config) {
            var _this = _super.call(this, exporter, config) || this;
            _this._onInit(config);
            return _this;
        }
        BatchLogRecordProcessor.prototype.onShutdown = function () {
            if (typeof document === 'undefined') {
                return;
            }
            if (this._visibilityChangeListener) {
                document.removeEventListener('visibilitychange', this._visibilityChangeListener);
            }
            if (this._pageHideListener) {
                document.removeEventListener('pagehide', this._pageHideListener);
            }
        };
        BatchLogRecordProcessor.prototype._onInit = function (config) {
            var _this = this;
            if ((config === null || config === void 0 ? void 0 : config.disableAutoFlushOnDocumentHide) === true ||
                typeof document === 'undefined') {
                return;
            }
            this._visibilityChangeListener = function () {
                if (document.visibilityState === 'hidden') {
                    void _this.forceFlush();
                }
            };
            this._pageHideListener = function () {
                void _this.forceFlush();
            };
            document.addEventListener('visibilitychange', this._visibilityChangeListener);
            // use 'pagehide' event as a fallback for Safari; see https://bugs.webkit.org/show_bug.cgi?id=116769
            document.addEventListener('pagehide', this._pageHideListener);
        };
        return BatchLogRecordProcessor;
    }(BatchLogRecordProcessorBase));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Event name definitions
    var ExceptionEventName = 'exception';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __assign$8 = (undefined && undefined.__assign) || function () {
        __assign$8 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$8.apply(this, arguments);
    };
    var __values$7 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$d = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$8 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /**
     * This class represents a span.
     */
    var Span = /** @class */ (function () {
        /**
         * Constructs a new Span instance.
         *
         * @deprecated calling Span constructor directly is not supported. Please use tracer.startSpan.
         * */
        function Span(parentTracer, context, spanName, spanContext, kind, parentSpanId, links, startTime, _deprecatedClock, // keeping this argument even though it is unused to ensure backwards compatibility
        attributes) {
            if (links === void 0) { links = []; }
            this.attributes = {};
            this.links = [];
            this.events = [];
            this._droppedAttributesCount = 0;
            this._droppedEventsCount = 0;
            this._droppedLinksCount = 0;
            this.status = {
                code: SpanStatusCode.UNSET,
            };
            this.endTime = [0, 0];
            this._ended = false;
            this._duration = [-1, -1];
            this.name = spanName;
            this._spanContext = spanContext;
            this.parentSpanId = parentSpanId;
            this.kind = kind;
            this.links = links;
            var now = Date.now();
            this._performanceStartTime = otperformance.now();
            this._performanceOffset =
                now - (this._performanceStartTime + getTimeOrigin());
            this._startTimeProvided = startTime != null;
            this.startTime = this._getTime(startTime !== null && startTime !== void 0 ? startTime : now);
            this.resource = parentTracer.resource;
            this.instrumentationLibrary = parentTracer.instrumentationLibrary;
            this._spanLimits = parentTracer.getSpanLimits();
            this._attributeValueLengthLimit =
                this._spanLimits.attributeValueLengthLimit || 0;
            if (attributes != null) {
                this.setAttributes(attributes);
            }
            this._spanProcessor = parentTracer.getActiveSpanProcessor();
            this._spanProcessor.onStart(this, context);
        }
        Span.prototype.spanContext = function () {
            return this._spanContext;
        };
        Span.prototype.setAttribute = function (key, value) {
            if (value == null || this._isSpanEnded())
                return this;
            if (key.length === 0) {
                diag.warn("Invalid attribute key: " + key);
                return this;
            }
            if (!isAttributeValue(value)) {
                diag.warn("Invalid attribute value set for key: " + key);
                return this;
            }
            if (Object.keys(this.attributes).length >=
                this._spanLimits.attributeCountLimit &&
                !Object.prototype.hasOwnProperty.call(this.attributes, key)) {
                this._droppedAttributesCount++;
                return this;
            }
            this.attributes[key] = this._truncateToSize(value);
            return this;
        };
        Span.prototype.setAttributes = function (attributes) {
            var e_1, _a;
            try {
                for (var _b = __values$7(Object.entries(attributes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var _d = __read$d(_c.value, 2), k = _d[0], v = _d[1];
                    this.setAttribute(k, v);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return this;
        };
        /**
         *
         * @param name Span Name
         * @param [attributesOrStartTime] Span attributes or start time
         *     if type is {@type TimeInput} and 3rd param is undefined
         * @param [timeStamp] Specified time stamp for the event
         */
        Span.prototype.addEvent = function (name, attributesOrStartTime, timeStamp) {
            if (this._isSpanEnded())
                return this;
            if (this._spanLimits.eventCountLimit === 0) {
                diag.warn('No events allowed.');
                this._droppedEventsCount++;
                return this;
            }
            if (this.events.length >= this._spanLimits.eventCountLimit) {
                if (this._droppedEventsCount === 0) {
                    diag.debug('Dropping extra events.');
                }
                this.events.shift();
                this._droppedEventsCount++;
            }
            if (isTimeInput(attributesOrStartTime)) {
                if (!isTimeInput(timeStamp)) {
                    timeStamp = attributesOrStartTime;
                }
                attributesOrStartTime = undefined;
            }
            var attributes = sanitizeAttributes(attributesOrStartTime);
            this.events.push({
                name: name,
                attributes: attributes,
                time: this._getTime(timeStamp),
                droppedAttributesCount: 0,
            });
            return this;
        };
        Span.prototype.addLink = function (link) {
            this.links.push(link);
            return this;
        };
        Span.prototype.addLinks = function (links) {
            var _a;
            (_a = this.links).push.apply(_a, __spreadArray$8([], __read$d(links), false));
            return this;
        };
        Span.prototype.setStatus = function (status) {
            if (this._isSpanEnded())
                return this;
            this.status = __assign$8({}, status);
            // When using try-catch, the caught "error" is of type `any`. When then assigning `any` to `status.message`,
            // TypeScript will not error. While this can happen during use of any API, it is more common on Span#setStatus()
            // as it's likely used in a catch-block. Therefore, we validate if `status.message` is actually a string, null, or
            // undefined to avoid an incorrect type causing issues downstream.
            if (this.status.message != null && typeof status.message !== 'string') {
                diag.warn("Dropping invalid status.message of type '" + typeof status.message + "', expected 'string'");
                delete this.status.message;
            }
            return this;
        };
        Span.prototype.updateName = function (name) {
            if (this._isSpanEnded())
                return this;
            this.name = name;
            return this;
        };
        Span.prototype.end = function (endTime) {
            if (this._isSpanEnded()) {
                diag.error(this.name + " " + this._spanContext.traceId + "-" + this._spanContext.spanId + " - You can only call end() on a span once.");
                return;
            }
            this._ended = true;
            this.endTime = this._getTime(endTime);
            this._duration = hrTimeDuration(this.startTime, this.endTime);
            if (this._duration[0] < 0) {
                diag.warn('Inconsistent start and end time, startTime > endTime. Setting span duration to 0ms.', this.startTime, this.endTime);
                this.endTime = this.startTime.slice();
                this._duration = [0, 0];
            }
            if (this._droppedEventsCount > 0) {
                diag.warn("Dropped " + this._droppedEventsCount + " events because eventCountLimit reached");
            }
            this._spanProcessor.onEnd(this);
        };
        Span.prototype._getTime = function (inp) {
            if (typeof inp === 'number' && inp <= otperformance.now()) {
                // must be a performance timestamp
                // apply correction and convert to hrtime
                return hrTime(inp + this._performanceOffset);
            }
            if (typeof inp === 'number') {
                return millisToHrTime(inp);
            }
            if (inp instanceof Date) {
                return millisToHrTime(inp.getTime());
            }
            if (isTimeInputHrTime(inp)) {
                return inp;
            }
            if (this._startTimeProvided) {
                // if user provided a time for the start manually
                // we can't use duration to calculate event/end times
                return millisToHrTime(Date.now());
            }
            var msDuration = otperformance.now() - this._performanceStartTime;
            return addHrTimes(this.startTime, millisToHrTime(msDuration));
        };
        Span.prototype.isRecording = function () {
            return this._ended === false;
        };
        Span.prototype.recordException = function (exception, time) {
            var attributes = {};
            if (typeof exception === 'string') {
                attributes[SEMATTRS_EXCEPTION_MESSAGE] = exception;
            }
            else if (exception) {
                if (exception.code) {
                    attributes[SEMATTRS_EXCEPTION_TYPE] = exception.code.toString();
                }
                else if (exception.name) {
                    attributes[SEMATTRS_EXCEPTION_TYPE] = exception.name;
                }
                if (exception.message) {
                    attributes[SEMATTRS_EXCEPTION_MESSAGE] = exception.message;
                }
                if (exception.stack) {
                    attributes[SEMATTRS_EXCEPTION_STACKTRACE] = exception.stack;
                }
            }
            // these are minimum requirements from spec
            if (attributes[SEMATTRS_EXCEPTION_TYPE] ||
                attributes[SEMATTRS_EXCEPTION_MESSAGE]) {
                this.addEvent(ExceptionEventName, attributes, time);
            }
            else {
                diag.warn("Failed to record an exception " + exception);
            }
        };
        Object.defineProperty(Span.prototype, "duration", {
            get: function () {
                return this._duration;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Span.prototype, "ended", {
            get: function () {
                return this._ended;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Span.prototype, "droppedAttributesCount", {
            get: function () {
                return this._droppedAttributesCount;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Span.prototype, "droppedEventsCount", {
            get: function () {
                return this._droppedEventsCount;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(Span.prototype, "droppedLinksCount", {
            get: function () {
                return this._droppedLinksCount;
            },
            enumerable: false,
            configurable: true
        });
        Span.prototype._isSpanEnded = function () {
            if (this._ended) {
                diag.warn("Can not execute the operation on ended Span {traceId: " + this._spanContext.traceId + ", spanId: " + this._spanContext.spanId + "}");
            }
            return this._ended;
        };
        // Utility function to truncate given value within size
        // for value type of string, will truncate to given limit
        // for type of non-string, will return same value
        Span.prototype._truncateToLimitUtil = function (value, limit) {
            if (value.length <= limit) {
                return value;
            }
            return value.substring(0, limit);
        };
        /**
         * If the given attribute value is of type string and has more characters than given {@code attributeValueLengthLimit} then
         * return string with truncated to {@code attributeValueLengthLimit} characters
         *
         * If the given attribute value is array of strings then
         * return new array of strings with each element truncated to {@code attributeValueLengthLimit} characters
         *
         * Otherwise return same Attribute {@code value}
         *
         * @param value Attribute value
         * @returns truncated attribute value if required, otherwise same value
         */
        Span.prototype._truncateToSize = function (value) {
            var _this = this;
            var limit = this._attributeValueLengthLimit;
            // Check limit
            if (limit <= 0) {
                // Negative values are invalid, so do not truncate
                diag.warn("Attribute value limit must be positive, got " + limit);
                return value;
            }
            // String
            if (typeof value === 'string') {
                return this._truncateToLimitUtil(value, limit);
            }
            // Array of strings
            if (Array.isArray(value)) {
                return value.map(function (val) {
                    return typeof val === 'string' ? _this._truncateToLimitUtil(val, limit) : val;
                });
            }
            // Other types, no need to apply value length limit
            return value;
        };
        return Span;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * A sampling decision that determines how a {@link Span} will be recorded
     * and collected.
     */
    var SamplingDecision;
    (function (SamplingDecision) {
        /**
         * `Span.isRecording() === false`, span will not be recorded and all events
         * and attributes will be dropped.
         */
        SamplingDecision[SamplingDecision["NOT_RECORD"] = 0] = "NOT_RECORD";
        /**
         * `Span.isRecording() === true`, but `Sampled` flag in {@link TraceFlags}
         * MUST NOT be set.
         */
        SamplingDecision[SamplingDecision["RECORD"] = 1] = "RECORD";
        /**
         * `Span.isRecording() === true` AND `Sampled` flag in {@link TraceFlags}
         * MUST be set.
         */
        SamplingDecision[SamplingDecision["RECORD_AND_SAMPLED"] = 2] = "RECORD_AND_SAMPLED";
    })(SamplingDecision || (SamplingDecision = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** Sampler that samples no traces. */
    var AlwaysOffSampler = /** @class */ (function () {
        function AlwaysOffSampler() {
        }
        AlwaysOffSampler.prototype.shouldSample = function () {
            return {
                decision: SamplingDecision.NOT_RECORD,
            };
        };
        AlwaysOffSampler.prototype.toString = function () {
            return 'AlwaysOffSampler';
        };
        return AlwaysOffSampler;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** Sampler that samples all traces. */
    var AlwaysOnSampler = /** @class */ (function () {
        function AlwaysOnSampler() {
        }
        AlwaysOnSampler.prototype.shouldSample = function () {
            return {
                decision: SamplingDecision.RECORD_AND_SAMPLED,
            };
        };
        AlwaysOnSampler.prototype.toString = function () {
            return 'AlwaysOnSampler';
        };
        return AlwaysOnSampler;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * A composite sampler that either respects the parent span's sampling decision
     * or delegates to `delegateSampler` for root spans.
     */
    var ParentBasedSampler = /** @class */ (function () {
        function ParentBasedSampler(config) {
            var _a, _b, _c, _d;
            this._root = config.root;
            if (!this._root) {
                globalErrorHandler(new Error('ParentBasedSampler must have a root sampler configured'));
                this._root = new AlwaysOnSampler();
            }
            this._remoteParentSampled =
                (_a = config.remoteParentSampled) !== null && _a !== void 0 ? _a : new AlwaysOnSampler();
            this._remoteParentNotSampled =
                (_b = config.remoteParentNotSampled) !== null && _b !== void 0 ? _b : new AlwaysOffSampler();
            this._localParentSampled =
                (_c = config.localParentSampled) !== null && _c !== void 0 ? _c : new AlwaysOnSampler();
            this._localParentNotSampled =
                (_d = config.localParentNotSampled) !== null && _d !== void 0 ? _d : new AlwaysOffSampler();
        }
        ParentBasedSampler.prototype.shouldSample = function (context, traceId, spanName, spanKind, attributes, links) {
            var parentContext = trace.getSpanContext(context);
            if (!parentContext || !isSpanContextValid(parentContext)) {
                return this._root.shouldSample(context, traceId, spanName, spanKind, attributes, links);
            }
            if (parentContext.isRemote) {
                if (parentContext.traceFlags & TraceFlags.SAMPLED) {
                    return this._remoteParentSampled.shouldSample(context, traceId, spanName, spanKind, attributes, links);
                }
                return this._remoteParentNotSampled.shouldSample(context, traceId, spanName, spanKind, attributes, links);
            }
            if (parentContext.traceFlags & TraceFlags.SAMPLED) {
                return this._localParentSampled.shouldSample(context, traceId, spanName, spanKind, attributes, links);
            }
            return this._localParentNotSampled.shouldSample(context, traceId, spanName, spanKind, attributes, links);
        };
        ParentBasedSampler.prototype.toString = function () {
            return "ParentBased{root=" + this._root.toString() + ", remoteParentSampled=" + this._remoteParentSampled.toString() + ", remoteParentNotSampled=" + this._remoteParentNotSampled.toString() + ", localParentSampled=" + this._localParentSampled.toString() + ", localParentNotSampled=" + this._localParentNotSampled.toString() + "}";
        };
        return ParentBasedSampler;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** Sampler that samples a given fraction of traces based of trace id deterministically. */
    var TraceIdRatioBasedSampler = /** @class */ (function () {
        function TraceIdRatioBasedSampler(_ratio) {
            if (_ratio === void 0) { _ratio = 0; }
            this._ratio = _ratio;
            this._ratio = this._normalize(_ratio);
            this._upperBound = Math.floor(this._ratio * 0xffffffff);
        }
        TraceIdRatioBasedSampler.prototype.shouldSample = function (context, traceId) {
            return {
                decision: isValidTraceId(traceId) && this._accumulate(traceId) < this._upperBound
                    ? SamplingDecision.RECORD_AND_SAMPLED
                    : SamplingDecision.NOT_RECORD,
            };
        };
        TraceIdRatioBasedSampler.prototype.toString = function () {
            return "TraceIdRatioBased{" + this._ratio + "}";
        };
        TraceIdRatioBasedSampler.prototype._normalize = function (ratio) {
            if (typeof ratio !== 'number' || isNaN(ratio))
                return 0;
            return ratio >= 1 ? 1 : ratio <= 0 ? 0 : ratio;
        };
        TraceIdRatioBasedSampler.prototype._accumulate = function (traceId) {
            var accumulation = 0;
            for (var i = 0; i < traceId.length / 8; i++) {
                var pos = i * 8;
                var part = parseInt(traceId.slice(pos, pos + 8), 16);
                accumulation = (accumulation ^ part) >>> 0;
            }
            return accumulation;
        };
        return TraceIdRatioBasedSampler;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var FALLBACK_OTEL_TRACES_SAMPLER = TracesSamplerValues.AlwaysOn;
    var DEFAULT_RATIO = 1;
    /**
     * Load default configuration. For fields with primitive values, any user-provided
     * value will override the corresponding default value. For fields with
     * non-primitive values (like `spanLimits`), the user-provided value will be
     * used to extend the default value.
     */
    // object needs to be wrapped in this function and called when needed otherwise
    // envs are parsed before tests are ran - causes tests using these envs to fail
    function loadDefaultConfig() {
        var env = getEnv();
        return {
            sampler: buildSamplerFromEnv(env),
            forceFlushTimeoutMillis: 30000,
            generalLimits: {
                attributeValueLengthLimit: env.OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT,
                attributeCountLimit: env.OTEL_ATTRIBUTE_COUNT_LIMIT,
            },
            spanLimits: {
                attributeValueLengthLimit: env.OTEL_SPAN_ATTRIBUTE_VALUE_LENGTH_LIMIT,
                attributeCountLimit: env.OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT,
                linkCountLimit: env.OTEL_SPAN_LINK_COUNT_LIMIT,
                eventCountLimit: env.OTEL_SPAN_EVENT_COUNT_LIMIT,
                attributePerEventCountLimit: env.OTEL_SPAN_ATTRIBUTE_PER_EVENT_COUNT_LIMIT,
                attributePerLinkCountLimit: env.OTEL_SPAN_ATTRIBUTE_PER_LINK_COUNT_LIMIT,
            },
            mergeResourceWithDefaults: true,
        };
    }
    /**
     * Based on environment, builds a sampler, complies with specification.
     * @param environment optional, by default uses getEnv(), but allows passing a value to reuse parsed environment
     */
    function buildSamplerFromEnv(environment) {
        if (environment === void 0) { environment = getEnv(); }
        switch (environment.OTEL_TRACES_SAMPLER) {
            case TracesSamplerValues.AlwaysOn:
                return new AlwaysOnSampler();
            case TracesSamplerValues.AlwaysOff:
                return new AlwaysOffSampler();
            case TracesSamplerValues.ParentBasedAlwaysOn:
                return new ParentBasedSampler({
                    root: new AlwaysOnSampler(),
                });
            case TracesSamplerValues.ParentBasedAlwaysOff:
                return new ParentBasedSampler({
                    root: new AlwaysOffSampler(),
                });
            case TracesSamplerValues.TraceIdRatio:
                return new TraceIdRatioBasedSampler(getSamplerProbabilityFromEnv(environment));
            case TracesSamplerValues.ParentBasedTraceIdRatio:
                return new ParentBasedSampler({
                    root: new TraceIdRatioBasedSampler(getSamplerProbabilityFromEnv(environment)),
                });
            default:
                diag.error("OTEL_TRACES_SAMPLER value \"" + environment.OTEL_TRACES_SAMPLER + " invalid, defaulting to " + FALLBACK_OTEL_TRACES_SAMPLER + "\".");
                return new AlwaysOnSampler();
        }
    }
    function getSamplerProbabilityFromEnv(environment) {
        if (environment.OTEL_TRACES_SAMPLER_ARG === undefined ||
            environment.OTEL_TRACES_SAMPLER_ARG === '') {
            diag.error("OTEL_TRACES_SAMPLER_ARG is blank, defaulting to " + DEFAULT_RATIO + ".");
            return DEFAULT_RATIO;
        }
        var probability = Number(environment.OTEL_TRACES_SAMPLER_ARG);
        if (isNaN(probability)) {
            diag.error("OTEL_TRACES_SAMPLER_ARG=" + environment.OTEL_TRACES_SAMPLER_ARG + " was given, but it is invalid, defaulting to " + DEFAULT_RATIO + ".");
            return DEFAULT_RATIO;
        }
        if (probability < 0 || probability > 1) {
            diag.error("OTEL_TRACES_SAMPLER_ARG=" + environment.OTEL_TRACES_SAMPLER_ARG + " was given, but it is out of range ([0..1]), defaulting to " + DEFAULT_RATIO + ".");
            return DEFAULT_RATIO;
        }
        return probability;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Function to merge Default configuration (as specified in './config') with
     * user provided configurations.
     */
    function mergeConfig(userConfig) {
        var perInstanceDefaults = {
            sampler: buildSamplerFromEnv(),
        };
        var DEFAULT_CONFIG = loadDefaultConfig();
        var target = Object.assign({}, DEFAULT_CONFIG, perInstanceDefaults, userConfig);
        target.generalLimits = Object.assign({}, DEFAULT_CONFIG.generalLimits, userConfig.generalLimits || {});
        target.spanLimits = Object.assign({}, DEFAULT_CONFIG.spanLimits, userConfig.spanLimits || {});
        return target;
    }
    /**
     * When general limits are provided and model specific limits are not,
     * configures the model specific limits by using the values from the general ones.
     * @param userConfig User provided tracer configuration
     */
    function reconfigureLimits(userConfig) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        var spanLimits = Object.assign({}, userConfig.spanLimits);
        var parsedEnvConfig = getEnvWithoutDefaults();
        /**
         * Reassign span attribute count limit to use first non null value defined by user or use default value
         */
        spanLimits.attributeCountLimit =
            (_f = (_e = (_d = (_b = (_a = userConfig.spanLimits) === null || _a === void 0 ? void 0 : _a.attributeCountLimit) !== null && _b !== void 0 ? _b : (_c = userConfig.generalLimits) === null || _c === void 0 ? void 0 : _c.attributeCountLimit) !== null && _d !== void 0 ? _d : parsedEnvConfig.OTEL_SPAN_ATTRIBUTE_COUNT_LIMIT) !== null && _e !== void 0 ? _e : parsedEnvConfig.OTEL_ATTRIBUTE_COUNT_LIMIT) !== null && _f !== void 0 ? _f : DEFAULT_ATTRIBUTE_COUNT_LIMIT;
        /**
         * Reassign span attribute value length limit to use first non null value defined by user or use default value
         */
        spanLimits.attributeValueLengthLimit =
            (_m = (_l = (_k = (_h = (_g = userConfig.spanLimits) === null || _g === void 0 ? void 0 : _g.attributeValueLengthLimit) !== null && _h !== void 0 ? _h : (_j = userConfig.generalLimits) === null || _j === void 0 ? void 0 : _j.attributeValueLengthLimit) !== null && _k !== void 0 ? _k : parsedEnvConfig.OTEL_SPAN_ATTRIBUTE_VALUE_LENGTH_LIMIT) !== null && _l !== void 0 ? _l : parsedEnvConfig.OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT) !== null && _m !== void 0 ? _m : DEFAULT_ATTRIBUTE_VALUE_LENGTH_LIMIT;
        return Object.assign({}, userConfig, { spanLimits: spanLimits });
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * Implementation of the {@link SpanProcessor} that batches spans exported by
     * the SDK then pushes them to the exporter pipeline.
     */
    var BatchSpanProcessorBase = /** @class */ (function () {
        function BatchSpanProcessorBase(_exporter, config) {
            this._exporter = _exporter;
            this._isExporting = false;
            this._finishedSpans = [];
            this._droppedSpansCount = 0;
            var env = getEnv();
            this._maxExportBatchSize =
                typeof (config === null || config === void 0 ? void 0 : config.maxExportBatchSize) === 'number'
                    ? config.maxExportBatchSize
                    : env.OTEL_BSP_MAX_EXPORT_BATCH_SIZE;
            this._maxQueueSize =
                typeof (config === null || config === void 0 ? void 0 : config.maxQueueSize) === 'number'
                    ? config.maxQueueSize
                    : env.OTEL_BSP_MAX_QUEUE_SIZE;
            this._scheduledDelayMillis =
                typeof (config === null || config === void 0 ? void 0 : config.scheduledDelayMillis) === 'number'
                    ? config.scheduledDelayMillis
                    : env.OTEL_BSP_SCHEDULE_DELAY;
            this._exportTimeoutMillis =
                typeof (config === null || config === void 0 ? void 0 : config.exportTimeoutMillis) === 'number'
                    ? config.exportTimeoutMillis
                    : env.OTEL_BSP_EXPORT_TIMEOUT;
            this._shutdownOnce = new BindOnceFuture(this._shutdown, this);
            if (this._maxExportBatchSize > this._maxQueueSize) {
                diag.warn('BatchSpanProcessor: maxExportBatchSize must be smaller or equal to maxQueueSize, setting maxExportBatchSize to match maxQueueSize');
                this._maxExportBatchSize = this._maxQueueSize;
            }
        }
        BatchSpanProcessorBase.prototype.forceFlush = function () {
            if (this._shutdownOnce.isCalled) {
                return this._shutdownOnce.promise;
            }
            return this._flushAll();
        };
        // does nothing.
        BatchSpanProcessorBase.prototype.onStart = function (_span, _parentContext) { };
        BatchSpanProcessorBase.prototype.onEnd = function (span) {
            if (this._shutdownOnce.isCalled) {
                return;
            }
            if ((span.spanContext().traceFlags & TraceFlags.SAMPLED) === 0) {
                return;
            }
            this._addToBuffer(span);
        };
        BatchSpanProcessorBase.prototype.shutdown = function () {
            return this._shutdownOnce.call();
        };
        BatchSpanProcessorBase.prototype._shutdown = function () {
            var _this = this;
            return Promise.resolve()
                .then(function () {
                return _this.onShutdown();
            })
                .then(function () {
                return _this._flushAll();
            })
                .then(function () {
                return _this._exporter.shutdown();
            });
        };
        /** Add a span in the buffer. */
        BatchSpanProcessorBase.prototype._addToBuffer = function (span) {
            if (this._finishedSpans.length >= this._maxQueueSize) {
                // limit reached, drop span
                if (this._droppedSpansCount === 0) {
                    diag.debug('maxQueueSize reached, dropping spans');
                }
                this._droppedSpansCount++;
                return;
            }
            if (this._droppedSpansCount > 0) {
                // some spans were dropped, log once with count of spans dropped
                diag.warn("Dropped " + this._droppedSpansCount + " spans because maxQueueSize reached");
                this._droppedSpansCount = 0;
            }
            this._finishedSpans.push(span);
            this._maybeStartTimer();
        };
        /**
         * Send all spans to the exporter respecting the batch size limit
         * This function is used only on forceFlush or shutdown,
         * for all other cases _flush should be used
         * */
        BatchSpanProcessorBase.prototype._flushAll = function () {
            var _this = this;
            return new Promise(function (resolve, reject) {
                var promises = [];
                // calculate number of batches
                var count = Math.ceil(_this._finishedSpans.length / _this._maxExportBatchSize);
                for (var i = 0, j = count; i < j; i++) {
                    promises.push(_this._flushOneBatch());
                }
                Promise.all(promises)
                    .then(function () {
                    resolve();
                })
                    .catch(reject);
            });
        };
        BatchSpanProcessorBase.prototype._flushOneBatch = function () {
            var _this = this;
            this._clearTimer();
            if (this._finishedSpans.length === 0) {
                return Promise.resolve();
            }
            return new Promise(function (resolve, reject) {
                var timer = setTimeout(function () {
                    // don't wait anymore for export, this way the next batch can start
                    reject(new Error('Timeout'));
                }, _this._exportTimeoutMillis);
                // prevent downstream exporter calls from generating spans
                context.with(suppressTracing(context.active()), function () {
                    // Reset the finished spans buffer here because the next invocations of the _flush method
                    // could pass the same finished spans to the exporter if the buffer is cleared
                    // outside the execution of this callback.
                    var spans;
                    if (_this._finishedSpans.length <= _this._maxExportBatchSize) {
                        spans = _this._finishedSpans;
                        _this._finishedSpans = [];
                    }
                    else {
                        spans = _this._finishedSpans.splice(0, _this._maxExportBatchSize);
                    }
                    var doExport = function () {
                        return _this._exporter.export(spans, function (result) {
                            var _a;
                            clearTimeout(timer);
                            if (result.code === ExportResultCode.SUCCESS) {
                                resolve();
                            }
                            else {
                                reject((_a = result.error) !== null && _a !== void 0 ? _a : new Error('BatchSpanProcessor: span export failed'));
                            }
                        });
                    };
                    var pendingResources = null;
                    for (var i = 0, len = spans.length; i < len; i++) {
                        var span = spans[i];
                        if (span.resource.asyncAttributesPending &&
                            span.resource.waitForAsyncAttributes) {
                            pendingResources !== null && pendingResources !== void 0 ? pendingResources : (pendingResources = []);
                            pendingResources.push(span.resource.waitForAsyncAttributes());
                        }
                    }
                    // Avoid scheduling a promise to make the behavior more predictable and easier to test
                    if (pendingResources === null) {
                        doExport();
                    }
                    else {
                        Promise.all(pendingResources).then(doExport, function (err) {
                            globalErrorHandler(err);
                            reject(err);
                        });
                    }
                });
            });
        };
        BatchSpanProcessorBase.prototype._maybeStartTimer = function () {
            var _this = this;
            if (this._isExporting)
                return;
            var flush = function () {
                _this._isExporting = true;
                _this._flushOneBatch()
                    .finally(function () {
                    _this._isExporting = false;
                    if (_this._finishedSpans.length > 0) {
                        _this._clearTimer();
                        _this._maybeStartTimer();
                    }
                })
                    .catch(function (e) {
                    _this._isExporting = false;
                    globalErrorHandler(e);
                });
            };
            // we only wait if the queue doesn't have enough elements yet
            if (this._finishedSpans.length >= this._maxExportBatchSize) {
                return flush();
            }
            if (this._timer !== undefined)
                return;
            this._timer = setTimeout(function () { return flush(); }, this._scheduledDelayMillis);
            unrefTimer(this._timer);
        };
        BatchSpanProcessorBase.prototype._clearTimer = function () {
            if (this._timer !== undefined) {
                clearTimeout(this._timer);
                this._timer = undefined;
            }
        };
        return BatchSpanProcessorBase;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$j = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var BatchSpanProcessor = /** @class */ (function (_super) {
        __extends$j(BatchSpanProcessor, _super);
        function BatchSpanProcessor(_exporter, config) {
            var _this = _super.call(this, _exporter, config) || this;
            _this.onInit(config);
            return _this;
        }
        BatchSpanProcessor.prototype.onInit = function (config) {
            var _this = this;
            if ((config === null || config === void 0 ? void 0 : config.disableAutoFlushOnDocumentHide) !== true &&
                typeof document !== 'undefined') {
                this._visibilityChangeListener = function () {
                    if (document.visibilityState === 'hidden') {
                        _this.forceFlush().catch(function (error) {
                            globalErrorHandler(error);
                        });
                    }
                };
                this._pageHideListener = function () {
                    _this.forceFlush().catch(function (error) {
                        globalErrorHandler(error);
                    });
                };
                document.addEventListener('visibilitychange', this._visibilityChangeListener);
                // use 'pagehide' event as a fallback for Safari; see https://bugs.webkit.org/show_bug.cgi?id=116769
                document.addEventListener('pagehide', this._pageHideListener);
            }
        };
        BatchSpanProcessor.prototype.onShutdown = function () {
            if (typeof document !== 'undefined') {
                if (this._visibilityChangeListener) {
                    document.removeEventListener('visibilitychange', this._visibilityChangeListener);
                }
                if (this._pageHideListener) {
                    document.removeEventListener('pagehide', this._pageHideListener);
                }
            }
        };
        return BatchSpanProcessor;
    }(BatchSpanProcessorBase));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var SPAN_ID_BYTES = 8;
    var TRACE_ID_BYTES = 16;
    var RandomIdGenerator = /** @class */ (function () {
        function RandomIdGenerator() {
            /**
             * Returns a random 16-byte trace ID formatted/encoded as a 32 lowercase hex
             * characters corresponding to 128 bits.
             */
            this.generateTraceId = getIdGenerator(TRACE_ID_BYTES);
            /**
             * Returns a random 8-byte span ID formatted/encoded as a 16 lowercase hex
             * characters corresponding to 64 bits.
             */
            this.generateSpanId = getIdGenerator(SPAN_ID_BYTES);
        }
        return RandomIdGenerator;
    }());
    var SHARED_CHAR_CODES_ARRAY = Array(32);
    function getIdGenerator(bytes) {
        return function generateId() {
            for (var i = 0; i < bytes * 2; i++) {
                SHARED_CHAR_CODES_ARRAY[i] = Math.floor(Math.random() * 16) + 48;
                // valid hex characters in the range 48-57 and 97-102
                if (SHARED_CHAR_CODES_ARRAY[i] >= 58) {
                    SHARED_CHAR_CODES_ARRAY[i] += 39;
                }
            }
            return String.fromCharCode.apply(null, SHARED_CHAR_CODES_ARRAY.slice(0, bytes * 2));
        };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * This class represents a basic tracer.
     */
    var Tracer = /** @class */ (function () {
        /**
         * Constructs a new Tracer instance.
         */
        function Tracer(instrumentationLibrary, config, _tracerProvider) {
            this._tracerProvider = _tracerProvider;
            var localConfig = mergeConfig(config);
            this._sampler = localConfig.sampler;
            this._generalLimits = localConfig.generalLimits;
            this._spanLimits = localConfig.spanLimits;
            this._idGenerator = config.idGenerator || new RandomIdGenerator();
            this.resource = _tracerProvider.resource;
            this.instrumentationLibrary = instrumentationLibrary;
        }
        /**
         * Starts a new Span or returns the default NoopSpan based on the sampling
         * decision.
         */
        Tracer.prototype.startSpan = function (name, options, context$1) {
            var _a, _b, _c;
            if (options === void 0) { options = {}; }
            if (context$1 === void 0) { context$1 = context.active(); }
            // remove span from context in case a root span is requested via options
            if (options.root) {
                context$1 = trace.deleteSpan(context$1);
            }
            var parentSpan = trace.getSpan(context$1);
            if (isTracingSuppressed(context$1)) {
                diag.debug('Instrumentation suppressed, returning Noop Span');
                var nonRecordingSpan = trace.wrapSpanContext(INVALID_SPAN_CONTEXT);
                return nonRecordingSpan;
            }
            var parentSpanContext = parentSpan === null || parentSpan === void 0 ? void 0 : parentSpan.spanContext();
            var spanId = this._idGenerator.generateSpanId();
            var traceId;
            var traceState;
            var parentSpanId;
            if (!parentSpanContext ||
                !trace.isSpanContextValid(parentSpanContext)) {
                // New root span.
                traceId = this._idGenerator.generateTraceId();
            }
            else {
                // New child span.
                traceId = parentSpanContext.traceId;
                traceState = parentSpanContext.traceState;
                parentSpanId = parentSpanContext.spanId;
            }
            var spanKind = (_a = options.kind) !== null && _a !== void 0 ? _a : SpanKind.INTERNAL;
            var links = ((_b = options.links) !== null && _b !== void 0 ? _b : []).map(function (link) {
                return {
                    context: link.context,
                    attributes: sanitizeAttributes(link.attributes),
                };
            });
            var attributes = sanitizeAttributes(options.attributes);
            // make sampling decision
            var samplingResult = this._sampler.shouldSample(context$1, traceId, name, spanKind, attributes, links);
            traceState = (_c = samplingResult.traceState) !== null && _c !== void 0 ? _c : traceState;
            var traceFlags = samplingResult.decision === SamplingDecision$1.RECORD_AND_SAMPLED
                ? TraceFlags.SAMPLED
                : TraceFlags.NONE;
            var spanContext = { traceId: traceId, spanId: spanId, traceFlags: traceFlags, traceState: traceState };
            if (samplingResult.decision === SamplingDecision$1.NOT_RECORD) {
                diag.debug('Recording is off, propagating context in a non-recording span');
                var nonRecordingSpan = trace.wrapSpanContext(spanContext);
                return nonRecordingSpan;
            }
            // Set initial span attributes. The attributes object may have been mutated
            // by the sampler, so we sanitize the merged attributes before setting them.
            var initAttributes = sanitizeAttributes(Object.assign(attributes, samplingResult.attributes));
            var span = new Span(this, context$1, name, spanContext, spanKind, parentSpanId, links, options.startTime, undefined, initAttributes);
            return span;
        };
        Tracer.prototype.startActiveSpan = function (name, arg2, arg3, arg4) {
            var opts;
            var ctx;
            var fn;
            if (arguments.length < 2) {
                return;
            }
            else if (arguments.length === 2) {
                fn = arg2;
            }
            else if (arguments.length === 3) {
                opts = arg2;
                fn = arg3;
            }
            else {
                opts = arg2;
                ctx = arg3;
                fn = arg4;
            }
            var parentContext = ctx !== null && ctx !== void 0 ? ctx : context.active();
            var span = this.startSpan(name, opts, parentContext);
            var contextWithSpanSet = trace.setSpan(parentContext, span);
            return context.with(contextWithSpanSet, fn, undefined, span);
        };
        /** Returns the active {@link GeneralLimits}. */
        Tracer.prototype.getGeneralLimits = function () {
            return this._generalLimits;
        };
        /** Returns the active {@link SpanLimits}. */
        Tracer.prototype.getSpanLimits = function () {
            return this._spanLimits;
        };
        Tracer.prototype.getActiveSpanProcessor = function () {
            return this._tracerProvider.getActiveSpanProcessor();
        };
        return Tracer;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$6 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    /**
     * Implementation of the {@link SpanProcessor} that simply forwards all
     * received events to a list of {@link SpanProcessor}s.
     */
    var MultiSpanProcessor = /** @class */ (function () {
        function MultiSpanProcessor(_spanProcessors) {
            this._spanProcessors = _spanProcessors;
        }
        MultiSpanProcessor.prototype.forceFlush = function () {
            var e_1, _a;
            var promises = [];
            try {
                for (var _b = __values$6(this._spanProcessors), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var spanProcessor = _c.value;
                    promises.push(spanProcessor.forceFlush());
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_1) throw e_1.error; }
            }
            return new Promise(function (resolve) {
                Promise.all(promises)
                    .then(function () {
                    resolve();
                })
                    .catch(function (error) {
                    globalErrorHandler(error || new Error('MultiSpanProcessor: forceFlush failed'));
                    resolve();
                });
            });
        };
        MultiSpanProcessor.prototype.onStart = function (span, context) {
            var e_2, _a;
            try {
                for (var _b = __values$6(this._spanProcessors), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var spanProcessor = _c.value;
                    spanProcessor.onStart(span, context);
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_2) throw e_2.error; }
            }
        };
        MultiSpanProcessor.prototype.onEnd = function (span) {
            var e_3, _a;
            try {
                for (var _b = __values$6(this._spanProcessors), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var spanProcessor = _c.value;
                    spanProcessor.onEnd(span);
                }
            }
            catch (e_3_1) { e_3 = { error: e_3_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_3) throw e_3.error; }
            }
        };
        MultiSpanProcessor.prototype.shutdown = function () {
            var e_4, _a;
            var promises = [];
            try {
                for (var _b = __values$6(this._spanProcessors), _c = _b.next(); !_c.done; _c = _b.next()) {
                    var spanProcessor = _c.value;
                    promises.push(spanProcessor.shutdown());
                }
            }
            catch (e_4_1) { e_4 = { error: e_4_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                }
                finally { if (e_4) throw e_4.error; }
            }
            return new Promise(function (resolve, reject) {
                Promise.all(promises).then(function () {
                    resolve();
                }, reject);
            });
        };
        return MultiSpanProcessor;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /** No-op implementation of SpanProcessor */
    var NoopSpanProcessor = /** @class */ (function () {
        function NoopSpanProcessor() {
        }
        NoopSpanProcessor.prototype.onStart = function (_span, _context) { };
        NoopSpanProcessor.prototype.onEnd = function (_span) { };
        NoopSpanProcessor.prototype.shutdown = function () {
            return Promise.resolve();
        };
        NoopSpanProcessor.prototype.forceFlush = function () {
            return Promise.resolve();
        };
        return NoopSpanProcessor;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$c = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$7 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var ForceFlushState;
    (function (ForceFlushState) {
        ForceFlushState[ForceFlushState["resolved"] = 0] = "resolved";
        ForceFlushState[ForceFlushState["timeout"] = 1] = "timeout";
        ForceFlushState[ForceFlushState["error"] = 2] = "error";
        ForceFlushState[ForceFlushState["unresolved"] = 3] = "unresolved";
    })(ForceFlushState || (ForceFlushState = {}));
    /**
     * This class represents a basic tracer provider which platform libraries can extend
     */
    var BasicTracerProvider = /** @class */ (function () {
        function BasicTracerProvider(config) {
            if (config === void 0) { config = {}; }
            var _a, _b;
            this._registeredSpanProcessors = [];
            this._tracers = new Map();
            var mergedConfig = merge({}, loadDefaultConfig(), reconfigureLimits(config));
            this.resource = (_a = mergedConfig.resource) !== null && _a !== void 0 ? _a : Resource.empty();
            if (mergedConfig.mergeResourceWithDefaults) {
                this.resource = Resource.default().merge(this.resource);
            }
            this._config = Object.assign({}, mergedConfig, {
                resource: this.resource,
            });
            if ((_b = config.spanProcessors) === null || _b === void 0 ? void 0 : _b.length) {
                this._registeredSpanProcessors = __spreadArray$7([], __read$c(config.spanProcessors), false);
                this.activeSpanProcessor = new MultiSpanProcessor(this._registeredSpanProcessors);
            }
            else {
                var defaultExporter = this._buildExporterFromEnv();
                if (defaultExporter !== undefined) {
                    var batchProcessor = new BatchSpanProcessor(defaultExporter);
                    this.activeSpanProcessor = batchProcessor;
                }
                else {
                    this.activeSpanProcessor = new NoopSpanProcessor();
                }
            }
        }
        BasicTracerProvider.prototype.getTracer = function (name, version, options) {
            var key = name + "@" + (version || '') + ":" + ((options === null || options === void 0 ? void 0 : options.schemaUrl) || '');
            if (!this._tracers.has(key)) {
                this._tracers.set(key, new Tracer({ name: name, version: version, schemaUrl: options === null || options === void 0 ? void 0 : options.schemaUrl }, this._config, this));
            }
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            return this._tracers.get(key);
        };
        /**
         * @deprecated please use {@link TracerConfig} spanProcessors property
         * Adds a new {@link SpanProcessor} to this tracer.
         * @param spanProcessor the new SpanProcessor to be added.
         */
        BasicTracerProvider.prototype.addSpanProcessor = function (spanProcessor) {
            if (this._registeredSpanProcessors.length === 0) {
                // since we might have enabled by default a batchProcessor, we disable it
                // before adding the new one
                this.activeSpanProcessor
                    .shutdown()
                    .catch(function (err) {
                    return diag.error('Error while trying to shutdown current span processor', err);
                });
            }
            this._registeredSpanProcessors.push(spanProcessor);
            this.activeSpanProcessor = new MultiSpanProcessor(this._registeredSpanProcessors);
        };
        BasicTracerProvider.prototype.getActiveSpanProcessor = function () {
            return this.activeSpanProcessor;
        };
        /**
         * Register this TracerProvider for use with the OpenTelemetry API.
         * Undefined values may be replaced with defaults, and
         * null values will be skipped.
         *
         * @param config Configuration object for SDK registration
         */
        BasicTracerProvider.prototype.register = function (config) {
            if (config === void 0) { config = {}; }
            trace.setGlobalTracerProvider(this);
            if (config.propagator === undefined) {
                config.propagator = this._buildPropagatorFromEnv();
            }
            if (config.contextManager) {
                context.setGlobalContextManager(config.contextManager);
            }
            if (config.propagator) {
                propagation.setGlobalPropagator(config.propagator);
            }
        };
        BasicTracerProvider.prototype.forceFlush = function () {
            var timeout = this._config.forceFlushTimeoutMillis;
            var promises = this._registeredSpanProcessors.map(function (spanProcessor) {
                return new Promise(function (resolve) {
                    var state;
                    var timeoutInterval = setTimeout(function () {
                        resolve(new Error("Span processor did not completed within timeout period of " + timeout + " ms"));
                        state = ForceFlushState.timeout;
                    }, timeout);
                    spanProcessor
                        .forceFlush()
                        .then(function () {
                        clearTimeout(timeoutInterval);
                        if (state !== ForceFlushState.timeout) {
                            state = ForceFlushState.resolved;
                            resolve(state);
                        }
                    })
                        .catch(function (error) {
                        clearTimeout(timeoutInterval);
                        state = ForceFlushState.error;
                        resolve(error);
                    });
                });
            });
            return new Promise(function (resolve, reject) {
                Promise.all(promises)
                    .then(function (results) {
                    var errors = results.filter(function (result) { return result !== ForceFlushState.resolved; });
                    if (errors.length > 0) {
                        reject(errors);
                    }
                    else {
                        resolve();
                    }
                })
                    .catch(function (error) { return reject([error]); });
            });
        };
        BasicTracerProvider.prototype.shutdown = function () {
            return this.activeSpanProcessor.shutdown();
        };
        /**
         * TS cannot yet infer the type of this.constructor:
         * https://github.com/Microsoft/TypeScript/issues/3841#issuecomment-337560146
         * There is no need to override either of the getters in your child class.
         * The type of the registered component maps should be the same across all
         * classes in the inheritance tree.
         */
        BasicTracerProvider.prototype._getPropagator = function (name) {
            var _a;
            return (_a = this.constructor._registeredPropagators.get(name)) === null || _a === void 0 ? void 0 : _a();
        };
        BasicTracerProvider.prototype._getSpanExporter = function (name) {
            var _a;
            return (_a = this.constructor._registeredExporters.get(name)) === null || _a === void 0 ? void 0 : _a();
        };
        BasicTracerProvider.prototype._buildPropagatorFromEnv = function () {
            var _this = this;
            // per spec, propagators from env must be deduplicated
            var uniquePropagatorNames = Array.from(new Set(getEnv().OTEL_PROPAGATORS));
            var propagators = uniquePropagatorNames.map(function (name) {
                var propagator = _this._getPropagator(name);
                if (!propagator) {
                    diag.warn("Propagator \"" + name + "\" requested through environment variable is unavailable.");
                }
                return propagator;
            });
            var validPropagators = propagators.reduce(function (list, item) {
                if (item) {
                    list.push(item);
                }
                return list;
            }, []);
            if (validPropagators.length === 0) {
                return;
            }
            else if (uniquePropagatorNames.length === 1) {
                return validPropagators[0];
            }
            else {
                return new CompositePropagator({
                    propagators: validPropagators,
                });
            }
        };
        BasicTracerProvider.prototype._buildExporterFromEnv = function () {
            var exporterName = getEnv().OTEL_TRACES_EXPORTER;
            if (exporterName === 'none' || exporterName === '')
                return;
            var exporter = this._getSpanExporter(exporterName);
            if (!exporter) {
                diag.error("Exporter \"" + exporterName + "\" requested through environment variable is unavailable.");
            }
            return exporter;
        };
        BasicTracerProvider._registeredPropagators = new Map([
            ['tracecontext', function () { return new W3CTraceContextPropagator(); }],
            ['baggage', function () { return new W3CBaggagePropagator(); }],
        ]);
        BasicTracerProvider._registeredExporters = new Map();
        return BasicTracerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __read$b = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$6 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /**
     * Stack Context Manager for managing the state in web
     * it doesn't fully support the async calls though
     */
    var StackContextManager = /** @class */ (function () {
        function StackContextManager() {
            /**
             * whether the context manager is enabled or not
             */
            this._enabled = false;
            /**
             * Keeps the reference to current context
             */
            this._currentContext = ROOT_CONTEXT;
        }
        /**
         *
         * @param context
         * @param target Function to be executed within the context
         */
        // eslint-disable-next-line @typescript-eslint/ban-types
        StackContextManager.prototype._bindFunction = function (context, target) {
            if (context === void 0) { context = ROOT_CONTEXT; }
            var manager = this;
            var contextWrapper = function () {
                var _this = this;
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                return manager.with(context, function () { return target.apply(_this, args); });
            };
            Object.defineProperty(contextWrapper, 'length', {
                enumerable: false,
                configurable: true,
                writable: false,
                value: target.length,
            });
            return contextWrapper;
        };
        /**
         * Returns the active context
         */
        StackContextManager.prototype.active = function () {
            return this._currentContext;
        };
        /**
         * Binds a the certain context or the active one to the target function and then returns the target
         * @param context A context (span) to be bind to target
         * @param target a function or event emitter. When target or one of its callbacks is called,
         *  the provided context will be used as the active context for the duration of the call.
         */
        StackContextManager.prototype.bind = function (context, target) {
            // if no specific context to propagate is given, we use the current one
            if (context === undefined) {
                context = this.active();
            }
            if (typeof target === 'function') {
                return this._bindFunction(context, target);
            }
            return target;
        };
        /**
         * Disable the context manager (clears the current context)
         */
        StackContextManager.prototype.disable = function () {
            this._currentContext = ROOT_CONTEXT;
            this._enabled = false;
            return this;
        };
        /**
         * Enables the context manager and creates a default(root) context
         */
        StackContextManager.prototype.enable = function () {
            if (this._enabled) {
                return this;
            }
            this._enabled = true;
            this._currentContext = ROOT_CONTEXT;
            return this;
        };
        /**
         * Calls the callback function [fn] with the provided [context]. If [context] is undefined then it will use the window.
         * The context will be set as active
         * @param context
         * @param fn Callback function
         * @param thisArg optional receiver to be used for calling fn
         * @param args optional arguments forwarded to fn
         */
        StackContextManager.prototype.with = function (context, fn, thisArg) {
            var args = [];
            for (var _i = 3; _i < arguments.length; _i++) {
                args[_i - 3] = arguments[_i];
            }
            var previousContext = this._currentContext;
            this._currentContext = context || ROOT_CONTEXT;
            try {
                return fn.call.apply(fn, __spreadArray$6([thisArg], __read$b(args), false));
            }
            finally {
                this._currentContext = previousContext;
            }
        };
        return StackContextManager;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$i = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * This class represents a web tracer with {@link StackContextManager}
     */
    var WebTracerProvider = /** @class */ (function (_super) {
        __extends$i(WebTracerProvider, _super);
        /**
         * Constructs a new Tracer instance.
         * @param config Web Tracer config
         */
        function WebTracerProvider(config) {
            if (config === void 0) { config = {}; }
            var _this = _super.call(this, config) || this;
            if (config.contextManager) {
                throw ('contextManager should be defined in register method not in' +
                    ' constructor');
            }
            if (config.propagator) {
                throw 'propagator should be defined in register method not in constructor';
            }
            return _this;
        }
        /**
         * Register this TracerProvider for use with the OpenTelemetry API.
         * Undefined values may be replaced with defaults, and
         * null values will be skipped.
         *
         * @param config Configuration object for SDK registration
         */
        WebTracerProvider.prototype.register = function (config) {
            if (config === void 0) { config = {}; }
            if (config.contextManager === undefined) {
                config.contextManager = new StackContextManager();
            }
            if (config.contextManager) {
                config.contextManager.enable();
            }
            _super.prototype.register.call(this, config);
        };
        return WebTracerProvider;
    }(BasicTracerProvider));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var PerformanceTimingNames;
    (function (PerformanceTimingNames) {
        PerformanceTimingNames["CONNECT_END"] = "connectEnd";
        PerformanceTimingNames["CONNECT_START"] = "connectStart";
        PerformanceTimingNames["DECODED_BODY_SIZE"] = "decodedBodySize";
        PerformanceTimingNames["DOM_COMPLETE"] = "domComplete";
        PerformanceTimingNames["DOM_CONTENT_LOADED_EVENT_END"] = "domContentLoadedEventEnd";
        PerformanceTimingNames["DOM_CONTENT_LOADED_EVENT_START"] = "domContentLoadedEventStart";
        PerformanceTimingNames["DOM_INTERACTIVE"] = "domInteractive";
        PerformanceTimingNames["DOMAIN_LOOKUP_END"] = "domainLookupEnd";
        PerformanceTimingNames["DOMAIN_LOOKUP_START"] = "domainLookupStart";
        PerformanceTimingNames["ENCODED_BODY_SIZE"] = "encodedBodySize";
        PerformanceTimingNames["FETCH_START"] = "fetchStart";
        PerformanceTimingNames["LOAD_EVENT_END"] = "loadEventEnd";
        PerformanceTimingNames["LOAD_EVENT_START"] = "loadEventStart";
        PerformanceTimingNames["NAVIGATION_START"] = "navigationStart";
        PerformanceTimingNames["REDIRECT_END"] = "redirectEnd";
        PerformanceTimingNames["REDIRECT_START"] = "redirectStart";
        PerformanceTimingNames["REQUEST_START"] = "requestStart";
        PerformanceTimingNames["RESPONSE_END"] = "responseEnd";
        PerformanceTimingNames["RESPONSE_START"] = "responseStart";
        PerformanceTimingNames["SECURE_CONNECTION_START"] = "secureConnectionStart";
        PerformanceTimingNames["UNLOAD_EVENT_END"] = "unloadEventEnd";
        PerformanceTimingNames["UNLOAD_EVENT_START"] = "unloadEventStart";
    })(PerformanceTimingNames || (PerformanceTimingNames = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Used to normalize relative URLs
    var urlNormalizingAnchor;
    function getUrlNormalizingAnchor() {
        if (!urlNormalizingAnchor) {
            urlNormalizingAnchor = document.createElement('a');
        }
        return urlNormalizingAnchor;
    }
    /**
     * Helper function to be able to use enum as typed key in type and in interface when using forEach
     * @param obj
     * @param key
     */
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    function hasKey(obj, key) {
        return key in obj;
    }
    /**
     * Helper function for starting an event on span based on {@link PerformanceEntries}
     * @param span
     * @param performanceName name of performance entry for time start
     * @param entries
     * @param refPerfName name of performance entry to use for reference
     */
    function addSpanNetworkEvent(span, performanceName, entries, refPerfName) {
        var perfTime = undefined;
        var refTime = undefined;
        if (hasKey(entries, performanceName) &&
            typeof entries[performanceName] === 'number') {
            perfTime = entries[performanceName];
        }
        var refName = PerformanceTimingNames.FETCH_START;
        // Use a reference time which is the earliest possible value so that the performance timings that are earlier should not be added
        // using FETCH START time in case no reference is provided
        if (hasKey(entries, refName) && typeof entries[refName] === 'number') {
            refTime = entries[refName];
        }
        if (perfTime !== undefined && refTime !== undefined && perfTime >= refTime) {
            span.addEvent(performanceName, perfTime);
            return span;
        }
        return undefined;
    }
    /**
     * Helper function for adding network events and content length attributes
     * @param span
     * @param resource
     * @param ignoreNetworkEvents
     */
    function addSpanNetworkEvents(span, resource, ignoreNetworkEvents) {
        if (ignoreNetworkEvents === void 0) { ignoreNetworkEvents = false; }
        if (!ignoreNetworkEvents) {
            addSpanNetworkEvent(span, PerformanceTimingNames.FETCH_START, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.DOMAIN_LOOKUP_START, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.DOMAIN_LOOKUP_END, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.CONNECT_START, resource);
            if (hasKey(resource, 'name') &&
                resource['name'].startsWith('https:')) {
                addSpanNetworkEvent(span, PerformanceTimingNames.SECURE_CONNECTION_START, resource);
            }
            addSpanNetworkEvent(span, PerformanceTimingNames.CONNECT_END, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.REQUEST_START, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.RESPONSE_START, resource);
            addSpanNetworkEvent(span, PerformanceTimingNames.RESPONSE_END, resource);
        }
        var encodedLength = resource[PerformanceTimingNames.ENCODED_BODY_SIZE];
        if (encodedLength !== undefined) {
            span.setAttribute(SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH, encodedLength);
        }
        var decodedLength = resource[PerformanceTimingNames.DECODED_BODY_SIZE];
        // Spec: Not set if transport encoding not used (in which case encoded and decoded sizes match)
        if (decodedLength !== undefined && encodedLength !== decodedLength) {
            span.setAttribute(SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH_UNCOMPRESSED, decodedLength);
        }
    }
    /**
     * sort resources by startTime
     * @param filteredResources
     */
    function sortResources(filteredResources) {
        return filteredResources.slice().sort(function (a, b) {
            var valueA = a[PerformanceTimingNames.FETCH_START];
            var valueB = b[PerformanceTimingNames.FETCH_START];
            if (valueA > valueB) {
                return 1;
            }
            else if (valueA < valueB) {
                return -1;
            }
            return 0;
        });
    }
    /** Returns the origin if present (if in browser context). */
    function getOrigin() {
        return typeof location !== 'undefined' ? location.origin : undefined;
    }
    /**
     * Get closest performance resource ignoring the resources that have been
     * already used.
     * @param spanUrl
     * @param startTimeHR
     * @param endTimeHR
     * @param resources
     * @param ignoredResources
     * @param initiatorType
     */
    function getResource(spanUrl, startTimeHR, endTimeHR, resources, ignoredResources, initiatorType) {
        if (ignoredResources === void 0) { ignoredResources = new WeakSet(); }
        // de-relativize the URL before usage (does no harm to absolute URLs)
        var parsedSpanUrl = parseUrl(spanUrl);
        spanUrl = parsedSpanUrl.toString();
        var filteredResources = filterResourcesForSpan(spanUrl, startTimeHR, endTimeHR, resources, ignoredResources, initiatorType);
        if (filteredResources.length === 0) {
            return {
                mainRequest: undefined,
            };
        }
        if (filteredResources.length === 1) {
            return {
                mainRequest: filteredResources[0],
            };
        }
        var sorted = sortResources(filteredResources);
        if (parsedSpanUrl.origin !== getOrigin() && sorted.length > 1) {
            var corsPreFlightRequest = sorted[0];
            var mainRequest = findMainRequest(sorted, corsPreFlightRequest[PerformanceTimingNames.RESPONSE_END], endTimeHR);
            var responseEnd = corsPreFlightRequest[PerformanceTimingNames.RESPONSE_END];
            var fetchStart = mainRequest[PerformanceTimingNames.FETCH_START];
            // no corsPreFlightRequest
            if (fetchStart < responseEnd) {
                mainRequest = corsPreFlightRequest;
                corsPreFlightRequest = undefined;
            }
            return {
                corsPreFlightRequest: corsPreFlightRequest,
                mainRequest: mainRequest,
            };
        }
        else {
            return {
                mainRequest: filteredResources[0],
            };
        }
    }
    /**
     * Will find the main request skipping the cors pre flight requests
     * @param resources
     * @param corsPreFlightRequestEndTime
     * @param spanEndTimeHR
     */
    function findMainRequest(resources, corsPreFlightRequestEndTime, spanEndTimeHR) {
        var spanEndTime = hrTimeToNanoseconds(spanEndTimeHR);
        var minTime = hrTimeToNanoseconds(timeInputToHrTime(corsPreFlightRequestEndTime));
        var mainRequest = resources[1];
        var bestGap;
        var length = resources.length;
        for (var i = 1; i < length; i++) {
            var resource = resources[i];
            var resourceStartTime = hrTimeToNanoseconds(timeInputToHrTime(resource[PerformanceTimingNames.FETCH_START]));
            var resourceEndTime = hrTimeToNanoseconds(timeInputToHrTime(resource[PerformanceTimingNames.RESPONSE_END]));
            var currentGap = spanEndTime - resourceEndTime;
            if (resourceStartTime >= minTime && (!bestGap || currentGap < bestGap)) {
                bestGap = currentGap;
                mainRequest = resource;
            }
        }
        return mainRequest;
    }
    /**
     * Filter all resources that has started and finished according to span start time and end time.
     *     It will return the closest resource to a start time
     * @param spanUrl
     * @param startTimeHR
     * @param endTimeHR
     * @param resources
     * @param ignoredResources
     */
    function filterResourcesForSpan(spanUrl, startTimeHR, endTimeHR, resources, ignoredResources, initiatorType) {
        var startTime = hrTimeToNanoseconds(startTimeHR);
        var endTime = hrTimeToNanoseconds(endTimeHR);
        var filteredResources = resources.filter(function (resource) {
            var resourceStartTime = hrTimeToNanoseconds(timeInputToHrTime(resource[PerformanceTimingNames.FETCH_START]));
            var resourceEndTime = hrTimeToNanoseconds(timeInputToHrTime(resource[PerformanceTimingNames.RESPONSE_END]));
            return (resource.initiatorType.toLowerCase() ===
                (initiatorType || 'xmlhttprequest') &&
                resource.name === spanUrl &&
                resourceStartTime >= startTime &&
                resourceEndTime <= endTime);
        });
        if (filteredResources.length > 0) {
            filteredResources = filteredResources.filter(function (resource) {
                return !ignoredResources.has(resource);
            });
        }
        return filteredResources;
    }
    /**
     * Parses url using URL constructor or fallback to anchor element.
     * @param url
     */
    function parseUrl(url) {
        if (typeof URL === 'function') {
            return new URL(url, typeof document !== 'undefined'
                ? document.baseURI
                : typeof location !== 'undefined' // Some JS runtimes (e.g. Deno) don't define this
                    ? location.href
                    : undefined);
        }
        var element = getUrlNormalizingAnchor();
        element.href = url;
        return element;
    }
    /**
     * Checks if trace headers should be propagated
     * @param spanUrl
     * @private
     */
    function shouldPropagateTraceHeaders(spanUrl, propagateTraceHeaderCorsUrls) {
        var propagateTraceHeaderUrls = propagateTraceHeaderCorsUrls || [];
        if (typeof propagateTraceHeaderUrls === 'string' ||
            propagateTraceHeaderUrls instanceof RegExp) {
            propagateTraceHeaderUrls = [propagateTraceHeaderUrls];
        }
        var parsedSpanUrl = parseUrl(spanUrl);
        if (parsedSpanUrl.origin === getOrigin()) {
            return true;
        }
        else {
            return propagateTraceHeaderUrls.some(function (propagateTraceHeaderUrl) {
                return urlMatches(spanUrl, propagateTraceHeaderUrl);
            });
        }
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function hrTimeToNanos(hrTime) {
        var NANOSECONDS = BigInt(1000000000);
        return BigInt(hrTime[0]) * NANOSECONDS + BigInt(hrTime[1]);
    }
    function toLongBits(value) {
        var low = Number(BigInt.asUintN(32, value));
        var high = Number(BigInt.asUintN(32, value >> BigInt(32)));
        return { low: low, high: high };
    }
    function encodeAsLongBits(hrTime) {
        var nanos = hrTimeToNanos(hrTime);
        return toLongBits(nanos);
    }
    function encodeAsString(hrTime) {
        var nanos = hrTimeToNanos(hrTime);
        return nanos.toString();
    }
    var encodeTimestamp = typeof BigInt !== 'undefined' ? encodeAsString : hrTimeToNanoseconds;
    function identity(value) {
        return value;
    }
    function optionalHexToBinary(str) {
        if (str === undefined)
            return undefined;
        return hexToBinary(str);
    }
    var DEFAULT_ENCODER = {
        encodeHrTime: encodeAsLongBits,
        encodeSpanContext: hexToBinary,
        encodeOptionalSpanContext: optionalHexToBinary,
    };
    function getOtlpEncoder(options) {
        var _a, _b;
        if (options === undefined) {
            return DEFAULT_ENCODER;
        }
        var useLongBits = (_a = options.useLongBits) !== null && _a !== void 0 ? _a : true;
        var useHex = (_b = options.useHex) !== null && _b !== void 0 ? _b : false;
        return {
            encodeHrTime: useLongBits ? encodeAsLongBits : encodeTimestamp,
            encodeSpanContext: useHex ? identity : hexToBinary,
            encodeOptionalSpanContext: useHex ? identity : optionalHexToBinary,
        };
    }

    var __read$a = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    function createResource(resource) {
        return {
            attributes: toAttributes(resource.attributes),
            droppedAttributesCount: 0,
        };
    }
    function createInstrumentationScope(scope) {
        return {
            name: scope.name,
            version: scope.version,
        };
    }
    function toAttributes(attributes) {
        return Object.keys(attributes).map(function (key) { return toKeyValue(key, attributes[key]); });
    }
    function toKeyValue(key, value) {
        return {
            key: key,
            value: toAnyValue(value),
        };
    }
    function toAnyValue(value) {
        var t = typeof value;
        if (t === 'string')
            return { stringValue: value };
        if (t === 'number') {
            if (!Number.isInteger(value))
                return { doubleValue: value };
            return { intValue: value };
        }
        if (t === 'boolean')
            return { boolValue: value };
        if (value instanceof Uint8Array)
            return { bytesValue: value };
        if (Array.isArray(value))
            return { arrayValue: { values: value.map(toAnyValue) } };
        if (t === 'object' && value != null)
            return {
                kvlistValue: {
                    values: Object.entries(value).map(function (_a) {
                        var _b = __read$a(_a, 2), k = _b[0], v = _b[1];
                        return toKeyValue(k, v);
                    }),
                },
            };
        return {};
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$5 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$9 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    function createExportLogsServiceRequest(logRecords, options) {
        var encoder = getOtlpEncoder(options);
        return {
            resourceLogs: logRecordsToResourceLogs(logRecords, encoder),
        };
    }
    function createResourceMap$1(logRecords) {
        var e_1, _a;
        var resourceMap = new Map();
        try {
            for (var logRecords_1 = __values$5(logRecords), logRecords_1_1 = logRecords_1.next(); !logRecords_1_1.done; logRecords_1_1 = logRecords_1.next()) {
                var record = logRecords_1_1.value;
                var resource = record.resource, _b = record.instrumentationScope, name_1 = _b.name, _c = _b.version, version = _c === void 0 ? '' : _c, _d = _b.schemaUrl, schemaUrl = _d === void 0 ? '' : _d;
                var ismMap = resourceMap.get(resource);
                if (!ismMap) {
                    ismMap = new Map();
                    resourceMap.set(resource, ismMap);
                }
                var ismKey = name_1 + "@" + version + ":" + schemaUrl;
                var records = ismMap.get(ismKey);
                if (!records) {
                    records = [];
                    ismMap.set(ismKey, records);
                }
                records.push(record);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (logRecords_1_1 && !logRecords_1_1.done && (_a = logRecords_1.return)) _a.call(logRecords_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return resourceMap;
    }
    function logRecordsToResourceLogs(logRecords, encoder) {
        var resourceMap = createResourceMap$1(logRecords);
        return Array.from(resourceMap, function (_a) {
            var _b = __read$9(_a, 2), resource = _b[0], ismMap = _b[1];
            return ({
                resource: createResource(resource),
                scopeLogs: Array.from(ismMap, function (_a) {
                    var _b = __read$9(_a, 2), scopeLogs = _b[1];
                    return {
                        scope: createInstrumentationScope(scopeLogs[0].instrumentationScope),
                        logRecords: scopeLogs.map(function (log) { return toLogRecord(log, encoder); }),
                        schemaUrl: scopeLogs[0].instrumentationScope.schemaUrl,
                    };
                }),
                schemaUrl: undefined,
            });
        });
    }
    function toLogRecord(log, encoder) {
        var _a, _b, _c;
        return {
            timeUnixNano: encoder.encodeHrTime(log.hrTime),
            observedTimeUnixNano: encoder.encodeHrTime(log.hrTimeObserved),
            severityNumber: toSeverityNumber(log.severityNumber),
            severityText: log.severityText,
            body: toAnyValue(log.body),
            attributes: toLogAttributes(log.attributes),
            droppedAttributesCount: log.droppedAttributesCount,
            flags: (_a = log.spanContext) === null || _a === void 0 ? void 0 : _a.traceFlags,
            traceId: encoder.encodeOptionalSpanContext((_b = log.spanContext) === null || _b === void 0 ? void 0 : _b.traceId),
            spanId: encoder.encodeOptionalSpanContext((_c = log.spanContext) === null || _c === void 0 ? void 0 : _c.spanId),
        };
    }
    function toSeverityNumber(severityNumber) {
        return severityNumber;
    }
    function toLogAttributes(attributes) {
        return Object.keys(attributes).map(function (key) { return toKeyValue(key, attributes[key]); });
    }

    var __values$4 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$8 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    function sdkSpanToOtlpSpan(span, encoder) {
        var _a;
        var ctx = span.spanContext();
        var status = span.status;
        return {
            traceId: encoder.encodeSpanContext(ctx.traceId),
            spanId: encoder.encodeSpanContext(ctx.spanId),
            parentSpanId: encoder.encodeOptionalSpanContext(span.parentSpanId),
            traceState: (_a = ctx.traceState) === null || _a === void 0 ? void 0 : _a.serialize(),
            name: span.name,
            // Span kind is offset by 1 because the API does not define a value for unset
            kind: span.kind == null ? 0 : span.kind + 1,
            startTimeUnixNano: encoder.encodeHrTime(span.startTime),
            endTimeUnixNano: encoder.encodeHrTime(span.endTime),
            attributes: toAttributes(span.attributes),
            droppedAttributesCount: span.droppedAttributesCount,
            events: span.events.map(function (event) { return toOtlpSpanEvent(event, encoder); }),
            droppedEventsCount: span.droppedEventsCount,
            status: {
                // API and proto enums share the same values
                code: status.code,
                message: status.message,
            },
            links: span.links.map(function (link) { return toOtlpLink(link, encoder); }),
            droppedLinksCount: span.droppedLinksCount,
        };
    }
    function toOtlpLink(link, encoder) {
        var _a;
        return {
            attributes: link.attributes ? toAttributes(link.attributes) : [],
            spanId: encoder.encodeSpanContext(link.context.spanId),
            traceId: encoder.encodeSpanContext(link.context.traceId),
            traceState: (_a = link.context.traceState) === null || _a === void 0 ? void 0 : _a.serialize(),
            droppedAttributesCount: link.droppedAttributesCount || 0,
        };
    }
    function toOtlpSpanEvent(timedEvent, encoder) {
        return {
            attributes: timedEvent.attributes
                ? toAttributes(timedEvent.attributes)
                : [],
            name: timedEvent.name,
            timeUnixNano: encoder.encodeHrTime(timedEvent.time),
            droppedAttributesCount: timedEvent.droppedAttributesCount || 0,
        };
    }
    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function createExportTraceServiceRequest(spans, options) {
        var encoder = getOtlpEncoder(options);
        return {
            resourceSpans: spanRecordsToResourceSpans(spans, encoder),
        };
    }
    function createResourceMap(readableSpans) {
        var e_1, _a;
        var resourceMap = new Map();
        try {
            for (var readableSpans_1 = __values$4(readableSpans), readableSpans_1_1 = readableSpans_1.next(); !readableSpans_1_1.done; readableSpans_1_1 = readableSpans_1.next()) {
                var record = readableSpans_1_1.value;
                var ilmMap = resourceMap.get(record.resource);
                if (!ilmMap) {
                    ilmMap = new Map();
                    resourceMap.set(record.resource, ilmMap);
                }
                // TODO this is duplicated in basic tracer. Consolidate on a common helper in core
                var instrumentationLibraryKey = record.instrumentationLibrary.name + "@" + (record.instrumentationLibrary.version || '') + ":" + (record.instrumentationLibrary.schemaUrl || '');
                var records = ilmMap.get(instrumentationLibraryKey);
                if (!records) {
                    records = [];
                    ilmMap.set(instrumentationLibraryKey, records);
                }
                records.push(record);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (readableSpans_1_1 && !readableSpans_1_1.done && (_a = readableSpans_1.return)) _a.call(readableSpans_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return resourceMap;
    }
    function spanRecordsToResourceSpans(readableSpans, encoder) {
        var resourceMap = createResourceMap(readableSpans);
        var out = [];
        var entryIterator = resourceMap.entries();
        var entry = entryIterator.next();
        while (!entry.done) {
            var _a = __read$8(entry.value, 2), resource = _a[0], ilmMap = _a[1];
            var scopeResourceSpans = [];
            var ilmIterator = ilmMap.values();
            var ilmEntry = ilmIterator.next();
            while (!ilmEntry.done) {
                var scopeSpans = ilmEntry.value;
                if (scopeSpans.length > 0) {
                    var spans = scopeSpans.map(function (readableSpan) {
                        return sdkSpanToOtlpSpan(readableSpan, encoder);
                    });
                    scopeResourceSpans.push({
                        scope: createInstrumentationScope(scopeSpans[0].instrumentationLibrary),
                        spans: spans,
                        schemaUrl: scopeSpans[0].instrumentationLibrary.schemaUrl,
                    });
                }
                ilmEntry = ilmIterator.next();
            }
            // TODO SDK types don't provide resource schema URL at this time
            var transformedSpans = {
                resource: createResource(resource),
                scopeSpans: scopeResourceSpans,
                schemaUrl: undefined,
            };
            out.push(transformedSpans);
            entry = entryIterator.next();
        }
        return out;
    }

    /*
     * @experimental this serializer may receive breaking changes in minor versions, pin this package's version when using this constant
     */
    var JsonLogsSerializer = {
        serializeRequest: function (arg) {
            var request = createExportLogsServiceRequest(arg, {
                useHex: true,
                useLongBits: false,
            });
            var encoder = new TextEncoder();
            return encoder.encode(JSON.stringify(request));
        },
        deserializeResponse: function (arg) {
            var decoder = new TextDecoder();
            return JSON.parse(decoder.decode(arg));
        },
    };

    var JsonTraceSerializer = {
        serializeRequest: function (arg) {
            var request = createExportTraceServiceRequest(arg, {
                useHex: true,
                useLongBits: false,
            });
            var encoder = new TextEncoder();
            return encoder.encode(JSON.stringify(request));
        },
        deserializeResponse: function (arg) {
            var decoder = new TextDecoder();
            return JSON.parse(decoder.decode(arg));
        },
    };

    var BaseFetchExporter = /** @class */ (function () {
        function BaseFetchExporter(_delegate) {
            this._delegate = _delegate;
        }
        BaseFetchExporter.prototype.export = function (items, resultCallback) {
            this._delegate.export(items, resultCallback);
        };
        BaseFetchExporter.prototype.forceFlush = function () {
            return this._delegate.forceFlush();
        };
        BaseFetchExporter.prototype.shutdown = function () {
            return this._delegate.shutdown();
        };
        return BaseFetchExporter;
    }());

    var __extends$h = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var OTLPFetchLogExporter = /** @class */ (function (_super) {
        __extends$h(OTLPFetchLogExporter, _super);
        function OTLPFetchLogExporter(config) {
            return _super.call(this, createOtlpBrowserFetchExportDelegate(config, JsonLogsSerializer)) || this;
        }
        return OTLPFetchLogExporter;
    }(BaseFetchExporter));

    var getLogEndpoint = function (appID) { return getDataURL(appID) + '/v2/logs'; };

    var __extends$g = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __assign$7 = (undefined && undefined.__assign) || function () {
        __assign$7 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$7.apply(this, arguments);
    };
    var EmbraceLogExporter = /** @class */ (function (_super) {
        __extends$g(EmbraceLogExporter, _super);
        function EmbraceLogExporter(_a) {
            var appID = _a.appID, userID = _a.userID;
            return _super.call(this, __assign$7(__assign$7({}, DEFAULT_EMBRACE_EXPORTER_CONFIG), { headers: getEmbraceHeaders(appID, userID), url: getLogEndpoint(appID) })) || this;
        }
        return EmbraceLogExporter;
    }(OTLPFetchLogExporter));

    var __extends$f = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __assign$6 = (undefined && undefined.__assign) || function () {
        __assign$6 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$6.apply(this, arguments);
    };
    var OTLPFetchTraceExporter = /** @class */ (function (_super) {
        __extends$f(OTLPFetchTraceExporter, _super);
        function OTLPFetchTraceExporter(config) {
            return _super.call(this, createOtlpBrowserFetchExportDelegate(__assign$6(__assign$6({}, config), { compression: 'gzip' }), JsonTraceSerializer)) || this;
        }
        return OTLPFetchTraceExporter;
    }(BaseFetchExporter));

    var getTraceEndpoint = function (appID) {
        return getDataURL(appID) + '/v2/spans';
    };

    var __extends$e = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __assign$5 = (undefined && undefined.__assign) || function () {
        __assign$5 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$5.apply(this, arguments);
    };
    var EmbraceTraceExporter = /** @class */ (function (_super) {
        __extends$e(EmbraceTraceExporter, _super);
        function EmbraceTraceExporter(_a) {
            var appID = _a.appID, userID = _a.userID;
            return _super.call(this, __assign$5(__assign$5({}, DEFAULT_EMBRACE_EXPORTER_CONFIG), { headers: getEmbraceHeaders(appID, userID), url: getTraceEndpoint(appID) })) || this;
        }
        return EmbraceTraceExporter;
    }(OTLPFetchTraceExporter));

    var getEmbraceHeaders = function (appID, userID) { return ({
        'X-EM-AID': appID,
        'X-EM-DID': userID,
    }); };
    var getDataURL = function (appID) {
        return "https://a-".concat(appID, ".data.emb-api.com");
    };

    var DEFAULT_CONCURRENCY = 5; // chrome supports 10 total, firefox 17
    var DEFAULT_EMBRACE_EXPORTER_CONFIG = {
        compression: 'gzip',
        keepalive: true,
        concurrencyLimit: DEFAULT_CONCURRENCY,
        timeoutMillis: 30 * 1000,
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$d = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * Interface for handling error
     */
    var OTLPExporterError = /** @class */ (function (_super) {
        __extends$d(OTLPExporterError, _super);
        function OTLPExporterError(message, code, data) {
            var _this = _super.call(this, message) || this;
            _this.name = 'OTLPExporterError';
            _this.data = data;
            _this.code = code;
            return _this;
        }
        return OTLPExporterError;
    }(Error));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$7 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$7 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var BoundedQueueExportPromiseHandler = /** @class */ (function () {
        /**
         * @param concurrencyLimit maximum promises allowed in a queue at the same time.
         */
        function BoundedQueueExportPromiseHandler(concurrencyLimit) {
            this._sendingPromises = [];
            this._concurrencyLimit = concurrencyLimit;
        }
        BoundedQueueExportPromiseHandler.prototype.pushPromise = function (promise) {
            var _this = this;
            if (this.hasReachedLimit()) {
                throw new Error('Concurrency Limit reached');
            }
            this._sendingPromises.push(promise);
            var popPromise = function () {
                var index = _this._sendingPromises.indexOf(promise);
                _this._sendingPromises.splice(index, 1);
            };
            promise.then(popPromise, popPromise);
        };
        BoundedQueueExportPromiseHandler.prototype.hasReachedLimit = function () {
            return this._sendingPromises.length >= this._concurrencyLimit;
        };
        BoundedQueueExportPromiseHandler.prototype.awaitAll = function () {
            return __awaiter$7(this, void 0, void 0, function () {
                return __generator$7(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, Promise.all(this._sendingPromises)];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        };
        return BoundedQueueExportPromiseHandler;
    }());
    /**
     * Promise queue for keeping track of export promises. Finished promises will be auto-dequeued.
     * Allows for awaiting all promises in the queue.
     */
    function createBoundedQueueExportPromiseHandler(options) {
        return new BoundedQueueExportPromiseHandler(options.concurrencyLimit);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function isPartialSuccessResponse(response) {
        return Object.prototype.hasOwnProperty.call(response, 'partialSuccess');
    }
    /**
     * Default response handler that logs a partial success to the console.
     */
    function createLoggingPartialSuccessResponseHandler() {
        return {
            handleResponse: function (response) {
                // Partial success MUST never be an empty object according the specification
                // see https://opentelemetry.io/docs/specs/otlp/#partial-success
                if (response == null ||
                    !isPartialSuccessResponse(response) ||
                    response.partialSuccess == null ||
                    Object.keys(response.partialSuccess).length === 0) {
                    return;
                }
                diag.warn('Received Partial Success response:', JSON.stringify(response.partialSuccess));
            },
        };
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$6 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$6 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var OTLPExportDelegate = /** @class */ (function () {
        function OTLPExportDelegate(_transport, _serializer, _responseHandler, _promiseQueue, _timeout) {
            this._transport = _transport;
            this._serializer = _serializer;
            this._responseHandler = _responseHandler;
            this._promiseQueue = _promiseQueue;
            this._timeout = _timeout;
            this._diagLogger = diag.createComponentLogger({
                namespace: 'OTLPExportDelegate',
            });
        }
        OTLPExportDelegate.prototype.export = function (internalRepresentation, resultCallback) {
            var _this = this;
            this._diagLogger.debug('items to be sent', internalRepresentation);
            // don't do any work if too many exports are in progress.
            if (this._promiseQueue.hasReachedLimit()) {
                resultCallback({
                    code: ExportResultCode.FAILED,
                    error: new Error('Concurrent export limit reached'),
                });
                return;
            }
            var serializedRequest = this._serializer.serializeRequest(internalRepresentation);
            if (serializedRequest == null) {
                resultCallback({
                    code: ExportResultCode.FAILED,
                    error: new Error('Nothing to send'),
                });
                return;
            }
            this._promiseQueue.pushPromise(this._transport.send(serializedRequest, this._timeout).then(function (response) {
                if (response.status === 'success') {
                    if (response.data != null) {
                        try {
                            _this._responseHandler.handleResponse(_this._serializer.deserializeResponse(response.data));
                        }
                        catch (e) {
                            _this._diagLogger.warn('Export succeeded but could not deserialize response - is the response specification compliant?', e, response.data);
                        }
                    }
                    // No matter the response, we can consider the export still successful.
                    resultCallback({
                        code: ExportResultCode.SUCCESS,
                    });
                    return;
                }
                else if (response.status === 'failure' && response.error) {
                    resultCallback({
                        code: ExportResultCode.FAILED,
                        error: response.error,
                    });
                    return;
                }
                else if (response.status === 'retryable') {
                    resultCallback({
                        code: ExportResultCode.FAILED,
                        error: new OTLPExporterError('Export failed with retryable status'),
                    });
                }
                else {
                    resultCallback({
                        code: ExportResultCode.FAILED,
                        error: new OTLPExporterError('Export failed with unknown error'),
                    });
                }
            }, function (reason) {
                return resultCallback({
                    code: ExportResultCode.FAILED,
                    error: reason,
                });
            }));
        };
        OTLPExportDelegate.prototype.forceFlush = function () {
            return this._promiseQueue.awaitAll();
        };
        OTLPExportDelegate.prototype.shutdown = function () {
            return __awaiter$6(this, void 0, void 0, function () {
                return __generator$6(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            this._diagLogger.debug('shutdown started');
                            return [4 /*yield*/, this.forceFlush()];
                        case 1:
                            _a.sent();
                            this._transport.shutdown();
                            return [2 /*return*/];
                    }
                });
            });
        };
        return OTLPExportDelegate;
    }());
    /**
     * Creates a generic delegate for OTLP exports which only contains parts of the OTLP export that are shared across all
     * signals.
     */
    function createOtlpExportDelegate(components, settings) {
        return new OTLPExportDelegate(components.transport, components.serializer, createLoggingPartialSuccessResponseHandler(), components.promiseHandler, settings.timeout);
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function createOtlpNetworkExportDelegate(options, serializer, transport) {
        return createOtlpExportDelegate({
            transport: transport,
            serializer: serializer,
            promiseHandler: createBoundedQueueExportPromiseHandler(options),
        }, { timeout: options.timeoutMillis });
    }

    var __assign$4 = (undefined && undefined.__assign) || function () {
        __assign$4 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$4.apply(this, arguments);
    };
    var __awaiter$5 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$5 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
        return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (g && (g = 0, op[0] && (_ = 0)), _) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var __values$3 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var FetchTransport = /** @class */ (function () {
        function FetchTransport(_config) {
            this._config = _config;
        }
        // _compressRequest compresses the data using the gzip algorithm.
        // Embrace Data endpoints require the data to be compressed.
        FetchTransport._compressRequest = function (data) {
            return __awaiter$5(this, void 0, void 0, function () {
                var stream, writer, compressedChunks, reader, done, result, compressedData, offset, compressedChunks_1, compressedChunks_1_1, chunk;
                var e_1, _a;
                return __generator$5(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            stream = new CompressionStream('gzip');
                            writer = stream.writable.getWriter();
                            void writer.write(data);
                            void writer.close();
                            compressedChunks = [];
                            reader = stream.readable.getReader();
                            done = false;
                            _b.label = 1;
                        case 1:
                            if (!!done) return [3 /*break*/, 3];
                            return [4 /*yield*/, reader.read()];
                        case 2:
                            result = _b.sent();
                            if (result.value) {
                                compressedChunks.push(result.value);
                            }
                            done = result.done;
                            return [3 /*break*/, 1];
                        case 3:
                            compressedData = new Uint8Array(compressedChunks.reduce(function (acc, chunk) { return acc + chunk.length; }, 0));
                            offset = 0;
                            try {
                                for (compressedChunks_1 = __values$3(compressedChunks), compressedChunks_1_1 = compressedChunks_1.next(); !compressedChunks_1_1.done; compressedChunks_1_1 = compressedChunks_1.next()) {
                                    chunk = compressedChunks_1_1.value;
                                    compressedData.set(chunk, offset);
                                    offset += chunk.length;
                                }
                            }
                            catch (e_1_1) { e_1 = { error: e_1_1 }; }
                            finally {
                                try {
                                    if (compressedChunks_1_1 && !compressedChunks_1_1.done && (_a = compressedChunks_1.return)) _a.call(compressedChunks_1);
                                }
                                finally { if (e_1) throw e_1.error; }
                            }
                            return [2 /*return*/, compressedData];
                    }
                });
            });
        };
        FetchTransport.prototype.send = function (data, timeoutMillis) {
            return this._asyncSend(data, timeoutMillis);
        };
        FetchTransport.prototype.shutdown = function () {
            // Intentionally left empty, nothing to do.
        };
        FetchTransport.prototype._asyncSend = function (data, timeoutMillis) {
            return __awaiter$5(this, void 0, void 0, function () {
                var request, headers, response;
                return __generator$5(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            request = data;
                            headers = __assign$4({ 'Content-Type': 'application/json' }, this._config.headers);
                            if (!(this._config.compression === 'gzip')) return [3 /*break*/, 2];
                            return [4 /*yield*/, FetchTransport._compressRequest(data)];
                        case 1:
                            request = _b.sent();
                            headers['Content-Encoding'] = 'gzip';
                            headers['Content-Length'] = request.length.toString();
                            _b.label = 2;
                        case 2:
                            _b.trys.push([2, 4, , 5]);
                            return [4 /*yield*/, fetch(this._config.url, {
                                    method: 'POST',
                                    keepalive: true,
                                    headers: headers,
                                    body: request,
                                    signal: AbortSignal.timeout(timeoutMillis),
                                })];
                        case 3:
                            response = _b.sent();
                            if (response.ok) {
                                return [2 /*return*/, { status: 'success' }];
                            }
                            else {
                                return [2 /*return*/, { status: 'failure', error: new Error('Fetch request failed') }];
                            }
                        case 4:
                            _b.sent();
                            return [2 /*return*/, { status: 'failure', error: new Error('Fetch request errored') }];
                        case 5: return [2 /*return*/];
                    }
                });
            });
        };
        return FetchTransport;
    }());

    var createFetchTransport = function (config) { return new FetchTransport(config); };

    const byteToHex = [];
    for (let i = 0; i < 256; ++i) {
        byteToHex.push((i + 0x100).toString(16).slice(1));
    }
    function unsafeStringify(arr, offset = 0) {
        return (byteToHex[arr[offset + 0]] +
            byteToHex[arr[offset + 1]] +
            byteToHex[arr[offset + 2]] +
            byteToHex[arr[offset + 3]] +
            '-' +
            byteToHex[arr[offset + 4]] +
            byteToHex[arr[offset + 5]] +
            '-' +
            byteToHex[arr[offset + 6]] +
            byteToHex[arr[offset + 7]] +
            '-' +
            byteToHex[arr[offset + 8]] +
            byteToHex[arr[offset + 9]] +
            '-' +
            byteToHex[arr[offset + 10]] +
            byteToHex[arr[offset + 11]] +
            byteToHex[arr[offset + 12]] +
            byteToHex[arr[offset + 13]] +
            byteToHex[arr[offset + 14]] +
            byteToHex[arr[offset + 15]]).toLowerCase();
    }

    let getRandomValues;
    const rnds8 = new Uint8Array(16);
    function rng() {
        if (!getRandomValues) {
            if (typeof crypto === 'undefined' || !crypto.getRandomValues) {
                throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
            }
            getRandomValues = crypto.getRandomValues.bind(crypto);
        }
        return getRandomValues(rnds8);
    }

    const randomUUID = typeof crypto !== 'undefined' && crypto.randomUUID && crypto.randomUUID.bind(crypto);
    var native = { randomUUID };

    function v4(options, buf, offset) {
        if (native.randomUUID && true && !options) {
            return native.randomUUID();
        }
        options = options || {};
        const rnds = options.random ?? options.rng?.() ?? rng();
        if (rnds.length < 16) {
            throw new Error('Random bytes length must be >= 16');
        }
        rnds[6] = (rnds[6] & 0x0f) | 0x40;
        rnds[8] = (rnds[8] & 0x3f) | 0x80;
        return unsafeStringify(rnds);
    }

    var generateUUID = function () { return v4().replace(/-/g, '').toUpperCase(); };

    var __read$7 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$5 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /**
     * Wraps a callback in a try-catch and returns a default value upon failure
     */
    var withErrorFallback = function (fn, defaultValue, silent, diag) {
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            try {
                return fn.apply(void 0, __spreadArray$5([], __read$7(args), false));
            }
            catch (e) {
                {
                    if (diag) {
                        var message = e instanceof Error ? e.message : 'Unknown error.';
                        diag.error(message);
                    }
                    else {
                        console.error(e);
                    }
                }
                return defaultValue;
            }
        };
    };

    /**
     * Add multiple event listeners to a target element.
     * example:
     *
     * ```
     * bulkAddEventListener({
     *  target: window,
     *  events: ['visibilitychange', 'resize'],
     *  callback: () => console.log('Event fired'),
     *  });
     *```
     * */
    var bulkAddEventListener = function (_a) {
        var target = _a.target, events = _a.events, callback = _a.callback;
        events.forEach(function (event) {
            target.addEventListener(event, callback);
        });
    };

    /**
     * Remove multiple event listeners from a target element.
     * example:
     *
     * ```
     * bulkRemoveEventListener({
     *  target: window,
     *  events: ['visibilitychange', 'resize'],
     *  callback: someRefToACallbackFunction,
     *  });
     *```
     * */
    var bulkRemoveEventListener = function (_a) {
        var target = _a.target, events = _a.events, callback = _a.callback;
        events.forEach(function (event) {
            target.removeEventListener(event, callback);
        });
    };

    var OTelPerformanceManager = /** @class */ (function () {
        function OTelPerformanceManager(clock) {
            if (clock === void 0) { clock = otperformance; }
            var _this = this;
            this.epochMillisFromOriginOffset = function (originOffset) {
                return _this._clock.timeOrigin + originOffset;
            };
            this.getNowHRTime = function () { return millisToHrTime(_this.getNowMillis()); };
            this.getNowMillis = function () {
                return _this.epochMillisFromOriginOffset(_this._clock.now());
            }; // otperformance.now() returns milliseconds since timeOrigin, timeOrigin is the time from epoch to the start of the page load
            this._clock = clock;
        }
        return OTelPerformanceManager;
    }());

    var __read$6 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$4 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    /** throttle wraps a function so it can only be called once, and then a time window must pass before it can be called again
     * any subsequent calls before the time window has passed will be ignored.
     *
     * NOTE: if the wrapped function makes use of "this", it must be properly bind from the caller, as this wrapper will not bind it.
     * For this, we suggest you always pass functions declared as fat arrow functions, as they have their "this" lexically defined.
     * */
    var throttle = function (func, timeout) {
        var isWaiting = false;
        return function () {
            var args = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                args[_i] = arguments[_i];
            }
            if (isWaiting) {
                return;
            }
            func.apply(void 0, __spreadArray$4([], __read$6(args), false));
            setTimeout(function () {
                isWaiting = false;
            }, timeout);
            isWaiting = true;
        };
    };

    var MAX_ATTEMPTS = 5;
    var INITIAL_BACKOFF = 1000;
    var MAX_BACKOFF = 5000;
    var BACKOFF_MULTIPLIER = 1.5;
    var JITTER = 20;

    var __awaiter$4 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$4 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
        return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (g && (g = 0, op[0] && (_ = 0)), _) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * Get a pseudo-random jitter that falls in the range of [-JITTER, +JITTER]
     */
    var getJitter = function () { return Math.random() * (2 * JITTER) - JITTER; };
    // Taken directly from open-telemetry/opentelemetry-js/experimental/packages/otlp-exporter-base/src/retrying-transport.ts
    // File is not exposed externally
    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var RetryingTransport = /** @class */ (function () {
        function RetryingTransport(_transport, _perf) {
            if (_perf === void 0) { _perf = new OTelPerformanceManager(); }
            this._transport = _transport;
            this._perf = _perf;
        }
        RetryingTransport.prototype.send = function (data, timeoutMillis) {
            return __awaiter$4(this, void 0, void 0, function () {
                var deadline, result, attempts, nextBackoff, backoff, retryInMillis, remainingTimeoutMillis;
                var _a;
                return __generator$4(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            deadline = this._perf.getNowMillis() + timeoutMillis;
                            return [4 /*yield*/, this._transport.send(data, timeoutMillis)];
                        case 1:
                            result = _b.sent();
                            attempts = MAX_ATTEMPTS;
                            nextBackoff = INITIAL_BACKOFF;
                            _b.label = 2;
                        case 2:
                            if (!(result.status === 'retryable' && attempts > 0)) return [3 /*break*/, 4];
                            attempts--;
                            backoff = Math.max(Math.min(nextBackoff, MAX_BACKOFF) + getJitter(), 0);
                            nextBackoff = nextBackoff * BACKOFF_MULTIPLIER;
                            retryInMillis = (_a = result.retryInMillis) !== null && _a !== void 0 ? _a : backoff;
                            remainingTimeoutMillis = deadline - this._perf.getNowMillis();
                            if (retryInMillis > remainingTimeoutMillis) {
                                return [2 /*return*/, result];
                            }
                            return [4 /*yield*/, this._retry(data, remainingTimeoutMillis, retryInMillis)];
                        case 3:
                            result = _b.sent();
                            return [3 /*break*/, 2];
                        case 4: return [2 /*return*/, result];
                    }
                });
            });
        };
        RetryingTransport.prototype.shutdown = function () {
            this._transport.shutdown();
        };
        RetryingTransport.prototype._retry = function (data, timeoutMillis, inMillis) {
            var _this = this;
            return new Promise(function (resolve, reject) {
                setTimeout(function () {
                    _this._transport.send(data, timeoutMillis).then(resolve, reject);
                }, inMillis);
            });
        };
        return RetryingTransport;
    }());

    /**
     * Creates an Exporter Transport that retries on 'retryable' response.
     */
    var createRetryingTransport = function (options) { return new RetryingTransport(options.transport); };

    // createOtlpBrowserFetchExportDelegate creates an export delegate that uses
    // the Fetch API to send data to an OTLP receiver.
    var createOtlpBrowserFetchExportDelegate = function (config, serializer) {
        // createOtlpNetworkExportDelegate has an internal queue that handles
        // multiple requests going at the same time.
        return createOtlpNetworkExportDelegate(config, serializer, createRetryingTransport({
            transport: createFetchTransport(config),
        }));
    };

    var KEY_EMB_TYPE = 'emb.type';
    var KEY_EMB_STATE = 'emb.state';
    var KEY_PREFIX_EMB_PROPERTIES = 'emb.properties.';
    var KEY_EMB_SESSION_REASON_ENDED = 'emb.session_end_type';
    var KEY_EMB_JS_EXCEPTION_STACKTRACE = 'emb.stacktrace.js';
    var KEY_EMB_EXCEPTION_HANDLING = 'emb.exception_handling';
    var EMB_TYPES;
    (function (EMB_TYPES) {
        EMB_TYPES["Session"] = "ux.session";
        EMB_TYPES["Network"] = "perf.network_request";
        EMB_TYPES["Perf"] = "perf";
        EMB_TYPES["SystemLog"] = "sys.log";
        EMB_TYPES["SystemException"] = "sys.exception";
        EMB_TYPES["WebVital"] = "ux.web_vital";
    })(EMB_TYPES || (EMB_TYPES = {}));
    var EMB_STATES;
    (function (EMB_STATES) {
        EMB_STATES["Foreground"] = "foreground";
    })(EMB_STATES || (EMB_STATES = {}));

    var __assign$3 = (undefined && undefined.__assign) || function () {
        __assign$3 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$3.apply(this, arguments);
    };
    var EmbraceLogManager = /** @class */ (function () {
        function EmbraceLogManager(_a) {
            var _b = _a === void 0 ? {} : _a, perf = _b.perf;
            this._perf = perf !== null && perf !== void 0 ? perf : new OTelPerformanceManager();
            this._logger = logs$1.getLogger('embrace-web-sdk-logs');
        }
        EmbraceLogManager._logSeverityToSeverityNumber = function (severity) {
            switch (severity) {
                case 'info':
                    return SeverityNumber.INFO;
                case 'warning':
                    return SeverityNumber.WARN;
                default:
                    return SeverityNumber.ERROR;
            }
        };
        EmbraceLogManager.prototype.logException = function (error, handled, attributes, timestamp) {
            var _a;
            if (attributes === void 0) { attributes = {}; }
            if (timestamp === void 0) { timestamp = this._perf.getNowMillis(); }
            this._logger.emit({
                timestamp: timestamp,
                severityNumber: SeverityNumber.ERROR,
                severityText: 'ERROR',
                body: error.message || '',
                attributes: __assign$3(__assign$3({}, attributes), (_a = {}, _a[KEY_EMB_TYPE] = EMB_TYPES.SystemException, _a[KEY_EMB_EXCEPTION_HANDLING] = handled ? 'HANDLED' : 'UNHANDLED', _a[ATTR_EXCEPTION_TYPE] = error.constructor.name, _a['exception.name'] = error.name, _a[ATTR_EXCEPTION_MESSAGE] = error.message, _a[ATTR_EXCEPTION_STACKTRACE] = error.stack, _a)),
            });
        };
        EmbraceLogManager.prototype.message = function (message, severity, attributes, includeStacktrace) {
            if (includeStacktrace === void 0) { includeStacktrace = true; }
            this._logMessage({
                message: message,
                severity: severity,
                timestamp: this._perf.getNowMillis(),
                attributes: attributes,
                stackTrace: includeStacktrace && severity != 'info' ? new Error().stack : undefined,
            });
        };
        EmbraceLogManager.prototype._logMessage = function (_a) {
            var _b, _c;
            var message = _a.message, severity = _a.severity, timestamp = _a.timestamp, _d = _a.attributes, attributes = _d === void 0 ? {} : _d, stackTrace = _a.stackTrace;
            this._logger.emit({
                timestamp: timestamp,
                severityNumber: EmbraceLogManager._logSeverityToSeverityNumber(severity),
                severityText: severity.toUpperCase(),
                body: message,
                attributes: __assign$3(__assign$3(__assign$3({}, attributes), (_b = {}, _b[KEY_EMB_TYPE] = EMB_TYPES.SystemLog, _b)), (stackTrace
                    ? (_c = {},
                        _c[KEY_EMB_JS_EXCEPTION_STACKTRACE] = stackTrace,
                        _c) : {})),
            });
        };
        return EmbraceLogManager;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    //----------------------------------------------------------------------------------------------------------
    // DO NOT EDIT, this is an Auto-generated file from scripts/semconv/templates/registry/stable/attributes.ts.j2
    //----------------------------------------------------------------------------------------------------------
    /**
     * The ID of a running ECS task. The ID **MUST** be extracted from `task.arn`.
     *
     * @example 10838bed-421f-43ef-870a-f43feacbbb5b
     * @example 23ebb8ac-c18f-46c6-8bbe-d55d0e37cfbd
     *
     * @experimental This attribute is experimental and is subject to breaking changes in minor releases of `@opentelemetry/semantic-conventions`.
     */
    /**
     * The size of the request payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the [Content-Length](https://www.rfc-editor.org/rfc/rfc9110.html#field.content-length) header. For requests using transport encoding, this should be the compressed size.
     *
     * @example 3495
     *
     * @experimental This attribute is experimental and is subject to breaking changes in minor releases of `@opentelemetry/semantic-conventions`.
     */
    var ATTR_HTTP_REQUEST_BODY_SIZE = 'http.request.body.size';
    /**
     * The size of the response payload body in bytes. This is the number of bytes transferred excluding headers and is often, but not always, present as the [Content-Length](https://www.rfc-editor.org/rfc/rfc9110.html#field.content-length) header. For requests using transport encoding, this should be the compressed size.
     *
     * @example 3495
     *
     * @experimental This attribute is experimental and is subject to breaking changes in minor releases of `@opentelemetry/semantic-conventions`.
     */
    var ATTR_HTTP_RESPONSE_BODY_SIZE = 'http.response.body.size';
    /**
     * A unique identifier for the Log Record.
     *
     * @example 01ARZ3NDEKTSV4RRFFQ69G5FAV
     *
     * @note If an id is provided, other log records with the same id will be considered duplicates and can be removed safely. This means, that two distinguishable log records **MUST** have different values.
     * The id **MAY** be an [Universally Unique Lexicographically Sortable Identifier (ULID)](https://github.com/ulid/spec), but other identifiers (e.g. UUID) may be used as needed.
     *
     * @experimental This attribute is experimental and is subject to breaking changes in minor releases of `@opentelemetry/semantic-conventions`.
     */
    var ATTR_LOG_RECORD_UID = 'log.record.uid';
    /**
     * A unique id to identify a session.
     *
     * @example "00112233-4455-6677-8899-aabbccddeeff"
     *
     * @experimental This attribute is experimental and is subject to breaking changes in minor releases of `@opentelemetry/semantic-conventions`.
     */
    var ATTR_SESSION_ID = 'session.id';

    var EmbraceSpanSessionManager = /** @class */ (function () {
        function EmbraceSpanSessionManager(_a) {
            var _b = _a === void 0 ? {} : _a, diagParam = _b.diag, perf = _b.perf;
            this._activeSessionId = null;
            this._activeSessionStartTime = null;
            this._sessionSpan = null;
            this._diag =
                diagParam !== null && diagParam !== void 0 ? diagParam : diag.createComponentLogger({
                    namespace: 'EmbraceSpanSessionManager',
                });
            this._perf = perf !== null && perf !== void 0 ? perf : new OTelPerformanceManager();
        }
        // the external api doesn't include a reason, and if a users uses it to end a session, the reason will be 'user_ended'
        EmbraceSpanSessionManager.prototype.addBreadcrumb = function (name) {
            if (!this._sessionSpan) {
                this._diag.debug('trying to add breadcrumb to a session, but there is no session in progress. This is a no-op.');
                return;
            }
            this._sessionSpan.addEvent('emb-breadcrumb', {
                message: name,
            }, this._perf.getNowMillis());
        };
        EmbraceSpanSessionManager.prototype.addProperty = function (key, value) {
            if (!this._sessionSpan) {
                this._diag.debug('trying to add properties to a session, but there is no session in progress. This is a no-op.');
                return;
            }
            this._sessionSpan.setAttribute(KEY_PREFIX_EMB_PROPERTIES + key, value);
        };
        // note: don't use this internally, this is just for user facing APIs. Use this.endSessionSpanInternal instead.
        EmbraceSpanSessionManager.prototype.endSessionSpan = function () {
            this.endSessionSpanInternal('manual');
        };
        // endSessionSpanInternal is not part of the public API, but is used internally to end a session span adding a specific reason
        EmbraceSpanSessionManager.prototype.endSessionSpanInternal = function (reason) {
            if (!this._sessionSpan) {
                this._diag.debug('trying to end a session, but there is no session in progress. This is a no-op.');
                return;
            }
            this._sessionSpan.setAttribute(KEY_EMB_SESSION_REASON_ENDED, reason);
            this._sessionSpan.end();
            this._sessionSpan = null;
            this._activeSessionStartTime = null;
            this._activeSessionId = null;
        };
        EmbraceSpanSessionManager.prototype.getSessionId = function () {
            return this._activeSessionId;
        };
        EmbraceSpanSessionManager.prototype.getSessionSpan = function () {
            return this._sessionSpan;
        };
        EmbraceSpanSessionManager.prototype.getSessionStartTime = function () {
            return this._activeSessionStartTime;
        };
        EmbraceSpanSessionManager.prototype.startSessionSpan = function () {
            var _a;
            //if there was a session in progress already, finish it first.
            if (this._sessionSpan) {
                this.endSessionSpanInternal('manual');
            }
            var tracer = trace.getTracer('embrace-web-sdk-sessions');
            this._activeSessionId = generateUUID();
            this._activeSessionStartTime = this._perf.getNowHRTime();
            this._sessionSpan = tracer.startSpan('emb-session', {
                attributes: (_a = {},
                    _a[KEY_EMB_TYPE] = EMB_TYPES.Session,
                    _a[KEY_EMB_STATE] = EMB_STATES.Foreground,
                    _a[ATTR_SESSION_ID] = this._activeSessionId,
                    _a),
            });
        };
        return EmbraceSpanSessionManager;
    }());

    var EmbraceTraceManager = /** @class */ (function () {
        function EmbraceTraceManager() {
        }
        EmbraceTraceManager.prototype.startPerformanceSpan = function (name, options) {
            if (options === void 0) { options = {}; }
            var tracer = trace.getTracer('embrace-web-sdk-traces');
            options.attributes = options.attributes ? options.attributes : {};
            options.attributes[KEY_EMB_TYPE] = EMB_TYPES.Perf;
            return tracer.startSpan(name, options);
        };
        return EmbraceTraceManager;
    }());

    var EMBRACE_USER_STORAGE_KEY = 'embrace_user';

    var isUser = function (user) {
        return typeof user[KEY_ENDUSER_PSEUDO_ID] === 'string' &&
            user[KEY_ENDUSER_PSEUDO_ID].length === 32;
    };

    var EmbraceUserManager = /** @class */ (function () {
        function EmbraceUserManager(_a) {
            var _b = _a === void 0 ? {} : _a, diagParam = _b.diag, _c = _b.storage, storage = _c === void 0 ? localStorage : _c;
            this._activeUser = null;
            this._diag =
                diagParam !== null && diagParam !== void 0 ? diagParam : diag.createComponentLogger({
                    namespace: 'EmbraceUserManager',
                });
            this._storage = storage;
            this._initialSetup();
        }
        EmbraceUserManager.prototype.clearUser = function () {
            try {
                this._storage.removeItem(EMBRACE_USER_STORAGE_KEY);
            }
            catch (e) {
                this._diag.warn('Failed to retrieve user object from storage', e);
            }
            this._activeUser = null;
        };
        EmbraceUserManager.prototype.getUser = function () {
            return this._activeUser;
        };
        EmbraceUserManager.prototype.setUser = function (user) {
            this._activeUser = user;
        };
        EmbraceUserManager.prototype._initialSetup = function () {
            try {
                var encodedUserString = this._storage.getItem(EMBRACE_USER_STORAGE_KEY);
                if (!encodedUserString) {
                    this._diag.debug('No existing user found in storage, creating a new one');
                    this._generateNewUser();
                    return;
                }
                var existingUser = JSON.parse(encodedUserString);
                if (isUser(existingUser)) {
                    this.setUser(existingUser);
                }
                else {
                    this._diag.warn('Invalid user object in localStorage, defaulting to a new one');
                }
            }
            catch (e) {
                this._diag.warn('Failed to parse user from localStorage, defaulting to a new one', e);
            }
            if (!this._activeUser) {
                this._generateNewUser();
            }
        };
        EmbraceUserManager.prototype._generateNewUser = function () {
            var _a;
            var user = (_a = {},
                _a[KEY_ENDUSER_PSEUDO_ID] = generateUUID(),
                _a);
            try {
                var encodedUserString = JSON.stringify(user);
                this._storage.setItem(EMBRACE_USER_STORAGE_KEY, encodedUserString);
            }
            catch (e) {
                this._diag.warn('Failed to persist user object for storage, keeping it in-memory only', e);
            }
            this.setUser(user);
        };
        return EmbraceUserManager;
    }());

    var EmbraceProcessor = /** @class */ (function () {
        function EmbraceProcessor(_a) {
            var providedDiag = _a.diag, processorName = _a.processorName;
            this._processorName = processorName;
            this._diag =
                providedDiag !== null && providedDiag !== void 0 ? providedDiag : diag.createComponentLogger({
                    namespace: processorName,
                });
        }
        Object.defineProperty(EmbraceProcessor.prototype, "diag", {
            /* Returns the diag logger */
            get: function () {
                return this._diag;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EmbraceProcessor.prototype, "processorName", {
            /* Returns the processor name */
            get: function () {
                return this._processorName;
            },
            enumerable: false,
            configurable: true
        });
        return EmbraceProcessor;
    }());

    var __extends$c = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __assign$2 = (undefined && undefined.__assign) || function () {
        __assign$2 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$2.apply(this, arguments);
    };
    var __rest = (undefined && undefined.__rest) || function (s, e) {
        var t = {};
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    };
    var __read$5 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$3 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var isSessionSpan = function (span) {
        return span.attributes[KEY_EMB_TYPE] === EMB_TYPES.Session;
    };
    var EmbraceSessionBatchedSpanProcessor = /** @class */ (function (_super) {
        __extends$c(EmbraceSessionBatchedSpanProcessor, _super);
        function EmbraceSessionBatchedSpanProcessor(_a) {
            var _this = this;
            var exporter = _a.exporter, parentArgs = __rest(_a, ["exporter"]);
            _this = _super.call(this, __assign$2(__assign$2({}, parentArgs), { processorName: 'EmbraceSessionBatchedSpanProcessor' })) || this;
            _this._pendingSpans = [];
            _this._shutdown = function () {
                return _this._exporter.shutdown();
            };
            _this._exporter = exporter;
            _this._shutdownOnce = new BindOnceFuture(_this._shutdown, _this);
            return _this;
        }
        EmbraceSessionBatchedSpanProcessor.prototype.forceFlush = function () {
            this.diag.debug('forceFlush called for EmbraceSessionBatchedSpanProcessor. This is a no op');
            return Promise.resolve(undefined);
        };
        EmbraceSessionBatchedSpanProcessor.prototype.onEnd = function (span) {
            var _this = this;
            if (this._shutdownOnce.isCalled) {
                this.diag.debug('span ended after processor shutdown. Ignoring span.');
                return;
            }
            if (!isSessionSpan(span)) {
                this.diag.debug('non-session span ended. Adding to pending spans queue.');
                this._pendingSpans.push(span);
            }
            else {
                this.diag.debug('session span ended. Exporting all pending spans.');
                internal
                    ._export(this._exporter, __spreadArray$3([span], __read$5(this._pendingSpans), false))
                    .then(function (result) {
                    var _a;
                    if (result.code === ExportResultCode.FAILED) {
                        _this.diag.error("spans failed to export: ".concat(((_a = result.error) === null || _a === void 0 ? void 0 : _a.message) || 'unknown error'));
                    }
                })
                    // Seems like everything related to the export logic does a good job of catching and only ever resolving with
                    // an ExportResult even on failure: https://github.com/open-telemetry/opentelemetry-js/blob/cf6dffeebcf72c42b2cb4d2bf2db720369b53081/packages/opentelemetry-core/src/internal/exporter.ts#L37
                    // Keep this block just in case that assumption changes in a future version
                    .catch(function (reason) {
                    var msg = 'unknown error';
                    if (reason && reason instanceof Error) {
                        msg = reason.message;
                    }
                    else if (typeof reason === 'string') {
                        msg = reason;
                    }
                    _this.diag.error("spans failed to export: ".concat(msg));
                });
                this._pendingSpans = [];
            }
        };
        EmbraceSessionBatchedSpanProcessor.prototype.onStart = function () {
            // do nothing.
        };
        EmbraceSessionBatchedSpanProcessor.prototype.shutdown = function () {
            return this._shutdownOnce.call();
        };
        return EmbraceSessionBatchedSpanProcessor;
    }(EmbraceProcessor));

    var IdentifiableSessionLogRecordProcessor = /** @class */ (function () {
        function IdentifiableSessionLogRecordProcessor(_a) {
            var spanSessionManager = _a.spanSessionManager;
            this._spanSessionManager = spanSessionManager;
        }
        // no-op
        IdentifiableSessionLogRecordProcessor.prototype.forceFlush = function () {
            return Promise.resolve(undefined);
        };
        IdentifiableSessionLogRecordProcessor.prototype.onEmit = function (logRecord) {
            var _a;
            logRecord.setAttributes((_a = {},
                _a[ATTR_LOG_RECORD_UID] = generateUUID(),
                _a[ATTR_SESSION_ID] = this._spanSessionManager.getSessionId(),
                _a));
        };
        // no-op
        IdentifiableSessionLogRecordProcessor.prototype.shutdown = function () {
            return Promise.resolve(undefined);
        };
        return IdentifiableSessionLogRecordProcessor;
    }());

    var SCHEME_RE = /.+:\/\/.+/;
    var isNetworkSpan = function (span) {
        var _a;
        if ((span.attributes[ATTR_HTTP_REQUEST_METHOD] || // eslint-disable-next-line @typescript-eslint/no-deprecated
            span.attributes[SEMATTRS_HTTP_METHOD]) &&
            (span.attributes[ATTR_HTTP_RESPONSE_STATUS_CODE] || // eslint-disable-next-line @typescript-eslint/no-deprecated
                span.attributes[SEMATTRS_HTTP_STATUS_CODE])) {
            var url = // eslint-disable-next-line @typescript-eslint/no-deprecated
             (_a = span.attributes[ATTR_URL_FULL]) !== null && _a !== void 0 ? _a : span.attributes[SEMATTRS_HTTP_URL];
            return !!(url && typeof url === 'string' && SCHEME_RE.exec(url));
        }
        return false;
    };
    // not used yet, but added for clarity. This is the type for Embrace tagged network spans
    // interface EmbraceNetworkSpanAttributes extends Attributes {
    //   [KEY_EMB_TYPE]: EMB_TYPES.Network;
    // }
    // interface EmbraceNetworkSpan extends NetworkSpan {
    //   attributes: NetworkSpanAttributes & EmbraceNetworkSpanAttributes;
    // }

    /**
     * Embrace's API expects network spans to have some specific attributes.
     * This processor checks if a span is a network span and adds them.
     */
    var EmbraceNetworkSpanProcessor = /** @class */ (function () {
        function EmbraceNetworkSpanProcessor() {
        }
        EmbraceNetworkSpanProcessor.prototype.forceFlush = function () {
            return Promise.resolve(undefined);
        };
        // TODO `onEnd` is not supposed to modify the span. There is a new experimental onEnding api that allows modifying
        //  the span before it is sent to the exporter. This processor should be updated to use that api once that is available
        EmbraceNetworkSpanProcessor.prototype.onEnd = function (span) {
            var _a, _b, _c, _d, _e;
            var _f, _g, _h, _j, _k;
            if (isNetworkSpan(span)) {
                span.attributes[KEY_EMB_TYPE] = EMB_TYPES.Network;
                /*
                  Fallback on deprecated attribute names in case the span is using those instead of the latest ones
          
                  The current versions of @opentelemetry/instrumentation-xml-http-request and @opentelemetry/instrumentation-fetch
                  that we're getting from @opentelemetry/auto-instrumentations-web are using these, once we update we'll remove
                  this fallback and only support a single version of the semantic convention
                 */
                // eslint-disable-next-line @typescript-eslint/no-deprecated
                (_a = (_f = span.attributes)[ATTR_URL_FULL]) !== null && _a !== void 0 ? _a : (_f[ATTR_URL_FULL] = span.attributes[SEMATTRS_HTTP_URL]);
                (_b = (_g = span.attributes)[ATTR_HTTP_RESPONSE_STATUS_CODE]) !== null && _b !== void 0 ? _b : (_g[ATTR_HTTP_RESPONSE_STATUS_CODE] = span.attributes[SEMATTRS_HTTP_STATUS_CODE]);
                (_c = (_h = span.attributes)[ATTR_HTTP_REQUEST_METHOD]) !== null && _c !== void 0 ? _c : (_h[ATTR_HTTP_REQUEST_METHOD] = span.attributes[SEMATTRS_HTTP_METHOD]);
                (_d = (_j = span.attributes)[ATTR_HTTP_RESPONSE_BODY_SIZE]) !== null && _d !== void 0 ? _d : (_j[ATTR_HTTP_RESPONSE_BODY_SIZE] = span.attributes[SEMATTRS_HTTP_RESPONSE_CONTENT_LENGTH]);
                (_e = (_k = span.attributes)[ATTR_HTTP_REQUEST_BODY_SIZE]) !== null && _e !== void 0 ? _e : (_k[ATTR_HTTP_REQUEST_BODY_SIZE] = span.attributes[SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH]);
            }
        };
        EmbraceNetworkSpanProcessor.prototype.onStart = function () {
            // do nothing.
        };
        EmbraceNetworkSpanProcessor.prototype.shutdown = function () {
            return Promise.resolve(undefined);
        };
        return EmbraceNetworkSpanProcessor;
    }());

    var EmbTypeLogRecordProcessor = /** @class */ (function () {
        function EmbTypeLogRecordProcessor() {
        }
        // no-op
        EmbTypeLogRecordProcessor.prototype.forceFlush = function () {
            return Promise.resolve(undefined);
        };
        EmbTypeLogRecordProcessor.prototype.onEmit = function (logRecord) {
            if (!logRecord.attributes[KEY_EMB_TYPE]) {
                logRecord.setAttribute(KEY_EMB_TYPE, EMB_TYPES.SystemLog);
            }
        };
        // no-op
        EmbTypeLogRecordProcessor.prototype.shutdown = function () {
            return Promise.resolve(undefined);
        };
        return EmbTypeLogRecordProcessor;
    }());

    var BROWSER_ATTRIBUTES = {
        PLATFORM: 'browser.platform',
        BRANDS: 'browser.brands',
        MOBILE: 'browser.mobile',
        LANGUAGE: 'browser.language',
        USER_AGENT: 'browser.user_agent',
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$3 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$3 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * BrowserDetector will be used to detect the resources related to browser.
     */
    var BrowserDetector = /** @class */ (function () {
        function BrowserDetector() {
        }
        BrowserDetector.prototype.detect = function (config) {
            return __awaiter$3(this, void 0, void 0, function () {
                var isBrowser, browserResource;
                return __generator$3(this, function (_a) {
                    isBrowser = typeof navigator !== 'undefined';
                    if (!isBrowser) {
                        return [2 /*return*/, Resource.empty()];
                    }
                    browserResource = getBrowserAttributes();
                    return [2 /*return*/, this._getResourceAttributes(browserResource, config)];
                });
            });
        };
        /**
         * Validates browser resource attribute map from browser variables
         *
         * @param browserResource The un-sanitized resource attributes from browser as key/value pairs.
         * @param config: Config
         * @returns The sanitized resource attributes.
         */
        BrowserDetector.prototype._getResourceAttributes = function (browserResource, _config) {
            if (!browserResource[BROWSER_ATTRIBUTES.USER_AGENT] &&
                !browserResource[BROWSER_ATTRIBUTES.PLATFORM]) {
                diag.debug('BrowserDetector failed: Unable to find required browser resources. ');
                return Resource.empty();
            }
            else {
                return new Resource(browserResource);
            }
        };
        return BrowserDetector;
    }());
    // Add Browser related attributes to resources
    function getBrowserAttributes() {
        var browserAttribs = {};
        var userAgentData = navigator
            .userAgentData;
        if (userAgentData) {
            browserAttribs[BROWSER_ATTRIBUTES.PLATFORM] = userAgentData.platform;
            browserAttribs[BROWSER_ATTRIBUTES.BRANDS] = userAgentData.brands.map(function (b) { return b.brand + " " + b.version; });
            browserAttribs[BROWSER_ATTRIBUTES.MOBILE] = userAgentData.mobile;
        }
        else {
            browserAttribs[BROWSER_ATTRIBUTES.USER_AGENT] = navigator.userAgent;
        }
        browserAttribs[BROWSER_ATTRIBUTES.LANGUAGE] = navigator.language;
        return browserAttribs;
    }
    var browserDetector = new BrowserDetector();

    // This will be replaced after bundling the app by the Embrace SourceUpload CLI tool.
    // It needs to always remain 32 chars long, so we don't mess with the sourcemaps location after replacing the bundle id with the real 32 chars long bundle ID
    var TEMPLATE_BUNDLE_ID = 'EmbIOBundleIDfd6996f1007b363f87a';
    var TEMPLATE_APP_VERSION = 'EmbIOAppVersionX.X.X';
    var SDK_VERSION = '0.2.0';
    var EMBRACE_SERVICE_NAME = 'embrace-web-sdk';
    // NATIVE_FRAMEWORK is the representation Embrace BE uses to differentiate between
    // sdks. It is an enum, so we just send a number here
    var NATIVE_FRAMEWORK = 1;

    var getWebSDKResource = function (appVersion) {
        var _a;
        /* We need to trim the app  version to remove any leading/trailing spaces
        added by our cli tool. This is required to guarantee that the version is always
        20 characters long in the final bundle, so sourcemaps don't get confused by
        changing the length of the inlined app version. E.g. versions "0.0.1" and "0.0.115"
        are both valid, but injecting them without leading whitespaces will result in
        different lengths, pushing the sourcemaps mapping out of range. Instead,
        "               0.0.1" and "             0.0.115" are both 20 characters long,
        and we trim them before loading at runtime
      
        if the app version has been passed as an argument, we use it instead of the
        one processed by our cli tool. This will allow for no cli installations,
        like importing the web sdk from a CDN
        */
        var processedAppVersion = appVersion !== null && appVersion !== void 0 ? appVersion : TEMPLATE_APP_VERSION.trim();
        var resource = new Resource((_a = {},
            _a[ATTR_SERVICE_NAME] = EMBRACE_SERVICE_NAME,
            _a[ATTR_TELEMETRY_SDK_NAME] = EMBRACE_SERVICE_NAME,
            _a.app_version = processedAppVersion,
            _a.app_framework = NATIVE_FRAMEWORK,
            _a.bundle_id = TEMPLATE_BUNDLE_ID,
            _a.sdk_version = SDK_VERSION,
            _a[ATTR_TELEMETRY_SDK_VERSION] = SDK_VERSION,
            _a.sdk_simple_version = 1,
            _a.sdk_platform = 'web',
            _a[ATTR_TELEMETRY_SDK_LANGUAGE] = 'webjs',
            _a));
        var detectedResources = detectResourcesSync({
            detectors: [browserDetector],
        });
        resource = resource.merge(detectedResources);
        return resource;
    };

    var isValidAppID = function (appID) {
        if (appID === undefined) {
            throw new Error('appID is required when using Embrace exporter');
        }
        if (appID.length !== 5) {
            throw new Error('appID should be 5 characters long');
        }
        return true;
    };

    var __assign$1 = (undefined && undefined.__assign) || function () {
        __assign$1 = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign$1.apply(this, arguments);
    };
    // copied directly from https://github.com/open-telemetry/opentelemetry-js/blob/90afa2850c0690f7a18ecc511c04927a3183490b/experimental/packages/opentelemetry-instrumentation/src/instrumentation.ts
    // to avoid importing internal and experimental code. Some unused blocks removed.
    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var InstrumentationAbstract$1 = /** @class */ (function () {
        function InstrumentationAbstract(instrumentationName, instrumentationVersion, config) {
            this.instrumentationName = instrumentationName;
            this.instrumentationVersion = instrumentationVersion;
            this._config = {};
            this.setConfig(config);
            this._diag = diag.createComponentLogger({
                namespace: instrumentationName,
            });
            this._tracer = trace.getTracer(instrumentationName, instrumentationVersion);
            this._meter = metrics.getMeter(instrumentationName, instrumentationVersion);
            this._logger = logs$1.getLogger(instrumentationName, instrumentationVersion);
            this._updateMetricInstruments();
        }
        Object.defineProperty(InstrumentationAbstract.prototype, "tracer", {
            /* Returns tracer */
            get: function () {
                return this._tracer;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(InstrumentationAbstract.prototype, "meter", {
            /* Returns meter */
            get: function () {
                return this._meter;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(InstrumentationAbstract.prototype, "logger", {
            /* Returns logger */
            get: function () {
                return this._logger;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * @experimental
         *
         * Get module definitions defined by {@link init}.
         * This can be used for experimental compile-time instrumentation.
         *
         * @returns an array of {@link InstrumentationModuleDefinition}
         */
        InstrumentationAbstract.prototype.getModuleDefinitions = function () {
            var _a;
            // NOTE: disabling typescript check, as this class was copied from OTel repo.
            // TBH, I agree with typescript here, but keeping it disabled for consistency with the base repo
            // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
            var initResult = (_a = this.init()) !== null && _a !== void 0 ? _a : [];
            if (!Array.isArray(initResult)) {
                return [initResult];
            }
            return initResult;
        };
        /* Returns InstrumentationConfig */
        InstrumentationAbstract.prototype.getConfig = function () {
            return this._config;
        };
        /**
         * Sets InstrumentationConfig to this plugin
         * @param config
         */
        InstrumentationAbstract.prototype.setConfig = function (config) {
            // copy config first level properties to ensure they are immutable.
            // nested properties are not copied, thus are mutable from the outside.
            this._config = __assign$1({ enabled: true }, config);
        };
        /**
         * Sets LoggerProvider to this plugin
         * @param loggerProvider
         */
        InstrumentationAbstract.prototype.setLoggerProvider = function (loggerProvider) {
            this._logger = loggerProvider.getLogger(this.instrumentationName, this.instrumentationVersion);
        };
        /**
         * Sets MeterProvider to this plugin
         * @param meterProvider
         */
        InstrumentationAbstract.prototype.setMeterProvider = function (meterProvider) {
            this._meter = meterProvider.getMeter(this.instrumentationName, this.instrumentationVersion);
            this._updateMetricInstruments();
        };
        /**
         * Sets TraceProvider to this plugin
         * @param tracerProvider
         */
        InstrumentationAbstract.prototype.setTracerProvider = function (tracerProvider) {
            this._tracer = tracerProvider.getTracer(this.instrumentationName, this.instrumentationVersion);
        };
        // eslint-disable-next-line @typescript-eslint/class-methods-use-this
        InstrumentationAbstract.prototype._updateMetricInstruments = function () {
            return;
        };
        /**
         * Execute span customization hook, if configured, and log any errors.
         * Any semantics of the trigger and info are defined by the specific instrumentation.
         * @param hookHandler The optional hook handler which the user has configured via instrumentation config
         * @param triggerName The name of the trigger for executing the hook for logging purposes
         * @param span The span to which the hook should be applied
         * @param info The info object to be passed to the hook, with useful data the hook may use
         */
        InstrumentationAbstract.prototype._runSpanCustomizationHook = function (hookHandler, triggerName, span, info) {
            if (!hookHandler) {
                return;
            }
            try {
                hookHandler(span, info);
            }
            catch (e) {
                this._diag.error("Error running span customization hook due to exception in handler", { triggerName: triggerName }, e);
            }
        };
        return InstrumentationAbstract;
    }());

    var __extends$b = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var EmbraceInstrumentationBase = /** @class */ (function (_super) {
        __extends$b(EmbraceInstrumentationBase, _super);
        function EmbraceInstrumentationBase(_a) {
            var instrumentationName = _a.instrumentationName, instrumentationVersion = _a.instrumentationVersion, config = _a.config, diag = _a.diag, perf = _a.perf;
            var _this = _super.call(this, instrumentationName, instrumentationVersion, config) || this;
            // optionally override the diag logger from the base class
            if (diag) {
                _this._diag = diag;
            }
            _this._perf = perf !== null && perf !== void 0 ? perf : new OTelPerformanceManager();
            _this._sessionManager = session.getSpanSessionManager();
            _this._logManager = log.getLogManager();
            return _this;
        }
        Object.defineProperty(EmbraceInstrumentationBase.prototype, "sessionManager", {
            /* Returns session provider */
            get: function () {
                return this._sessionManager;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EmbraceInstrumentationBase.prototype, "logManager", {
            /* Returns session provider */
            get: function () {
                return this._logManager;
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(EmbraceInstrumentationBase.prototype, "perf", {
            /* Returns the performance manager */
            get: function () {
                return this._perf;
            },
            enumerable: false,
            configurable: true
        });
        // no-op
        EmbraceInstrumentationBase.prototype.init = function () {
            return undefined;
        };
        return EmbraceInstrumentationBase;
    }(InstrumentationAbstract$1));

    var __extends$a = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var SpanSessionVisibilityInstrumentation = /** @class */ (function (_super) {
        __extends$a(SpanSessionVisibilityInstrumentation, _super);
        function SpanSessionVisibilityInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag;
            var _this = _super.call(this, {
                instrumentationName: 'SpanSessionOnLoadInstrumentation',
                instrumentationVersion: '1.0.0',
                config: {},
                diag: diag,
            }) || this;
            _this._onVisibilityChange = function () {
                if (document.visibilityState === 'hidden') {
                    _this._diag.debug('Visibility change detected: hidden');
                    _this.sessionManager.endSessionSpanInternal('bkgnd_state');
                }
                else {
                    _this._diag.debug('Visibility change detected: visible');
                    _this.sessionManager.startSessionSpan();
                }
            };
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        SpanSessionVisibilityInstrumentation.prototype.disable = function () {
            window.removeEventListener('visibilitychange', this._onVisibilityChange);
        };
        SpanSessionVisibilityInstrumentation.prototype.enable = function () {
            window.addEventListener('visibilitychange', this._onVisibilityChange);
        };
        return SpanSessionVisibilityInstrumentation;
    }(EmbraceInstrumentationBase));

    /** 30 minutes */
    var TIMEOUT_TIME$1 = 30 * 60 * 1000; // half an hour in milis = 1.800.000 milis
    /** 30 seconds */
    var EVENT_THROTTLING_TIME_WINDOW = 30 * 1000; // 30 seconds in milis = 30.000 milis
    // TODO allow users to configure what events they want to listen to, or at list some flavors like "minimal" and "full"
    //  switching from the current list to the full list:
    /*export const WINDOW_USER_EVENTS = [
      'resize',
      'copy',
      'cut',
      'paste',
      'focus',
      'afterprint',
      'beforeprint',
      'scrollsnapchange',
      'auxclick',
      'click',
      'dblclick',
      'drag',
      'dragend',
      'dragenter',
      'drageleave',
      'dragover',
      'dragstart',
      'drop',
      'keydown',
      'keyup',
      'keypress',
      'mousedown',
      'mouseenter',
      'mouseleave',
      'mousemove',
      'mouseout',
      'mouseover',
      'mouseup',
    ]; // list manually generated from the user related event in https://developer.mozilla.org/en-US/docs/Web/API/Window#events, updated on 2025-02-24
    */
    /** List of events we listen for user interactions*/
    var WINDOW_USER_EVENTS = [
        'keydown',
        'mousedown',
        'mousemove',
        'scroll',
    ];

    var __extends$9 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     *  SpanSessionBrowserActivityInstrumentation will track the user activity and end the session span if there is no
     *  activity for a certain amount of time.
     *  SpanSessionBrowserActivityInstrumentation will initialize new sessions if new activity is detected and there is no
     *  active session.
     * */
    var SpanSessionBrowserActivityInstrumentation = /** @class */ (function (_super) {
        __extends$9(SpanSessionBrowserActivityInstrumentation, _super);
        function SpanSessionBrowserActivityInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag;
            var _this = _super.call(this, {
                instrumentationName: 'SpanSessionBrowserActivityInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                config: {},
            }) || this;
            _this.disable = function () {
                bulkRemoveEventListener({
                    target: window,
                    events: WINDOW_USER_EVENTS,
                    callback: _this._onActivityThrottled,
                });
                if (_this._activityTimeout) {
                    clearTimeout(_this._activityTimeout);
                }
                _this._activityTimeout = null;
            };
            _this.enable = function () {
                bulkAddEventListener({
                    target: window,
                    events: WINDOW_USER_EVENTS,
                    callback: _this._onActivityThrottled,
                });
            };
            _this._onInactivity = function () {
                _this._diag.debug('Inactivity detected');
                if (_this._activityTimeout) {
                    clearTimeout(_this._activityTimeout);
                }
                _this._activityTimeout = null;
                _this.sessionManager.endSessionSpanInternal('inactivity');
            };
            _this._onActivity = function () {
                _this._diag.debug('Activity detected');
                if (_this._activityTimeout) {
                    clearTimeout(_this._activityTimeout);
                }
                // if there was no active session, start one
                if (!_this.sessionManager.getSessionId()) {
                    _this.sessionManager.startSessionSpan();
                }
                _this._activityTimeout = setTimeout(_this._onInactivity, TIMEOUT_TIME$1);
            };
            _this._activityTimeout = null;
            _this._onActivityThrottled = throttle(_this._onActivity, EVENT_THROTTLING_TIME_WINDOW);
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        return SpanSessionBrowserActivityInstrumentation;
    }(EmbraceInstrumentationBase));

    var __extends$8 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var SpanSessionOnLoadInstrumentation = /** @class */ (function (_super) {
        __extends$8(SpanSessionOnLoadInstrumentation, _super);
        function SpanSessionOnLoadInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag;
            var _this = _super.call(this, {
                instrumentationName: 'SpanSessionOnLoadInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                config: {},
            }) || this;
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        SpanSessionOnLoadInstrumentation.prototype.disable = function () {
            this.sessionManager.endSessionSpanInternal('unknown');
        };
        SpanSessionOnLoadInstrumentation.prototype.enable = function () {
            this.sessionManager.startSessionSpan();
        };
        return SpanSessionOnLoadInstrumentation;
    }(EmbraceInstrumentationBase));

    var TIMEOUT_TIME = 4 * 60 * 60 * 1000; // 4 hours in milis = 14.400.000 milis

    var __extends$7 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     *  SpanSessionTimeoutInstrumentation will track how long has a session been active and end it after a certain amount of time.
     *  It will immediately start a new session after the previous one ends.
     **/
    var SpanSessionTimeoutInstrumentation = /** @class */ (function (_super) {
        __extends$7(SpanSessionTimeoutInstrumentation, _super);
        function SpanSessionTimeoutInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf;
            var _this = _super.call(this, {
                instrumentationName: 'SpanSessionTimeoutInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                perf: perf,
                config: {},
            }) || this;
            _this.disable = function () {
                if (_this._sessionTimeout) {
                    clearTimeout(_this._sessionTimeout);
                }
                _this._sessionTimeout = null;
            };
            _this.enable = function () {
                _this._checkTimeout();
            };
            _this._onTimeout = function () {
                _this._diag.debug('Timeout detected');
                // clear existing timeout
                if (_this._sessionTimeout) {
                    clearTimeout(_this._sessionTimeout);
                }
                _this.sessionManager.endSessionSpanInternal('timer');
                _this.sessionManager.startSessionSpan();
                // set a new check in TIMEOUT_TIME for the session we just started
                _this._sessionTimeout = setTimeout(_this._checkTimeout, TIMEOUT_TIME);
            };
            _this._checkTimeout = function () {
                var currentSessionStartTime = _this.sessionManager.getSessionStartTime();
                // validate that there is an active session, as it may already been finished for other reasons.
                if (currentSessionStartTime) {
                    // check how much time has passed since the session started
                    var currentTime = _this.perf.getNowHRTime();
                    var currentTimeMillis = hrTimeToMilliseconds(currentTime);
                    var currentSessionStartTimeMillis = hrTimeToMilliseconds(currentSessionStartTime);
                    var timePassed = currentTimeMillis - currentSessionStartTimeMillis;
                    var remainingTime = TIMEOUT_TIME - timePassed;
                    // if the remaining time is 0 or less, the session has already timed out.
                    if (remainingTime <= 0) {
                        // the session has already timed out.
                        _this._onTimeout();
                        return;
                    }
                    // if there is time remaining, set a new timeout for check again after it
                    if (_this._sessionTimeout) {
                        clearTimeout(_this._sessionTimeout);
                    }
                    _this._sessionTimeout = setTimeout(_this._checkTimeout, remainingTime);
                    return;
                }
                // if there is no currentSessionStartTime then there is no active session,
                //  check again in TIMEOUT_TIME in case a new one is started.
                if (_this._sessionTimeout) {
                    clearTimeout(_this._sessionTimeout);
                }
                _this._sessionTimeout = setTimeout(_this._checkTimeout, TIMEOUT_TIME);
            };
            _this._sessionTimeout = null;
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        return SpanSessionTimeoutInstrumentation;
    }(EmbraceInstrumentationBase));

    var __extends$6 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var GlobalExceptionInstrumentation = /** @class */ (function (_super) {
        __extends$6(GlobalExceptionInstrumentation, _super);
        function GlobalExceptionInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf;
            var _this = _super.call(this, {
                instrumentationName: 'GlobalExceptionInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                perf: perf,
                config: {},
            }) || this;
            _this._onErrorHandler = function (event) {
                _this.logManager.logException(event.error, false, {}, _this.perf.epochMillisFromOriginOffset(event.timeStamp));
            };
            _this._onUnhandledRejectionHandler = function (event) {
                var error;
                if (event.reason && event.reason instanceof Error) {
                    error = event.reason;
                }
                else {
                    error = new Error(typeof event.reason === 'string'
                        ? event.reason
                        : 'Unhandled Rejected Promise');
                    error.stack = '';
                }
                _this.logManager.logException(error, false, {}, _this.perf.epochMillisFromOriginOffset(event.timeStamp));
            };
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        GlobalExceptionInstrumentation.prototype.disable = function () {
            window.removeEventListener('error', this._onErrorHandler);
            window.removeEventListener('unhandledrejection', this._onUnhandledRejectionHandler);
        };
        GlobalExceptionInstrumentation.prototype.enable = function () {
            window.addEventListener('error', this._onErrorHandler);
            window.addEventListener('unhandledrejection', this._onUnhandledRejectionHandler);
        };
        return GlobalExceptionInstrumentation;
    }(EmbraceInstrumentationBase));

    var MAX_INNER_TEXT = 30;
    var getHTMLElementFriendlyName = function (element) {
        var nodeName = element.nodeName.toLowerCase();
        var innerText = element.innerText.substring(0, MAX_INNER_TEXT);
        var ellipsis = element.innerText.length > MAX_INNER_TEXT ? '...' : '';
        var className = element.className ? " class=\"".concat(element.className, "\"") : '';
        return "<".concat(nodeName).concat(className, ">").concat(innerText).concat(ellipsis, "</").concat(nodeName, ">");
    };

    /*
      This instrumentation is taking code from here as a starting point:
        https://github.com/open-telemetry/opentelemetry-js-contrib/blob/main/plugins/web/opentelemetry-instrumentation-user-interaction/src/instrumentation.ts

      But not using that instrumentation directly because:

        1) We want to record clicks as span events on the Session span
        2) There is a bug with the instrumentation that causes a large number of spans to be created for a single click
          when zone context isn't available. To avoid the bug we take a simpler approach here and add a listener directly
          to `document` rather than trying to patch the `addEventListener` method on the prototype, this does mean we miss
          recording click events for which `stopPropagation` is called. See https://github.com/open-telemetry/opentelemetry-js-contrib/issues/1368
     */
    var __extends$5 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var ClicksInstrumentation = /** @class */ (function (_super) {
        __extends$5(ClicksInstrumentation, _super);
        function ClicksInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf;
            var _this = _super.call(this, {
                instrumentationName: 'SpanSessionBrowserActivityInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                perf: perf,
                config: {},
            }) || this;
            _this._onClickHandler = function (event) {
                var element = event.target;
                if (!(element instanceof HTMLElement)) {
                    return;
                }
                if (element.hasAttribute('disabled')) {
                    return;
                }
                try {
                    var currentSessionSpan = _this.sessionManager.getSessionSpan();
                    if (currentSessionSpan) {
                        currentSessionSpan.addEvent('click', {
                            'emb.type': 'ux.tap',
                            'view.name': getHTMLElementFriendlyName(element),
                            'tap.coords': "".concat(event.x.toString(), ",").concat(event.y.toString()),
                        }, _this.perf.epochMillisFromOriginOffset(event.timeStamp));
                    }
                }
                catch (e) {
                    _this._diag.error('failed to create new user interaction span event', e);
                }
            };
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        ClicksInstrumentation.prototype.disable = function () {
            document.removeEventListener('click', this._onClickHandler);
        };
        ClicksInstrumentation.prototype.enable = function () {
            document.addEventListener('click', this._onClickHandler);
        };
        return ClicksInstrumentation;
    }(EmbraceInstrumentationBase));

    var t,e,n=function(){var t=self.performance&&performance.getEntriesByType&&performance.getEntriesByType("navigation")[0];if(t&&t.responseStart>0&&t.responseStart<performance.now())return t},r=function(t){if("loading"===document.readyState)return "loading";var e=n();if(e){if(t<e.domInteractive)return "loading";if(0===e.domContentLoadedEventStart||t<e.domContentLoadedEventStart)return "dom-interactive";if(0===e.domComplete||t<e.domComplete)return "dom-content-loaded"}return "complete"},i=function(t){var e=t.nodeName;return 1===t.nodeType?e.toLowerCase():e.toUpperCase().replace(/^#/,"")},a=function(t,e){var n="";try{for(;t&&9!==t.nodeType;){var r=t,a=r.id?"#"+r.id:i(r)+(r.classList&&r.classList.value&&r.classList.value.trim()&&r.classList.value.trim().length?"."+r.classList.value.trim().replace(/\s+/g,"."):"");if(n.length+a.length>(e||100)-1)return n||a;if(n=n?a+">"+n:a,r.id)break;t=r.parentNode;}}catch(t){}return n},o=-1,c=function(){return o},u=function(t){addEventListener("pageshow",(function(e){e.persisted&&(o=e.timeStamp,t(e));}),true);},s=function(){var t=n();return t&&t.activationStart||0},f=function(t,e){var r=n(),i="navigate";c()>=0?i="back-forward-cache":r&&(document.prerendering||s()>0?i="prerender":document.wasDiscarded?i="restore":r.type&&(i=r.type.replace(/_/g,"-")));return {name:t,value:void 0===e?-1:e,rating:"good",delta:0,entries:[],id:"v4-".concat(Date.now(),"-").concat(Math.floor(8999999999999*Math.random())+1e12),navigationType:i}},d=function(t,e,n){try{if(PerformanceObserver.supportedEntryTypes.includes(t)){var r=new PerformanceObserver((function(t){Promise.resolve().then((function(){e(t.getEntries());}));}));return r.observe(Object.assign({type:t,buffered:!0},n||{})),r}}catch(t){}},l=function(t,e,n,r){var i,a;return function(o){e.value>=0&&(o||r)&&((a=e.value-(i||0))||void 0===i)&&(i=e.value,e.delta=a,e.rating=function(t,e){return t>e[1]?"poor":t>e[0]?"needs-improvement":"good"}(e.value,n),t(e));}},m=function(t){requestAnimationFrame((function(){return requestAnimationFrame((function(){return t()}))}));},p=function(t){document.addEventListener("visibilitychange",(function(){"hidden"===document.visibilityState&&t();}));},v=function(t){var e=false;return function(){e||(t(),e=true);}},g=-1,h=function(){return "hidden"!==document.visibilityState||document.prerendering?1/0:0},T=function(t){"hidden"===document.visibilityState&&g>-1&&(g="visibilitychange"===t.type?t.timeStamp:0,E());},y=function(){addEventListener("visibilitychange",T,true),addEventListener("prerenderingchange",T,true);},E=function(){removeEventListener("visibilitychange",T,true),removeEventListener("prerenderingchange",T,true);},S=function(){return g<0&&(g=h(),y(),u((function(){setTimeout((function(){g=h(),y();}),0);}))),{get firstHiddenTime(){return g}}},b=function(t){document.prerendering?addEventListener("prerenderingchange",(function(){return t()}),true):t();},L=[1800,3e3],C=function(t,e){e=e||{},b((function(){var n,r=S(),i=f("FCP"),a=d("paint",(function(t){t.forEach((function(t){"first-contentful-paint"===t.name&&(a.disconnect(),t.startTime<r.firstHiddenTime&&(i.value=Math.max(t.startTime-s(),0),i.entries.push(t),n(true)));}));}));a&&(n=l(t,i,L,e.reportAllChanges),u((function(r){i=f("FCP"),n=l(t,i,L,e.reportAllChanges),m((function(){i.value=performance.now()-r.timeStamp,n(true);}));})));}));},M=[.1,.25],D=function(t,e){!function(t,e){e=e||{},C(v((function(){var n,r=f("CLS",0),i=0,a=[],o=function(t){t.forEach((function(t){if(!t.hadRecentInput){var e=a[0],n=a[a.length-1];i&&t.startTime-n.startTime<1e3&&t.startTime-e.startTime<5e3?(i+=t.value,a.push(t)):(i=t.value,a=[t]);}})),i>r.value&&(r.value=i,r.entries=a,n());},c=d("layout-shift",o);c&&(n=l(t,r,M,e.reportAllChanges),p((function(){o(c.takeRecords()),n(true);})),u((function(){i=0,r=f("CLS",0),n=l(t,r,M,e.reportAllChanges),m((function(){return n()}));})),setTimeout(n,0));})));}((function(e){var n=function(t){var e,n={};if(t.entries.length){var i=t.entries.reduce((function(t,e){return t&&t.value>e.value?t:e}));if(i&&i.sources&&i.sources.length){var o=(e=i.sources).find((function(t){return t.node&&1===t.node.nodeType}))||e[0];o&&(n={largestShiftTarget:a(o.node),largestShiftTime:i.startTime,largestShiftValue:i.value,largestShiftSource:o,largestShiftEntry:i,loadState:r(i.startTime)});}}return Object.assign(t,{attribution:n})}(e);t(n);}),e);},w=function(t,e){C((function(e){var i=function(t){var e={timeToFirstByte:0,firstByteToFCP:t.value,loadState:r(c())};if(t.entries.length){var i=n(),a=t.entries[t.entries.length-1];if(i){var o=i.activationStart||0,u=Math.max(0,i.responseStart-o);e={timeToFirstByte:u,firstByteToFCP:t.value-u,loadState:r(t.entries[0].startTime),navigationEntry:i,fcpEntry:a};}}return Object.assign(t,{attribution:e})}(e);t(i);}),e);},x=0,I=1/0,k=0,A=function(t){t.forEach((function(t){t.interactionId&&(I=Math.min(I,t.interactionId),k=Math.max(k,t.interactionId),x=k?(k-I)/7+1:0);}));},F=function(){return t?x:performance.interactionCount||0},P=function(){"interactionCount"in performance||t||(t=d("event",A,{type:"event",buffered:true,durationThreshold:0}));},B=[],O=new Map,R=0,j=function(){var t=Math.min(B.length-1,Math.floor((F()-R)/50));return B[t]},q=[],H=function(t){if(q.forEach((function(e){return e(t)})),t.interactionId||"first-input"===t.entryType){var e=B[B.length-1],n=O.get(t.interactionId);if(n||B.length<10||t.duration>e.latency){if(n)t.duration>n.latency?(n.entries=[t],n.latency=t.duration):t.duration===n.latency&&t.startTime===n.entries[0].startTime&&n.entries.push(t);else {var r={id:t.interactionId,latency:t.duration,entries:[t]};O.set(r.id,r),B.push(r);}B.sort((function(t,e){return e.latency-t.latency})),B.length>10&&B.splice(10).forEach((function(t){return O.delete(t.id)}));}}},N=function(t){var e=self.requestIdleCallback||self.setTimeout,n=-1;return t=v(t),"hidden"===document.visibilityState?t():(n=e(t),p(t)),n},W=[200,500],z=function(t,e){"PerformanceEventTiming"in self&&"interactionId"in PerformanceEventTiming.prototype&&(e=e||{},b((function(){var n;P();var r,i=f("INP"),a=function(t){N((function(){t.forEach(H);var e=j();e&&e.latency!==i.value&&(i.value=e.latency,i.entries=e.entries,r());}));},o=d("event",a,{durationThreshold:null!==(n=e.durationThreshold)&&void 0!==n?n:40});r=l(t,i,W,e.reportAllChanges),o&&(o.observe({type:"first-input",buffered:true}),p((function(){a(o.takeRecords()),r(true);})),u((function(){R=F(),B.length=0,O.clear(),i=f("INP"),r=l(t,i,W,e.reportAllChanges);})));})));},U=[],V=[],_=0,G=new WeakMap,J=new Map,K=-1,Q=function(t){U=U.concat(t),X();},X=function(){K<0&&(K=N(Y));},Y=function(){J.size>10&&J.forEach((function(t,e){O.has(e)||J.delete(e);}));var t=B.map((function(t){return G.get(t.entries[0])})),e=V.length-50;V=V.filter((function(n,r){return r>=e||t.includes(n)}));for(var n=new Set,r=0;r<V.length;r++){var i=V[r];nt(i.startTime,i.processingEnd).forEach((function(t){n.add(t);}));}var a=U.length-1-50;U=U.filter((function(t,e){return t.startTime>_&&e>a||n.has(t)})),K=-1;};q.push((function(t){t.interactionId&&t.target&&!J.has(t.interactionId)&&J.set(t.interactionId,t.target);}),(function(t){var e,n=t.startTime+t.duration;_=Math.max(_,t.processingEnd);for(var r=V.length-1;r>=0;r--){var i=V[r];if(Math.abs(n-i.renderTime)<=8){(e=i).startTime=Math.min(t.startTime,e.startTime),e.processingStart=Math.min(t.processingStart,e.processingStart),e.processingEnd=Math.max(t.processingEnd,e.processingEnd),e.entries.push(t);break}}e||(e={startTime:t.startTime,processingStart:t.processingStart,processingEnd:t.processingEnd,renderTime:n,entries:[t]},V.push(e)),(t.interactionId||"first-input"===t.entryType)&&G.set(t,e),X();}));var nt=function(t,e){for(var n,r=[],i=0;n=U[i];i++)if(!(n.startTime+n.duration<t)){if(n.startTime>e)break;r.push(n);}return r},rt=function(t,n){e||(e=d("long-animation-frame",Q)),z((function(e){var n=function(t){var e=t.entries[0],n=G.get(e),i=e.processingStart,o=n.processingEnd,c=n.entries.sort((function(t,e){return t.processingStart-e.processingStart})),u=nt(e.startTime,o),s=t.entries.find((function(t){return t.target})),f=s&&s.target||J.get(e.interactionId),d=[e.startTime+e.duration,o].concat(u.map((function(t){return t.startTime+t.duration}))),l=Math.max.apply(Math,d),m={interactionTarget:a(f),interactionTargetElement:f,interactionType:e.name.startsWith("key")?"keyboard":"pointer",interactionTime:e.startTime,nextPaintTime:l,processedEventEntries:c,longAnimationFrameEntries:u,inputDelay:i-e.startTime,processingDuration:o-i,presentationDelay:Math.max(l-o,0),loadState:r(e.startTime)};return Object.assign(t,{attribution:m})}(e);t(n);}),n);},it=[2500,4e3],at={},ot=function(t,e){!function(t,e){e=e||{},b((function(){var n,r=S(),i=f("LCP"),a=function(t){e.reportAllChanges||(t=t.slice(-1)),t.forEach((function(t){t.startTime<r.firstHiddenTime&&(i.value=Math.max(t.startTime-s(),0),i.entries=[t],n());}));},o=d("largest-contentful-paint",a);if(o){n=l(t,i,it,e.reportAllChanges);var c=v((function(){at[i.id]||(a(o.takeRecords()),o.disconnect(),at[i.id]=true,n(true));}));["keydown","click"].forEach((function(t){addEventListener(t,(function(){return N(c)}),{once:true,capture:true});})),p(c),u((function(r){i=f("LCP"),n=l(t,i,it,e.reportAllChanges),m((function(){i.value=performance.now()-r.timeStamp,at[i.id]=true,n(true);}));}));}}));}((function(e){var r=function(t){var e={timeToFirstByte:0,resourceLoadDelay:0,resourceLoadDuration:0,elementRenderDelay:t.value};if(t.entries.length){var r=n();if(r){var i=r.activationStart||0,o=t.entries[t.entries.length-1],c=o.url&&performance.getEntriesByType("resource").filter((function(t){return t.name===o.url}))[0],u=Math.max(0,r.responseStart-i),s=Math.max(u,c?(c.requestStart||c.startTime)-i:0),f=Math.max(s,c?c.responseEnd-i:0),d=Math.max(f,o.startTime-i);e={element:a(o.element),timeToFirstByte:u,resourceLoadDelay:s-u,resourceLoadDuration:f-s,elementRenderDelay:d-f,navigationEntry:r,lcpEntry:o},o.url&&(e.url=o.url),c&&(e.lcpResourceEntry=c);}}return Object.assign(t,{attribution:e})}(e);t(r);}),e);},ct=[800,1800],ut=function t(e){document.prerendering?b((function(){return t(e)})):"complete"!==document.readyState?addEventListener("load",(function(){return t(e)}),true):setTimeout(e,0);},st=function(t,e){e=e||{};var r=f("TTFB"),i=l(t,r,ct,e.reportAllChanges);ut((function(){var a=n();a&&(r.value=Math.max(a.responseStart-s(),0),r.entries=[a],i(true),u((function(){r=f("TTFB",0),(i=l(t,r,ct,e.reportAllChanges))(true);})));}));},ft=function(t,e){st((function(e){var n=function(t){var e={waitingDuration:0,cacheDuration:0,dnsDuration:0,connectionDuration:0,requestDuration:0};if(t.entries.length){var n=t.entries[0],r=n.activationStart||0,i=Math.max((n.workerStart||n.fetchStart)-r,0),a=Math.max(n.domainLookupStart-r,0),o=Math.max(n.connectStart-r,0),c=Math.max(n.connectEnd-r,0);e={waitingDuration:i,cacheDuration:a-i,dnsDuration:o-a,connectionDuration:c-o,requestDuration:t.value-c,navigationEntry:n};}return Object.assign(t,{attribution:e})}(e);t(n);}),e);};

    var EMB_WEB_VITALS_PREFIX = 'emb-web-vitals';
    var CORE_WEB_VITALS = ['CLS', 'INP', 'LCP'];
    var ALL_WEB_VITALS = ['CLS', 'INP', 'LCP', 'FCP', 'TTFB'];
    var WEB_VITALS_ID_TO_LISTENER = {
        /**
         *  Cumulative Layout Shift (CLS)
         *  https://web.dev/articles/cls
         *
         *  Measures _unexpected_ layout shifts throughout the lifespan of a page load. User-initiated shifts, e.g. showing
         *  a loading indicator after a user clicked a button that triggered a network request, are excluded since these are
         *  expected.
         *
         *  onCLS is always called when the page's visibility state changes to hidden and may be called multiple times for
         *  a single page load.
         *
         *  SPA Note: Since this is cumulative it could be misleading in a SPA, e.g. you might cross the threshold from
         *  good -> bad on Page 3 but the largest contributor to your score might have actually occurred on Page 1
         */
        CLS: D,
        /**
         * First Contentful Paint (FCP)
         * https://web.dev/articles/fcp
         *
         * Measures from first hard page load to when the first "content" (text, image, svg elements, etc.) is rendered
         *
         * Only measured once per page load
         */
        FCP: w,
        /**
         * Largest Contentful Paint (LCP)
         * https://web.dev/articles/lcp
         *
         * Uses heuristics to try and measure when the "main" content has been rendered on the page. Size is a factor, but
         * certain elements that likely represent backgrounds or splash screens are excluded.
         *
         * As the page loads the element considered the largest could change, once the user interacts with the page these
         * entries stop getting reported and the metric is ready
         *
         * Only measured once per page load
         */
        LCP: ot,
        /**
         * Interaction to Next Paint (INP)
         * https://web.dev/articles/inp
         *
         * Measures how long it takes from a user interaction until the next paint. The final INP value is the longest
         * interaction observed, ignoring outliers.
         *
         * onINP is always called when the page's visibility state changes to hidden and may be called multiple times for
         * a single page load.
         *
         * Each interaction is not reported even when setting reportAllChanges=true, just when an interaction causes an
         * increase to INP.
         */
        INP: rt,
        /**
         * Time to First Byte (TTFB)
         * https://web.dev/articles/ttfb
         *
         * Measures the time between the request for a resource and when the first byte of a response begins to arrive.
         */
        TTFB: ft,
        // Omitting onFID since FID (First Input Delay) has been deprecated
        FID: undefined,
    };

    var __extends$4 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __read$4 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$2 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var WebVitalsInstrumentation = /** @class */ (function (_super) {
        __extends$4(WebVitalsInstrumentation, _super);
        // instrumentation that adds an event to the session span for each web vital report
        function WebVitalsInstrumentation(_a) {
            var _b = _a === void 0 ? {} : _a, diag = _b.diag, perf = _b.perf, _c = _b.trackingLevel, trackingLevel = _c === void 0 ? 'core' : _c, _d = _b.listeners, listeners = _d === void 0 ? WEB_VITALS_ID_TO_LISTENER : _d;
            var _this = _super.call(this, {
                instrumentationName: 'WebVitalsInstrumentation',
                instrumentationVersion: '1.0.0',
                diag: diag,
                perf: perf,
                config: {},
            }) || this;
            _this._listeners = listeners;
            _this._metricsToTrack =
                trackingLevel === 'core' ? __spreadArray$2([], __read$4(CORE_WEB_VITALS), false) : __spreadArray$2([], __read$4(ALL_WEB_VITALS), false);
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        WebVitalsInstrumentation.prototype.disable = function () {
            // do nothing.
            // https://github.com/GoogleChrome/web-vitals/issues/357#issuecomment-1593439036
        };
        WebVitalsInstrumentation.prototype.enable = function () {
            var _this = this;
            this._metricsToTrack.forEach(function (name) {
                var _a, _b;
                (_b = (_a = _this._listeners)[name]) === null || _b === void 0 ? void 0 : _b.call(_a, function (metric) {
                    var _a;
                    var currentSessionSpan = _this.sessionManager.getSessionSpan();
                    if (!currentSessionSpan) {
                        return;
                    }
                    // first thing record the time when this cb was invoked
                    var metricTime = _this._getTimeForMetric(metric);
                    var attrs = (_a = {},
                        _a[KEY_EMB_TYPE] = EMB_TYPES.WebVital,
                        _a['emb.web_vital.navigation_type'] = metric.navigationType,
                        _a['emb.web_vital.name'] = metric.name,
                        _a['emb.web_vital.rating'] = metric.rating,
                        _a['emb.web_vital.id'] = metric.id,
                        _a['emb.web_vital.delta'] = metric.delta,
                        _a['emb.web_vital.value'] = metric.value,
                        _a);
                    Object.entries(metric.attribution).forEach(function (_a) {
                        var _b = __read$4(_a, 2), key = _b[0], value = _b[1];
                        attrs["emb.web_vital.attribution.".concat(key)] =
                            typeof value === 'number'
                                ? value
                                : withErrorFallback(JSON.stringify, 'Error: unable to serialize the value as JSON. Likely a js circular structure.', false, _this._diag)(value);
                    });
                    currentSessionSpan.addEvent("".concat(EMB_WEB_VITALS_PREFIX, "-report-").concat(name), attrs, metricTime);
                });
            });
        };
        WebVitalsInstrumentation.prototype._getTimeForMetric = function (metric) {
            if (metric.name === 'CLS' && metric.attribution.largestShiftTime) {
                return this.perf.epochMillisFromOriginOffset(metric.attribution.largestShiftTime);
            }
            if (metric.name === 'INP' && metric.attribution.interactionTime) {
                return this.perf.epochMillisFromOriginOffset(metric.attribution.interactionTime);
            }
            return this.perf.getNowMillis();
        };
        return WebVitalsInstrumentation;
    }(EmbraceInstrumentationBase));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NoopLogger = /** @class */ (function () {
        function NoopLogger() {
        }
        NoopLogger.prototype.emit = function (_logRecord) { };
        return NoopLogger;
    }());
    var NOOP_LOGGER = new NoopLogger();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var NoopLoggerProvider = /** @class */ (function () {
        function NoopLoggerProvider() {
        }
        NoopLoggerProvider.prototype.getLogger = function (_name, _version, _options) {
            return new NoopLogger();
        };
        return NoopLoggerProvider;
    }());
    var NOOP_LOGGER_PROVIDER = new NoopLoggerProvider();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var ProxyLogger = /** @class */ (function () {
        function ProxyLogger(_provider, name, version, options) {
            this._provider = _provider;
            this.name = name;
            this.version = version;
            this.options = options;
        }
        /**
         * Emit a log record. This method should only be used by log appenders.
         *
         * @param logRecord
         */
        ProxyLogger.prototype.emit = function (logRecord) {
            this._getLogger().emit(logRecord);
        };
        /**
         * Try to get a logger from the proxy logger provider.
         * If the proxy logger provider has no delegate, return a noop logger.
         */
        ProxyLogger.prototype._getLogger = function () {
            if (this._delegate) {
                return this._delegate;
            }
            var logger = this._provider.getDelegateLogger(this.name, this.version, this.options);
            if (!logger) {
                return NOOP_LOGGER;
            }
            this._delegate = logger;
            return this._delegate;
        };
        return ProxyLogger;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var ProxyLoggerProvider = /** @class */ (function () {
        function ProxyLoggerProvider() {
        }
        ProxyLoggerProvider.prototype.getLogger = function (name, version, options) {
            var _a;
            return ((_a = this.getDelegateLogger(name, version, options)) !== null && _a !== void 0 ? _a : new ProxyLogger(this, name, version, options));
        };
        ProxyLoggerProvider.prototype.getDelegate = function () {
            var _a;
            return (_a = this._delegate) !== null && _a !== void 0 ? _a : NOOP_LOGGER_PROVIDER;
        };
        /**
         * Set the delegate logger provider
         */
        ProxyLoggerProvider.prototype.setDelegate = function (delegate) {
            this._delegate = delegate;
        };
        ProxyLoggerProvider.prototype.getDelegateLogger = function (name, version, options) {
            var _a;
            return (_a = this._delegate) === null || _a === void 0 ? void 0 : _a.getLogger(name, version, options);
        };
        return ProxyLoggerProvider;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // Updates to this file should also be replicated to @opentelemetry/api and
    // @opentelemetry/core too.
    /**
     * - globalThis (New standard)
     * - self (Will return the current window instance for supported browsers)
     * - window (fallback for older browser implementations)
     * - global (NodeJS implementation)
     * - <object> (When all else fails)
     */
    /** only globals that common to node and browsers are allowed */
    // eslint-disable-next-line node/no-unsupported-features/es-builtins, no-undef
    var _globalThis = typeof globalThis === 'object'
        ? globalThis
        : typeof self === 'object'
            ? self
            : typeof window === 'object'
                ? window
                : typeof global === 'object'
                    ? global
                    : {};

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var GLOBAL_LOGS_API_KEY = Symbol.for('io.opentelemetry.js.api.logs');
    var _global = _globalThis;
    /**
     * Make a function which accepts a version integer and returns the instance of an API if the version
     * is compatible, or a fallback version (usually NOOP) if it is not.
     *
     * @param requiredVersion Backwards compatibility version which is required to return the instance
     * @param instance Instance which should be returned if the required version is compatible
     * @param fallback Fallback instance, usually NOOP, which will be returned if the required version is not compatible
     */
    function makeGetter(requiredVersion, instance, fallback) {
        return function (version) {
            return version === requiredVersion ? instance : fallback;
        };
    }
    /**
     * A number which should be incremented each time a backwards incompatible
     * change is made to the API. This number is used when an API package
     * attempts to access the global API to ensure it is getting a compatible
     * version. If the global API is not compatible with the API package
     * attempting to get it, a NOOP API implementation will be returned.
     */
    var API_BACKWARDS_COMPATIBILITY_VERSION = 1;

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var LogsAPI = /** @class */ (function () {
        function LogsAPI() {
            this._proxyLoggerProvider = new ProxyLoggerProvider();
        }
        LogsAPI.getInstance = function () {
            if (!this._instance) {
                this._instance = new LogsAPI();
            }
            return this._instance;
        };
        LogsAPI.prototype.setGlobalLoggerProvider = function (provider) {
            if (_global[GLOBAL_LOGS_API_KEY]) {
                return this.getLoggerProvider();
            }
            _global[GLOBAL_LOGS_API_KEY] = makeGetter(API_BACKWARDS_COMPATIBILITY_VERSION, provider, NOOP_LOGGER_PROVIDER);
            this._proxyLoggerProvider.setDelegate(provider);
            return provider;
        };
        /**
         * Returns the global logger provider.
         *
         * @returns LoggerProvider
         */
        LogsAPI.prototype.getLoggerProvider = function () {
            var _a, _b;
            return ((_b = (_a = _global[GLOBAL_LOGS_API_KEY]) === null || _a === void 0 ? void 0 : _a.call(_global, API_BACKWARDS_COMPATIBILITY_VERSION)) !== null && _b !== void 0 ? _b : this._proxyLoggerProvider);
        };
        /**
         * Returns a logger from the global logger provider.
         *
         * @returns Logger
         */
        LogsAPI.prototype.getLogger = function (name, version, options) {
            return this.getLoggerProvider().getLogger(name, version, options);
        };
        /** Remove the global logger provider */
        LogsAPI.prototype.disable = function () {
            delete _global[GLOBAL_LOGS_API_KEY];
            this._proxyLoggerProvider = new ProxyLoggerProvider();
        };
        return LogsAPI;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var logs = LogsAPI.getInstance();

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __assign = (undefined && undefined.__assign) || function () {
        __assign = Object.assign || function(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                    t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    /**
     * Base abstract internal class for instrumenting node and web plugins
     */
    var InstrumentationAbstract = /** @class */ (function () {
        function InstrumentationAbstract(instrumentationName, instrumentationVersion, config) {
            this.instrumentationName = instrumentationName;
            this.instrumentationVersion = instrumentationVersion;
            this._config = {};
            /* Api to wrap instrumented method */
            this._wrap = shimmerExports.wrap;
            /* Api to unwrap instrumented methods */
            this._unwrap = shimmerExports.unwrap;
            /* Api to mass wrap instrumented method */
            this._massWrap = shimmerExports.massWrap;
            /* Api to mass unwrap instrumented methods */
            this._massUnwrap = shimmerExports.massUnwrap;
            this.setConfig(config);
            this._diag = diag.createComponentLogger({
                namespace: instrumentationName,
            });
            this._tracer = trace.getTracer(instrumentationName, instrumentationVersion);
            this._meter = metrics.getMeter(instrumentationName, instrumentationVersion);
            this._logger = logs.getLogger(instrumentationName, instrumentationVersion);
            this._updateMetricInstruments();
        }
        Object.defineProperty(InstrumentationAbstract.prototype, "meter", {
            /* Returns meter */
            get: function () {
                return this._meter;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Sets MeterProvider to this plugin
         * @param meterProvider
         */
        InstrumentationAbstract.prototype.setMeterProvider = function (meterProvider) {
            this._meter = meterProvider.getMeter(this.instrumentationName, this.instrumentationVersion);
            this._updateMetricInstruments();
        };
        Object.defineProperty(InstrumentationAbstract.prototype, "logger", {
            /* Returns logger */
            get: function () {
                return this._logger;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Sets LoggerProvider to this plugin
         * @param loggerProvider
         */
        InstrumentationAbstract.prototype.setLoggerProvider = function (loggerProvider) {
            this._logger = loggerProvider.getLogger(this.instrumentationName, this.instrumentationVersion);
        };
        /**
         * @experimental
         *
         * Get module definitions defined by {@link init}.
         * This can be used for experimental compile-time instrumentation.
         *
         * @returns an array of {@link InstrumentationModuleDefinition}
         */
        InstrumentationAbstract.prototype.getModuleDefinitions = function () {
            var _a;
            var initResult = (_a = this.init()) !== null && _a !== void 0 ? _a : [];
            if (!Array.isArray(initResult)) {
                return [initResult];
            }
            return initResult;
        };
        /**
         * Sets the new metric instruments with the current Meter.
         */
        InstrumentationAbstract.prototype._updateMetricInstruments = function () {
            return;
        };
        /* Returns InstrumentationConfig */
        InstrumentationAbstract.prototype.getConfig = function () {
            return this._config;
        };
        /**
         * Sets InstrumentationConfig to this plugin
         * @param config
         */
        InstrumentationAbstract.prototype.setConfig = function (config) {
            // copy config first level properties to ensure they are immutable.
            // nested properties are not copied, thus are mutable from the outside.
            this._config = __assign({ enabled: true }, config);
        };
        /**
         * Sets TraceProvider to this plugin
         * @param tracerProvider
         */
        InstrumentationAbstract.prototype.setTracerProvider = function (tracerProvider) {
            this._tracer = tracerProvider.getTracer(this.instrumentationName, this.instrumentationVersion);
        };
        Object.defineProperty(InstrumentationAbstract.prototype, "tracer", {
            /* Returns tracer */
            get: function () {
                return this._tracer;
            },
            enumerable: false,
            configurable: true
        });
        /**
         * Execute span customization hook, if configured, and log any errors.
         * Any semantics of the trigger and info are defined by the specific instrumentation.
         * @param hookHandler The optional hook handler which the user has configured via instrumentation config
         * @param triggerName The name of the trigger for executing the hook for logging purposes
         * @param span The span to which the hook should be applied
         * @param info The info object to be passed to the hook, with useful data the hook may use
         */
        InstrumentationAbstract.prototype._runSpanCustomizationHook = function (hookHandler, triggerName, span, info) {
            if (!hookHandler) {
                return;
            }
            try {
                hookHandler(span, info);
            }
            catch (e) {
                this._diag.error("Error running span customization hook due to exception in handler", { triggerName: triggerName }, e);
            }
        };
        return InstrumentationAbstract;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$3 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * Base abstract class for instrumenting web plugins
     */
    var InstrumentationBase = /** @class */ (function (_super) {
        __extends$3(InstrumentationBase, _super);
        function InstrumentationBase(instrumentationName, instrumentationVersion, config) {
            var _this = _super.call(this, instrumentationName, instrumentationVersion, config) || this;
            if (_this._config.enabled) {
                _this.enable();
            }
            return _this;
        }
        return InstrumentationBase;
    }(InstrumentationAbstract));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * function to execute patched function and being able to catch errors
     * @param execute - function to be executed
     * @param onFinish - callback to run when execute finishes
     */
    function safeExecuteInTheMiddle(execute, onFinish, preventThrowingError) {
        var error;
        var result;
        try {
            result = execute();
        }
        catch (e) {
            error = e;
        }
        finally {
            onFinish(error, result);
            // eslint-disable-next-line no-unsafe-finally
            return result;
        }
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var AttributeNames$2;
    (function (AttributeNames) {
        AttributeNames["DOCUMENT_LOAD"] = "documentLoad";
        AttributeNames["DOCUMENT_FETCH"] = "documentFetch";
        AttributeNames["RESOURCE_FETCH"] = "resourceFetch";
    })(AttributeNames$2 || (AttributeNames$2 = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // this is autogenerated file, see scripts/version-update.js
    var PACKAGE_VERSION = '0.44.1';
    var PACKAGE_NAME = '@opentelemetry/instrumentation-document-load';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var EventNames$1;
    (function (EventNames) {
        EventNames["FIRST_PAINT"] = "firstPaint";
        EventNames["FIRST_CONTENTFUL_PAINT"] = "firstContentfulPaint";
    })(EventNames$1 || (EventNames$1 = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var getPerformanceNavigationEntries = function () {
        var _a, _b;
        var entries = {};
        var performanceNavigationTiming = (_b = (_a = otperformance).getEntriesByType) === null || _b === void 0 ? void 0 : _b.call(_a, 'navigation')[0];
        if (performanceNavigationTiming) {
            var keys = Object.values(PerformanceTimingNames);
            keys.forEach(function (key) {
                if (hasKey(performanceNavigationTiming, key)) {
                    var value = performanceNavigationTiming[key];
                    if (typeof value === 'number') {
                        entries[key] = value;
                    }
                }
            });
        }
        else {
            // // fallback to previous version
            var perf = otperformance;
            var performanceTiming_1 = perf.timing;
            if (performanceTiming_1) {
                var keys = Object.values(PerformanceTimingNames);
                keys.forEach(function (key) {
                    if (hasKey(performanceTiming_1, key)) {
                        var value = performanceTiming_1[key];
                        if (typeof value === 'number') {
                            entries[key] = value;
                        }
                    }
                });
            }
        }
        return entries;
    };
    var performancePaintNames = {
        'first-paint': EventNames$1.FIRST_PAINT,
        'first-contentful-paint': EventNames$1.FIRST_CONTENTFUL_PAINT,
    };
    var addSpanPerformancePaintEvents = function (span) {
        var _a, _b;
        var performancePaintTiming = (_b = (_a = otperformance).getEntriesByType) === null || _b === void 0 ? void 0 : _b.call(_a, 'paint');
        if (performancePaintTiming) {
            performancePaintTiming.forEach(function (_a) {
                var name = _a.name, startTime = _a.startTime;
                if (hasKey(performancePaintNames, name)) {
                    span.addEvent(performancePaintNames[name], startTime);
                }
            });
        }
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$2 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    /**
     * This class represents a document load plugin
     */
    var DocumentLoadInstrumentation = /** @class */ (function (_super) {
        __extends$2(DocumentLoadInstrumentation, _super);
        function DocumentLoadInstrumentation(config) {
            if (config === void 0) { config = {}; }
            var _this = _super.call(this, PACKAGE_NAME, PACKAGE_VERSION, config) || this;
            _this.component = 'document-load';
            _this.version = '1';
            _this.moduleName = _this.component;
            return _this;
        }
        DocumentLoadInstrumentation.prototype.init = function () { };
        /**
         * callback to be executed when page is loaded
         */
        DocumentLoadInstrumentation.prototype._onDocumentLoaded = function () {
            var _this = this;
            // Timeout is needed as load event doesn't have yet the performance metrics for loadEnd.
            // Support for event "loadend" is very limited and cannot be used
            window.setTimeout(function () {
                _this._collectPerformance();
            });
        };
        /**
         * Adds spans for all resources
         * @param rootSpan
         */
        DocumentLoadInstrumentation.prototype._addResourcesSpans = function (rootSpan) {
            var _this = this;
            var _a, _b;
            var resources = (_b = (_a = otperformance).getEntriesByType) === null || _b === void 0 ? void 0 : _b.call(_a, 'resource');
            if (resources) {
                resources.forEach(function (resource) {
                    _this._initResourceSpan(resource, rootSpan);
                });
            }
        };
        /**
         * Collects information about performance and creates appropriate spans
         */
        DocumentLoadInstrumentation.prototype._collectPerformance = function () {
            var _this = this;
            var metaElement = Array.from(document.getElementsByTagName('meta')).find(function (e) { return e.getAttribute('name') === TRACE_PARENT_HEADER; });
            var entries = getPerformanceNavigationEntries();
            var traceparent = (metaElement && metaElement.content) || '';
            context.with(propagation.extract(ROOT_CONTEXT, { traceparent: traceparent }), function () {
                var _a;
                var rootSpan = _this._startSpan(AttributeNames$2.DOCUMENT_LOAD, PerformanceTimingNames.FETCH_START, entries);
                if (!rootSpan) {
                    return;
                }
                context.with(trace.setSpan(context.active(), rootSpan), function () {
                    var fetchSpan = _this._startSpan(AttributeNames$2.DOCUMENT_FETCH, PerformanceTimingNames.FETCH_START, entries);
                    if (fetchSpan) {
                        fetchSpan.setAttribute(SEMATTRS_HTTP_URL, location.href);
                        context.with(trace.setSpan(context.active(), fetchSpan), function () {
                            var _a;
                            if (!_this.getConfig().ignoreNetworkEvents) {
                                addSpanNetworkEvents(fetchSpan, entries);
                            }
                            _this._addCustomAttributesOnSpan(fetchSpan, (_a = _this.getConfig().applyCustomAttributesOnSpan) === null || _a === void 0 ? void 0 : _a.documentFetch);
                            _this._endSpan(fetchSpan, PerformanceTimingNames.RESPONSE_END, entries);
                        });
                    }
                });
                rootSpan.setAttribute(SEMATTRS_HTTP_URL, location.href);
                rootSpan.setAttribute(SEMATTRS_HTTP_USER_AGENT, navigator.userAgent);
                _this._addResourcesSpans(rootSpan);
                if (!_this.getConfig().ignoreNetworkEvents) {
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.FETCH_START, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.UNLOAD_EVENT_START, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.UNLOAD_EVENT_END, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.DOM_INTERACTIVE, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.DOM_CONTENT_LOADED_EVENT_START, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.DOM_CONTENT_LOADED_EVENT_END, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.DOM_COMPLETE, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.LOAD_EVENT_START, entries);
                    addSpanNetworkEvent(rootSpan, PerformanceTimingNames.LOAD_EVENT_END, entries);
                }
                if (!_this.getConfig().ignorePerformancePaintEvents) {
                    addSpanPerformancePaintEvents(rootSpan);
                }
                _this._addCustomAttributesOnSpan(rootSpan, (_a = _this.getConfig().applyCustomAttributesOnSpan) === null || _a === void 0 ? void 0 : _a.documentLoad);
                _this._endSpan(rootSpan, PerformanceTimingNames.LOAD_EVENT_END, entries);
            });
        };
        /**
         * Helper function for ending span
         * @param span
         * @param performanceName name of performance entry for time end
         * @param entries
         */
        DocumentLoadInstrumentation.prototype._endSpan = function (span, performanceName, entries) {
            // span can be undefined when entries are missing the certain performance - the span will not be created
            if (span) {
                if (hasKey(entries, performanceName)) {
                    span.end(entries[performanceName]);
                }
                else {
                    // just end span
                    span.end();
                }
            }
        };
        /**
         * Creates and ends a span with network information about resource added as timed events
         * @param resource
         * @param parentSpan
         */
        DocumentLoadInstrumentation.prototype._initResourceSpan = function (resource, parentSpan) {
            var _a;
            var span = this._startSpan(AttributeNames$2.RESOURCE_FETCH, PerformanceTimingNames.FETCH_START, resource, parentSpan);
            if (span) {
                span.setAttribute(SEMATTRS_HTTP_URL, resource.name);
                if (!this.getConfig().ignoreNetworkEvents) {
                    addSpanNetworkEvents(span, resource);
                }
                this._addCustomAttributesOnResourceSpan(span, resource, (_a = this.getConfig().applyCustomAttributesOnSpan) === null || _a === void 0 ? void 0 : _a.resourceFetch);
                this._endSpan(span, PerformanceTimingNames.RESPONSE_END, resource);
            }
        };
        /**
         * Helper function for starting a span
         * @param spanName name of span
         * @param performanceName name of performance entry for time start
         * @param entries
         * @param parentSpan
         */
        DocumentLoadInstrumentation.prototype._startSpan = function (spanName, performanceName, entries, parentSpan) {
            if (hasKey(entries, performanceName) &&
                typeof entries[performanceName] === 'number') {
                var span = this.tracer.startSpan(spanName, {
                    startTime: entries[performanceName],
                }, parentSpan ? trace.setSpan(context.active(), parentSpan) : undefined);
                return span;
            }
            return undefined;
        };
        /**
         * executes callback {_onDocumentLoaded} when the page is loaded
         */
        DocumentLoadInstrumentation.prototype._waitForPageLoad = function () {
            if (window.document.readyState === 'complete') {
                this._onDocumentLoaded();
            }
            else {
                this._onDocumentLoaded = this._onDocumentLoaded.bind(this);
                window.addEventListener('load', this._onDocumentLoaded);
            }
        };
        /**
         * adds custom attributes to root span if configured
         */
        DocumentLoadInstrumentation.prototype._addCustomAttributesOnSpan = function (span, applyCustomAttributesOnSpan) {
            var _this = this;
            if (applyCustomAttributesOnSpan) {
                safeExecuteInTheMiddle(function () { return applyCustomAttributesOnSpan(span); }, function (error) {
                    if (!error) {
                        return;
                    }
                    _this._diag.error('addCustomAttributesOnSpan', error);
                });
            }
        };
        /**
         * adds custom attributes to span if configured
         */
        DocumentLoadInstrumentation.prototype._addCustomAttributesOnResourceSpan = function (span, resource, applyCustomAttributesOnSpan) {
            var _this = this;
            if (applyCustomAttributesOnSpan) {
                safeExecuteInTheMiddle(function () { return applyCustomAttributesOnSpan(span, resource); }, function (error) {
                    if (!error) {
                        return;
                    }
                    _this._diag.error('addCustomAttributesOnResourceSpan', error);
                });
            }
        };
        /**
         * implements enable function
         */
        DocumentLoadInstrumentation.prototype.enable = function () {
            // remove previously attached load to avoid adding the same event twice
            // in case of multiple enable calling.
            window.removeEventListener('load', this._onDocumentLoaded);
            this._waitForPageLoad();
        };
        /**
         * implements disable function
         */
        DocumentLoadInstrumentation.prototype.disable = function () {
            window.removeEventListener('load', this._onDocumentLoaded);
        };
        return DocumentLoadInstrumentation;
    }(InstrumentationBase));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * https://github.com/open-telemetry/opentelemetry-specification/blob/master/specification/trace/semantic_conventions/http.md
     */
    var AttributeNames$1;
    (function (AttributeNames) {
        AttributeNames["COMPONENT"] = "component";
        AttributeNames["HTTP_ERROR_NAME"] = "http.error_name";
        AttributeNames["HTTP_STATUS_TEXT"] = "http.status_text";
    })(AttributeNames$1 || (AttributeNames$1 = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$2 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$2 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var __values$2 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$3 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var DIAG_LOGGER$1 = diag.createComponentLogger({
        namespace: '@opentelemetry/opentelemetry-instrumentation-fetch/utils',
    });
    /**
     * Helper function to determine payload content length for fetch requests
     *
     * The fetch API is kinda messy: there are a couple of ways the body can be passed in.
     *
     * In all cases, the body param can be some variation of ReadableStream,
     * and ReadableStreams can only be read once! We want to avoid consuming the body here,
     * because that would mean that the body never gets sent with the actual fetch request.
     *
     * Either the first arg is a Request object, which can be cloned
     *   so we can clone that object and read the body of the clone
     *   without disturbing the original argument
     *   However, reading the body here can only be done async; the body() method returns a promise
     *   this means this entire function has to return a promise
     *
     * OR the first arg is a url/string
     *   in which case the second arg has type RequestInit
     *   RequestInit is NOT cloneable, but RequestInit.body is writable
     *   so we can chain it into ReadableStream.pipeThrough()
     *
     *   ReadableStream.pipeThrough() lets us process a stream and returns a new stream
     *   So we can measure the body length as it passes through the pie, but need to attach
     *   the new stream to the original request
     *   so that the browser still has access to the body.
     *
     * @param body
     * @returns promise that resolves to the content length of the body
     */
    function getFetchBodyLength() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (args[0] instanceof URL || typeof args[0] === 'string') {
            var requestInit = args[1];
            if (!(requestInit === null || requestInit === void 0 ? void 0 : requestInit.body)) {
                return Promise.resolve();
            }
            if (requestInit.body instanceof ReadableStream) {
                var _a = _getBodyNonDestructively(requestInit.body), body = _a.body, length_1 = _a.length;
                requestInit.body = body;
                return length_1;
            }
            else {
                return Promise.resolve(getXHRBodyLength$1(requestInit.body));
            }
        }
        else {
            var info = args[0];
            if (!(info === null || info === void 0 ? void 0 : info.body)) {
                return Promise.resolve();
            }
            return info
                .clone()
                .text()
                .then(function (t) { return getByteLength$1(t); });
        }
    }
    function _getBodyNonDestructively(body) {
        // can't read a ReadableStream without destroying it
        // but we CAN pipe it through and return a new ReadableStream
        // some (older) platforms don't expose the pipeThrough method and in that scenario, we're out of luck;
        //   there's no way to read the stream without consuming it.
        if (!body.pipeThrough) {
            DIAG_LOGGER$1.warn('Platform has ReadableStream but not pipeThrough!');
            return {
                body: body,
                length: Promise.resolve(undefined),
            };
        }
        var length = 0;
        var resolveLength;
        var lengthPromise = new Promise(function (resolve) {
            resolveLength = resolve;
        });
        var transform = new TransformStream({
            start: function () { },
            transform: function (chunk, controller) {
                return __awaiter$2(this, void 0, void 0, function () {
                    var bytearray;
                    return __generator$2(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, chunk];
                            case 1:
                                bytearray = (_a.sent());
                                length += bytearray.byteLength;
                                controller.enqueue(chunk);
                                return [2 /*return*/];
                        }
                    });
                });
            },
            flush: function () {
                resolveLength(length);
            },
        });
        return {
            body: body.pipeThrough(transform),
            length: lengthPromise,
        };
    }
    /**
     * Helper function to determine payload content length for XHR requests
     * @param body
     * @returns content length
     */
    function getXHRBodyLength$1(body) {
        if (typeof Document !== 'undefined' && body instanceof Document) {
            return new XMLSerializer().serializeToString(document).length;
        }
        // XMLHttpRequestBodyInit expands to the following:
        if (body instanceof Blob) {
            return body.size;
        }
        // ArrayBuffer | ArrayBufferView
        if (body.byteLength !== undefined) {
            return body.byteLength;
        }
        if (body instanceof FormData) {
            return getFormDataSize$1(body);
        }
        if (body instanceof URLSearchParams) {
            return getByteLength$1(body.toString());
        }
        if (typeof body === 'string') {
            return getByteLength$1(body);
        }
        DIAG_LOGGER$1.warn('unknown body type');
        return undefined;
    }
    var TEXT_ENCODER$1 = new TextEncoder();
    function getByteLength$1(s) {
        return TEXT_ENCODER$1.encode(s).byteLength;
    }
    function getFormDataSize$1(formData) {
        var e_1, _a;
        var size = 0;
        try {
            for (var _b = __values$2(formData.entries()), _c = _b.next(); !_c.done; _c = _b.next()) {
                var _d = __read$3(_c.value, 2), key = _d[0], value = _d[1];
                size += key.length;
                if (value instanceof Blob) {
                    size += value.size;
                }
                else {
                    size += value.length;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return size;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // this is autogenerated file, see scripts/version-update.js
    var VERSION$1 = '0.57.0';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends$1 = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    var __read$2 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray$1 = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var _a;
    // how long to wait for observer to collect information about resources
    // this is needed as event "load" is called before observer
    // hard to say how long it should really wait, seems like 300ms is
    // safe enough
    var OBSERVER_WAIT_TIME_MS$1 = 300;
    var isNode = typeof process === 'object' && ((_a = process.release) === null || _a === void 0 ? void 0 : _a.name) === 'node';
    /**
     * This class represents a fetch plugin for auto instrumentation
     */
    var FetchInstrumentation = /** @class */ (function (_super) {
        __extends$1(FetchInstrumentation, _super);
        function FetchInstrumentation(config) {
            if (config === void 0) { config = {}; }
            var _this = _super.call(this, '@opentelemetry/instrumentation-fetch', VERSION$1, config) || this;
            _this.component = 'fetch';
            _this.version = VERSION$1;
            _this.moduleName = _this.component;
            _this._usedResources = new WeakSet();
            _this._tasksCount = 0;
            return _this;
        }
        FetchInstrumentation.prototype.init = function () { };
        /**
         * Add cors pre flight child span
         * @param span
         * @param corsPreFlightRequest
         */
        FetchInstrumentation.prototype._addChildSpan = function (span, corsPreFlightRequest) {
            var childSpan = this.tracer.startSpan('CORS Preflight', {
                startTime: corsPreFlightRequest[PerformanceTimingNames.FETCH_START],
            }, trace.setSpan(context.active(), span));
            addSpanNetworkEvents(childSpan, corsPreFlightRequest, this.getConfig().ignoreNetworkEvents);
            childSpan.end(corsPreFlightRequest[PerformanceTimingNames.RESPONSE_END]);
        };
        /**
         * Adds more attributes to span just before ending it
         * @param span
         * @param response
         */
        FetchInstrumentation.prototype._addFinalSpanAttributes = function (span, response) {
            var parsedUrl = parseUrl(response.url);
            span.setAttribute(SEMATTRS_HTTP_STATUS_CODE, response.status);
            if (response.statusText != null) {
                span.setAttribute(AttributeNames$1.HTTP_STATUS_TEXT, response.statusText);
            }
            span.setAttribute(SEMATTRS_HTTP_HOST, parsedUrl.host);
            span.setAttribute(SEMATTRS_HTTP_SCHEME, parsedUrl.protocol.replace(':', ''));
            if (typeof navigator !== 'undefined') {
                span.setAttribute(SEMATTRS_HTTP_USER_AGENT, navigator.userAgent);
            }
        };
        /**
         * Add headers
         * @param options
         * @param spanUrl
         */
        FetchInstrumentation.prototype._addHeaders = function (options, spanUrl) {
            if (!shouldPropagateTraceHeaders(spanUrl, this.getConfig().propagateTraceHeaderCorsUrls)) {
                var headers = {};
                propagation.inject(context.active(), headers);
                if (Object.keys(headers).length > 0) {
                    this._diag.debug('headers inject skipped due to CORS policy');
                }
                return;
            }
            if (options instanceof Request) {
                propagation.inject(context.active(), options.headers, {
                    set: function (h, k, v) { return h.set(k, typeof v === 'string' ? v : String(v)); },
                });
            }
            else if (options.headers instanceof Headers) {
                propagation.inject(context.active(), options.headers, {
                    set: function (h, k, v) { return h.set(k, typeof v === 'string' ? v : String(v)); },
                });
            }
            else if (options.headers instanceof Map) {
                propagation.inject(context.active(), options.headers, {
                    set: function (h, k, v) { return h.set(k, typeof v === 'string' ? v : String(v)); },
                });
            }
            else {
                var headers = {};
                propagation.inject(context.active(), headers);
                options.headers = Object.assign({}, headers, options.headers || {});
            }
        };
        /**
         * Clears the resource timings and all resources assigned with spans
         *     when {@link FetchPluginConfig.clearTimingResources} is
         *     set to true (default false)
         * @private
         */
        FetchInstrumentation.prototype._clearResources = function () {
            if (this._tasksCount === 0 && this.getConfig().clearTimingResources) {
                performance.clearResourceTimings();
                this._usedResources = new WeakSet();
            }
        };
        /**
         * Creates a new span
         * @param url
         * @param options
         */
        FetchInstrumentation.prototype._createSpan = function (url, options) {
            var _a;
            if (options === void 0) { options = {}; }
            if (isUrlIgnored(url, this.getConfig().ignoreUrls)) {
                this._diag.debug('ignoring span as url matches ignored url');
                return;
            }
            var method = (options.method || 'GET').toUpperCase();
            var spanName = "HTTP " + method;
            return this.tracer.startSpan(spanName, {
                kind: SpanKind.CLIENT,
                attributes: (_a = {},
                    _a[AttributeNames$1.COMPONENT] = this.moduleName,
                    _a[SEMATTRS_HTTP_METHOD] = method,
                    _a[SEMATTRS_HTTP_URL] = url,
                    _a),
            });
        };
        /**
         * Finds appropriate resource and add network events to the span
         * @param span
         * @param resourcesObserver
         * @param endTime
         */
        FetchInstrumentation.prototype._findResourceAndAddNetworkEvents = function (span, resourcesObserver, endTime) {
            var resources = resourcesObserver.entries;
            if (!resources.length) {
                if (!performance.getEntriesByType) {
                    return;
                }
                // fallback - either Observer is not available or it took longer
                // then OBSERVER_WAIT_TIME_MS and observer didn't collect enough
                // information
                resources = performance.getEntriesByType('resource');
            }
            var resource = getResource(resourcesObserver.spanUrl, resourcesObserver.startTime, endTime, resources, this._usedResources, 'fetch');
            if (resource.mainRequest) {
                var mainRequest = resource.mainRequest;
                this._markResourceAsUsed(mainRequest);
                var corsPreFlightRequest = resource.corsPreFlightRequest;
                if (corsPreFlightRequest) {
                    this._addChildSpan(span, corsPreFlightRequest);
                    this._markResourceAsUsed(corsPreFlightRequest);
                }
                addSpanNetworkEvents(span, mainRequest, this.getConfig().ignoreNetworkEvents);
            }
        };
        /**
         * Marks certain [resource]{@link PerformanceResourceTiming} when information
         * from this is used to add events to span.
         * This is done to avoid reusing the same resource again for next span
         * @param resource
         */
        FetchInstrumentation.prototype._markResourceAsUsed = function (resource) {
            this._usedResources.add(resource);
        };
        /**
         * Finish span, add attributes, network events etc.
         * @param span
         * @param spanData
         * @param response
         */
        FetchInstrumentation.prototype._endSpan = function (span, spanData, response) {
            var _this = this;
            var endTime = millisToHrTime(Date.now());
            var performanceEndTime = hrTime();
            this._addFinalSpanAttributes(span, response);
            setTimeout(function () {
                var _a;
                (_a = spanData.observer) === null || _a === void 0 ? void 0 : _a.disconnect();
                _this._findResourceAndAddNetworkEvents(span, spanData, performanceEndTime);
                _this._tasksCount--;
                _this._clearResources();
                span.end(endTime);
            }, OBSERVER_WAIT_TIME_MS$1);
        };
        /**
         * Patches the constructor of fetch
         */
        FetchInstrumentation.prototype._patchConstructor = function () {
            var _this = this;
            return function (original) {
                var plugin = _this;
                return function patchConstructor() {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    var self = this;
                    var url = parseUrl(args[0] instanceof Request ? args[0].url : String(args[0])).href;
                    var options = args[0] instanceof Request ? args[0] : args[1] || {};
                    var createdSpan = plugin._createSpan(url, options);
                    if (!createdSpan) {
                        return original.apply(this, args);
                    }
                    var spanData = plugin._prepareSpanData(url);
                    if (plugin.getConfig().measureRequestSize) {
                        getFetchBodyLength.apply(void 0, __spreadArray$1([], __read$2(args), false)).then(function (length) {
                            if (!length)
                                return;
                            createdSpan.setAttribute(SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED, length);
                        })
                            .catch(function (error) {
                            plugin._diag.warn('getFetchBodyLength', error);
                        });
                    }
                    function endSpanOnError(span, error) {
                        plugin._applyAttributesAfterFetch(span, options, error);
                        plugin._endSpan(span, spanData, {
                            status: error.status || 0,
                            statusText: error.message,
                            url: url,
                        });
                    }
                    function endSpanOnSuccess(span, response) {
                        plugin._applyAttributesAfterFetch(span, options, response);
                        if (response.status >= 200 && response.status < 400) {
                            plugin._endSpan(span, spanData, response);
                        }
                        else {
                            plugin._endSpan(span, spanData, {
                                status: response.status,
                                statusText: response.statusText,
                                url: url,
                            });
                        }
                    }
                    function onSuccess(span, resolve, response) {
                        try {
                            var resClone = response.clone();
                            var resClone4Hook_1 = response.clone();
                            var body = resClone.body;
                            if (body) {
                                var reader_1 = body.getReader();
                                var read_1 = function () {
                                    reader_1.read().then(function (_a) {
                                        var done = _a.done;
                                        if (done) {
                                            endSpanOnSuccess(span, resClone4Hook_1);
                                        }
                                        else {
                                            read_1();
                                        }
                                    }, function (error) {
                                        endSpanOnError(span, error);
                                    });
                                };
                                read_1();
                            }
                            else {
                                // some older browsers don't have .body implemented
                                endSpanOnSuccess(span, response);
                            }
                        }
                        finally {
                            resolve(response);
                        }
                    }
                    function onError(span, reject, error) {
                        try {
                            endSpanOnError(span, error);
                        }
                        finally {
                            reject(error);
                        }
                    }
                    return new Promise(function (resolve, reject) {
                        return context.with(trace.setSpan(context.active(), createdSpan), function () {
                            plugin._addHeaders(options, url);
                            plugin._tasksCount++;
                            // TypeScript complains about arrow function captured a this typed as globalThis
                            // ts(7041)
                            return original
                                .apply(self, options instanceof Request ? [options] : [url, options])
                                .then(onSuccess.bind(self, createdSpan, resolve), onError.bind(self, createdSpan, reject));
                        });
                    });
                };
            };
        };
        FetchInstrumentation.prototype._applyAttributesAfterFetch = function (span, request, result) {
            var _this = this;
            var applyCustomAttributesOnSpan = this.getConfig().applyCustomAttributesOnSpan;
            if (applyCustomAttributesOnSpan) {
                safeExecuteInTheMiddle$1(function () { return applyCustomAttributesOnSpan(span, request, result); }, function (error) {
                    if (!error) {
                        return;
                    }
                    _this._diag.error('applyCustomAttributesOnSpan', error);
                });
            }
        };
        /**
         * Prepares a span data - needed later for matching appropriate network
         *     resources
         * @param spanUrl
         */
        FetchInstrumentation.prototype._prepareSpanData = function (spanUrl) {
            var startTime = hrTime();
            var entries = [];
            if (typeof PerformanceObserver !== 'function') {
                return { entries: entries, startTime: startTime, spanUrl: spanUrl };
            }
            var observer = new PerformanceObserver(function (list) {
                var perfObsEntries = list.getEntries();
                perfObsEntries.forEach(function (entry) {
                    if (entry.initiatorType === 'fetch' && entry.name === spanUrl) {
                        entries.push(entry);
                    }
                });
            });
            observer.observe({
                entryTypes: ['resource'],
            });
            return { entries: entries, observer: observer, startTime: startTime, spanUrl: spanUrl };
        };
        /**
         * implements enable function
         */
        FetchInstrumentation.prototype.enable = function () {
            if (isNode) {
                // Node.js v18+ *does* have a global `fetch()`, but this package does not
                // support instrumenting it.
                this._diag.warn("this instrumentation is intended for web usage only, it does not instrument Node.js's fetch()");
                return;
            }
            if (isWrapped(fetch)) {
                this._unwrap(_globalThis$1, 'fetch');
                this._diag.debug('removing previous patch for constructor');
            }
            this._wrap(_globalThis$1, 'fetch', this._patchConstructor());
        };
        /**
         * implements unpatch function
         */
        FetchInstrumentation.prototype.disable = function () {
            if (isNode) {
                return;
            }
            this._unwrap(_globalThis$1, 'fetch');
            this._usedResources = new WeakSet();
        };
        return FetchInstrumentation;
    }(InstrumentationBase$1));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var EventNames;
    (function (EventNames) {
        EventNames["METHOD_OPEN"] = "open";
        EventNames["METHOD_SEND"] = "send";
        EventNames["EVENT_ABORT"] = "abort";
        EventNames["EVENT_ERROR"] = "error";
        EventNames["EVENT_LOAD"] = "loaded";
        EventNames["EVENT_TIMEOUT"] = "timeout";
    })(EventNames || (EventNames = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __values$1 = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var __read$1 = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var DIAG_LOGGER = diag.createComponentLogger({
        namespace: '@opentelemetry/opentelemetry-instrumentation-xml-http-request/utils',
    });
    /**
     * Helper function to determine payload content length for XHR requests
     * @param body
     * @returns content length
     */
    function getXHRBodyLength(body) {
        if (typeof Document !== 'undefined' && body instanceof Document) {
            return new XMLSerializer().serializeToString(document).length;
        }
        // XMLHttpRequestBodyInit expands to the following:
        if (body instanceof Blob) {
            return body.size;
        }
        // ArrayBuffer | ArrayBufferView
        if (body.byteLength !== undefined) {
            return body.byteLength;
        }
        if (body instanceof FormData) {
            return getFormDataSize(body);
        }
        if (body instanceof URLSearchParams) {
            return getByteLength(body.toString());
        }
        if (typeof body === 'string') {
            return getByteLength(body);
        }
        DIAG_LOGGER.warn('unknown body type');
        return undefined;
    }
    var TEXT_ENCODER = new TextEncoder();
    function getByteLength(s) {
        return TEXT_ENCODER.encode(s).byteLength;
    }
    function getFormDataSize(formData) {
        var e_1, _a;
        var size = 0;
        try {
            for (var _b = __values$1(formData.entries()), _c = _b.next(); !_c.done; _c = _b.next()) {
                var _d = __read$1(_c.value, 2), key = _d[0], value = _d[1];
                size += key.length;
                if (value instanceof Blob) {
                    size += value.size;
                }
                else {
                    size += value.length;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_1) throw e_1.error; }
        }
        return size;
    }

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    // this is autogenerated file, see scripts/version-update.js
    var VERSION = '0.57.0';

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    /**
     * https://github.com/open-telemetry/opentelemetry-specification/blob/master/specification/trace/semantic_conventions/http.md
     */
    var AttributeNames;
    (function (AttributeNames) {
        AttributeNames["HTTP_STATUS_TEXT"] = "http.status_text";
    })(AttributeNames || (AttributeNames = {}));

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __extends = (undefined && undefined.__extends) || (function () {
        var extendStatics = function (d, b) {
            extendStatics = Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
                function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
            return extendStatics(d, b);
        };
        return function (d, b) {
            if (typeof b !== "function" && b !== null)
                throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
            extendStatics(d, b);
            function __() { this.constructor = d; }
            d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
        };
    })();
    // how long to wait for observer to collect information about resources
    // this is needed as event "load" is called before observer
    // hard to say how long it should really wait, seems like 300ms is
    // safe enough
    var OBSERVER_WAIT_TIME_MS = 300;
    /**
     * This class represents a XMLHttpRequest plugin for auto instrumentation
     */
    var XMLHttpRequestInstrumentation = /** @class */ (function (_super) {
        __extends(XMLHttpRequestInstrumentation, _super);
        function XMLHttpRequestInstrumentation(config) {
            if (config === void 0) { config = {}; }
            var _this = _super.call(this, '@opentelemetry/instrumentation-xml-http-request', VERSION, config) || this;
            _this.component = 'xml-http-request';
            _this.version = VERSION;
            _this.moduleName = _this.component;
            _this._tasksCount = 0;
            _this._xhrMem = new WeakMap();
            _this._usedResources = new WeakSet();
            return _this;
        }
        XMLHttpRequestInstrumentation.prototype.init = function () { };
        /**
         * Adds custom headers to XMLHttpRequest
         * @param xhr
         * @param spanUrl
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._addHeaders = function (xhr, spanUrl) {
            var url = parseUrl(spanUrl).href;
            if (!shouldPropagateTraceHeaders(url, this.getConfig().propagateTraceHeaderCorsUrls)) {
                var headers_1 = {};
                propagation.inject(context.active(), headers_1);
                if (Object.keys(headers_1).length > 0) {
                    this._diag.debug('headers inject skipped due to CORS policy');
                }
                return;
            }
            var headers = {};
            propagation.inject(context.active(), headers);
            Object.keys(headers).forEach(function (key) {
                xhr.setRequestHeader(key, String(headers[key]));
            });
        };
        /**
         * Add cors pre flight child span
         * @param span
         * @param corsPreFlightRequest
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._addChildSpan = function (span, corsPreFlightRequest) {
            var _this = this;
            context.with(trace.setSpan(context.active(), span), function () {
                var childSpan = _this.tracer.startSpan('CORS Preflight', {
                    startTime: corsPreFlightRequest[PerformanceTimingNames.FETCH_START],
                });
                addSpanNetworkEvents(childSpan, corsPreFlightRequest, _this.getConfig().ignoreNetworkEvents);
                childSpan.end(corsPreFlightRequest[PerformanceTimingNames.RESPONSE_END]);
            });
        };
        /**
         * Add attributes when span is going to end
         * @param span
         * @param xhr
         * @param spanUrl
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._addFinalSpanAttributes = function (span, xhrMem, spanUrl) {
            if (typeof spanUrl === 'string') {
                var parsedUrl = parseUrl(spanUrl);
                if (xhrMem.status !== undefined) {
                    span.setAttribute(SEMATTRS_HTTP_STATUS_CODE, xhrMem.status);
                }
                if (xhrMem.statusText !== undefined) {
                    span.setAttribute(AttributeNames.HTTP_STATUS_TEXT, xhrMem.statusText);
                }
                span.setAttribute(SEMATTRS_HTTP_HOST, parsedUrl.host);
                span.setAttribute(SEMATTRS_HTTP_SCHEME, parsedUrl.protocol.replace(':', ''));
                // @TODO do we want to collect this or it will be collected earlier once only or
                //    maybe when parent span is not available ?
                span.setAttribute(SEMATTRS_HTTP_USER_AGENT, navigator.userAgent);
            }
        };
        XMLHttpRequestInstrumentation.prototype._applyAttributesAfterXHR = function (span, xhr) {
            var _this = this;
            var applyCustomAttributesOnSpan = this.getConfig().applyCustomAttributesOnSpan;
            if (typeof applyCustomAttributesOnSpan === 'function') {
                safeExecuteInTheMiddle$1(function () { return applyCustomAttributesOnSpan(span, xhr); }, function (error) {
                    if (!error) {
                        return;
                    }
                    _this._diag.error('applyCustomAttributesOnSpan', error);
                });
            }
        };
        /**
         * will collect information about all resources created
         * between "send" and "end" with additional waiting for main resource
         * @param xhr
         * @param spanUrl
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._addResourceObserver = function (xhr, spanUrl) {
            var xhrMem = this._xhrMem.get(xhr);
            if (!xhrMem ||
                typeof PerformanceObserver !== 'function' ||
                typeof PerformanceResourceTiming !== 'function') {
                return;
            }
            xhrMem.createdResources = {
                observer: new PerformanceObserver(function (list) {
                    var entries = list.getEntries();
                    var parsedUrl = parseUrl(spanUrl);
                    entries.forEach(function (entry) {
                        if (entry.initiatorType === 'xmlhttprequest' &&
                            entry.name === parsedUrl.href) {
                            if (xhrMem.createdResources) {
                                xhrMem.createdResources.entries.push(entry);
                            }
                        }
                    });
                }),
                entries: [],
            };
            xhrMem.createdResources.observer.observe({
                entryTypes: ['resource'],
            });
        };
        /**
         * Clears the resource timings and all resources assigned with spans
         *     when {@link XMLHttpRequestInstrumentationConfig.clearTimingResources} is
         *     set to true (default false)
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._clearResources = function () {
            if (this._tasksCount === 0 && this.getConfig().clearTimingResources) {
                otperformance.clearResourceTimings();
                this._xhrMem = new WeakMap();
                this._usedResources = new WeakSet();
            }
        };
        /**
         * Finds appropriate resource and add network events to the span
         * @param span
         */
        XMLHttpRequestInstrumentation.prototype._findResourceAndAddNetworkEvents = function (xhrMem, span, spanUrl, startTime, endTime) {
            if (!spanUrl || !startTime || !endTime || !xhrMem.createdResources) {
                return;
            }
            var resources = xhrMem.createdResources.entries;
            if (!resources || !resources.length) {
                // fallback - either Observer is not available or it took longer
                // then OBSERVER_WAIT_TIME_MS and observer didn't collect enough
                // information
                // ts thinks this is the perf_hooks module, but it is the browser performance api
                resources = otperformance.getEntriesByType('resource');
            }
            var resource = getResource(parseUrl(spanUrl).href, startTime, endTime, resources, this._usedResources);
            if (resource.mainRequest) {
                var mainRequest = resource.mainRequest;
                this._markResourceAsUsed(mainRequest);
                var corsPreFlightRequest = resource.corsPreFlightRequest;
                if (corsPreFlightRequest) {
                    this._addChildSpan(span, corsPreFlightRequest);
                    this._markResourceAsUsed(corsPreFlightRequest);
                }
                addSpanNetworkEvents(span, mainRequest, this.getConfig().ignoreNetworkEvents);
            }
        };
        /**
         * Removes the previous information about span.
         * This might happened when the same xhr is used again.
         * @param xhr
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._cleanPreviousSpanInformation = function (xhr) {
            var xhrMem = this._xhrMem.get(xhr);
            if (xhrMem) {
                var callbackToRemoveEvents = xhrMem.callbackToRemoveEvents;
                if (callbackToRemoveEvents) {
                    callbackToRemoveEvents();
                }
                this._xhrMem.delete(xhr);
            }
        };
        /**
         * Creates a new span when method "open" is called
         * @param xhr
         * @param url
         * @param method
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._createSpan = function (xhr, url, method) {
            var _a;
            if (isUrlIgnored(url, this.getConfig().ignoreUrls)) {
                this._diag.debug('ignoring span as url matches ignored url');
                return;
            }
            var spanName = method.toUpperCase();
            var currentSpan = this.tracer.startSpan(spanName, {
                kind: SpanKind.CLIENT,
                attributes: (_a = {},
                    _a[SEMATTRS_HTTP_METHOD] = method,
                    _a[SEMATTRS_HTTP_URL] = parseUrl(url).toString(),
                    _a),
            });
            currentSpan.addEvent(EventNames.METHOD_OPEN);
            this._cleanPreviousSpanInformation(xhr);
            this._xhrMem.set(xhr, {
                span: currentSpan,
                spanUrl: url,
            });
            return currentSpan;
        };
        /**
         * Marks certain [resource]{@link PerformanceResourceTiming} when information
         * from this is used to add events to span.
         * This is done to avoid reusing the same resource again for next span
         * @param resource
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._markResourceAsUsed = function (resource) {
            this._usedResources.add(resource);
        };
        /**
         * Patches the method open
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._patchOpen = function () {
            var _this = this;
            return function (original) {
                var plugin = _this;
                return function patchOpen() {
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    var method = args[0];
                    var url = args[1];
                    plugin._createSpan(this, url, method);
                    return original.apply(this, args);
                };
            };
        };
        /**
         * Patches the method send
         * @private
         */
        XMLHttpRequestInstrumentation.prototype._patchSend = function () {
            var plugin = this;
            function endSpanTimeout(eventName, xhrMem, performanceEndTime, endTime) {
                var callbackToRemoveEvents = xhrMem.callbackToRemoveEvents;
                if (typeof callbackToRemoveEvents === 'function') {
                    callbackToRemoveEvents();
                }
                var span = xhrMem.span, spanUrl = xhrMem.spanUrl, sendStartTime = xhrMem.sendStartTime;
                if (span) {
                    plugin._findResourceAndAddNetworkEvents(xhrMem, span, spanUrl, sendStartTime, performanceEndTime);
                    span.addEvent(eventName, endTime);
                    plugin._addFinalSpanAttributes(span, xhrMem, spanUrl);
                    span.end(endTime);
                    plugin._tasksCount--;
                }
                plugin._clearResources();
            }
            function endSpan(eventName, xhr) {
                var xhrMem = plugin._xhrMem.get(xhr);
                if (!xhrMem) {
                    return;
                }
                xhrMem.status = xhr.status;
                xhrMem.statusText = xhr.statusText;
                plugin._xhrMem.delete(xhr);
                if (xhrMem.span) {
                    plugin._applyAttributesAfterXHR(xhrMem.span, xhr);
                }
                var performanceEndTime = hrTime();
                var endTime = Date.now();
                // the timeout is needed as observer doesn't have yet information
                // when event "load" is called. Also the time may differ depends on
                // browser and speed of computer
                setTimeout(function () {
                    endSpanTimeout(eventName, xhrMem, performanceEndTime, endTime);
                }, OBSERVER_WAIT_TIME_MS);
            }
            function onError() {
                endSpan(EventNames.EVENT_ERROR, this);
            }
            function onAbort() {
                endSpan(EventNames.EVENT_ABORT, this);
            }
            function onTimeout() {
                endSpan(EventNames.EVENT_TIMEOUT, this);
            }
            function onLoad() {
                if (this.status < 299) {
                    endSpan(EventNames.EVENT_LOAD, this);
                }
                else {
                    endSpan(EventNames.EVENT_ERROR, this);
                }
            }
            function unregister(xhr) {
                xhr.removeEventListener('abort', onAbort);
                xhr.removeEventListener('error', onError);
                xhr.removeEventListener('load', onLoad);
                xhr.removeEventListener('timeout', onTimeout);
                var xhrMem = plugin._xhrMem.get(xhr);
                if (xhrMem) {
                    xhrMem.callbackToRemoveEvents = undefined;
                }
            }
            return function (original) {
                return function patchSend() {
                    var _this = this;
                    var args = [];
                    for (var _i = 0; _i < arguments.length; _i++) {
                        args[_i] = arguments[_i];
                    }
                    var xhrMem = plugin._xhrMem.get(this);
                    if (!xhrMem) {
                        return original.apply(this, args);
                    }
                    var currentSpan = xhrMem.span;
                    var spanUrl = xhrMem.spanUrl;
                    if (currentSpan && spanUrl) {
                        if (plugin.getConfig().measureRequestSize && (args === null || args === void 0 ? void 0 : args[0])) {
                            var body = args[0];
                            var bodyLength = getXHRBodyLength(body);
                            if (bodyLength !== undefined) {
                                currentSpan.setAttribute(SEMATTRS_HTTP_REQUEST_CONTENT_LENGTH_UNCOMPRESSED, bodyLength);
                            }
                        }
                        context.with(trace.setSpan(context.active(), currentSpan), function () {
                            plugin._tasksCount++;
                            xhrMem.sendStartTime = hrTime();
                            currentSpan.addEvent(EventNames.METHOD_SEND);
                            _this.addEventListener('abort', onAbort);
                            _this.addEventListener('error', onError);
                            _this.addEventListener('load', onLoad);
                            _this.addEventListener('timeout', onTimeout);
                            xhrMem.callbackToRemoveEvents = function () {
                                unregister(_this);
                                if (xhrMem.createdResources) {
                                    xhrMem.createdResources.observer.disconnect();
                                }
                            };
                            plugin._addHeaders(_this, spanUrl);
                            plugin._addResourceObserver(_this, spanUrl);
                        });
                    }
                    return original.apply(this, args);
                };
            };
        };
        /**
         * implements enable function
         */
        XMLHttpRequestInstrumentation.prototype.enable = function () {
            this._diag.debug('applying patch to', this.moduleName, this.version);
            if (isWrapped(XMLHttpRequest.prototype.open)) {
                this._unwrap(XMLHttpRequest.prototype, 'open');
                this._diag.debug('removing previous patch from method open');
            }
            if (isWrapped(XMLHttpRequest.prototype.send)) {
                this._unwrap(XMLHttpRequest.prototype, 'send');
                this._diag.debug('removing previous patch from method send');
            }
            this._wrap(XMLHttpRequest.prototype, 'open', this._patchOpen());
            this._wrap(XMLHttpRequest.prototype, 'send', this._patchSend());
        };
        /**
         * implements disable function
         */
        XMLHttpRequestInstrumentation.prototype.disable = function () {
            this._diag.debug('removing patch from', this.moduleName, this.version);
            this._unwrap(XMLHttpRequest.prototype, 'open');
            this._unwrap(XMLHttpRequest.prototype, 'send');
            this._tasksCount = 0;
            this._xhrMem = new WeakMap();
            this._usedResources = new WeakSet();
        };
        return XMLHttpRequestInstrumentation;
    }(InstrumentationBase$1));

    var setupDefaultInstrumentations = function (config) {
        var _a, _b, _c, _d, _e, _f;
        if (config === void 0) { config = {}; }
        /*
          These instrumentations are core to managing the session lifecycle and so are not optional
         */
        var instrumentations = [
            new SpanSessionOnLoadInstrumentation(config['session-on-load']),
            new SpanSessionVisibilityInstrumentation(config['session-visibility']),
            new SpanSessionBrowserActivityInstrumentation(config['session-activity']),
            new SpanSessionTimeoutInstrumentation(config['session-timeout']),
        ];
        if (!((_a = config.omit) === null || _a === void 0 ? void 0 : _a.has('exception'))) {
            instrumentations.push(new GlobalExceptionInstrumentation(config['exception']));
        }
        if (!((_b = config.omit) === null || _b === void 0 ? void 0 : _b.has('click'))) {
            instrumentations.push(new ClicksInstrumentation(config['click']));
        }
        if (!((_c = config.omit) === null || _c === void 0 ? void 0 : _c.has('web-vital'))) {
            instrumentations.push(new WebVitalsInstrumentation(config['web-vital']));
        }
        if (!((_d = config.omit) === null || _d === void 0 ? void 0 : _d.has('@opentelemetry/instrumentation-document-load'))) {
            instrumentations.push(new DocumentLoadInstrumentation(config['@opentelemetry/instrumentation-document-load']));
        }
        if (!((_e = config.omit) === null || _e === void 0 ? void 0 : _e.has('@opentelemetry/instrumentation-fetch'))) {
            instrumentations.push(new FetchInstrumentation(config['@opentelemetry/instrumentation-fetch']));
        }
        if (!((_f = config.omit) === null || _f === void 0 ? void 0 : _f.has('@opentelemetry/instrumentation-xml-http-request'))) {
            instrumentations.push(new XMLHttpRequestInstrumentation(config['@opentelemetry/instrumentation-xml-http-request']));
        }
        return instrumentations;
    };

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    var __awaiter$1 = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator$1 = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    /**
     * SessionSpanProcessor is a {@link SpanProcessor} that adds the session.id attribute
     */
    var SessionSpanProcessor = /** @class */ (function () {
        function SessionSpanProcessor(sessionIdProvider) {
            this._sessionIdProvider = sessionIdProvider;
        }
        /**
         * Forces to export all finished spans
         */
        SessionSpanProcessor.prototype.forceFlush = function () {
            return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
                return [2 /*return*/];
            }); });
        };
        /**
         * Called when a {@link Span} is started, if the `span.isRecording()`
         * returns true.
         * @param span the Span that just started.
         */
        SessionSpanProcessor.prototype.onStart = function (span, _parentContext) {
            var _a;
            var sessionId = (_a = this._sessionIdProvider) === null || _a === void 0 ? void 0 : _a.getSessionId();
            if (sessionId) {
                span.setAttribute(ATTR_SESSION_ID, sessionId);
            }
        };
        /**
         * Called when a {@link ReadableSpan} is ended, if the `span.isRecording()`
         * returns true.
         * @param span the Span that just ended.
         */
        SessionSpanProcessor.prototype.onEnd = function (_) {
            // no-op
        };
        /**
         * Shuts down the processor. Called when SDK is shut down. This is an
         * opportunity for processor to do any cleanup required.
         */
        SessionSpanProcessor.prototype.shutdown = function () {
            return __awaiter$1(this, void 0, void 0, function () { return __generator$1(this, function (_a) {
                return [2 /*return*/];
            }); });
        };
        return SessionSpanProcessor;
    }());

    /*
     * Copyright The OpenTelemetry Authors
     *
     * Licensed under the Apache License, Version 2.0 (the "License");
     * you may not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *      https://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing, software
     * distributed under the License is distributed on an "AS IS" BASIS,
     * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     * See the License for the specific language governing permissions and
     * limitations under the License.
     */
    function createSessionSpanProcessor(sessionProvider) {
        return new SessionSpanProcessor(sessionProvider);
    }

    var Registry = /** @class */ (function () {
        function Registry(_a) {
            var _b = _a === void 0 ? {} : _a, _c = _b.diagLogger, diagLogger = _c === void 0 ? diag.createComponentLogger({ namespace: 'embrace-registry' }) : _c;
            var _this = this;
            this._sdk = null;
            this.register = function (sdk) {
                if (_this._sdk !== null) {
                    _this._diag.warn('previously registered sdk will be overwritten');
                }
                _this._sdk = sdk;
            };
            this.clear = function () {
                if (_this._sdk === null) {
                    _this._diag.warn('sdk already cleared, this is a no-op');
                }
                _this._sdk = null;
            };
            this.registered = function () {
                return _this._sdk;
            };
            this._diag = diagLogger;
        }
        return Registry;
    }());
    var registry = new Registry();

    var __awaiter = (undefined && undefined.__awaiter) || function (thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    };
    var __generator = (undefined && undefined.__generator) || function (thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g = Object.create((typeof Iterator === "function" ? Iterator : Object).prototype);
        return g.next = verb(0), g["throw"] = verb(1), g["return"] = verb(2), typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (g && (g = 0, op[0] && (_ = 0)), _) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    };
    var __read = (undefined && undefined.__read) || function (o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m) return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
        }
        catch (error) { e = { error: error }; }
        finally {
            try {
                if (r && !r.done && (m = i["return"])) m.call(i);
            }
            finally { if (e) throw e.error; }
        }
        return ar;
    };
    var __spreadArray = (undefined && undefined.__spreadArray) || function (to, from, pack) {
        if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
            if (ar || !(i in from)) {
                if (!ar) ar = Array.prototype.slice.call(from, 0, i);
                ar[i] = from[i];
            }
        }
        return to.concat(ar || Array.prototype.slice.call(from));
    };
    var __values = (undefined && undefined.__values) || function(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m) return m.call(o);
        if (o && typeof o.length === "number") return {
            next: function () {
                if (o && i >= o.length) o = void 0;
                return { value: o && o[i++], done: !o };
            }
        };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    var initSDK = function (_a) {
        var _b;
        var _c = _a === void 0 ? { appID: '' } : _a, appID = _c.appID, appVersion = _c.appVersion, _d = _c.resource, resource = _d === void 0 ? Resource.empty() : _d, _e = _c.spanExporters, spanExporters = _e === void 0 ? [] : _e, _f = _c.logExporters, logExporters = _f === void 0 ? [] : _f, _g = _c.spanProcessors, spanProcessors = _g === void 0 ? [] : _g, _h = _c.propagator, propagator = _h === void 0 ? null : _h, defaultInstrumentationConfig = _c.defaultInstrumentationConfig, _j = _c.instrumentations, instrumentations = _j === void 0 ? [] : _j, _k = _c.contextManager, contextManager = _k === void 0 ? null : _k, _l = _c.logProcessors, logProcessors = _l === void 0 ? [] : _l, _m = _c.logLevel, logLevel = _m === void 0 ? DiagLogLevel.ERROR : _m, _o = _c.diagLogger, diagLogger = _o === void 0 ? diag.createComponentLogger({
            namespace: 'embrace-sdk',
        }) : _o;
        try {
            var existingSDK = registry.registered();
            if (existingSDK !== null) {
                diagLogger.warn('SDK has already been successfully initialized, skipping this invocation of initSDK');
                return existingSDK;
            }
            diag.setLogger(new DiagConsoleLogger(), {
                logLevel: logLevel,
            });
            var resourceWithWebSDKAttributes = resource.merge(getWebSDKResource(appVersion));
            var sendingToEmbrace = !!appID && isValidAppID(appID);
            if (!sendingToEmbrace && !logExporters.length && !spanExporters.length) {
                throw new Error('when the embrace appID is omitted then at least one logExporter or spanExporter must be set');
            }
            var userManager = setupUser();
            var enduserPseudoID = (_b = userManager.getUser()) === null || _b === void 0 ? void 0 : _b[KEY_ENDUSER_PSEUDO_ID];
            if (sendingToEmbrace && !enduserPseudoID) {
                throw new Error('userID is required when using Embrace exporter');
            }
            var spanSessionManager = setupSession();
            var tracerProvider_1 = setupTraces({
                sendingToEmbrace: sendingToEmbrace,
                appID: appID,
                enduserPseudoID: enduserPseudoID,
                resource: resourceWithWebSDKAttributes,
                spanSessionManager: spanSessionManager,
                spanExporters: spanExporters,
                spanProcessors: spanProcessors,
                propagator: propagator,
                contextManager: contextManager,
            });
            var loggerProvider_1 = setupLogs({
                sendingToEmbrace: sendingToEmbrace,
                appID: appID,
                enduserPseudoID: enduserPseudoID,
                resource: resourceWithWebSDKAttributes,
                logExporters: logExporters,
                logProcessors: logProcessors,
                spanSessionManager: spanSessionManager,
            });
            // NOTE: we require setupInstrumentation to run the last, after setupLogs and setupTraces. This is how OTel works wrt
            // the dependencies between instrumentations and global providers. We need the providers for tracers, and logs to be
            // setup before we enable instrumentations.
            registerInstrumentations({
                instrumentations: __spreadArray(__spreadArray([], __read(instrumentations), false), [
                    setupDefaultInstrumentations(defaultInstrumentationConfig),
                ], false),
            });
            diagLogger.info('successfully initialized the SDK');
            var sdkControl = {
                flush: function () { return __awaiter(void 0, void 0, void 0, function () {
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, tracerProvider_1.forceFlush()];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, loggerProvider_1.forceFlush()];
                            case 2:
                                _a.sent();
                                return [2 /*return*/];
                        }
                    });
                }); },
            };
            registry.register(sdkControl);
            return sdkControl;
        }
        catch (e) {
            var message = e instanceof Error ? e.message : 'Unknown error.';
            diagLogger.error("failed to initialize the SDK: ".concat(message));
            return false;
        }
    };
    var setupUser = function () {
        var embraceUserManager = new EmbraceUserManager();
        user.setGlobalUserManager(embraceUserManager);
        return embraceUserManager;
    };
    var setupSession = function () {
        var embraceSpanSessionManager = new EmbraceSpanSessionManager();
        session.setGlobalSessionManager(embraceSpanSessionManager);
        return embraceSpanSessionManager;
    };
    var setupTraces = function (_a) {
        var sendingToEmbrace = _a.sendingToEmbrace, appID = _a.appID, enduserPseudoID = _a.enduserPseudoID, resource = _a.resource, spanSessionManager = _a.spanSessionManager, spanExporters = _a.spanExporters, _b = _a.spanProcessors, spanProcessors = _b === void 0 ? [] : _b, _c = _a.propagator, propagator = _c === void 0 ? null : _c, _d = _a.contextManager, contextManager = _d === void 0 ? null : _d;
        var embraceTraceManager = new EmbraceTraceManager();
        trace$1.setGlobalTraceManager(embraceTraceManager);
        var finalSpanProcessors = __spreadArray(__spreadArray([], __read(spanProcessors), false), [
            createSessionSpanProcessor(spanSessionManager),
            new EmbraceNetworkSpanProcessor(),
        ], false);
        spanExporters === null || spanExporters === void 0 ? void 0 : spanExporters.forEach(function (exporter) {
            finalSpanProcessors.push(new BatchSpanProcessor(exporter));
        });
        if (sendingToEmbrace && appID && enduserPseudoID) {
            finalSpanProcessors.push(new EmbraceSessionBatchedSpanProcessor({
                exporter: new EmbraceTraceExporter({
                    appID: appID,
                    userID: enduserPseudoID,
                }),
            }));
        }
        var tracerProvider = new WebTracerProvider({
            resource: resource,
            spanProcessors: finalSpanProcessors,
        });
        tracerProvider.register({
            contextManager: contextManager,
            propagator: propagator,
        });
        return tracerProvider;
    };
    var setupLogs = function (_a) {
        var e_1, _b;
        var sendingToEmbrace = _a.sendingToEmbrace, appID = _a.appID, enduserPseudoID = _a.enduserPseudoID, resource = _a.resource, logExporters = _a.logExporters, logProcessors = _a.logProcessors, spanSessionManager = _a.spanSessionManager;
        var embraceLogManager = new EmbraceLogManager();
        log.setGlobalLogManager(embraceLogManager);
        var loggerProvider = new LoggerProvider({
            resource: resource,
        });
        var finalLogProcessors = __spreadArray(__spreadArray([], __read(logProcessors), false), [
            new IdentifiableSessionLogRecordProcessor({
                spanSessionManager: spanSessionManager,
            }),
            new EmbTypeLogRecordProcessor(),
        ], false);
        logExporters === null || logExporters === void 0 ? void 0 : logExporters.forEach(function (exporter) {
            finalLogProcessors.push(new BatchLogRecordProcessor(exporter));
        });
        if (sendingToEmbrace && appID && enduserPseudoID) {
            finalLogProcessors.push(new BatchLogRecordProcessor(new EmbraceLogExporter({
                appID: appID,
                userID: enduserPseudoID,
            })));
        }
        try {
            for (var finalLogProcessors_1 = __values(finalLogProcessors), finalLogProcessors_1_1 = finalLogProcessors_1.next(); !finalLogProcessors_1_1.done; finalLogProcessors_1_1 = finalLogProcessors_1.next()) {
                var logProcessor = finalLogProcessors_1_1.value;
                loggerProvider.addLogRecordProcessor(logProcessor);
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (finalLogProcessors_1_1 && !finalLogProcessors_1_1.done && (_b = finalLogProcessors_1.return)) _b.call(finalLogProcessors_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        logs$1.setGlobalLoggerProvider(loggerProvider);
        return loggerProvider;
    };

    var index = /*#__PURE__*/Object.freeze({
        __proto__: null,
        get DiagLogLevel () { return DiagLogLevel; },
        initSDK: initSDK
    });

    exports.log = log;
    exports.sdk = index;
    exports.session = session;
    exports.trace = trace$1;
    exports.user = user;

    return exports;

})({});
